@@ -41,6 +41,7 @@ fixDatetime <- function(str)
 
 #Function to get the interpolated x at a given y
 interpolateXAtY <- function(X, Y, desiredY){
+    # print(paste("finding the X at desiredY:", desiredY))
         if(max(Y) < desiredY){
                 # print("desiredY is greater than max(Y)")
                 return(max(Y))
@@ -93,7 +94,7 @@ getAreaUnderCurve <- function(x, y)
 
 getAreaUnderCurve2 <- function(x, y)
 {
-        print("Calculating Area")
+        # print("Calculating Area")
         # print("X:")
         # print(x)
         # print("Y:")
@@ -117,7 +118,7 @@ getAreaUnderCurve2 <- function(x, y)
 #Calculates the mean of a curve interval
 getMeanValue <- function(X, Y, startX, endX)
 {
-        print(paste("Calculating mean in the X range of [", startX, ",", endX, "]"))
+        # print(paste("Calculating mean in the X range of [", startX, ",", endX, "]"))
         # print("x:")
         # print(X)
         # print("y:")
