@@ -65,8 +65,8 @@ public class ChronoJump
 	{/*
 		bool timeLogPassedOk = Log.Start(args);
 		Log.WriteLine(string.Format("Time log passed: {0}", timeLogPassedOk.ToString()));
-		Log.WriteLine(string.Format("Client database option 1 in ... " + Util.GetDatabaseDir()));
-		Log.WriteLine(string.Format("Client database option 2 in ... " + Util.GetDatabaseTempDir()));
+		Log.WriteLine(string.Format("Client database option 1 in … " + Util.GetDatabaseDir()));
+		Log.WriteLine(string.Format("Client database option 2 in … " + Util.GetDatabaseTempDir()));
 		*/
 		
 		LogSync.Initialize();
@@ -282,6 +282,7 @@ public class ChronoJump
 		UtilEncoder.CreateEncoderDirIfNeeded();
 		Util.CreateForceSensorDirIfNeeded();
 		Util.CreateRunEncoderDirIfNeeded();
+		News.CreateNewsDirIfNeeded();
 
 //TODO: when a session is deleted, encoder data has to be deleted, also multimedia videos, I suppose. Show message to user warning about it
 //TODO: encoder weight auto written depending on person loaded, and changes if it changes person or weight
@@ -313,7 +314,7 @@ public class ChronoJump
 		
 		//Chech if the DB file exists
 		if (!Sqlite.CheckTables(defaultDBLocation)) {
-			LogB.SQL ( Catalog.GetString ("no tables, creating ...") );
+			LogB.SQL ( Catalog.GetString ("no tables, creating …") );
 
 			creatingDB = true;
 			splashMessageChange(2);  //creating database
@@ -717,7 +718,7 @@ public class ChronoJump
 		windowsTextLog = "\n" + crashLogFile;
 		*/
 			
-		//if there's a copy on temp...
+		//if there's a copy on temp …
 		if(File.Exists(Util.GetDatabaseTempDir() + Path.DirectorySeparatorChar + "chronojump.db")) 
 		{
 			// if exist also a file in default db location (improbable but done for solve eventual problems
@@ -734,7 +735,7 @@ public class ChronoJump
 		string sendErrorLogStr = Catalog.GetString("Send error log");
 		messageCrashedBefore =
 			string.Format(Catalog.GetString("Chronojump {0} crashed before."), BuildInfo.chronojumpVersion) + "\n" +
-			string.Format(Catalog.GetString("Please, fill your email and click on '{0}' in order to fix this fast and contact you if appropriate."), sendErrorLogStr) + "\n" +
+			string.Format(Catalog.GetString("Please, fill your email and click on '{0}' in order to fix this fast and contact you if appropriate."), sendErrorLogStr) + " " +
 			Catalog.GetString("Your help is needed.");
 
 
