@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com>
+ *  Copyright (C) 2004-2021   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -45,7 +45,9 @@ public class Constants
 			};
 		else if(e == AuthorsEnum.NETWORKS)
 			return new String []{
-				"Max Ros Morejón <mros33@gmail.com>, 2019-2020" +
+				"Arnau-Lenin Gols <arnau.lenin@sobtec.cat>, 2020-2021" +
+					"\n\t" + Catalog.GetString("Full Stack developer."),
+				"\nMax Ros Morejón <mros33@gmail.com>, 2019-2020" +
 					"\n\t" + Catalog.GetString("Django developer."),
 				"\nMarcos Venteo <mventeo@gmail.com>, 2017-2018" +
 					"\n\t" + Catalog.GetString("Django migration."),
@@ -145,6 +147,8 @@ public class Constants
 	public const string PersonSessionOldWeightTable = "personSessionWeight"; //old table, used from db 0.53 to 0.76
 
 	public const string SessionTable = "session";
+	public const string TagSessionTable = "tagSession";
+	public const string SessionTagSessionTable = "sessionTagSession";
 	public const string PersonNotUploadTable = "personSessionNotUpload"; 
 	public const string SportTable = "sport";
 	public const string SpeciallityTable = "speciallity";
@@ -152,6 +156,7 @@ public class Constants
 	public const string CountryTable = "country";
 	public const string ConvertTempTable = "convertTemp"; //for conversions
 	public const string ChronopicRegisterTable = "chronopicRegister";
+	public const string NewsTable = "news";
 
 	//tests
 	public const string JumpTable = "jump";
@@ -178,6 +183,9 @@ public class Constants
 	public const string RunEncoderTable = "runEncoder";
 	public const string RunEncoderExerciseTable = "runEncoderExercise";
 
+	public const string LastJumpSimpleTypeParamsTable = "lastJumpSimpleTypeParams";
+	public const string LastJumpRjTypeParamsTable = "lastJumpRjTypeParams";
+
 	// Dummy variables that exists for translating purposes
 	// pragma warning is to avoid warnings of "defined and not used" for these variables.
 #pragma warning disable 0414
@@ -326,7 +334,7 @@ public class Constants
 		if(CSVExportDecimalSeparator != "COMMA")
 			sep = ",";
 
-		return "\n\n" + Catalog.GetString("Importing from your spreadsheet (LibreOffice, R, MS Excel, ...)") + "\n" +
+		return "\n\n" + Catalog.GetString("Importing from your spreadsheet (LibreOffice, R, MS Excel, …)") + "\n" +
 			Catalog.GetString("Remember the separator character is:") + " <b>" + sep + "</b>" + "\n\n" +
 			Catalog.GetString("This can be changed at preferences.");
 	}
@@ -730,7 +738,7 @@ public class Constants
 
 	public static string ChronopicDetectingStr()
 	{
-		return Catalog.GetString("Detecting ...");
+		return Catalog.GetString("Detecting …");
 	}
 	public static string ChronopicNeedTouchStr()
 	{
@@ -872,7 +880,7 @@ public class Constants
 	}
 	public static string WebsiteNotFoundStr()
 	{
-		return Catalog.GetString("Sorry, cannot open website.");
+		return Catalog.GetString("Sorry, cannot open website."); //note this message is also in Glade
 	}
 	public static string DirectoryCannotOpenStr()
 	{
@@ -944,7 +952,8 @@ public class Constants
 	//heightmetric contains 2 spins
 	public enum GenericWindowShow {
 		ENTRY, ENTRY2, ENTRY3, SPININT, SPININT2, SPININT3, SPINDOUBLE, HBOXSPINDOUBLE2, 
-		HEIGHTMETRIC, CHECK1, COMBO, COMBOALLNONESELECTED, BUTTONMIDDLE, TEXTVIEW, TREEVIEW
+		HEIGHTMETRIC, CHECK1, COMBO, COMBOALLNONESELECTED, BUTTONMIDDLE,
+		LABELBEFORETEXTVIEWTREEVIEW, TEXTVIEW, TREEVIEW
 	}
 
 
@@ -1100,15 +1109,24 @@ public class Constants
 
 	public enum EncoderGI {ALL, GRAVITATORY, INERTIAL}
 	public enum CheckFileOp {
+		JUMPS_SIMPLE_CAPTURE_SAVE_IMAGE,
 		JUMPS_PROFILE_SAVE_IMAGE, JUMPS_DJ_OPTIMAL_FALL_SAVE_IMAGE, JUMPS_WEIGHT_FV_PROFILE_SAVE_IMAGE, JUMPS_EVOLUTION_SAVE_IMAGE,
 		JUMPS_RJ_FATIGUE_SAVE_IMAGE,
+		RUNS_SIMPLE_CAPTURE_SAVE_IMAGE,
+		RUNS_EVOLUTION_SAVE_IMAGE,
 		RUNS_SPRINT_SAVE_IMAGE,
-		ENCODER_CAPTURE_EXPORT_ALL, ENCODER_ANALYZE_SAVE_IMAGE,
+		RUNS_SPRINT_EXPORT_INDIVIDUAL_CURRENT_SESSION_NO_IMAGES, RUNS_SPRINT_EXPORT_GROUPAL_CURRENT_SESSION_NO_IMAGES,
+		RUNS_SPRINT_EXPORT_INDIVIDUAL_CURRENT_SESSION_YES_IMAGES, RUNS_SPRINT_EXPORT_GROUPAL_CURRENT_SESSION_YES_IMAGES,
+		ENCODER_CAPTURE_EXPORT_ALL, ENCODER_CAPTURE_SAVE_IMAGE, ENCODER_ANALYZE_SAVE_IMAGE,
 		ENCODER_ANALYZE_SEND_IMAGE, //like save image but just defines the name exportFileName to be sended
 		ENCODER_ANALYZE_SAVE_AB, ENCODER_ANALYZE_SAVE_TABLE,
 		FORCESENSOR_SAVE_IMAGE_SIGNAL, FORCESENSOR_SAVE_IMAGE_RFD_AUTO,
 		FORCESENSOR_SAVE_IMAGE_RFD_MANUAL, FORCESENSOR_ANALYZE_SAVE_AB,
-		RUNENCODER_SAVE_IMAGE
+		FORCESENSOR_EXPORT_INDIVIDUAL_CURRENT_SESSION_NO_IMAGES, FORCESENSOR_EXPORT_GROUPAL_CURRENT_SESSION_NO_IMAGES,
+		FORCESENSOR_EXPORT_INDIVIDUAL_CURRENT_SESSION_YES_IMAGES, FORCESENSOR_EXPORT_GROUPAL_CURRENT_SESSION_YES_IMAGES,
+		RUNENCODER_SAVE_IMAGE, RUNENCODER_SAVE_TABLE,
+		RUNENCODER_EXPORT_INDIVIDUAL_CURRENT_SESSION_NO_IMAGES, RUNENCODER_EXPORT_GROUPAL_CURRENT_SESSION_NO_IMAGES,
+		RUNENCODER_EXPORT_INDIVIDUAL_CURRENT_SESSION_YES_IMAGES, RUNENCODER_EXPORT_GROUPAL_CURRENT_SESSION_YES_IMAGES,
 	}
 
 	public static double EncoderErrorCode = -1;
@@ -1189,11 +1207,13 @@ public class Constants
 	public const string MaxForce = "Max force";
 	public const string MeanPower = "Mean power";
 	public const string PeakPower = "Peak power";
+	public const string WorkJ = "WorkJ";
+	public const string Impulse = "Impulse";
 	public static string [] EncoderVariablesCaptureList = {
-		RangeAbsolute, MeanSpeed, MaxSpeed, MeanForce, MaxForce, MeanPower, PeakPower
+		RangeAbsolute, MeanSpeed, MaxSpeed, MeanForce, MaxForce, MeanPower, PeakPower, WorkJ, Impulse
 	};
 	public enum EncoderVariablesCapture {
-		RangeAbsolute, MeanSpeed, MaxSpeed, MeanForce, MaxForce, MeanPower, PeakPower
+		RangeAbsolute, MeanSpeed, MaxSpeed, MeanForce, MaxForce, MeanPower, PeakPower, WorkJ, Impulse
 	}
 	public static string GetEncoderVariablesCapture(EncoderVariablesCapture enumVariable) {
 		switch(enumVariable) {
@@ -1211,6 +1231,10 @@ public class Constants
 				return MeanPower;
 			case EncoderVariablesCapture.PeakPower:
 				return PeakPower;
+			case EncoderVariablesCapture.WorkJ:
+				return WorkJ;
+			case EncoderVariablesCapture.Impulse:
+				return Impulse;
 		}
 		return MeanPower;
 	}
@@ -1230,6 +1254,10 @@ public class Constants
 				return EncoderVariablesCapture.MeanPower;
 			case PeakPower:
 				return EncoderVariablesCapture.PeakPower;
+			case WorkJ:
+				return EncoderVariablesCapture.WorkJ;
+			case Impulse:
+				return EncoderVariablesCapture.Impulse;
 		}
 		return EncoderVariablesCapture.MeanPower;
 	}
