@@ -163,6 +163,7 @@ public class EncoderGraphROptions
 	private string triggerList;
 	public bool separateSessionInDays;
 	public AnalysisModes analysisMode; //the four analysisModes
+	Preferences.EncoderInertialGraphsXTypes inertialGraphX;
 
 	public enum AnalysisModes { CAPTURE, INDIVIDUAL_CURRENT_SET, INDIVIDUAL_CURRENT_SESSION, INDIVIDUAL_ALL_SESSIONS, GROUPAL_CURRENT_SESSION }
 
@@ -173,7 +174,7 @@ public class EncoderGraphROptions
 			string title, string operatingSystem,
 			string englishWords, string translatedWords,
 			bool debug, bool crossValidate, bool cutByTriggers, string triggerList,
-			bool separateSessionInDays, AnalysisModes analysisMode)
+			bool separateSessionInDays, AnalysisModes analysisMode, Preferences.EncoderInertialGraphsXTypes inertialGraphX)
 	{
 		this.inputData = inputData;
 		this.outputGraph = outputGraph;
@@ -191,6 +192,7 @@ public class EncoderGraphROptions
 		this.triggerList = triggerList;
 		this.separateSessionInDays = separateSessionInDays;
 		this.analysisMode = analysisMode;
+		this.inertialGraphX = inertialGraphX;
 
 		//ensure triggerList is not null or blank
 		if(triggerList == null || triggerList == "")
@@ -214,7 +216,8 @@ public class EncoderGraphROptions
 			"#cutByTriggers\n" +	Util.BoolToRBool(cutByTriggers) + "\n" +
 			"#triggerList\n" +	triggerList + "\n" +
 			"#separateSessionInDays\n" +	Util.BoolToRBool(separateSessionInDays) + "\n" +
-			"#analysisMode\n" + 	analysisMode.ToString() + "\n";
+			"#analysisMode\n" + 	analysisMode.ToString() + "\n" +
+			"#inertialGraphX\n" + 	inertialGraphX.ToString() + "\n";
 	}
 	
 
@@ -233,7 +236,9 @@ public class EncoderCurve
 	public string Laterality;	//only on analyze
 	public double ExtraWeight;
 	public double DisplacedWeight;
-	public int Inertia;
+	public int Inertia; 		//analyze inertial
+	public double Diameter;		//analyze inertial
+	public double EquivalentMass;	//analyze inertial
 	public string Start;
 	public string Duration;
 	public string Height;
@@ -289,7 +294,7 @@ public class EncoderCurve
 	public EncoderCurve (string n, string series, string exercise, 
 			string laterality,
 			double extraWeight, double displacedWeight,
-			int inertia,
+			int inertia, double diameter, double EquivalentMass, 	//3 inertial params
 			string start, string duration, string height,
 			string meanSpeed, string maxSpeed, string maxSpeedT,
 			string meanPower, string peakPower, string peakPowerT, 
@@ -304,7 +309,9 @@ public class EncoderCurve
 		this.Laterality = laterality;
 		this.ExtraWeight = extraWeight;
 		this.DisplacedWeight = displacedWeight;
-		this.Inertia = inertia;
+		this.Inertia = inertia;		//inertial
+		this.Diameter = diameter;	//inertial
+		this.EquivalentMass = EquivalentMass;	//inertial
 		this.Start = start;
 		this.Duration = duration;
 		this.Height = height;
@@ -420,16 +427,17 @@ public class EncoderCurve
 
 	//ecChar adds an 'e', 'c' or nothing to N
 	//if e or c then N will be /2
-	public string ToCSV (bool captureOrAnalyze, string decimalSeparator, bool useWorkKcal, string ecChar)
+	public string ToCSV (bool captureOrAnalyze, Constants.Menuitem_modes currentMode,
+			string decimalSeparator, bool useWorkKcal, string ecChar)
 	{
 		//latin:	2,3 ; 2,5
 		//non-latin:	2.3 , 2.5
 
 		string sep = ":::";
 
-		double work = WorkJD;
+		string workString = Util.TrimDecimals(WorkJD, 1);
 		if(useWorkKcal)
-			work = WorkKcalD;
+			workString = Util.TrimDecimals(WorkKcalD, 3);
 		
 		string str = "";
 		//TODO: if capture not shown because some variables like Inertia are not defined
@@ -442,14 +450,19 @@ public class EncoderCurve
 			str = 
 				nprint + sep +
 				Series + sep + Exercise + sep + Laterality + sep +
-				ExtraWeight + sep + DisplacedWeight + sep + Inertia + sep + 
+				ExtraWeight + sep + DisplacedWeight + sep;
+
+			if(currentMode == Constants.Menuitem_modes.POWERINERTIAL)
+				str += Inertia + sep + Util.TrimDecimals(Diameter,1) + sep + Util.TrimDecimals(EquivalentMass,3) + sep;
+
+			str +=
 				Start + sep + Duration + sep + Height + sep + 
 				MeanSpeed + sep + MaxSpeed + sep + MaxSpeedT + sep + 
 				MeanPower + sep + PeakPower + sep + PeakPowerT + sep + 
 				PP_PPT + sep +
 				MeanForce + sep + MaxForce + sep + MaxForceT + sep +
 				MaxForce_MaxForceT + sep +
-				work.ToString() + sep + Impulse;
+				workString + sep + Impulse;
 		}
 		
 		if(decimalSeparator == "COMMA")
@@ -1206,6 +1219,7 @@ public class EncoderExercise
 	public string ressistance;
 	public string description;
 	public double speed1RM;
+	private Constants.EncoderGI type;
 
 	public EncoderExercise() {
 	}
@@ -1215,7 +1229,7 @@ public class EncoderExercise
 	}
 
 	public EncoderExercise(int uniqueID, string name, int percentBodyWeight, 
-			string ressistance, string description, double speed1RM)
+			string ressistance, string description, double speed1RM, Constants.EncoderGI type)
 	{
 		this.uniqueID = uniqueID;
 		this.name = name;
@@ -1223,6 +1237,7 @@ public class EncoderExercise
 		this.ressistance = ressistance;
 		this.description = description;
 		this.speed1RM = speed1RM;
+		this.type = type;
 	}
 
 	/*
@@ -1244,7 +1259,7 @@ public class EncoderExercise
 	public override string ToString()
 	{
 		return uniqueID.ToString() + ": " + name + " (" + percentBodyWeight.ToString() + "%) " +
-			ressistance + "," + description + "," + speed1RM.ToString();
+			ressistance + "," + description + "," + speed1RM.ToString() + "," + type.ToString();
 	}
 
 	public int UniqueID
@@ -1271,6 +1286,10 @@ public class EncoderExercise
 	{
 		get { return speed1RM; }
 	}
+	public Constants.EncoderGI Type
+	{
+		get { return type; }
+	}
 
 	~EncoderExercise() {}
 }
@@ -1375,8 +1394,11 @@ public class EncoderBarsData
 	public double MaxForce;
 	public double MeanPower;
 	public double PeakPower;
+	public double WorkJ;
+	public double Impulse;
 	
-	public EncoderBarsData(double range, double meanSpeed, double maxSpeed, double meanForce, double maxForce, double meanPower, double peakPower)
+	public EncoderBarsData(double range, double meanSpeed, double maxSpeed, double meanForce, double maxForce,
+			double meanPower, double peakPower, double workJ, double impulse)
 	{
 		this.Range = range;
 		this.MeanSpeed = meanSpeed;
@@ -1385,6 +1407,8 @@ public class EncoderBarsData
 		this.MaxForce  = maxForce;
 		this.MeanPower = meanPower;
 		this.PeakPower = peakPower;
+		this.WorkJ = workJ;
+		this.Impulse = impulse;
 	}
 
 	public double GetValue (string option)
@@ -1403,8 +1427,14 @@ public class EncoderBarsData
 			return MaxForce;
 		else if(option == Constants.MeanPower)
 			return MeanPower;
-		else // option == Constants.PeakPower
+		else if(option == Constants.PeakPower)
 			return PeakPower;
+		else if(option == Constants.WorkJ)
+			return WorkJ;
+		else if(option == Constants.Impulse)
+			return Impulse;
+
+		return MeanPower;
 	}
 	
 	~EncoderBarsData() {}
