@@ -76,6 +76,8 @@ public class RunExecute : EventExecute
 	protected Gtk.Image image_run_execute_running;
 	protected Gtk.Image image_run_execute_photocell;
 
+	protected PhotocellWirelessCapture photocellWirelessCapture;
+
 //	protected bool firstTrackDone;
 
 	public RunExecute() {
@@ -84,7 +86,8 @@ public class RunExecute : EventExecute
 	//run execution
 	//if wireless: string wirelessPort, wirelessBauds will be used instead of Chronopic cp
 	public RunExecute(int personID, int sessionID, string type, double distance,   
-			Chronopic cp, string wirelessPort, int wirelessBauds, Gtk.Window app,
+			Chronopic cp, PhotocellWirelessCapture photocellWirelessCapture,
+			string wirelessPort, int wirelessBauds,
 			int pDN, bool metersSecondsPreferred,
 			bool volumeOn, Preferences.GstreamerTypes gstreamer,
 			double progressbarLimit, ExecutingGraphData egd,
@@ -100,11 +103,11 @@ public class RunExecute : EventExecute
 		this.distance = distance;
 		
 		this.cp = cp;
+		this.photocellWirelessCapture = photocellWirelessCapture;
 		this.wirelessPort = wirelessPort;
 		this.wirelessBauds = wirelessBauds;
 		wireless = (wirelessPort != "" && wirelessBauds > 0);
 		LogB.Information(string.Format("This is a run simple capture with wireless?: {0}", wireless));
-		this.app = app;
 
 		this.pDN = pDN;
 		this.metersSecondsPreferred = metersSecondsPreferred;
@@ -193,7 +196,9 @@ public class RunExecute : EventExecute
 		Util.PlaySound(Constants.SoundTypes.CAN_START, volumeOn, gstreamer);
 
 
-		//runPhase = runPhases.START_WIRELESS_UNKNOWN;
+		//runPhase = runPhases.START_WIRELESS_UNKNOWN; //done before
+
+		/*
 		//provem de forçar a que comencem en off, a veure si va be
 		platformState = Chronopic.Plataforma.OFF;
 		if (platformState==Chronopic.Plataforma.OFF) {
@@ -206,6 +211,7 @@ public class RunExecute : EventExecute
 			runPhase = runPhases.PRE_RUNNING;
 			runChangeImage.Current = RunChangeImage.Types.RUNNING;
 		}
+		*/
 	}
 
 	private void manageIniNotWireless()
@@ -310,14 +316,16 @@ public class RunExecute : EventExecute
 				checkDoubleContactTime
 				);
 
-LogB.Information("going to call pwc.CaptureStart ()");
-		PhotocellWirelessCapture pwc = null;
+LogB.Information("going to call photocellWirelessCapture.CaptureStart ()");
+		//PhotocellWirelessCapture pwc = null;
 		if(wireless)
 		{
 			feedbackMessage = Catalog.GetString("Please, wait!");
 			needShowFeedbackMessage = true;
-			pwc = new PhotocellWirelessCapture(wirelessPort);
-			pwc.CaptureStart ();
+			runPhase = runPhases.START_WIRELESS_UNKNOWN;
+			//photocellWirelessCapture = new PhotocellWirelessCapture(wirelessPort);
+			photocellWirelessCapture.Reset(wirelessPort);
+			photocellWirelessCapture.CaptureStart ();
 
 			manageIniWireless();
 		}
@@ -327,14 +335,14 @@ LogB.Information("going to call pwc.CaptureStart ()");
 		do {
 			if (wireless)
 			{
-				if(! pwc.CaptureLine())
+				if(! photocellWirelessCapture.CaptureLine())
 					cancel = true; //problem reading line (capturing)
 
 				ok = false;
-				if(pwc.CanRead())
+				if(photocellWirelessCapture.CanRead())
 				{
 					LogB.Information("waitEvent 3");
-					PhotocellWirelessEvent pwe = pwc.PhotocellWirelessCaptureReadNext();
+					PhotocellWirelessEvent pwe = photocellWirelessCapture.PhotocellWirelessCaptureReadNext();
 					LogB.Information("wait_event pwe: " + pwe.ToString());
 					//TODO: photocell = pwe.photocell;
 					timestamp = pwe.timeMs - timestampAccumulated; //photocell does not send splittime, sends absolute time
@@ -439,11 +447,11 @@ LogB.Information("going to call pwc.CaptureStart ()");
 					//it has confirmed that first phase is PLATFORM_INI_YES/NO_TIME
 					if(wireless && runPhase == runPhases.START_WIRELESS_UNKNOWN)
 					{
-						if(speedStartArrival || measureReactionTime)
-							runPhase = runPhases.PLATFORM_INI_YES_TIME;
-						else
-							runPhase = runPhases.PLATFORM_INI_NO_TIME;
-
+						/*
+						   on wireless if we are still on unknown, change to INI_NO_TIME
+						   as we cannot know how much time we were on the platform, so INI_YES_TIME will be not aplicable
+						   */
+						runPhase = runPhases.PLATFORM_INI_NO_TIME;
 						startIn = true;
 					}
 
@@ -510,9 +518,7 @@ LogB.Information("going to call pwc.CaptureStart ()");
 		} while ( ! exitWaitEventBucle );
 
 		if(wireless)
-		{
-			pwc.Stop();
-		}
+			photocellWirelessCapture.Stop();
 
 		onlyInterval_FinishWaitEventWrite();
 	}
@@ -774,8 +780,7 @@ LogB.Information("going to call pwc.CaptureStart ()");
 				myTimeValue = timerCount; //show time from the timerCount
 				break;
 		}
-				
-		
+
 		//has no finished, but move progressbar time
 		progressBarEventOrTimePreExecution(
 				false, //isEvent false: time
@@ -815,15 +820,18 @@ LogB.Information("going to call pwc.CaptureStart ()");
 			description += descriptionAddReactionTime(reactionTimeMS, pDN, speedStartArrival);
 
 		string table = Constants.RunTable;
+		string datetime = UtilDate.ToFile(DateTime.Now);
 
 		uniqueID = SqliteRun.Insert(false, table, "NULL", personID, sessionID, 
 				type, distance, trackTime, description,
 				Util.BoolToNegativeInt(simulated), 
-				!startIn	//initialSpeed true if not startIn
+				!startIn,	//initialSpeed true if not startIn
+				datetime
 				); 
 		
 		//define the created object
-		eventDone = new Run(uniqueID, personID, sessionID, type, distance, trackTime, description, Util.BoolToNegativeInt(simulated), !startIn);
+		eventDone = new Run(uniqueID, personID, sessionID, type, distance, trackTime, description,
+				Util.BoolToNegativeInt(simulated), !startIn, datetime);
 
 		if(graphAllTypes)
 			type = "";
@@ -899,7 +907,8 @@ public class RunIntervalExecute : RunExecute
 
 	//run execution
 	public RunIntervalExecute(int personID, int sessionID, string type, double distanceInterval, double limitAsDouble, bool tracksLimited,  
-			Chronopic cp, string wirelessPort, int wirelessBauds, Gtk.Window app,
+			Chronopic cp, PhotocellWirelessCapture photocellWirelessCapture,
+			string wirelessPort, int wirelessBauds,
 			int pDN, bool metersSecondsPreferred,
 			bool volumeOn, Preferences.GstreamerTypes gstreamer,
 			RepetitiveConditionsWindow repetitiveConditionsWin,
@@ -933,11 +942,11 @@ public class RunIntervalExecute : RunExecute
 		
 		
 		this.cp = cp;
+		this.photocellWirelessCapture = photocellWirelessCapture;
 		this.wirelessPort = wirelessPort;
 		this.wirelessBauds = wirelessBauds;
 		wireless = (wirelessPort != "" && wirelessBauds > 0);
 		LogB.Information(string.Format("This is a run interval capture with wireless?: {0}", wireless));
-		this.app = app;
 
 		this.metersSecondsPreferred = metersSecondsPreferred;
 		this.pDN = pDN;
@@ -1212,7 +1221,6 @@ public class RunIntervalExecute : RunExecute
 				myTimeValue = timerCount; //show time from the timerCount
 				break;
 		}
-			
 		if(! finish) 
 			progressBarEventOrTimePreExecution(
 					false, //isEvent false: time
@@ -1293,7 +1301,7 @@ public class RunIntervalExecute : RunExecute
 		else if(measureReactionTime && reactionTimeMS > 0)
 			description += descriptionAddReactionTime(reactionTimeMS, pDN, speedStartArrival);
 
-
+		string datetime = UtilDate.ToFile(DateTime.Now);
 
 		if(tempTable)
 			SqliteRunInterval.Insert(false, Constants.TempRunIntervalTable, "NULL", personID, sessionID, type, 
@@ -1302,7 +1310,8 @@ public class RunIntervalExecute : RunExecute
 					description,
 					limitString,
 					Util.BoolToNegativeInt(simulated),
-					!startIn	//initialSpeed true if not startIn
+					!startIn,	//initialSpeed true if not startIn
+					datetime
 					);
 		else {
 			uniqueID = SqliteRunInterval.Insert(false, Constants.RunIntervalTable, "NULL", personID, sessionID, type, 
@@ -1311,12 +1320,13 @@ public class RunIntervalExecute : RunExecute
 					description,
 					limitString,
 					Util.BoolToNegativeInt(simulated),
-					!startIn
+					!startIn,
+					datetime
 					);
 
 			//define the created object
 			eventDone = new RunInterval(uniqueID, personID, sessionID, type, distanceTotal, timeTotal, distanceInterval, intervalTimesString,
-					tracksHere, description, limitString, Util.BoolToNegativeInt(simulated), !startIn); 
+					tracksHere, description, limitString, Util.BoolToNegativeInt(simulated), !startIn, datetime); 
 
 			/*
 			string tempValuesString;
