@@ -62,7 +62,7 @@ public class ExportSession
 	{
 		string exportString = "";
 		if(formatFile == "report") {
-			exportString = Catalog.GetString ("Save report as...");
+			exportString = Catalog.GetString ("Save report as …");
 		} else {
 			exportString = Catalog.GetString ("Export session in format " + formatFile);
 		}
@@ -102,7 +102,7 @@ public class ExportSession
 			if (File.Exists(fileName)) {
 				LogB.Warning(string.Format("File {0} exists with attributes {1}, created at {2}",
 							fileName, File.GetAttributes(fileName), File.GetCreationTime(fileName)));
-				LogB.Information("Overwrite...");
+				LogB.Information("Overwrite …");
 				ConfirmWindow confirmWin = ConfirmWindow.Show(Catalog.GetString("Are you sure you want to overwrite file: "),
 						"", fileName);
 				confirmWin.Button_accept.Clicked += new EventHandler(on_overwrite_file_accepted);
@@ -189,7 +189,7 @@ public class ExportSession
 		myRuns= SqliteRun.SelectRunsSA (true, mySession.UniqueID, -1, "",
 				Sqlite.Orders_by.DEFAULT, -1);
 
-		myRunsInterval = SqliteRunInterval.SelectRuns(true, mySession.UniqueID, -1, "");
+		myRunsInterval = SqliteRunInterval.SelectRunsSA (true, mySession.UniqueID, -1, "");
 		myReactionTimes = SqliteReactionTime.SelectReactionTimes(true, mySession.UniqueID, -1, "",
 				Sqlite.Orders_by.DEFAULT, -1);
 
@@ -572,6 +572,7 @@ public class ExportSession
 					Catalog.GetString("Distance") + ":" + 
 					Catalog.GetString("Time") + ":" + 
 					Catalog.GetString("Speed") + ":" + 
+					Catalog.GetString("Datetime") + ":" +
 					Catalog.GetString("Description") + ":" +
 					Catalog.GetString("Simulated") + ":" +
 					Catalog.GetString("Initial Speed") );
@@ -588,6 +589,7 @@ public class ExportSession
 						myStr[4] + ":" +  myStr[5] + ":" + 	//run.type, run.distance
 						Util.TrimDecimals(myStr[6], dec) + ":" +  	//run.time
 						speed + ":" + 				//speed in m/s (true)
+						myStr[10] + ":" +			//datetime
 						Util.RemoveNewLine(myStr[7], true) + ":" + 	//description
 						Util.SimulatedTestNoYes(Convert.ToInt32(myStr[8])) + ":" + //simulated
 						Util.NoYes(Util.StringToBool(myStr[9]))	//initialSpeed
@@ -628,6 +630,7 @@ public class ExportSession
 						Catalog.GetString("Distance interval") + ":" + 
 						Catalog.GetString("Laps") + ":" +
 						Catalog.GetString("Limited") + ":" +
+						Catalog.GetString("Datetime") + ":" +
 						Catalog.GetString("Description") + ":" +
 						Catalog.GetString("Simulated") + ":" +
 						Catalog.GetString("Initial Speed") );
@@ -651,6 +654,7 @@ public class ExportSession
 					Util.TrimDecimals(Util.GetSpeed(myStr[5], myStr[6], true), dec) + ":" + 	//speed AVG in m/s(true)
 					myStr[7] + ":" + 	 	//run.distanceInterval
 					myStr[9] + ":" +  Util.GetLimitedRounded(myStr[11], dec) + ":" + 	//tracks, limited
+					myStr[14] + ":" +				//datetime
 					Util.RemoveNewLine(myStr[10], true) + ":" + 	//description
 					Util.SimulatedTestNoYes(Convert.ToInt32(myStr[12])) + ":" +	//simulated
 					Util.NoYes(Util.StringToBool(myStr[13]))	//initialSpeed
