@@ -15,11 +15,12 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2017-2020   Xavier de Blas <xaviblas@gmail.com>
+ *  Copyright (C) 2017-2021   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
 using System.IO; 		//for detect OS //TextWriter
+using System.Collections; //ArrayList
 using System.Collections.Generic; //List<T>
 using Mono.Unix;
 
@@ -186,6 +187,8 @@ public class ForceSensor
 		if(! fse.ForceResultant)
 			return calculeForceWithCaptureOptions(forceRaw, fsco);
 
+		//forceResultant --->
+
 		double totalMass = 0;
 		if(fse.PercentBodyWeight > 0 && personMass > 0)
 			totalMass = fse.PercentBodyWeight * personMass / 100.0;
@@ -217,11 +220,17 @@ public class ForceSensor
 		//TODO: now we are using fse.AngleDefault, but we have to implement especific angle on capture
 
 		double forceResultant = Math.Sqrt(
-				Math.Pow(Math.Cos(fse.AngleDefault * Math.PI / 180.0) * (forceRaw + totalMass * accel),2) +                	//Horizontal component
-				Math.Pow(Math.Sin(fse.AngleDefault * Math.PI / 180.0) * (forceRaw + totalMass * accel) + totalMass * 9.81,2) 	//Vertical component
+				//Math.Pow(Math.Cos(fse.AngleDefault * Math.PI / 180.0) * (forceRaw + totalMass * accel),2) +                	//Horizontal component
+				//Math.Pow(Math.Sin(fse.AngleDefault * Math.PI / 180.0) * (forceRaw + totalMass * accel) + totalMass * 9.81,2) 	//Vertical component
+				Math.Pow(Math.Cos(fse.AngleDefault * Math.PI / 180.0) * (Math.Abs(forceRaw) + totalMass * accel),2) +                	//Horizontal component
+				Math.Pow(Math.Sin(fse.AngleDefault * Math.PI / 180.0) * (Math.Abs(forceRaw) + totalMass * accel) + totalMass * 9.81,2) 	//Vertical component
 				);
 
-		return calculeForceWithCaptureOptions(forceResultant, fsco);
+		//LogB.Information(string.Format("Abs(forceRaw): {0}, totalMass: {1}, forceResultant: {2}",
+		//			Math.Abs(forceRaw), totalMass, forceResultant));
+
+		//return calculeForceWithCaptureOptions(forceResultant, fsco);
+		return forceResultant;
 	}
 	private static double calculeForceWithCaptureOptions(double force, CaptureOptions fsco)
 	{
@@ -274,7 +283,7 @@ public class ForceSensor
 		else if(s == "b")
 			return "Button OFF";
 		else
-			return "RCA or button unknown, readed: " + s;
+			return "RCA or button unknown, read: " + s;
 	}
 
 	public string FullURL
@@ -295,6 +304,26 @@ public class ForceSensor
 	{
 		get { return dateTime; }
 	}
+	public string DatePublic
+	{
+		get {
+			if(dateTime.Split(new char[] {'_'}).Length == 2)
+				return Util.ChangeChars(dateTime.Split(new char[] {'_'})[0], "-", "/");
+			else
+				return "";
+		}
+	}
+	public string TimePublic
+	{
+		get {
+			if(dateTime.Split(new char[] {'_'}).Length == 2)
+				return Util.ChangeChars(dateTime.Split(new char[] {'_'})[1], "-", ":");
+			else
+				return "";
+		}
+	}
+
+
 
 	public string Filename
 	{
@@ -306,6 +335,10 @@ public class ForceSensor
 		get { return uniqueID; }
 		set { uniqueID = value; }
 	}
+	public int PersonID
+	{
+		get { return personID; }
+	}
 	public int ExerciseID
 	{
 		get { return exerciseID; }
@@ -359,7 +392,9 @@ public class ForceSensorExercise
 	private bool tareBeforeCapture;
 	private bool forceResultant;
 	private bool elastic;
-	private bool eccReps;
+	//private bool eccReps;
+	public enum RepetitionsShowTypes { CONCENTRIC, BOTHTOGETHER, BOTHSEPARATED };
+	private RepetitionsShowTypes repetitionsShow;
 	private double eccMin;
 	private double conMin;
 
@@ -388,7 +423,7 @@ public class ForceSensorExercise
 
 	public ForceSensorExercise(int uniqueID, string name, int percentBodyWeight, string resistance, int angleDefault,
 			string description, bool tareBeforeCapture, bool forceResultant, bool elastic,
-			bool eccReps, double eccMin, double conMin)
+			RepetitionsShowTypes repetitionsShow, double eccMin, double conMin)
 	{
 		this.uniqueID = uniqueID;
 		this.name = name;
@@ -399,7 +434,7 @@ public class ForceSensorExercise
 		this.tareBeforeCapture = tareBeforeCapture;
 		this.forceResultant = forceResultant;
 		this.elastic = elastic;
-		this.eccReps = eccReps;
+		this.repetitionsShow = repetitionsShow;
 		this.eccMin = eccMin;
 		this.conMin = conMin;
 	}
@@ -424,7 +459,39 @@ public class ForceSensorExercise
 		return uniqueID.ToString() + ":" + name + ":" + percentBodyWeight.ToString() + ":" +
 			resistance + ":" + angleDefault.ToString() + ":" + description + ":" +
 			tareBeforeCapture.ToString() + ":" + forceResultant.ToString() + ":" + elastic.ToString() + ":" +
-			eccReps.ToString() + ":" + eccMin.ToString() + ":" + conMin.ToString();
+			repetitionsShow.ToString() + ":" + eccMin.ToString() + ":" + conMin.ToString();
+	}
+
+	public int RepetitionsShowToCode()
+	{
+		/*
+		  DB 2.21 and before	DB ~2.22 	SQL code
+		  eccReps 0		CONCENTRIC		0
+		  eccReps 1		BOTHTOGETHER		1
+					BOTHSEPARATED		2
+
+		  ~2.22 because is not really a change on DB
+		*/
+
+		if(repetitionsShow == RepetitionsShowTypes.CONCENTRIC)
+			return 0;
+		else if(repetitionsShow == RepetitionsShowTypes.BOTHTOGETHER)
+			return 1;
+		else if(repetitionsShow == RepetitionsShowTypes.BOTHSEPARATED)
+			return 2;
+
+		return 0;
+	}
+	public static RepetitionsShowTypes RepetitionsShowFromCode(int code)
+	{
+		if(code == 0)
+			return RepetitionsShowTypes.CONCENTRIC;
+		else if(code == 1)
+			return RepetitionsShowTypes.BOTHTOGETHER;
+		else if(code == 2)
+			return RepetitionsShowTypes.BOTHSEPARATED;
+
+		return RepetitionsShowTypes.CONCENTRIC;
 	}
 
 	public string ToSQLInsertString()
@@ -439,7 +506,7 @@ public class ForceSensorExercise
 			Util.BoolToInt(tareBeforeCapture).ToString() + ", " +
 			Util.BoolToInt(forceResultant).ToString() + ", " +
 			Util.BoolToInt(elastic).ToString() + ", " +
-			Util.BoolToInt(eccReps).ToString() + ", " +
+			RepetitionsShowToCode().ToString() + ", " +
 			Util.ConvertToPoint(eccMin) + ", " + Util.ConvertToPoint(conMin);
 	}
 
@@ -467,7 +534,7 @@ public class ForceSensorExercise
 				tareBeforeCapture == newEx.TareBeforeCapture &&
 				forceResultant == newEx.ForceResultant &&
 				elastic == newEx.Elastic &&
-				eccReps == newEx.EccReps &&
+				repetitionsShow == newEx.RepetitionsShow &&
 				eccMin == newEx.EccMin &&
 				conMin == newEx.ConMin)
 			return false;
@@ -517,9 +584,10 @@ public class ForceSensorExercise
 	{
 		get { return forceResultant && elastic; }
 	}
-	public bool EccReps
+	public RepetitionsShowTypes RepetitionsShow
 	{
-		get { return eccReps; }
+		get { return repetitionsShow; }
+		set { repetitionsShow = value; }
 	}
 	public double EccMin
 	{
@@ -764,9 +832,9 @@ public class ForceSensorCapturePoints
 	public int RealWidthG; //width of graph in microseconds (will be upgraded if needed, but not while capturing on scroll)
 
 	public const int DefaultRealHeightG = 2;
-	public const int DefaultRealHeightGNeg = 2;
+	public const int DefaultRealHeightGNeg = 2; //absolute values
 	public int RealHeightG; //Newtons (will be upgraded if needed)
-	public int RealHeightGNeg; //Newtons (negative) (will be upgraded if needed)
+	public int RealHeightGNeg; //Newtons (negative) (will be upgraded if needed) //absolute values
 
 	//for displacement
 	public const int DefaultRealHeightGDispl = 1;
@@ -932,6 +1000,84 @@ public class ForceSensorCapturePoints
 
 		avg = sum / ((countB - countA) +1);
 	}
+
+
+	//stored, to not calculate again with same data
+	CalculatedForceMaxAvgInWindow calculatedForceMaxAvgInWindow;
+
+	public void GetForceMaxAvgInWindow (int countA, int countB, double windowSeconds,
+			out double avgMax, out int avgMaxSampleStart, out int avgMaxSampleEnd, out string error)
+	{
+		// 1) check if ws calculated before
+		if(calculatedForceMaxAvgInWindow != null &&
+				calculatedForceMaxAvgInWindow.InputsToString() ==
+				new CalculatedForceMaxAvgInWindow(countA, countB, windowSeconds).InputsToString())
+		{
+			LogB.Information("Was calculated before");
+			avgMax = calculatedForceMaxAvgInWindow.Result;
+			avgMaxSampleStart = calculatedForceMaxAvgInWindow.ResultSampleStart;
+			avgMaxSampleEnd = calculatedForceMaxAvgInWindow.ResultSampleEnd;
+			error = ""; //there will be no error, because when is stored is without error
+			return;
+		}
+
+		// 2) check if countB - countA fits in window time
+		double timeA = GetTimeAtCount(countA);
+		
+		if(GetTimeAtCount(countB) - timeA <= 1000000 * windowSeconds)
+		{
+			avgMax = 0;
+			avgMaxSampleStart = countA; //there is an error, this will not be used
+			avgMaxSampleEnd = countA; //there is an error, this will not be used
+			error = "Need more time";
+			return;
+		}
+
+		avgMax = 0;
+		avgMaxSampleStart = countA; 	//sample where avgMax starts (to draw a line)
+		avgMaxSampleEnd = countA; 	//sample where avgMax starts (to draw a line)
+		error = "";
+
+		double sum = 0;
+		int count = 0;
+
+		//note if countB - countA < 1s then can have higher values than all the set
+		// 3) get the first second (or whatever in windowSeconds)
+		int i;
+		for(i = countA; i <= countB && GetTimeAtCount(i) - timeA <= 1000000 * windowSeconds; i ++)
+		{
+			sum += forces[i];
+			count ++;
+		}
+		avgMax = sum / count;
+		avgMaxSampleEnd = countA + count;
+
+		LogB.Information(string.Format("avgMax 1st for: {0}", avgMax));
+		//note "count" has the window size in samples
+
+		// 4) continue until the end (countB)
+		for(int j = i; j < countB; j ++)
+		{
+			sum -= forces[j - count];
+			sum += forces[j];
+
+			double avg = sum / count;
+			if(avg > avgMax)
+			{
+				avgMax = avg;
+				avgMaxSampleStart = j - count;
+				avgMaxSampleEnd = j;
+			}
+		}
+
+		LogB.Information(string.Format("Average max force in {0} seconds: {1}, started at sample range: {2}:{3}",
+					windowSeconds, avgMax, avgMaxSampleStart, avgMaxSampleEnd));
+
+		// 5) store data to not calculate it again if data is the same
+		calculatedForceMaxAvgInWindow = new CalculatedForceMaxAvgInWindow (
+				countA, countB, windowSeconds, avgMax, avgMaxSampleStart, avgMaxSampleEnd);
+	}
+
 	public double GetRFD(int countA, int countB)
 	{
 		double calc = (forces[countB] - forces[countA]) / (times[countB]/1000000.0 - times[countA]/1000000.0); //microsec to sec
@@ -952,7 +1098,10 @@ public class ForceSensorCapturePoints
 		double elapsedSeconds = times[countB]/1000000.0 - times[countA]/1000000.0;
 		return sum * UtilAll.DivideSafe(elapsedSeconds, samples);
 	}
-	public void GetVariabilityAndAccuracy(int countA, int countB, int feedbackF, out double variability, out double feedbackDifference)
+	
+	public void GetVariabilityAndAccuracy(int countA, int countB, int feedbackF,
+			out double variability, out double feedbackDifference,
+			Preferences.VariabilityMethodEnum variabilityMethod)
 	{
 		if(countA == countB)
 		{
@@ -961,10 +1110,54 @@ public class ForceSensorCapturePoints
 			return;
 		}
 
-		//calculate numSamples. Note countA and countB are included, so
+		// 1) calculate numSamples. Note countA and countB are included, so
 		//countA = 2; countB = 4; samples are: 2,3,4; 3 samples
 		int numSamples = (countB - countA) + 1;
 
+		// 2) get variability
+		if(variabilityMethod == Preferences.VariabilityMethodEnum.CHRONOJUMP_OLD)
+			variability = getVariabilityOldMethod (countA, countB, numSamples);
+		else
+			variability = getVariabilityRMSSDCVRMSSD (variabilityMethod, countA, countB, numSamples);
+
+		// 3) Calculate difference.
+		// Average of the differences between force and average
+		//feedbackDifference = Math.Abs(feedbackF - avg);
+		double sum = 0;
+		for(int i = countA; i <= countB; i ++)
+		{
+			sum += Math.Abs(forces[i]-feedbackF);
+		}
+
+		feedbackDifference = UtilAll.DivideSafe(sum, numSamples);
+	}
+	private double getVariabilityRMSSDCVRMSSD (Preferences.VariabilityMethodEnum method, int countA, int countB, int numSamples)
+	{
+		//see a test of this method below:
+		//public static void TestVariabilityCVRMSSD()
+
+		//sqrt(Σ( x_i - x_{i+1})^2 /(n-1)) )   //note pow should be inside the summation
+		double sum = 0;
+		double sumForMean = 0;
+		for(int i = countA; i < countB; i ++)
+		{
+			sum += Math.Pow(forces[i] - forces[i+1], 2);
+			sumForMean += forces[i];
+		}
+
+		double rmssd = Math.Sqrt(UtilAll.DivideSafe(sum, numSamples -1));
+		LogB.Information("RMSSD: " + rmssd.ToString());
+
+		if(method == Preferences.VariabilityMethodEnum.RMSSD)
+			return rmssd;
+
+		//sumForMean += forces[countB]; //need this?
+		double mean = sumForMean / numSamples;
+
+		return 100 * UtilAll.DivideSafe(rmssd, mean);
+	}
+	private double getVariabilityOldMethod (int countA, int countB, int numSamples)
+	{
 		// 1) get average
 		double sum = 0;
 		for(int i = countA; i <= countB; i ++)
@@ -977,17 +1170,96 @@ public class ForceSensorCapturePoints
 		for(int i = countA; i <= countB; i ++)
 			sum += Math.Abs(forces[i]-avg);
 
-		variability = UtilAll.DivideSafe(sum, numSamples);
+		return UtilAll.DivideSafe(sum, numSamples);
+	}
 
-		// 3) Calculate difference.
-		// Average of the differences between force and average
+	public static void TestVariabilityCVRMSSD()
+	{
+		/*
+		   R psych test:
+		   library("psych")
+		   > x=c(21, 45, 75, 54, 5.5, 545.5, 44, 17, 8, -15, -12.8)
+		   > rmssd(x,group=NULL, lag=1, na.rm=TRUE)
+		   [1] 234.2467
+		*/
 
-		//feedbackDifference = Math.Abs(feedbackF - avg);
-		sum = 0;
-		for(int i = countA; i <= countB; i ++)
-			sum += Math.Abs(forces[i]-feedbackF);
+		ForceSensorCapturePoints fscp = new ForceSensorCapturePoints(
+				ForceSensorCapturePoints.GraphTypes.FORCESIGNAL, 300, 300, 10);
+		List <double> nums = new List<double> {21, 45, 75, 54, 5.5, 545.5, 44, 17, 8, -15, -12.8};
+		for (int i = 0; i < nums.Count; i ++)
+			fscp.Add(i+1, nums[i]);
 
-		feedbackDifference = UtilAll.DivideSafe(sum, numSamples);
+		double variability = 0;
+		double feedbackDiff = 0;
+		fscp.GetVariabilityAndAccuracy(0, nums.Count -1, 20, out variability, out feedbackDiff, Preferences.VariabilityMethodEnum.CVRMSSD);
+		LogB.Information("cvRMSSD: " + variability);
+	}
+
+	public void TestVariabilityRMSSDAndCVRMSSD ()
+	{
+		/* R code:
+
+		library("psych")
+		d=read.csv2("rmssd2.csv")
+		png(width=1920, height=1080, filename="rmssd.png")
+		y=d$Force..N.
+		maxyStored = max(y)
+		plot(y, ylim=c(0,maxyStored))
+		#abline(v=seq(from=1, to=length(y), by=100))
+		maxVariab = 0
+		for(n in seq(from=1, to=(length(y) -100), by=100)) {
+			variab = rmssd(y[n:(n+100)], group=NULL, lag=1, na.rm=TRUE)
+			mtext(side=1, at=n+50, round(variab,3), line=0)
+			if(variab > maxVariab)
+				maxVariab = variab
+		}
+		for(n in seq(from=1, to=(length(y) -100), by=100)) {
+			variab = rmssd(y[n:(n+100)], group=NULL, lag=1, na.rm=TRUE)
+			variabScaled = max(y) * variab / maxVariab
+			#rect(n, 0, n+100, variabScaled)
+		}
+
+		#try to lower the values
+		y=y-100
+		lines(y, col="blue")
+		for(n in seq(from=1, to=(length(y) -100), by=100)) {
+			variab = rmssd(y[n:(n+100)], group=NULL, lag=1, na.rm=TRUE)
+			mtext(side=1, at=n+50, round(variab,3), col="blue", line=1)
+		}
+		for(n in seq(from=1, to=(length(y) -100), by=100)) {
+			variab = rmssd(y[n:(n+100)], group=NULL, lag=1, na.rm=TRUE)
+			variabScaled = maxyStored * variab / maxVariab
+			#rect(n, 0, n+100, variabScaled, col="blue")
+		}
+
+		#cv rmssd
+		y=d$Force..N.
+		lines(y, col="green4")
+		for(n in seq(from=1, to=(length(y) -100), by=100)) {
+			variab = 100*rmssd(y[n:(n+100)], group=NULL, lag=1, na.rm=TRUE)/mean(y[n:(n+100)])
+			mtext(side=1, at=n+50, round(variab,3), col="green4", line=2)
+		}
+		for(n in seq(from=1, to=(length(y) -100), by=100)) {
+			variab = 100*rmssd(y[n:(n+100)], group=NULL, lag=1, na.rm=TRUE)/mean(y[n:(n+100)])
+			variabScaled = maxyStored * variab / maxVariab
+			#rect(n, 0, n+100, variabScaled, col="green4")
+		}
+
+		# y/2
+		y=d$Force..N.
+		y=y/2
+		lines(y, col="red")
+		for(n in seq(from=1, to=(length(y) -100), by=100)) {
+			variab = rmssd(y[n:(n+100)], group=NULL, lag=1, na.rm=TRUE)
+			mtext(side=1, at=n+50, round(variab,3), col="red", line=3)
+		}
+		for(n in seq(from=1, to=(length(y) -100), by=100)) {
+			variab = rmssd(y[n:(n+100)], group=NULL, lag=1, na.rm=TRUE)
+			variabScaled = maxyStored * variab / maxVariab
+			#rect(n, 0, n+100, variabScaled, col="red")
+		}
+		dev.off()
+		 */
 	}
 
 	public int MarginLeft
@@ -1119,6 +1391,51 @@ public class ForceSensorCapturePoints
 	}
 }
 
+public class CalculatedForceMaxAvgInWindow
+{
+	private int countA;
+	private int countB;
+	private double windowSeconds;
+	private double result; //avgMax
+	private int resultSampleStart; //avgMaxSampleStart
+	private int resultSampleEnd; //avgMaxSampleEnd
+
+	public CalculatedForceMaxAvgInWindow (int countA, int countB, double windowSeconds,
+			double result, int resultSampleStart, int resultSampleEnd)
+	{
+		this.countA = countA;
+		this.countB = countB;
+		this.windowSeconds = windowSeconds;
+		this.result = result;
+		this.resultSampleStart = resultSampleStart;
+		this.resultSampleEnd = resultSampleEnd;
+	}
+	public CalculatedForceMaxAvgInWindow (int countA, int countB, double windowSeconds)
+	{
+		this.countA = countA;
+		this.countB = countB;
+		this.windowSeconds = windowSeconds;
+	}
+
+	public string InputsToString()
+	{
+		return string.Format("{0};{1};{2}", countA, countB, windowSeconds);
+	}
+
+	public double Result
+	{
+		get { return result; }
+	}
+	public int ResultSampleStart
+	{
+		get { return resultSampleStart; }
+	}
+	public int ResultSampleEnd
+	{
+		get { return resultSampleEnd; }
+	}
+}
+
 public class ForceSensorRFD
 {
 	//if these names change, change FunctionPrint() below
@@ -1245,6 +1562,19 @@ public class ForceSensorRFD
 		return function.ToString() + ";" + type.ToString() + ";" + num1.ToString() + ";" + num2.ToString();
 	}
 
+	public string ToExport(bool translated, string sep)
+	{
+		return FunctionPrint(translated) + sep +
+			TypePrint(translated) + sep +
+			num1 + sep +
+			num2;
+	}
+
+	public bool Active
+	{
+		get { return active; }
+	}
+
 	public static string Function_RAW_name
 	{
 		get { return function_RAW_name; }
@@ -1341,6 +1671,135 @@ public class ForceSensorImpulse : ForceSensorRFD
 	}
 }
 
+//A-B data sent to R
+//can be just one on analyze or multiple (as a list) on export
+public class ForceSensorGraphAB
+{
+	//for graph and for export
+	public ForceSensor.CaptureOptions fsco;
+	public int startSample;
+	public int endSample;
+	public string title;
+	public string exercise;
+	public string date;
+	public string time;
+	public TriggerList triggerList;
+
+	protected void assignParams(ForceSensor.CaptureOptions fsco, int startSample, int endSample,
+			string title, string exercise, string date, string time, TriggerList triggerList)
+	{
+		this.fsco = fsco;
+		this.startSample = startSample;
+		this.endSample = endSample;
+		this.title = title;
+		this.exercise = exercise;
+		this.date = date;
+		this.time = time;
+		this.triggerList = triggerList;
+	}
+
+	//for inheritance
+	public ForceSensorGraphAB ()
+	{
+	}
+
+	//constructor for graph on analyze
+	public ForceSensorGraphAB (
+			ForceSensor.CaptureOptions fsco, int startSample, int endSample,
+			string title, string exercise, string date, string time, TriggerList triggerList)
+	{
+		assignParams(fsco, startSample, endSample, title, exercise, date, time, triggerList);
+	}
+
+
+}
+//this class creates the rows of each force sensor AB for the csv input multi that is read by R
+public class ForceSensorGraphABExport: ForceSensorGraphAB
+{
+	private bool isWindows;
+	public string fullURL;
+	public bool decimalIsPoint;
+	public double maxForceRaw;
+	public double maxAvgForceInWindow;
+	public double forceSensorAnalyzeMaxAVGInWindowSeconds;
+	public double maxAvgForceInWindowSampleStart;
+	public double maxAvgForceInWindowSampleEnd;
+	public string laterality;
+	public int setCount;
+	public int repCount;
+	public string commentOfSet;
+
+	public ForceSensorGraphABExport (
+			bool isWindows,
+			string fullURL, bool decimalIsPoint, double maxForceRaw,
+			double maxAvgForceInWindow, double forceSensorAnalyzeMaxAVGInWindowSeconds,
+			double maxAvgForceInWindowSampleStart, double maxAvgForceInWindowSampleEnd,
+			string laterality, int setCount, int repCount, string commentOfSet,
+			ForceSensor.CaptureOptions fsco, int startSample, int endSample,
+			string title, string exercise, string date, string time, TriggerList triggerList)
+	{
+		assignParams(fsco, startSample, endSample, title, exercise, date, time, triggerList);
+
+		this.isWindows = isWindows;
+		this.fullURL = fullURL;
+		this.decimalIsPoint = decimalIsPoint;
+		this.maxForceRaw = maxForceRaw;
+		this.maxAvgForceInWindow = maxAvgForceInWindow;
+		this.forceSensorAnalyzeMaxAVGInWindowSeconds = forceSensorAnalyzeMaxAVGInWindowSeconds;
+		this.maxAvgForceInWindowSampleStart = maxAvgForceInWindowSampleStart;
+		this.maxAvgForceInWindowSampleEnd = maxAvgForceInWindowSampleEnd;
+		this.laterality = laterality;
+		this.setCount = setCount;
+		this.repCount = repCount;
+		this.commentOfSet = commentOfSet;
+	}
+
+	public string ToCSVRowOnExport()
+	{
+		//since 2.0.3 decimalChar is . (before it was locale specific)
+		string decimalChar = ".";
+		if(! decimalIsPoint)
+		{
+			System.Globalization.NumberFormatInfo localeInfo = new System.Globalization.NumberFormatInfo();
+			localeInfo = System.Globalization.NumberFormatInfo.CurrentInfo;
+			decimalChar = localeInfo.NumberDecimalSeparator;
+		}
+
+		string url = fullURL;
+		if(isWindows)
+			url = url.Replace("\\","/");
+
+		return url + ";" +
+			decimalChar + ";" +
+			Util.ConvertToPoint(maxForceRaw) + ";" +
+			Util.ConvertToPoint(maxAvgForceInWindow) + ";" +
+			maxAvgForceInWindowSampleStart + ";" +
+			maxAvgForceInWindowSampleEnd + ";" +
+			fsco.ToString() + ";" +
+			title + ";" +
+			exercise + ";" +
+			date + ";" +
+			time + ";" +
+			laterality + ";" +
+			setCount + ";" +
+			repCount + ";" +
+			"\"\";\"\";" + 	// triggers unused on export
+			startSample.ToString() + ";" +
+			endSample.ToString() + ";" +
+			Util.RemoveChar(commentOfSet, ';');  //TODO: check this really removes
+	}
+
+	public static string PrintCSVHeaderOnExport()
+	{
+		return "fullURL;decimalChar;maxForceRaw;" +
+			"maxAvgForceInWindow;maxAvgForceInWindowSampleStart;maxAvgForceInWindowSampleEnd;" +
+			"captureOptions;title;exercise;date;time;laterality;set;rep;" +
+			"triggersON;triggersOFF;" + //unused on export
+			"startSample;endSample;comments";
+	}
+}
+
+
 public class ForceSensorGraph
 {
 	ForceSensor.CaptureOptions fsco;
@@ -1353,22 +1812,37 @@ public class ForceSensorGraph
 	bool vline50fmax_fitted;
 	bool hline50fmax_raw;
 	bool hline50fmax_fitted;
-	int testLength;
+	double testLength;
 	string title;
 	string exercise;
-	string datetime;
+	string date;
+	string time;
+	private TriggerList triggerList;
+	private int startSample;
+	private int endSample;
+	private bool startEndOptimized;
+	private bool decimalIsPointAtReadFile; //but on export this will be related to each set
+	private char exportDecimalSeparator;
+	private double forceSensorAnalyzeMaxAVGInWindowSeconds; //on export
+	private bool includeImagesOnExport;
 
-	public ForceSensorGraph(ForceSensor.CaptureOptions fsco, List<ForceSensorRFD> rfdList,
-			ForceSensorImpulse impulse, int testLength, int percentChange, string title, string exercise, string datetime)
+	//private method to help on assigning params
+	private void assignGenericParams(
+			List<ForceSensorRFD> rfdList,
+			ForceSensorImpulse impulse, double testLength, int percentChange,
+			bool startEndOptimized,
+			bool decimalIsPointAtReadFile, 	//at read
+			char exportDecimalSeparator 	//at write
+			)
 	{
-		this.fsco = fsco;
+		//generic of any data
 		this.rfdList = rfdList;
 		this.impulse = impulse;
 		this.testLength = testLength;
 		this.percentChange = percentChange;
-		this.title = title;
-		this.exercise = exercise;
-		this.datetime = datetime;
+		this.startEndOptimized = startEndOptimized;
+		this.decimalIsPointAtReadFile = decimalIsPointAtReadFile;
+		this.exportDecimalSeparator = exportDecimalSeparator;
 
 		averageLength = 0.1;
 		vlineT0 = false;
@@ -1376,17 +1850,65 @@ public class ForceSensorGraph
 		vline50fmax_fitted = false;
 		hline50fmax_raw = false;
 		hline50fmax_fitted = false;
+		includeImagesOnExport = false;
 	}
 
-	public bool CallR(int graphWidth, int graphHeight)
+	//constructor for analyze one graph of a set from startSample to endSample. singleOrMultiple = true
+	public ForceSensorGraph(
+			List<ForceSensorRFD> rfdList,
+			ForceSensorImpulse impulse, double testLength, int percentChange,
+			bool startEndOptimized,
+			bool decimalIsPointAtReadFile,
+			char exportDecimalSeparator,
+			ForceSensorGraphAB fsgAB
+			)
+	{
+		assignGenericParams(rfdList, impulse, testLength, percentChange, startEndOptimized,
+				decimalIsPointAtReadFile, exportDecimalSeparator);
+
+		//this A-B data
+		this.fsco = fsgAB.fsco;
+		this.startSample = fsgAB.startSample;
+		this.endSample = fsgAB.endSample;
+		this.title = fsgAB.title;
+		this.exercise = fsgAB.exercise;
+		this.date = fsgAB.date;
+		this.time = fsgAB.time;
+		this.triggerList = fsgAB.triggerList;
+	}
+
+	//constructor for export. singleOrMultiple = false
+	public ForceSensorGraph(
+			List<ForceSensorRFD> rfdList,
+			ForceSensorImpulse impulse, double testLength, int percentChange,
+			bool startEndOptimized,
+			bool decimalIsPointAtReadFile, //this param is used here to print results. but to read data what id is used is in fsgAB_l
+			char exportDecimalSeparator,
+			List<ForceSensorGraphABExport> fsgABe_l,
+			double forceSensorAnalyzeMaxAVGInWindowSeconds,
+			bool includeImagesOnExport
+			)
+	{
+		assignGenericParams(rfdList, impulse, testLength, percentChange, startEndOptimized,
+				decimalIsPointAtReadFile, exportDecimalSeparator);
+			
+		this.forceSensorAnalyzeMaxAVGInWindowSeconds = forceSensorAnalyzeMaxAVGInWindowSeconds;
+		this.includeImagesOnExport = includeImagesOnExport;
+
+		writeMultipleFilesCSV(fsgABe_l);
+	}
+
+	//multiple is export
+	public bool CallR(int graphWidth, int graphHeight, bool singleOrMultiple)
 	{
 		LogB.Information("\nforceSensor CallR ----->");
-		writeOptionsFile(graphWidth, graphHeight);
+		writeOptionsFile(graphWidth, graphHeight, singleOrMultiple);
 		return ExecuteProcess.CallR(UtilEncoder.GetmifScript());
 	}
 
-	private void writeOptionsFile(int graphWidth, int graphHeight)
+	private void writeOptionsFile(int graphWidth, int graphHeight, bool singleOrMultiple)
 	{
+		LogB.Information("writeOptionsFile 0");
 		string scriptsPath = UtilEncoder.GetSprintPath();
 		if(UtilAll.IsWindows())
 			scriptsPath = scriptsPath.Replace("\\","/");
@@ -1394,9 +1916,15 @@ public class ForceSensorGraph
 		System.Globalization.NumberFormatInfo localeInfo = new System.Globalization.NumberFormatInfo();
 		localeInfo = System.Globalization.NumberFormatInfo.CurrentInfo;
 
+		LogB.Information("writeOptionsFile 1");
+		//since 2.0.3 decimalChar is . (before it was locale specific)
+		string decimalCharAtFile = ".";
+		if(! decimalIsPointAtReadFile)
+			decimalCharAtFile = localeInfo.NumberDecimalSeparator;
+
 		string scriptOptions =
 			"#os\n" + 			UtilEncoder.OperatingSystemForRGraphs() + "\n" +
-			"#decimalChar\n" + 		localeInfo.NumberDecimalSeparator + "\n" +
+			"#decimalCharAtFile\n" +	decimalCharAtFile + "\n" +
 			"#graphWidth\n" + 		graphWidth.ToString() + "\n" +
 			"#graphHeight\n" + 		graphHeight.ToString() + "\n" +
 			"#averageLength\n" + 		Util.ConvertToPoint(averageLength) + "\n" +
@@ -1408,30 +1936,96 @@ public class ForceSensorGraph
 			"#hline50fmax.fitted\n" + 	Util.BoolToRBool(hline50fmax_fitted) + "\n" +
 			"#RFDs";
 
+		LogB.Information("writeOptionsFile 2");
 		foreach(ForceSensorRFD rfd in rfdList)
 			if(rfd.active)
 				scriptOptions += "\n" + rfd.ToR();
 			else
 				scriptOptions += "\n-1";
 
+		LogB.Information("writeOptionsFile 3");
 		if(impulse.active)
 			scriptOptions += "\n" + impulse.ToR();
 		else
 			scriptOptions += "\n-1";
 
-		scriptOptions +=
-			"\n#testLength\n" + 		testLength.ToString() + "\n" +
-			"#captureOptions\n" + 		fsco.ToString() + "\n" +
-			"#title\n" + 			title + "\n" +
-			"#exercise\n" + 		exercise + "\n" +
-			"#datetime\n" + 		datetime + "\n" +
-			"#scriptsPath\n" + 		UtilEncoder.GetScriptsPath() + "\n";
+		LogB.Information("writeOptionsFile 4");
 
+		string captureOptionsStr = "-1";
+		string triggersOnStr = TriggerList.TriggersNotFoundString;
+		string triggersOffStr = TriggerList.TriggersNotFoundString;
+		string forceSensorAnalyzeMaxAVGInWindowSecondsStr =
+			Util.ConvertToPoint(forceSensorAnalyzeMaxAVGInWindowSeconds);
+
+		if(singleOrMultiple)
+		{
+			captureOptionsStr = fsco.ToString();
+			triggersOnStr = printTriggers(TriggerList.Type3.ON);
+			triggersOffStr = printTriggers(TriggerList.Type3.OFF);
+			forceSensorAnalyzeMaxAVGInWindowSecondsStr = "-1";
+		} else {
+			captureOptionsStr = "-1";
+			title = "-1";
+			exercise = "-1";
+			date = "-1";
+			time = "-1";
+		}
+
+		scriptOptions +=
+			"\n#testLength\n" + 		Util.ConvertToPoint(testLength) + "\n" +
+			"#captureOptions\n" + 		captureOptionsStr + "\n" + 	//unused on multiple
+			"#title\n" + 			title + "\n" + 			//unused on multiple
+			"#exercise\n" + 		exercise + "\n" +		//unused on multiple
+			"#date\n" + 			date + "\n" +			//unused on multiple
+			"#time\n" + 			time + "\n" +			//unused on multiple
+			"#scriptsPath\n" + 		UtilEncoder.GetScriptsPath() + "\n" +
+			triggersOnStr + "\n" + 						//unused on multiple
+			triggersOffStr + "\n" + 						//unused on multiple
+			"#startSample\n" + 		startSample.ToString() + "\n" +	//unused on multiple
+			"#endSample\n" + 		endSample.ToString() + "\n" +	//unused on multiple
+			"#startEndOptimized\n" +	Util.BoolToRBool(startEndOptimized) + "\n" +
+			"#singleOrMultiple\n" +		Util.BoolToRBool(singleOrMultiple) + "\n" +
+			"#decimalCharAtExport\n" +	exportDecimalSeparator + "\n" +
+			"#maxAvgInWindowSeconds\n" + 	forceSensorAnalyzeMaxAVGInWindowSecondsStr + "\n" +
+			"#includeImagesOnExport\n" + 	Util.BoolToRBool(includeImagesOnExport) + "\n";
+
+		/*
+		#startEndOptimized on gui can be:
+		Range of analysis:
+		- startEndOptimized FALSE: user AB selection (use AB selected range)
+		- startEndOptimized TRUE (default): optimized range (program will find best fitting samples on user selected range)
+		*/
+
+		LogB.Information("writeOptionsFile 5");
 		TextWriter writer = File.CreateText(Path.GetTempPath() + "Roptions.txt");
 		writer.Write(scriptOptions);
 		writer.Flush();
 		writer.Close();
 		((IDisposable)writer).Dispose();
+		LogB.Information("writeOptionsFile 6");
+	}
+
+	private void writeMultipleFilesCSV(List<ForceSensorGraphABExport> fsgABe_l)
+	{
+		LogB.Information("writeMultipleFilesCSV start");
+		TextWriter writer = File.CreateText(UtilEncoder.GetmifCSVInputMulti());
+
+		//write header
+		writer.WriteLine(ForceSensorGraphABExport.PrintCSVHeaderOnExport());
+
+		//write fsgAB_l for
+		foreach(ForceSensorGraphABExport fsgABe in fsgABe_l)
+			writer.WriteLine(fsgABe.ToCSVRowOnExport());
+
+		writer.Flush();
+		writer.Close();
+		((IDisposable)writer).Dispose();
+		LogB.Information("writeMultipleFilesCSV end");
+	}
+
+	private string printTriggers(TriggerList.Type3 type3)
+	{
+		return triggerList.ToRCurvesString(type3, ';');
 	}
 
 	public static string GetDataDir(int sessionID)
@@ -1461,6 +2055,11 @@ public class ForceSensorAnalyzeInstant
 	public double PowerAVG;
 	public double PowerMAX;
 
+	public double ForceMaxAvgInWindow; 		//the result
+	public int ForceMaxAvgInWindowSampleStart;	//the start sample of the result
+	public int ForceMaxAvgInWindowSampleEnd;	//the end sample of the result
+	public string ForceMaxAvgInWindowError; 	//if there is any error
+
 	//for elastic
 	public bool CalculedElasticPSAP;
 	public List<double> Position_l;
@@ -1563,12 +2162,10 @@ public class ForceSensorAnalyzeInstant
 				if(strFull.Length != 2)
 					continue;
 
-				/*
-				 * TODO: Make this work with decimals as comma and decimals as point
-				 * to fix problems on importing data on different localised computer
-				 */
+				//this can takt forces recorded as , or as . because before 2.0.3 forces decimal was locale specific.
+				//since 2.0.3 forces are recorded with .
 
-				if(Util.IsNumber(strFull[0], false) && Util.IsNumber(strFull[1], true))
+				if(Util.IsNumber(strFull[0], false) && Util.IsNumber(Util.ChangeDecimalSeparator(strFull[1]), true))
 				{
 					double timeD = Convert.ToDouble(strFull[0]);
 
@@ -1588,7 +2185,7 @@ public class ForceSensorAnalyzeInstant
 					*/
 
 					times.Add(Convert.ToInt32(timeD));
-					forces.Add(Convert.ToDouble(strFull[1]));
+					forces.Add(Convert.ToDouble(Util.ChangeDecimalSeparator(strFull[1])));
 				}
 			}
 		}
@@ -1753,7 +2350,7 @@ public class ForceSensorAnalyzeInstant
 	}
 
 	//calculates from a range
-	public bool CalculateRangeParams(int countA, int countB)
+	public bool CalculateRangeParams(int countA, int countB, double forceSensorAnalyzeMaxAVGInWindowSeconds)
 	{
 		//countA will be the lowest and countB the highest to calcule Avg and max correctly no matter if B is before A
 		if(countA > countB) {
@@ -1763,6 +2360,9 @@ public class ForceSensorAnalyzeInstant
 		}
 
 		fscAIPoints.GetAverageAndMaxForce(countA, countB, out ForceAVG, out ForceMAX);
+		fscAIPoints.GetForceMaxAvgInWindow (countA, countB, forceSensorAnalyzeMaxAVGInWindowSeconds,
+				out ForceMaxAvgInWindow, out ForceMaxAvgInWindowSampleStart, out ForceMaxAvgInWindowSampleEnd,
+				out ForceMaxAvgInWindowError);
 
 		if(CalculedElasticPSAP)
 		{
@@ -1804,9 +2404,10 @@ public class ForceSensorAnalyzeInstant
 	}
 
 	public void CalculateVariabilityAndAccuracy(int countA, int countB,
-			int feedbackF, out double variability, out double feedbackDifference)
+			int feedbackF, out double variability, out double feedbackDifference,
+			Preferences.VariabilityMethodEnum variabilityMethod)
 	{
-		fscAIPoints.GetVariabilityAndAccuracy(countA, countB, feedbackF, out variability, out feedbackDifference);
+		fscAIPoints.GetVariabilityAndAccuracy(countA, countB, feedbackF, out variability, out feedbackDifference, variabilityMethod);
 	}
 	/*
 	 * Calculates RFD in a point using previous and next point
@@ -2024,7 +2625,7 @@ public class ForceSensorAnalyzeInstant
 		string str = (i+1).ToString() + sep; //sample
 
 		//str += ForceSensorRepetition.GetRepetitionNumFromList(ForceSensorRepetition_l, i).ToString() + sep + 	//repetition
-		str += ForceSensorRepetition.GetRepetitionCodeFromList(ForceSensorRepetition_l, i, fse.EccReps) + sep + 	//repetition
+		str += ForceSensorRepetition.GetRepetitionCodeFromList(ForceSensorRepetition_l, i, fse.RepetitionsShow) + sep + 	//repetition
 			Util.DoubleToCSV(timeAtCount, sepString) + sep +
 			Util.DoubleToCSV(fscAIPoints.GetForceAtCount(i), sepString) + sep +
 			Util.DoubleToCSV(CalculateRFD(i-1, i+1), 3, sepString);
@@ -2163,3 +2764,25 @@ public class ForceSensorLoadTryToAssignPersonAndMore
 		return "";
 	}
 }
+
+public class PathAccuracy
+{
+	//as public because they are used as ref, so cannot be properties
+	public int CountIn;
+	public int CountOut;
+
+	private int accuracy;
+
+	//constructor
+	public PathAccuracy ()
+	{
+		CountIn = 0;
+		CountOut = 0;
+		accuracy = 0;
+	}
+
+	public double Accuracy
+	{
+		get { return 100 * UtilAll.DivideSafe(CountIn, 1.0 * (CountIn + CountOut)); }
+	}
+}
