@@ -93,6 +93,8 @@ public abstract class ForceSensorDynamics
 			force_l[i] = calculeForceWithCaptureOptions(force_l[i]);
 	}
 
+	protected abstract void calculeResultant ();
+
 	//adapted from r-scripts/forcePosition.R
 	//yList is position_not_smoothed_l on elastic
 	//yList is force_l on not elastic
@@ -205,7 +207,7 @@ public abstract class ForceSensorDynamics
 				concentricFlag, yList.Count, sampleStart, sampleEnd));
 
 		//should accept eccentric reps?
-		if(! fse.EccReps && concentricFlag == -1)
+		if(fse.RepetitionsShow == ForceSensorExercise.RepetitionsShowTypes.CONCENTRIC && concentricFlag == -1)
 			return;
 
 		// 1) remove low force at beginning ot end of the repetition
@@ -298,6 +300,20 @@ public abstract class ForceSensorDynamics
 		return false;
 	}
 
+	protected ForceSensorRepetition.Types getForceSensorRepetitionType (double ySampleStart, double ySampleEnd)
+	{
+		ForceSensorRepetition.Types fsrType = ForceSensorRepetition.Types.DONOTSHOW;
+		if(fse.RepetitionsShow != ForceSensorExercise.RepetitionsShowTypes.CONCENTRIC)
+		{
+			if(ySampleEnd < ySampleStart)
+				fsrType = ForceSensorRepetition.Types.ECC;
+			else
+				fsrType = ForceSensorRepetition.Types.CON;
+		}
+
+		return fsrType;
+	}
+
 	protected abstract void addRepetition(List <double> yList, int sampleStart, int sampleEnd);
 
 	public void CutSamplesForZoom(int startAtSample, int endAtSample)
@@ -370,19 +386,17 @@ public class ForceSensorDynamicsNotElastic : ForceSensorDynamics
 			return;
 		}
 
-		calcule();
+		calculeResultant ();
 	}
 
 	//forces are updated, so do not Add to the list
-	private void calcule()
+	protected override void calculeResultant ()
 	{
-		double accel = 0;
-
 		for (int i = 0 ; i < force_l.Count; i ++)
 		{
 			double force = Math.Sqrt(
-					Math.Pow(Math.Cos(fse.AngleDefault * Math.PI / 180.0) * (force_l[i] + totalMass * accel), 2) +                  //Horizontal
-					Math.Pow(Math.Sin(fse.AngleDefault * Math.PI / 180.0) * (force_l[i] + totalMass * accel) + totalMass * 9.81, 2) //Vertical
+					Math.Pow(Math.Cos(fse.AngleDefault * Math.PI / 180.0) * (Math.Abs(force_l[i])), 2) +                  //Horizontal
+					Math.Pow(Math.Sin(fse.AngleDefault * Math.PI / 180.0) * (Math.Abs(force_l[i])) + totalMass * 9.81, 2) //Vertical
 					);
 			force_l[i] = calculeForceWithCaptureOptions(force);
 		}
@@ -394,15 +408,17 @@ public class ForceSensorDynamicsNotElastic : ForceSensorDynamics
 	{
 		//TODO: need to cut reps with low force prolonged at start or end
 
-		ForceSensorRepetition.Types fsrType = ForceSensorRepetition.Types.DONOTSHOW;
-		if(fse.EccReps)
+		ForceSensorRepetition.Types fsrType = getForceSensorRepetitionType (yList[sampleStart], yList[sampleEnd]);
+
+		//  modify previous repetition if this repetition is ECC and fse.RepetitionsShow == ForceSensorExercise.RepetitionsShowTypes.BOTHTOGETHER
+		if(fsrType == ForceSensorRepetition.Types.ECC &&
+				fse.RepetitionsShow == ForceSensorExercise.RepetitionsShowTypes.BOTHTOGETHER &&
+				forceSensorRepetition_l.Count > 0)
 		{
-			if(yList[sampleEnd] < yList[sampleStart])
-				fsrType = ForceSensorRepetition.Types.ECC;
-			else
-				fsrType = ForceSensorRepetition.Types.CON;
-		}
-		forceSensorRepetition_l.Add(new ForceSensorRepetition(sampleStart, sampleEnd, fsrType));
+			forceSensorRepetition_l[forceSensorRepetition_l.Count -1].sampleEnd = sampleEnd;
+			forceSensorRepetition_l[forceSensorRepetition_l.Count -1].type = ForceSensorRepetition.Types.DONOTSHOW;
+		} else
+			forceSensorRepetition_l.Add(new ForceSensorRepetition(sampleStart, sampleEnd, fsrType));
 	}
 
 	protected override void cutSamplesForZoomDo(int startAtSample, int endAtSample)
@@ -426,7 +442,6 @@ public class ForceSensorDynamicsElastic : ForceSensorDynamics
 	List<double> power_l;
 	private bool zoomed;
 
-
 	public ForceSensorDynamicsElastic (List<int> time_micros_l, List<double> force_l, 
 			ForceSensor.CaptureOptions fsco, ForceSensorExercise fse,
 			double personMass, double stiffness,
@@ -447,7 +462,7 @@ public class ForceSensorDynamicsElastic : ForceSensorDynamics
 			return;
 		}
 
-		calcule();
+		calculeResultant ();
 		CalculedElasticPSAP = true;
 	}
 
@@ -468,7 +483,7 @@ public class ForceSensorDynamicsElastic : ForceSensorDynamics
 		time_l.RemoveAt(0);
 	}
 
-	private void calcule()
+	protected override void calculeResultant ()
 	{
 		//TODO: check minimum length of forces
 
@@ -537,20 +552,19 @@ public class ForceSensorDynamicsElastic : ForceSensorDynamics
 
 	private void calculeAccels()
 	{
+		int window = 10;
 		for (int i = 0 ; i < speed_l.Count; i ++)
 		{
-			int pre = i - 1;
-			int post = i + 1;
+			int pre = i - window;
+			int post = i + window;
 
-			if(i == 0)
+			if(pre <= 0)
 				pre = 0;
-			else if(i == speed_l.Count -1)
-				post = i;
-
-			accel_l.Add( (speed_l[post] - speed_l[pre]) / (time_l[post] - time_l[pre]) );
-			//LogB.Information(string.Format("i: {0}, accel_l[i]: {1}", i, accel_l[i]));
-		}
+			else if(post >= speed_l.Count -1)
+				post = speed_l.Count -1;
 
+			accel_l.Add( UtilAll.DivideSafe(speed_l[post] - speed_l[pre], time_l[post] - time_l[pre]) );
+                }
 		accel_l = smoothVariable(accel_l);
 	}
 
@@ -563,11 +577,13 @@ public class ForceSensorDynamicsElastic : ForceSensorDynamics
 			LogB.Information(string.Format("i pre: {0}, force_l[i]: {1}", i, force_l[i]));
 			//LogB.Information(string.Format("i: {0}, force_l[i]: {1}, force_l.Count: {2}", i, force_l[i], force_l.Count));
 			double force = Math.Sqrt(
-					Math.Pow(Math.Cos(fse.AngleDefault * Math.PI / 180.0) * (force_l[i] + totalMass * accel_l[i]), 2) +                  //Horizontal
-					Math.Pow(Math.Sin(fse.AngleDefault * Math.PI / 180.0) * (force_l[i] + totalMass * accel_l[i]) + totalMass * 9.81, 2) //Vertical
+					Math.Pow(Math.Cos(fse.AngleDefault * Math.PI / 180.0) * (Math.Abs(force_l[i]) + totalMass * accel_l[i]), 2) +                  //Horizontal
+					Math.Pow(Math.Sin(fse.AngleDefault * Math.PI / 180.0) * (Math.Abs(force_l[i]) + totalMass * accel_l[i]) + totalMass * 9.81, 2) //Vertical
 					);
 			LogB.Information(string.Format("i post: {0}, force: {1}", i, force));
-			force_l[i] = calculeForceWithCaptureOptions(force);
+
+			//force_l[i] = calculeForceWithCaptureOptions(force); //Elastic is always resultant. Capture otions does not apply
+			force_l[i] = force;
 		}
 	}
 	
@@ -586,20 +602,31 @@ public class ForceSensorDynamicsElastic : ForceSensorDynamics
 	{
 		//TODO: need to cut reps with low force prolonged at start or end
 
-		ForceSensorRepetition.Types fsrType = ForceSensorRepetition.Types.DONOTSHOW;
-		if(fse.EccReps)
+		ForceSensorRepetition.Types fsrType = getForceSensorRepetitionType (yList[sampleStart], yList[sampleEnd]);
+
+		//  modify previous repetition if this repetition is ECC and fse.RepetitionsShow == ForceSensorExercise.RepetitionsShowTypes.BOTHTOGETHER
+		if(fsrType == ForceSensorRepetition.Types.ECC &&
+				fse.RepetitionsShow == ForceSensorExercise.RepetitionsShowTypes.BOTHTOGETHER &&
+				forceSensorRepetition_l.Count > 0)
 		{
-			if(yList[sampleEnd] < yList[sampleStart])
-				fsrType = ForceSensorRepetition.Types.ECC;
-			else
-				fsrType = ForceSensorRepetition.Types.CON;
+			forceSensorRepetition_l[forceSensorRepetition_l.Count -1].sampleEnd = sampleEnd;
+			forceSensorRepetition_l[forceSensorRepetition_l.Count -1].type = ForceSensorRepetition.Types.DONOTSHOW;
+
+			int sampleStartPreviousRep = forceSensorRepetition_l[forceSensorRepetition_l.Count -1].sampleStart;
+
+			forceSensorRepetition_l[forceSensorRepetition_l.Count -1].RFD =
+				(force_l[sampleEnd] - force_l[sampleStartPreviousRep]) / (time_l[sampleEnd] - time_l[sampleStartPreviousRep]);
+
+			forceSensorRepetition_l[forceSensorRepetition_l.Count -1].meanSpeed =
+				(yList[sampleEnd] - yList[sampleStartPreviousRep]) /  (time_l[sampleEnd] - time_l[sampleStartPreviousRep]);
+		} else
+		{
+			//Calculate mean RFD and mean speed of the phase
+			double lastRFD = (force_l[sampleEnd] - force_l[sampleStart]) / (time_l[sampleEnd] - time_l[sampleStart]);
+			double lastMeanSpeed = (yList[sampleEnd] - yList[sampleStart]) / (time_l[sampleEnd] - time_l[sampleStart]);
+
+			forceSensorRepetition_l.Add(new ForceSensorRepetition(sampleStart, sampleEnd, fsrType, lastMeanSpeed, lastRFD));
 		}
-
-		//Calculate mean RFD and mean speed of the phase
-		double lastRFD = (force_l[sampleEnd] - force_l[sampleStart]) / (time_l[sampleEnd] - time_l[sampleStart]);
-		double lastMeanSpeed = (yList[sampleEnd] - yList[sampleStart]) / (time_l[sampleEnd] - time_l[sampleStart]);
-
-		forceSensorRepetition_l.Add(new ForceSensorRepetition(sampleStart, sampleEnd, fsrType, lastMeanSpeed, lastRFD));
 	}
 
 	protected override void cutSamplesForZoomDo(int startAtSample, int endAtSample)
@@ -658,7 +685,8 @@ public class ForceSensorRepetition
 	public int sampleStart; // this is sample, not graph in pixels.
 	public int sampleEnd; // this is sample, not graph in pixels.
 
-	//if !fse.EccReps, then DONOTSHOW
+	//if(!fse.EccReps), then DONOTSHOW
+	//if(fse.RepetitionsShow == ForceSensorExercise.RepetitionsShowTypes.CONCENTRIC), then DONOTSHOW
 	public enum Types { DONOTSHOW, CON, ECC }
 	public Types type;
 
@@ -709,7 +737,7 @@ public class ForceSensorRepetition
 	}
 	*/
 
-	public static string GetRepetitionCodeFromList(List<ForceSensorRepetition> l, int sampleEnd, bool eccReps)
+	public static string GetRepetitionCodeFromList(List<ForceSensorRepetition> l, int sampleEnd, ForceSensorExercise.RepetitionsShowTypes repetitionsShow)
 	{
 		int rep = 1;
 		foreach(ForceSensorRepetition fsr in l)
@@ -717,7 +745,9 @@ public class ForceSensorRepetition
 			if(sampleEnd >= fsr.sampleStart && sampleEnd <= fsr.sampleEnd)
 			{
 				LogB.Information(string.Format("fsr.sampleStart: {0}; fsr.sampleEnd: {1}; sampleEnd: {2}; rep: {3}", fsr.sampleStart, fsr.sampleEnd, sampleEnd, rep));
-				if(! eccReps || rep == 0)
+				if(repetitionsShow == ForceSensorExercise.RepetitionsShowTypes.CONCENTRIC ||
+						repetitionsShow == ForceSensorExercise.RepetitionsShowTypes.BOTHTOGETHER ||
+						rep == 0)
 					return rep.ToString();
 				else
 					return string.Format("{0}{1}", Math.Ceiling(rep/2.0), typeShort(fsr.type));
