@@ -32,35 +32,44 @@ public class ChronojumpLogo
 	private bool timer;
 	private double alpha;
 	private double size;
+	private double xpos;
+	private double ypos;
 	private Stopwatch stopwatch1;
 	private Stopwatch stopwatch2;
 	private Stopwatch stopwatch3;
 
+	private Gtk.Notebook notebook;
 	private Gtk.DrawingArea drawingarea; 	//contains the animation
 	private Gtk.Viewport viewport; 		//contains the logo and version number
 	private string font;
 
 	//constructor
-	public ChronojumpLogo (Gtk.DrawingArea drawingarea, Gtk.Viewport viewport, bool showAnimated, string font)
+	public ChronojumpLogo (Gtk.Notebook notebook, Gtk.DrawingArea drawingarea, Gtk.Viewport viewport, bool showAnimated, string font)
 	{
-		if(! showAnimated)
-		{
-			viewport.Visible = true;
-			drawingarea.Visible = false;
-			return;
-		}
-
 		LogB.Information("Chronojump logo constructor start");
+
+		this.notebook = notebook;
 		this.drawingarea = drawingarea;
 		this.viewport = viewport;
 		this.font = font;
 
-		viewport.Visible = false;
-		drawingarea.Visible = true;
+		if(! showAnimated)
+		{
+			notebook.CurrentPage = 1;
+			//viewport.Visible = true;
+			//drawingarea.Visible = false;
+			return;
+		}
+
+		//viewport.Visible = false;
+		//drawingarea.Visible = true;
+		notebook.CurrentPage = 0;
 
 		timer = true;
 		alpha = 1.0;
 		size = 1.0;
+		xpos = 0;
+		ypos = .5;
 		stopwatch1 = new Stopwatch();
 		stopwatch2 = new Stopwatch();
 		stopwatch3 = new Stopwatch();
@@ -76,8 +85,9 @@ public class ChronojumpLogo
 	{ 
                 if (! timer)
 		{
-			drawingarea.Visible = false;
-			viewport.Visible = true;
+			//drawingarea.Visible = false;
+			//viewport.Visible = true;
+			notebook.CurrentPage = 1;
 
 			return false;
 		}
@@ -90,8 +100,13 @@ public class ChronojumpLogo
 	{
                 Cairo.Context cr =  Gdk.CairoHelper.Create(drawingarea.GdkWindow);
 
-                int x = drawingarea.Allocation.Width / 2;
-                int y = drawingarea.Allocation.Height / 2;
+		double elapsedMs1 = stopwatch1.Elapsed.TotalMilliseconds;
+
+		xpos = UtilAll.DivideSafeFraction(elapsedMs1, 500);
+		ypos = Math.Pow(xpos,3);
+
+                int x = Convert.ToInt32(xpos * drawingarea.Allocation.Width / 2);
+                int y = Convert.ToInt32(ypos * drawingarea.Allocation.Height / 2);
 
                 cr.SetSourceRGB(.055, .118, .275);
                 cr.Paint();
@@ -101,9 +116,10 @@ public class ChronojumpLogo
 		cr.SelectFontFace("Helvetica", FontSlant.Normal, FontWeight.Bold);
 
 		bool showVersion = false;
-		if (size <= 80)
+		if (size <= 80) {
 			//size += 0.6;
-			size = stopwatch1.Elapsed.TotalMilliseconds / 20.0;
+			size = elapsedMs1 / 20.0;
+		}
 
 		if(size > 20)
 		{
@@ -120,7 +136,9 @@ public class ChronojumpLogo
 		}
 
 		if (stopwatch3.Elapsed.TotalMilliseconds >= 300)
+		{
 			timer = false;
+		}
 
 		chronojumpLogo_showChronojump (cr, x, y);
 
@@ -133,7 +151,7 @@ public class ChronojumpLogo
                 cr.SetFontSize(size);
                 cr.SetSourceRGB(1, 1, 1);
 
-		string	message = "CHRONOJUMP   2.0";
+		string	message = "CHRONOJUMP   2.1";
                 TextExtents extents = cr.TextExtents(message);
 
                 cr.MoveTo(x - extents.Width/2, y + extents.Height/2);
