@@ -52,10 +52,16 @@ public partial class ChronoJumpWindow
 
 	private void on_button_manage_persons_clicked (object o, EventArgs args)
 	{
-		vbox_manage_persons.Visible = ! vbox_manage_persons.Visible;
-
-		arrow_manage_persons_up.Visible = vbox_manage_persons.Visible;
-		arrow_manage_persons_down.Visible = ! vbox_manage_persons.Visible;
+		if(vbox_manage_persons.Visible)
+		{
+			vbox_manage_persons.Visible = false;
+			arrow_manage_persons_down.Visible = true;
+			arrow_manage_persons_up.Visible = false;
+		} else {
+			vbox_manage_persons.Visible = true;
+			arrow_manage_persons_down.Visible = false;
+			arrow_manage_persons_up.Visible = true;
+		}
 	}
 
 	private void showPersonPhoto (bool showPhoto)
@@ -367,7 +373,7 @@ public partial class ChronoJumpWindow
 	private void on_delete_current_person_from_session_clicked (object o, EventArgs args) {
 		LogB.Information("delete current person from this session");
 		ConfirmWindow confirmWin = ConfirmWindow.Show(
-				Catalog.GetString("Are you sure you want to delete the current person and all his/her tests (jumps, races, pulses, ...) from this session?\n(His/her personal data and tests in other sessions will remain intact.)"), "",
+				Catalog.GetString("Are you sure you want to delete the current person and all his/her tests (jumps, races, pulses, …) from this session?\n(His/her personal data and tests in other sessions will remain intact.)"), "",
 				Catalog.GetString("Current Person: ") + "<b>" + currentPerson.Name + "</b>");
 
 		confirmWin.Button_accept.Clicked += new EventHandler(on_delete_current_person_from_session_accepted);
@@ -378,14 +384,14 @@ public partial class ChronoJumpWindow
 		new DialogMessage(Constants.MessageTypes.INFO, Catalog.GetString("Deleted person and all his/her tests on this session."));
 		SqlitePersonSession.DeletePersonFromSessionAndTests(
 				currentSession.UniqueID.ToString(), currentPerson.UniqueID.ToString());
-		
-		resetAllTreeViews(false, true, true); //fill, resetPersons, fillPersons
+
+		resetAllTreeViews(true, true, true); //fillTests, resetPersons, fillPersons
 		bool foundPersons = selectRowTreeView_persons(treeview_persons, 0);
-			
+
 		if(createdStatsWin) {
 			stats_win_fillTreeView_stats(false, true);
 		}
-		
+
 		//if there are no persons
 		if(! foundPersons) {
 			currentPerson = null;
@@ -410,7 +416,8 @@ public partial class ChronoJumpWindow
 				currentSession.UniqueID, 
 				false); //means: do not returnPersonAndPSlist
 
-		personSelectWin = PersonSelectWindow.Show(app1, myPersons, currentPerson, preferences.colorBackground);
+		personSelectWin = PersonSelectWindow.Show(app1, myPersons, currentPerson, preferences.colorBackground,
+				configChronojump.Raspberry, configChronojump.LowHeight, preferences.personSelectWinImages);
 		personSelectWin.FakeButtonAddPerson.Clicked += new EventHandler(on_button_top_person_add_person);
 		personSelectWin.FakeButtonAddPersonMultiple.Clicked += new EventHandler(on_button_top_person_add_person_multiple);
 		personSelectWin.FakeButtonLoadPerson.Clicked += new EventHandler(on_button_top_person_load_person);
@@ -418,7 +425,9 @@ public partial class ChronoJumpWindow
 		personSelectWin.FakeButtonEditPerson.Clicked += new EventHandler(on_button_top_person_edit_person);
 		personSelectWin.FakeButtonPersonShowAllEvents.Clicked += new EventHandler(on_button_top_person_show_all_events);
 		personSelectWin.FakeButtonDeletePerson.Clicked += new EventHandler(on_button_top_person_delete_person);
-		personSelectWin.FakeButtonDone.Clicked += new EventHandler(on_button_top_person_change_done);
+		personSelectWin.FakeButtonShowImages.Clicked += new EventHandler(on_button_top_person_show_images);
+		personSelectWin.FakeButtonHideImages.Clicked += new EventHandler(on_button_top_person_hide_images);
+		personSelectWin.FakeButtonDone.Clicked += new EventHandler(on_button_top_person_change_done); //on window close, and on double click (it also closes the window)
 	}
 	private void on_button_top_person_add_person(object o, EventArgs args)
 	{
@@ -478,8 +487,27 @@ public partial class ChronoJumpWindow
 				false); //means: do not returnPersonAndPSlist
 		personSelectWin.Update(myPersons, currentPerson);
 	}
+	private void on_button_top_person_show_images (object o, EventArgs args)
+	{
+		Sqlite.Open();
+		preferences.personSelectWinImages = Preferences.PreferencesChange(SqlitePreferences.PersonSelectWinImages, false, true);
+		Sqlite.Close();
+	}
+	private void on_button_top_person_hide_images (object o, EventArgs args)
+	{
+		Sqlite.Open();
+		preferences.personSelectWinImages = Preferences.PreferencesChange(SqlitePreferences.PersonSelectWinImages, true, false);
+		Sqlite.Close();
+	}
+
 	private void on_button_top_person_change_done(object o, EventArgs args)
 	{
+		if(personSelectWin.SelectedPerson == null)
+			return;
+
+		if(currentPerson.UniqueID == personSelectWin.SelectedPerson.UniqueID)
+			return;
+
 		currentPerson = personSelectWin.SelectedPerson; 
 		currentPersonSession = SqlitePersonSession.Select(currentPerson.UniqueID, currentSession.UniqueID);
 		label_person_change();
@@ -488,4 +516,14 @@ public partial class ChronoJumpWindow
 		myTreeViewPersons.SelectRowByUniqueID(currentPerson.UniqueID);
 	}
 
+
+	private void on_button_persons_raspberry_left_clicked(object o, EventArgs args)
+	{
+		hpaned_contacts_main.Position -= 10;
+	}
+	private void on_button_persons_raspberry_right_clicked(object o, EventArgs args)
+	{
+		hpaned_contacts_main.Position += 10;
+	}
+
 }
