@@ -37,7 +37,7 @@ public partial class ChronoJumpWindow
 		hbox_top_person.Sensitive = false;
 
 		button_contacts_exercise_close_and_capture.Sensitive = myTreeViewPersons.IsThereAnyRecord();
-		notebook_contacts_execute_or_instructions.CurrentPage = 1;
+		notebook_contacts_execute_or.CurrentPage = 1;
 	}
 	private void on_button_contacts_exercise_close_clicked (object o, EventArgs args)
 	{
@@ -49,7 +49,7 @@ public partial class ChronoJumpWindow
 		hbox_contacts_sup_capture_analyze_two_buttons.Sensitive = true;
 		hbox_top_person.Sensitive = true;
 
-		notebook_contacts_execute_or_instructions.CurrentPage = 0;
+		notebook_contacts_execute_or.CurrentPage = 0;
 	}
 	private void on_button_contacts_exercise_close_and_capture_clicked (object o, EventArgs args)
 	{
@@ -238,6 +238,7 @@ public partial class ChronoJumpWindow
 		label_contacts_exercise_selected_options.Text = name;
 	}
 
+	/* Now just showing laterality icon with setForceSensorLateralityPixbuf()
 	private void setLabelContactsExerciseSelectedOptionsForceSensor()
 	{
 		string name = Catalog.GetString("Laterality:");
@@ -250,4 +251,5 @@ public partial class ChronoJumpWindow
 
 		label_contacts_exercise_selected_options.Text = name;
 	}
+	*/
 }
