@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2017-2020   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2017-2021   Xavier de Blas <xaviblas@gmail.com>
  */
 
 
@@ -34,6 +34,7 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_minimize;
 	//[Widget] Gtk.Image image_minimize1;
 	[Widget] Gtk.Image image_session_delete;
+	[Widget] Gtk.Image app1s_image_button_close;
 	[Widget] Gtk.Image image_db_backup;
 	[Widget] Gtk.Image image_db_view;
 	[Widget] Gtk.Image image_mode_encoder_capture;
@@ -41,6 +42,7 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_current_person_zoom_h;
 	[Widget] Gtk.Image image_person;
 	[Widget] Gtk.Image image_person1;
+	[Widget] Gtk.Image image_person2;
 	[Widget] Gtk.Image image_edit_current_person;
 	[Widget] Gtk.Image image_edit_current_person_h;
 	//[Widget] Gtk.Image image_persons_up;
@@ -52,7 +54,6 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_contacts_session_overview;
 	[Widget] Gtk.Image image_encoder_session_overview;
 	[Widget] Gtk.Image image_contacts_recalculate;
-	[Widget] Gtk.Image image_rest;
 	[Widget] Gtk.Image image_all_persons_events;
 	[Widget] Gtk.Image image_all_persons_events_h;
 	[Widget] Gtk.Image image_person_delete;
@@ -113,16 +114,26 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Label label_start_selector_races;
 	[Widget] Gtk.Label label_start_selector_encoder;
 
+	//jumps
+	[Widget] Gtk.Image image_button_jumps_simple_capture_save_image_chart;
+	[Widget] Gtk.Image image_button_jumps_simple_capture_save_image_disk;
+
 	//run
+	[Widget] Gtk.Image image_button_runs_simple_capture_save_image_chart;
+	[Widget] Gtk.Image image_button_runs_simple_capture_save_image_disk;
 	[Widget] Gtk.Image image_run_execute_running;
 	[Widget] Gtk.Image image_run_execute_photocell;
 	[Widget] Gtk.Image image_sprint_analyze_save;
+	[Widget] Gtk.Image image_sprint_analyze_table_save;
+	[Widget] Gtk.Image image_sprint_analyze_table_save_1;
+	[Widget] Gtk.Image image_sprint_export_cancel;
 
 	//encoder images
 	[Widget] Gtk.Image image_top_eccon;
 	[Widget] Gtk.Image image_encoder_eccon_concentric;
 	[Widget] Gtk.Image image_encoder_eccon_eccentric_concentric;
 	[Widget] Gtk.Image image_top_laterality;
+	[Widget] Gtk.Image image_top_laterality_contacts;
 	[Widget] Gtk.Image image_encoder_laterality_both;
 	[Widget] Gtk.Image image_encoder_laterality_r;
 	[Widget] Gtk.Image image_encoder_laterality_l;
@@ -133,6 +144,10 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_recalculate;
 	[Widget] Gtk.Image image_encoder_configuration;
 	[Widget] Gtk.Image image_encoder_exercise;
+	[Widget] Gtk.Image image_button_encoder_exercise_actions_cancel;
+	[Widget] Gtk.Image image_button_encoder_exercise_actions_edit_do;
+	[Widget] Gtk.Image image_button_encoder_exercise_actions_add_do;
+	[Widget] Gtk.Image image_button_radio_encoder_exercise_help;
 	[Widget] Gtk.Image image_encoder_exercise_settings;
 	[Widget] Gtk.Image image_encoder_exercise_close;
 	[Widget] Gtk.Image image_encoder_capture_open;
@@ -180,6 +195,26 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_force_sensor_laterality_both;
 	[Widget] Gtk.Image image_force_sensor_laterality_r;
 	[Widget] Gtk.Image image_force_sensor_laterality_l;
+	[Widget] Gtk.Image image_force_sensor_export_cancel;
+	[Widget] Gtk.Image image_force_sensor_ai_chained_link;
+	[Widget] Gtk.Image image_force_sensor_ai_chained_link_off;
+	[Widget] Gtk.Image image_force_sensor_ai_zoom;
+	[Widget] Gtk.Image image_force_sensor_ai_zoom_out;
+	[Widget] Gtk.Image image_button_force_sensor_analyze_back_to_signal;
+
+	[Widget] Gtk.Image image_hscale_force_sensor_ai_a_first;
+	[Widget] Gtk.Image image_hscale_force_sensor_ai_a_last;
+	[Widget] Gtk.Image image_hscale_force_sensor_ai_a_pre;
+	[Widget] Gtk.Image image_hscale_force_sensor_ai_a_pre_1s;
+	[Widget] Gtk.Image image_hscale_force_sensor_ai_a_post;
+	[Widget] Gtk.Image image_hscale_force_sensor_ai_a_post_1s;
+
+	[Widget] Gtk.Image image_hscale_force_sensor_ai_b_first;
+	[Widget] Gtk.Image image_hscale_force_sensor_ai_b_last;
+	[Widget] Gtk.Image image_hscale_force_sensor_ai_b_pre;
+	[Widget] Gtk.Image image_hscale_force_sensor_ai_b_pre_1s;
+	[Widget] Gtk.Image image_hscale_force_sensor_ai_b_post;
+	[Widget] Gtk.Image image_hscale_force_sensor_ai_b_post_1s;
 
 	//race encoder
 	[Widget] Gtk.Image image_run_encoder_exercise_edit;
@@ -188,6 +223,7 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_run_encoder_analyze_load;
 	[Widget] Gtk.Image image_run_encoder_analyze_image_save_graph;
 	[Widget] Gtk.Image image_run_encoder_analyze_image_save_disk;
+	[Widget] Gtk.Image image_run_encoder_export_cancel;
 
 	//video play icons
 	[Widget] Gtk.Image image_video_play_this_test_contacts;
@@ -202,6 +238,8 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_video_contacts_preview;
 	[Widget] Gtk.Image image_video_encoder_preview;
 
+	[Widget] Gtk.Image image_encoder_capture_image_save;
+	[Widget] Gtk.Image image_encoder_capture_image_save_1;
 	[Widget] Gtk.Image image_encoder_capture_curves_save;
 	[Widget] Gtk.Image image_encoder_analyze_table_save_1;
 	[Widget] Gtk.Image image_encoder_analyze_image_save_1;
@@ -215,7 +253,13 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_forcesensor_analyze_image_save5;
 	[Widget] Gtk.Image image_forcesensor_analyze_image_save6;
 	[Widget] Gtk.Image image_forcesensor_analyze_image_save7;
+	[Widget] Gtk.Image image_force_sensor_analyze_table_save;
+	[Widget] Gtk.Image image_force_sensor_analyze_table_save_1;
+	[Widget] Gtk.Image image_run_encoder_analyze_table_save;
+	[Widget] Gtk.Image image_run_encoder_analyze_table_save_1;
 	[Widget] Gtk.Image image_sprint_analyze_image_save;
+	[Widget] Gtk.Image image_raceAnalyzer_table_save_grid;
+	[Widget] Gtk.Image image_raceAnalyzer_table_save_disk;
 	[Widget] Gtk.Image image_message_permissions_at_boot;
 	[Widget] Gtk.Image image_camera_at_boot;
 
@@ -244,6 +288,13 @@ public partial class ChronoJumpWindow
 		image_contacts_exercise_settings.Pixbuf = pixbuf;
 		image_encoder_exercise_settings.Pixbuf = pixbuf;
 
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_store_blue.png");
+		image_menu_news.Pixbuf = pixbuf;
+		image_menu_news1.Pixbuf = pixbuf;
+		image_news_blue.Pixbuf = pixbuf;
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_store_yellow.png");
+		image_news_yellow.Pixbuf = pixbuf;
+
 		//pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_minimize.png");
 		//image_minimize.Pixbuf = pixbuf;
 		//image_minimize1.Pixbuf = pixbuf;
@@ -266,6 +317,7 @@ public partial class ChronoJumpWindow
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_help.png");
 		image_menu_help.Pixbuf = pixbuf;
 		image_menu_help1.Pixbuf = pixbuf;
+		image_button_radio_encoder_exercise_help.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_book.png");
 		image_menu_help_documents.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_keyboard.png");
@@ -292,6 +344,7 @@ public partial class ChronoJumpWindow
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "laterality-both.png");
 		image_top_laterality.Pixbuf = pixbuf;
+		image_top_laterality_contacts.Pixbuf = pixbuf;
 		image_encoder_laterality_both.Pixbuf = pixbuf;
 		image_force_sensor_laterality_both.Pixbuf = pixbuf;
 
@@ -319,8 +372,21 @@ public partial class ChronoJumpWindow
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_weight.png");
 		image_mode_encoder_gravitatory.Pixbuf = pixbuf;
+		image_change_modes_encoder_gravitatory.Pixbuf = pixbuf;
+		app1s_image_show_data_encoder_grav.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_inertia.png");
 		image_mode_encoder_inertial.Pixbuf = pixbuf;
+		image_change_modes_encoder_inertial.Pixbuf = pixbuf;
+		app1s_image_show_data_encoder_inertial.Pixbuf = pixbuf;
+
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_jump.png");
+		app1s_image_show_data_jumps.Pixbuf = pixbuf;
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_run.png");
+		app1s_image_show_data_runs.Pixbuf = pixbuf;
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "race_encoder_icon.png");
+		app1s_image_show_data_run_encoder.Pixbuf = pixbuf;
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "force_sensor_icon.png");
+		app1s_image_show_data_force_sensor.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_capture.png");
 		image_tests_capture.Pixbuf = pixbuf;
@@ -333,6 +399,7 @@ public partial class ChronoJumpWindow
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "arrow_back.png");
 		image_selector_start_back.Pixbuf = pixbuf;
+		image_button_force_sensor_analyze_back_to_signal.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_person_pin.png");
 		image_radio_show_persons.Pixbuf = pixbuf;
@@ -340,6 +407,8 @@ public partial class ChronoJumpWindow
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_person.png");
 		image_person.Pixbuf = pixbuf;
 		image_person1.Pixbuf = pixbuf;
+		image_person2.Pixbuf = pixbuf;
+		app1s_image_show_data_persons.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_info.png");
 		image_info1.Pixbuf = pixbuf;
@@ -399,6 +468,7 @@ public partial class ChronoJumpWindow
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_weight.png");
 		image_encoder_exercise.Pixbuf = pixbuf;
 
+
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "folder_new.png");
 		image_session_new1.Pixbuf = pixbuf;
 		image_session_new3.Pixbuf = pixbuf;
@@ -411,6 +481,7 @@ public partial class ChronoJumpWindow
 		image_session_load1.Pixbuf = pixbuf;
 		image_session_load2.Pixbuf = pixbuf;
 		image_session_load3_blue.Pixbuf = pixbuf;
+		app1s_image_load.Pixbuf = pixbuf;
 		app1s_image_open_database.Pixbuf = pixbuf;
 		app1s_image_button_backup_select.Pixbuf = pixbuf;
 		app1s_image_button_export_select.Pixbuf = pixbuf;
@@ -439,6 +510,7 @@ public partial class ChronoJumpWindow
 		image_edit_current_person.Pixbuf = pixbuf;
 		image_edit_current_person_h.Pixbuf = pixbuf;
 		image_session_edit2.Pixbuf = pixbuf;
+		app1s_image_edit.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_close.png");
 		image_contacts_exercise_close.Pixbuf = pixbuf;
@@ -447,6 +519,7 @@ public partial class ChronoJumpWindow
 		image_force_sensor_analyze_options_close1.Pixbuf = pixbuf;
 		image_encoder_analyze_mode_options_close.Pixbuf = pixbuf;
 		image_force_sensor_capture_adjust_close.Pixbuf = pixbuf;
+		app1s_image_button_close.Pixbuf = pixbuf;
 
 
 		/*
@@ -471,7 +544,6 @@ public partial class ChronoJumpWindow
 		//image_persons_open_plus_2.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_rest.png");
-		image_rest.Pixbuf = pixbuf;
 		image_encoder_rhythm_rest.Pixbuf = pixbuf;
 		image_contacts_rest_time_dark_blue.Pixbuf = pixbuf;
 		image_encoder_rest_time_dark_blue.Pixbuf = pixbuf;
@@ -545,17 +617,22 @@ public partial class ChronoJumpWindow
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_jump_simple.png");
 		image_mode_jumps_small.Pixbuf = pixbuf;
+		image_change_modes_contacts_jumps_simple.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_jump_reactive.png");
 		image_mode_jumps_reactive_small.Pixbuf = pixbuf;
+		image_change_modes_contacts_jumps_reactive.Pixbuf = pixbuf;
 		image_tests_analyze_jump_rj.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_run_simple.png");
 		image_mode_runs_small.Pixbuf = pixbuf;
 		image_mode_runs_small1.Pixbuf = pixbuf;
+		image_change_modes_contacts_runs_simple.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_run_multiple.png");
 		image_mode_runs_intervallic_small.Pixbuf = pixbuf;
 		image_mode_runs_intervallic_small1.Pixbuf = pixbuf;
+		image_change_modes_contacts_runs_intervallic.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "race_encoder_icon.png");
 		image_mode_race_encoder_small.Pixbuf = pixbuf;
+		image_change_modes_contacts_runs_encoder.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "run_2x.png");
 		image_run_execute_running.Pixbuf = pixbuf;
@@ -667,9 +744,15 @@ public partial class ChronoJumpWindow
 		image_button_cancel.Pixbuf = pixbuf;
 		image_encoder_capture_cancel.Pixbuf = pixbuf;
 		image_encoder_signal_delete.Pixbuf = pixbuf;
+		app1s_image_delete.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_cancel.png");
+		image_sprint_export_cancel.Pixbuf = pixbuf;
+		image_button_encoder_exercise_actions_cancel.Pixbuf = pixbuf;
 		image_encoder_analyze_cancel.Pixbuf = pixbuf;
+		image_force_sensor_export_cancel.Pixbuf = pixbuf;
+		image_run_encoder_export_cancel.Pixbuf = pixbuf;
+		app1s_image_cancel.Pixbuf = pixbuf;
 		
 		//zoom icons, done like this because there's one zoom icon created ad-hoc, 
 		//and is not nice that the other are different for an user theme change
@@ -701,8 +784,12 @@ public partial class ChronoJumpWindow
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_grid_on.png");
 		image_contacts_session_overview.Pixbuf = pixbuf;
+		image_sprint_analyze_table_save.Pixbuf = pixbuf;
 		image_encoder_session_overview.Pixbuf = pixbuf;
 		image_encoder_analyze_table_save.Pixbuf = pixbuf;
+		image_force_sensor_analyze_table_save.Pixbuf = pixbuf;
+		image_run_encoder_analyze_table_save.Pixbuf = pixbuf;
+		image_raceAnalyzer_table_save_grid.Pixbuf = pixbuf;
 		image_session_export_csv1.Pixbuf = pixbuf;
 
 		//encoder
@@ -721,7 +808,10 @@ public partial class ChronoJumpWindow
 		UtilGtk.ColorsCheckbox(viewport_chronopics, check_encoder_analyze_show_time_to_peak_power);
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_analyze.png");
+		image_button_jumps_simple_capture_save_image_chart.Pixbuf = pixbuf;
+		image_button_runs_simple_capture_save_image_chart.Pixbuf = pixbuf;
 		image_encoder_analyze_stats.Pixbuf = pixbuf;
+		image_encoder_capture_image_save.Pixbuf = pixbuf;
 		image_encoder_analyze_image_save.Pixbuf = pixbuf;
 		image_forcesensor_analyze_save_signal.Pixbuf = pixbuf;
 		image_forcesensor_analyze_save_rfd_auto.Pixbuf = pixbuf;
@@ -734,15 +824,22 @@ public partial class ChronoJumpWindow
 		image_jumps_dj_optimal_fall_save.Pixbuf = pixbuf;
 		image_jumps_weight_fv_profile_save.Pixbuf = pixbuf;
 		image_jumps_evolution_save.Pixbuf = pixbuf;
+		image_runs_evolution_save.Pixbuf = pixbuf;
 		image_jumps_rj_fatigue_save.Pixbuf = pixbuf;
 		image_sprint_analyze_save.Pixbuf = pixbuf;
 		image_encoder_analyze_image_compujump_send_email_image.Pixbuf = pixbuf;
 		image_run_encoder_analyze_image_save_graph.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "save.png");
+		image_button_jumps_simple_capture_save_image_disk.Pixbuf = pixbuf;
+		image_button_runs_simple_capture_save_image_disk.Pixbuf = pixbuf;
 		image_jumps_rj_fatigue_image_save.Pixbuf = pixbuf;
+		image_sprint_analyze_table_save_1.Pixbuf = pixbuf;
+		image_button_encoder_exercise_actions_edit_do.Pixbuf = pixbuf;
+		image_button_encoder_exercise_actions_add_do.Pixbuf = pixbuf;
 		image_encoder_capture_curves_save.Pixbuf = pixbuf;
 		image_encoder_analyze_table_save_1.Pixbuf = pixbuf;
+		image_encoder_capture_image_save_1.Pixbuf = pixbuf;
 		image_encoder_analyze_image_save_1.Pixbuf = pixbuf;
 		image_encoder_analyze_1RM_save_1.Pixbuf = pixbuf;
 		image_encoder_analyze_image_save_2.Pixbuf = pixbuf;
@@ -754,8 +851,12 @@ public partial class ChronoJumpWindow
 		image_forcesensor_analyze_image_save5.Pixbuf = pixbuf;
 		image_forcesensor_analyze_image_save6.Pixbuf = pixbuf;
 		image_forcesensor_analyze_image_save7.Pixbuf = pixbuf;
+		image_runs_evolution_analyze_image_save.Pixbuf = pixbuf;
+		image_force_sensor_analyze_table_save_1.Pixbuf = pixbuf;
+		image_run_encoder_analyze_table_save_1.Pixbuf = pixbuf;
 		image_sprint_analyze_image_save.Pixbuf = pixbuf;
 		image_run_encoder_analyze_image_save_disk.Pixbuf = pixbuf;
+		image_raceAnalyzer_table_save_disk.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_email.png");
 		image_encoder_analyze_image_compujump_send_email_send.Pixbuf = pixbuf;
@@ -785,14 +886,27 @@ public partial class ChronoJumpWindow
 
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameEncoderAnalyzeIndividualCurrentSetIcon);
+		image_sprint_analyze_individual_current_set.Pixbuf = pixbuf;
 		image_encoder_analyze_individual_current_set.Pixbuf = pixbuf;
+		image_force_sensor_analyze_individual_current_set.Pixbuf = pixbuf;
+		image_run_encoder_analyze_individual_current_set.Pixbuf = pixbuf;
+
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameEncoderAnalyzeIndividualCurrentSessionIcon);
+		image_sprint_analyze_individual_current_session.Pixbuf = pixbuf;
 		image_encoder_analyze_individual_current_session.Pixbuf = pixbuf;
+		image_force_sensor_analyze_individual_current_session.Pixbuf = pixbuf;
+		image_run_encoder_analyze_individual_current_session.Pixbuf = pixbuf;
+
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameEncoderAnalyzeIndividualAllSessionsIcon);
 		image_encoder_analyze_individual_all_sessions.Pixbuf = pixbuf;
 		image_tab_jumps_evolution.Pixbuf = pixbuf;
+		image_tab_runs_evolution.Pixbuf = pixbuf;
+
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameEncoderAnalyzeGroupalCurrentSessionIcon);
+		image_sprint_analyze_groupal_current_session.Pixbuf = pixbuf;
 		image_encoder_analyze_groupal_current_session.Pixbuf = pixbuf;
+		image_force_sensor_analyze_groupal_current_session.Pixbuf = pixbuf;
+		image_run_encoder_analyze_groupal_current_session.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameEncoderAnalyzePowerbarsIcon);
 		image_encoder_analyze_powerbars.Pixbuf = pixbuf;
@@ -865,5 +979,30 @@ public partial class ChronoJumpWindow
 				
 		//pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameLogo320); //changed to 270 for the presentation
 		//image_presentation_logo.Pixbuf = pixbuf;
+
+		pixbuf = new Pixbuf(null, Util.GetImagePath(false) + "first.png");
+		image_hscale_force_sensor_ai_a_first.Pixbuf = pixbuf;
+		image_hscale_force_sensor_ai_b_first.Pixbuf = pixbuf;
+		pixbuf = new Pixbuf(null, Util.GetImagePath(false) + "left_cut.png");
+		image_hscale_force_sensor_ai_a_pre_1s.Pixbuf = pixbuf;
+		image_hscale_force_sensor_ai_b_pre_1s.Pixbuf = pixbuf;
+		pixbuf = new Pixbuf(null, Util.GetImagePath(false) + "left.png");
+		image_hscale_force_sensor_ai_a_pre.Pixbuf = pixbuf;
+		image_hscale_force_sensor_ai_b_pre.Pixbuf = pixbuf;
+
+		pixbuf = new Pixbuf(null, Util.GetImagePath(false) + "right.png");
+		image_hscale_force_sensor_ai_a_post.Pixbuf = pixbuf;
+		image_hscale_force_sensor_ai_b_post.Pixbuf = pixbuf;
+		pixbuf = new Pixbuf(null, Util.GetImagePath(false) + "right_cut.png");
+		image_hscale_force_sensor_ai_a_post_1s.Pixbuf = pixbuf;
+		image_hscale_force_sensor_ai_b_post_1s.Pixbuf = pixbuf;
+		pixbuf = new Pixbuf(null, Util.GetImagePath(false) + "last.png");
+		image_hscale_force_sensor_ai_a_last.Pixbuf = pixbuf;
+		image_hscale_force_sensor_ai_b_last.Pixbuf = pixbuf;
+
+		image_force_sensor_ai_chained_link.Pixbuf = new Pixbuf(null, Util.GetImagePath(false) + "link.png"); 
+		image_force_sensor_ai_chained_link_off.Pixbuf = new Pixbuf(null, Util.GetImagePath(false) + "link_off.png"); 
+		image_force_sensor_ai_zoom.Pixbuf = new Pixbuf(null, Util.GetImagePath(false) + "zoom_in.png");
+		image_force_sensor_ai_zoom_out.Pixbuf = new Pixbuf(null, Util.GetImagePath(false) + "zoom_out.png");
 	}
 }
