@@ -33,8 +33,11 @@ using Mono.Unix;
 public partial class ChronoJumpWindow
 {
 	//options jumps
+	[Widget] Gtk.Button button_combo_jumps_exercise_capture_left;
+	[Widget] Gtk.Button button_combo_jumps_exercise_capture_right;
 	[Widget] Gtk.Button button_jump_type_delete_simple;
 	[Widget] Gtk.SpinButton extra_window_jumps_spinbutton_weight;
+	[Widget] Gtk.HBox extra_window_jumps_simple_hbox_start_inside;
 	[Widget] Gtk.Box extra_window_jumps_hbox_fall;
 	[Widget] Gtk.CheckButton extra_window_jumps_check_dj_fall_calculate;
 	[Widget] Gtk.Label extra_window_jumps_label_dj_start_inside;
@@ -45,6 +48,7 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.RadioButton extra_window_jumps_radiobutton_weight;
 	[Widget] Gtk.Label extra_window_jumps_label_weight;
 	[Widget] Gtk.CheckButton extra_window_jumps_check_dj_arms;
+	[Widget] Gtk.Button button_jumps_simple_capture_save_image;
 
 	//show weight on kg when percent is selected (SJl, CMJl, ABKl)
 	[Widget] Gtk.Label label_extra_window_jumps_radiobutton_weight_percent_as_kg;
@@ -62,6 +66,8 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.SpinButton extra_window_jumps_spin_single_leg_angle;
 	
 	//options jumps_rj
+	[Widget] Gtk.Button button_combo_jumps_rj_exercise_capture_left;
+	[Widget] Gtk.Button button_combo_jumps_rj_exercise_capture_right;
 	[Widget] Gtk.Button button_jump_type_delete_reactive;
 	[Widget] Gtk.Label extra_window_jumps_rj_label_limit;
 	[Widget] Gtk.SpinButton extra_window_jumps_rj_spinbutton_limit;
@@ -74,6 +80,8 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Label extra_window_jumps_rj_label_weight;
 	[Widget] Gtk.Label extra_window_jumps_rj_label_fall;
 	[Widget] Gtk.Label extra_window_jumps_rj_label_cm;
+	[Widget] Gtk.Label extra_window_jumps_label_rj_start_inside;
+	[Widget] Gtk.Label extra_window_jumps_label_rj_start_outside;
 	[Widget] Gtk.CheckButton checkbutton_allow_finish_rj_after_time;
 
 	
@@ -115,6 +123,29 @@ public partial class ChronoJumpWindow
 		return t;
 	}
 
+	//left-right buttons on jumps combo exercise selection
+	private void on_button_combo_jumps_exercise_capture_left_clicked (object o, EventArgs args)
+	{
+		contacts_exercise_left_button (combo_select_jumps,
+				button_combo_jumps_exercise_capture_left, button_combo_jumps_exercise_capture_right);
+	}
+	private void on_button_combo_jumps_exercise_capture_right_clicked (object o, EventArgs args)
+	{
+		contacts_exercise_right_button (combo_select_jumps,
+				button_combo_jumps_exercise_capture_left, button_combo_jumps_exercise_capture_right);
+	}
+
+	//left-right buttons on jumps_rj combo exercise selection
+	private void on_button_combo_jumps_rj_exercise_capture_left_clicked (object o, EventArgs args)
+	{
+		contacts_exercise_left_button (combo_select_jumps_rj,
+				button_combo_jumps_rj_exercise_capture_left, button_combo_jumps_rj_exercise_capture_right);
+	}
+	private void on_button_combo_jumps_rj_exercise_capture_right_clicked (object o, EventArgs args)
+	{
+		contacts_exercise_right_button (combo_select_jumps_rj,
+				button_combo_jumps_rj_exercise_capture_left, button_combo_jumps_rj_exercise_capture_right);
+	}
 
 	/*
 	 * when pre-jump from inside, dj fall is calculated
@@ -189,14 +220,19 @@ public partial class ChronoJumpWindow
 		changeTestImage(EventType.Types.JUMP.ToString(), myJumpType.Name, myJumpType.ImageFileName);
 		setLabelContactsExerciseSelected(Constants.Menuitem_modes.JUMPSSIMPLE);
 
+		LastJumpSimpleTypeParams ljstp = new LastJumpSimpleTypeParams(myJumpType.Name);
+		if(myJumpType.HasWeight || myJumpType.HasFall)
+			ljstp = SqliteJumpType.LastJumpSimpleTypeParamsSelect(myJumpType.Name); //search it on DB
 
-		if(myJumpType.HasWeight) {
+		if(myJumpType.HasWeight)
 			extra_window_showWeightData(myJumpType, true);	
-		} else 
+		else
 			extra_window_showWeightData(myJumpType, false);	
 
 		if(myJumpType.HasFall) {
 			extra_window_showFallData(myJumpType, true);
+			if(ljstp.uniqueID != -1)
+				extra_window_jumps_check_dj_fall_calculate.Active = (ljstp.fallmm == -1);
 		} else
 			extra_window_showFallData(myJumpType, false);	
 		
@@ -226,12 +262,25 @@ public partial class ChronoJumpWindow
 
 		button_jump_type_delete_simple.Sensitive = ! myJumpType.IsPredefined;
 
-		extra_window_jumps_spinbutton_weight.Value = 100;
-		extra_window_jumps_spinbutton_fall.Value = extra_window_jumps_fall;
-		if (extra_window_jumps_option == "Kg") {
-			extra_window_jumps_radiobutton_kg.Active = true;
+		if( (myJumpType.HasWeight || myJumpType.HasFall) && ljstp.uniqueID != -1) {
+			extra_window_jumps_spinbutton_weight.Value = ljstp.weightValue;
+			extra_window_jumps_spinbutton_fall.Value = ljstp.fallmm/10.0;
 		} else {
-			extra_window_jumps_radiobutton_weight.Active = true;
+			extra_window_jumps_spinbutton_weight.Value = 100;
+			extra_window_jumps_spinbutton_fall.Value = extra_window_jumps_fall;
+		}
+
+		if(myJumpType.HasWeight && ljstp.uniqueID != -1)
+		{
+			if(ljstp.weightIsPercent)
+				extra_window_jumps_radiobutton_weight.Active = true;
+			else
+				extra_window_jumps_radiobutton_kg.Active = true;
+		} else {
+			if (extra_window_jumps_option == "Kg")
+				extra_window_jumps_radiobutton_kg.Active = true;
+			else
+				extra_window_jumps_radiobutton_weight.Active = true;
 		}
 
 		extra_window_showSingleLegStuff(myJumpType.Name == "slCMJleft" || myJumpType.Name == "slCMJright");
@@ -313,6 +362,8 @@ public partial class ChronoJumpWindow
 		setLabelContactsExerciseSelected(Constants.Menuitem_modes.JUMPSREACTIVE);
 		checkbutton_allow_finish_rj_after_time.Visible = false;
 	
+		LastJumpRjTypeParams ljrtp = SqliteJumpType.LastJumpRjTypeParamsSelect(myJumpType.Name); //search it on DB
+
 		if(myJumpType.FixedValue >= 0) {
 			string jumpsName = Catalog.GetString("jumps");
 			string secondsName = Catalog.GetString("seconds");
@@ -329,7 +380,9 @@ public partial class ChronoJumpWindow
 				extra_window_jumps_rj_spinbutton_limit.Value = myJumpType.FixedValue;
 			} else {
 				extra_window_jumps_rj_spinbutton_limit.Sensitive = true;
-				extra_window_jumps_rj_spinbutton_limit.Value = extra_window_jumps_rj_limited;
+				//extra_window_jumps_rj_spinbutton_limit.Value = extra_window_jumps_rj_limited;
+				if(ljrtp.uniqueID != -1)
+					extra_window_jumps_rj_spinbutton_limit.Value = ljrtp.limitedValue;
 			}
 			extra_window_showLimitData (true);
 		} else  //unlimited
@@ -347,12 +400,27 @@ public partial class ChronoJumpWindow
 
 		button_jump_type_delete_reactive.Sensitive = ! myJumpType.IsPredefined;
 
-		extra_window_jumps_rj_spinbutton_weight.Value = extra_window_jumps_rj_weight;
-		extra_window_jumps_rj_spinbutton_fall.Value = extra_window_jumps_rj_fall;
-		if (extra_window_jumps_rj_option == "Kg") {
-			extra_window_jumps_rj_radiobutton_kg.Active = true;
+		if( (myJumpType.HasWeight || myJumpType.HasFall) && ljrtp.uniqueID != -1) {
+			extra_window_jumps_rj_spinbutton_weight.Value = ljrtp.weightValue;
+			extra_window_jumps_rj_spinbutton_fall.Value = ljrtp.fallmm/10.0;
 		} else {
-			extra_window_jumps_rj_radiobutton_weight.Active = true;
+			extra_window_jumps_rj_spinbutton_weight.Value = extra_window_jumps_rj_weight;
+			extra_window_jumps_rj_spinbutton_fall.Value = extra_window_jumps_rj_fall;
+		}
+
+		if(ljrtp.uniqueID != -1)
+		{
+			LogB.Information("ljrtp.weightIsPercent: " + ljrtp.weightIsPercent.ToString());
+			if(ljrtp.weightIsPercent)
+				extra_window_jumps_rj_radiobutton_weight.Active = true;
+			else
+				extra_window_jumps_rj_radiobutton_kg.Active = true;
+		}
+		else {
+			if (extra_window_jumps_rj_option == "Kg")
+				extra_window_jumps_rj_radiobutton_kg.Active = true;
+			else
+				extra_window_jumps_rj_radiobutton_weight.Active = true;
 		}
 
 		if(! configChronojump.Exhibition)
@@ -447,16 +515,23 @@ public partial class ChronoJumpWindow
 		extra_window_jumps_check_dj_arms.Sensitive = sensitive;
 	}
 	
-	private void extra_window_showFallData (JumpType myJumpType, bool show) {
-		if(myJumpType.IsRepetitive) {
+	private void extra_window_showFallData (JumpType myJumpType, bool show)
+	{
+		if(myJumpType.IsRepetitive)
+		{
 			extra_window_jumps_rj_label_fall.Visible = show;
 			extra_window_jumps_rj_spinbutton_fall.Visible = show;
 			extra_window_jumps_rj_label_cm.Visible = show;
+
+			extra_window_jumps_label_rj_start_inside.Visible = ! show;
+			extra_window_jumps_label_rj_start_outside.Visible = show;
 		
 			//only on simple jumps	
 			extra_window_jumps_hbox_fall.Visible = false;
-		} else 
+		} else {
+			extra_window_jumps_simple_hbox_start_inside.Visible = ! show;
 			extra_window_jumps_hbox_fall.Visible = show;
+		}
 	}
 	
 	private void extra_window_showLimitData (bool show) {
@@ -595,6 +670,36 @@ public partial class ChronoJumpWindow
 		notebook_contacts_capture_doing_wait.CurrentPage = 0;
 	}
 
+	// ---- save jumps simple image start ---->
+
+	private void on_button_jumps_simple_capture_save_image_clicked (object o, EventArgs args)
+	{
+		checkFile(Constants.CheckFileOp.JUMPS_SIMPLE_CAPTURE_SAVE_IMAGE);
+	}
+
+	private void on_button_jumps_simple_capture_save_image_selected (string destination)
+	{
+		if(event_execute_drawingarea == null)
+			return;
+
+		Gdk.Pixbuf pixbuf = Gdk.Pixbuf.FromDrawable(event_execute_drawingarea.GdkWindow, Gdk.Colormap.System,
+				0, 0, 0, 0,
+				UtilGtk.WidgetWidth(event_execute_drawingarea),
+				UtilGtk.WidgetHeight(event_execute_drawingarea) );
+
+		LogB.Information("Saving");
+		pixbuf.Save(destination,"png");
+	}
+	private void on_overwrite_file_jumps_simple_capture_save_image_accepted (object o, EventArgs args)
+	{
+		on_button_jumps_simple_capture_save_image_selected (exportFileName);
+
+		string myString = string.Format(Catalog.GetString("Saved to {0}"), exportFileName);
+		new DialogMessage(Constants.MessageTypes.INFO, myString);
+	}
+
+	// <---- save jumps simple image end ----
+
 }
 
 
