@@ -15,12 +15,13 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2018-2020   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2018-2021   Xavier de Blas <xaviblas@gmail.com>
  */
 
 //this file has methods of ChronoJumpWindow related to manage menu
 
 using System;
+using Gdk;
 using Gtk;
 using Glade;
 using System.Collections.Generic; //List
@@ -37,6 +38,7 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Alignment alignment_viewport_menu_top;
 	[Widget] Gtk.Viewport viewport_send_log;
 	[Widget] Gtk.Viewport viewport_exit_confirm;
+	[Widget] Gtk.Viewport viewport_social_network_poll;
 	[Widget] Gtk.Viewport viewport_start_modes;
 	[Widget] Gtk.Viewport viewport_menu_top;
 	[Widget] Gtk.Viewport viewport_menu;
@@ -49,9 +51,11 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.EventBox eventbox_button_menu_session_more;
 	[Widget] Gtk.EventBox eventbox_button_menu_preferences;
 	[Widget] Gtk.EventBox eventbox_button_menu_help;
+	[Widget] Gtk.EventBox eventbox_button_menu_news;
 	[Widget] Gtk.EventBox eventbox_button_menu_exit;
 	[Widget] Gtk.CheckButton check_menu_session;
 	[Widget] Gtk.Button button_menu_help;
+	[Widget] Gtk.Button button_menu_news;
 	[Widget] Gtk.VBox vbox_menu_session;
 	[Widget] Gtk.Alignment alignment_menu_session_options;
 	[Widget] Gtk.Alignment alignment_menu_person_options;
@@ -65,6 +69,7 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Button button_menu_help_documents;
 	[Widget] Gtk.Button button_menu_help_shortcuts;
 	[Widget] Gtk.Button button_menu_help_about;
+	[Widget] Gtk.Button button_menu_guiTest;
 
 	//just to manage width
 	[Widget] Gtk.HButtonBox hbuttonbox_person_admin_create;
@@ -89,6 +94,7 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_menu_help_documents;
 	[Widget] Gtk.Image image_menu_help_shortcuts;
 	[Widget] Gtk.Image image_menu_help_about;
+	[Widget] Gtk.Image image_menu_news;
 	[Widget] Gtk.Image image_menu_quit;
 
 	private void initialize_menu_or_menu_tiny()
@@ -104,8 +110,11 @@ public partial class ChronoJumpWindow
 		alignment_buttons_menu_and_persons.Sensitive = sensitive;
 		viewport_menu.Sensitive = sensitive;
 		vbox_menu_tiny_menu.Sensitive = sensitive;
-		button_show_modes_contacts.Sensitive = sensitive;
-		button_show_modes_encoder.Sensitive = sensitive;
+
+		//button_show_modes_contacts.Sensitive = sensitive;
+		hbox_change_modes_contacts.Sensitive = sensitive;
+		//button_show_modes_encoder.Sensitive = sensitive;
+		hbox_change_modes_encoder.Sensitive = sensitive;
 	}
 
 	/* if import started we need to reload at the end
@@ -146,6 +155,7 @@ public partial class ChronoJumpWindow
 		//menus
 		l.Add(check_menu_session.SizeRequest().Width);
 		l.Add(button_menu_help.SizeRequest().Width);
+		l.Add(button_menu_news.SizeRequest().Width);
 		l.Add(button_menu_exit.SizeRequest().Width);
 		l.Add(button_menu_preferences.SizeRequest().Width);
 
@@ -221,6 +231,7 @@ public partial class ChronoJumpWindow
 		image_menu_help_documents.Visible = preferences.menuType != Preferences.MenuTypes.TEXT;
 		image_menu_help_shortcuts.Visible = preferences.menuType != Preferences.MenuTypes.TEXT;
 		image_menu_help_about.Visible = preferences.menuType != Preferences.MenuTypes.TEXT;
+		image_menu_news.Visible = preferences.menuType != Preferences.MenuTypes.TEXT;
 		image_menu_quit.Visible = preferences.menuType != Preferences.MenuTypes.TEXT;
 	}
 
@@ -237,6 +248,7 @@ public partial class ChronoJumpWindow
 			UtilGtk.WindowColor(app1, color);
 			UtilGtk.ViewportColor(viewport_send_log, color);
 			UtilGtk.ViewportColor(viewport_exit_confirm, color);
+			UtilGtk.ViewportColor(viewport_social_network_poll, color);
 			UtilGtk.ViewportColor(viewport_menu_top, color);
 			UtilGtk.ViewportColor(viewport_menu, color);
 		}
@@ -251,6 +263,7 @@ public partial class ChronoJumpWindow
 		UtilGtk.EventBoxColorBackgroundActive (eventbox_check_menu_session, UtilGtk.YELLOW, UtilGtk.YELLOW_LIGHT);
 		UtilGtk.EventBoxColorBackgroundActive (eventbox_button_menu_preferences, UtilGtk.YELLOW, UtilGtk.YELLOW_LIGHT);
 		UtilGtk.EventBoxColorBackgroundActive (eventbox_button_menu_help, UtilGtk.YELLOW, UtilGtk.YELLOW_LIGHT);
+		UtilGtk.EventBoxColorBackgroundActive (eventbox_button_menu_news, UtilGtk.YELLOW, UtilGtk.YELLOW_LIGHT);
 		UtilGtk.EventBoxColorBackgroundActive (eventbox_button_menu_exit, UtilGtk.YELLOW, UtilGtk.YELLOW_LIGHT);
 
 		UtilGtk.EventBoxColorBackgroundActive (eventbox_button_menu_session_new, UtilGtk.YELLOW, UtilGtk.YELLOW_LIGHT);
@@ -292,13 +305,27 @@ public partial class ChronoJumpWindow
 		app1s_notebook_sup_entered_from = notebook_sup.CurrentPage;
 		notebook_sup.CurrentPage = Convert.ToInt32(notebook_sup_pages.HELP);
 	}
-
 	private void on_button_help_close_clicked (object o, EventArgs args)
 	{
 		menus_and_mode_sensitive(true);
 		notebook_sup.CurrentPage = app1s_notebook_sup_entered_from;
 	}
 
+	private void on_button_menu_news_clicked (object o, EventArgs args)
+	{
+		newsGetThreadPrepare();
+	}
+	private void on_button_news_close_clicked (object o, EventArgs args)
+	{
+		menus_and_mode_sensitive(true);
+		notebook_sup.CurrentPage = app1s_notebook_sup_entered_from;
+
+		//put default news store icon because window has been opened (and hopefully seen)
+		Pixbuf pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_store_blue.png");
+		image_menu_news.Pixbuf = pixbuf;
+		image_menu_news1.Pixbuf = pixbuf;
+	}
+
 	private int getMenuButtonsMaxWidth(List<int> l)
 	{
 		int max = 0;
