@@ -33,13 +33,18 @@ using Mono.Unix;
 public partial class ChronoJumpWindow
 {
 	//options runs
+	[Widget] Gtk.Button button_combo_runs_exercise_capture_left;
+	[Widget] Gtk.Button button_combo_runs_exercise_capture_right;
 	[Widget] Gtk.Button button_run_type_delete_simple;
 	[Widget] Gtk.CheckButton check_run_simple_with_reaction_time;
 	[Widget] Gtk.Button button_runs_simple_track_distance;
 	[Widget] Gtk.Label label_runs_simple_track_distance_value;
 	[Widget] Gtk.Label label_runs_simple_track_distance_units;
+	[Widget] Gtk.Button button_runs_simple_capture_save_image;
 
 	//options runs interval
+	[Widget] Gtk.Button button_combo_runs_interval_exercise_capture_left;
+	[Widget] Gtk.Button button_combo_runs_interval_exercise_capture_right;
 	[Widget] Gtk.Button button_run_type_delete_interval;
 	[Widget] Gtk.Button button_runs_interval_track_distance;
 	[Widget] Gtk.Label label_runs_interval_track_distance_value;
@@ -75,6 +80,33 @@ public partial class ChronoJumpWindow
 		return t;
 	}
 	
+	//left-right buttons on runs combo exercise selection
+	private void on_button_combo_runs_exercise_capture_left_clicked (object o, EventArgs args)
+	{
+		contacts_exercise_left_button (combo_select_runs,
+				button_combo_runs_exercise_capture_left,
+				button_combo_runs_exercise_capture_right);
+	}
+	private void on_button_combo_runs_exercise_capture_right_clicked (object o, EventArgs args)
+	{
+		contacts_exercise_right_button (combo_select_runs,
+				button_combo_runs_exercise_capture_left,
+				button_combo_runs_exercise_capture_right);
+	}
+
+	//left-right buttons on runs_interval combo exercise selection
+	private void on_button_combo_runs_interval_exercise_capture_left_clicked (object o, EventArgs args)
+	{
+		contacts_exercise_left_button (combo_select_runs_interval,
+				button_combo_runs_interval_exercise_capture_left,
+				button_combo_runs_interval_exercise_capture_right);
+	}
+	private void on_button_combo_runs_interval_exercise_capture_right_clicked (object o, EventArgs args)
+	{
+		contacts_exercise_right_button (combo_select_runs_interval,
+				button_combo_runs_interval_exercise_capture_left,
+				button_combo_runs_interval_exercise_capture_right);
+	}
 	
 	private void on_extra_window_runs_test_changed(object o, EventArgs args)
 	{
@@ -415,12 +447,43 @@ public partial class ChronoJumpWindow
 	private void on_button_run_with_reaction_time_help_clicked (object o, EventArgs args)
 	{
 		new DialogMessage(Constants.MessageTypes.INFO,
-				"\nThis feature need a new Chronojump device under development." +
+				"\nThis feature needs a new Chronojump device under development." +
 				"\n\nTest will start when person is at start pad and push button is pressed" +
 				"\nreaction time will be in ms and as a comment on Description"
 				);
 	}
 
+
+	// ---- save runs simple image start ---->
+
+	private void on_button_runs_simple_capture_save_image_clicked (object o, EventArgs args)
+	{
+		checkFile(Constants.CheckFileOp.RUNS_SIMPLE_CAPTURE_SAVE_IMAGE);
+	}
+
+	private void on_button_runs_simple_capture_save_image_selected (string destination)
+	{
+		if(event_execute_drawingarea == null)
+			return;
+
+		Gdk.Pixbuf pixbuf = Gdk.Pixbuf.FromDrawable(event_execute_drawingarea.GdkWindow, Gdk.Colormap.System,
+				0, 0, 0, 0,
+				UtilGtk.WidgetWidth(event_execute_drawingarea),
+				UtilGtk.WidgetHeight(event_execute_drawingarea) );
+
+		LogB.Information("Saving");
+		pixbuf.Save(destination,"png");
+	}
+	private void on_overwrite_file_runs_simple_capture_save_image_accepted (object o, EventArgs args)
+	{
+		on_button_runs_simple_capture_save_image_selected (exportFileName);
+
+		string myString = string.Format(Catalog.GetString("Saved to {0}"), exportFileName);
+		new DialogMessage(Constants.MessageTypes.INFO, myString);
+	}
+
+	// <---- save runs simple image end ----
+
 }
 
 
