@@ -29,6 +29,7 @@ using System.Text; //StringBuilder
 using System.Collections;
 using System.Collections.Generic; //List<T>
 using System.Text.RegularExpressions; //Regex
+using System.Diagnostics;  //Stopwatch
 using Mono.Unix;
 
 
@@ -36,6 +37,8 @@ public partial class ChronoJumpWindow
 {
 	//[Widget] Gtk.CheckMenuItem menuitem_check_race_encoder_capture_simulate;
 
+	[Widget] Gtk.Button button_combo_run_encoder_exercise_capture_left;
+	[Widget] Gtk.Button button_combo_run_encoder_exercise_capture_right;
 	[Widget] Gtk.VBox vbox_run_encoder_capture_buttons;
 	[Widget] Gtk.VBox vbox_run_encoder_capture_options;
 	[Widget] Gtk.HBox hbox_combo_run_encoder_exercise;
@@ -45,6 +48,13 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.ComboBox combo_race_analyzer_device;
 	[Widget] Gtk.Image image_run_encoder_graph;
 	[Widget] Gtk.Viewport viewport_run_encoder_graph;
+	[Widget] Gtk.TreeView treeview_raceAnalyzer;
+	[Widget] Gtk.Button button_raceAnalyzer_table_save;
+	//[Widget] Gtk.Label label_race_analyzer_capture_speed;
+	[Widget] Gtk.DrawingArea drawingarea_race_analyzer_capture;
+	[Widget] Gtk.DrawingArea drawingarea_race_analyzer_capture_position_time;
+	[Widget] Gtk.DrawingArea drawingarea_race_analyzer_capture_speed_time;
+	[Widget] Gtk.DrawingArea drawingarea_race_analyzer_capture_accel_time;
 
 	int race_analyzer_distance;
 	int race_analyzer_temperature;
@@ -56,11 +66,13 @@ public partial class ChronoJumpWindow
 	static bool runEncoderProcessCancel;
 	static bool runEncoderProcessError;
         static string runEncoderPulseMessage = "";
+	static bool runEncoderShouldShowCaptureGraphsWithData; //on change person this is false
 	
 	private RunEncoder currentRunEncoder;
 	private RunEncoderExercise currentRunEncoderExercise;
 	DateTime runEncoderTimeStartCapture;
 	bool runEncoderCaptureSimulated;
+	string runEncoderFirmwareVersion;
 
 	static string lastRunEncoderFile = "";
 	static string lastRunEncoderFullPath = "";
@@ -91,6 +103,9 @@ public partial class ChronoJumpWindow
 		createRunEncoderExerciseCombo();
 		createRunEncoderAnalyzeCombos();
 		setRunEncoderAnalyzeWidgets();
+
+		spinbutton_run_encoder_export_image_width.Value = preferences.exportGraphWidth;
+		spinbutton_run_encoder_export_image_height.Value = preferences.exportGraphHeight;
 	}
 
 	//no GTK here
@@ -132,8 +147,8 @@ public partial class ChronoJumpWindow
 
 		LogB.Information(" RE connect 6: get version");
 
-		string version = runEncoderCheckVersionDo();
-		LogB.Information("Version found: [" + version + "]");
+		runEncoderFirmwareVersion = runEncoderCheckVersionDo();
+		LogB.Information("Version found: [" + runEncoderFirmwareVersion + "]");
 
 		portREOpened = true;
 		runEncoderPulseMessage = "Connected!";
@@ -207,6 +222,23 @@ public partial class ChronoJumpWindow
 		return true;
 	}
 
+	private string runEncoderReceiveFeedback(string expected)
+	{
+		string str = "";
+		do {
+			Thread.Sleep(100); //sleep to let arduino start reading
+			try {
+				str = portRE.ReadLine();
+			} catch {
+				runEncoderProcessError = true;
+				return "";
+			}
+			LogB.Information("runEncoder feedback string: " + str);
+		}
+		while(! str.Contains(expected));
+		return str;
+	}
+
 	private void on_runs_encoder_capture_clicked ()
 	{
 		if(UtilGtk.ComboGetActive(combo_run_encoder_exercise) == "")
@@ -221,17 +253,36 @@ public partial class ChronoJumpWindow
 			return;
 		}
 
+		/*
 		if(currentPersonSession.Height == 0)
 		{
 			new DialogMessage(Constants.MessageTypes.WARNING,
 					Catalog.GetString("Error, height of the person cannot be 0"));
 			return;
 		}
+		allow to do the capture, but after show message: no height
+		*/
 
 		runEncoderPulseMessage = "";
 		runEncoderButtonsSensitive(false);
 		sensitiveLastTestButtons(false);
 
+		//reset capture tab graphs
+		if(cairoRadial != null)
+			cairoRadial.ResetSpeedMax();
+
+		//blank Cairo scatterplot graphs
+		cairoGraphRaceAnalyzer_dt = null;
+		cairoGraphRaceAnalyzer_st = null;
+		cairoGraphRaceAnalyzer_at = null;
+		cairoGraphRaceAnalyzerPoints_dt_l = new List<PointF>();
+		cairoGraphRaceAnalyzerPoints_st_l = new List<PointF>();
+		cairoGraphRaceAnalyzerPoints_at_l = new List<PointF>();
+		updateRaceAnalyzerCapturePositionTime(true);
+		updateRaceAnalyzerCaptureSpeedTime(true);
+		updateRaceAnalyzerCaptureAccelTime(true);
+
+
 		if(chronopicRegister.NumConnectedOfType(ChronopicRegisterPort.Types.ARDUINO_RUN_ENCODER) == 0)
 		{
 			event_execute_label_message.Text = runEncoderNotConnectedString;
@@ -255,6 +306,10 @@ public partial class ChronoJumpWindow
 		raceEncoderReadWidgets();
 		button_contacts_exercise_close_and_recalculate.Sensitive = false;
 
+		//remove stuff on analyze tab
+		image_run_encoder_graph.Visible = false;
+		treeview_raceAnalyzer = UtilGtk.RemoveColumns(treeview_raceAnalyzer);
+
 		bool connected = runEncoderCapturePre4_GTK();
 		if(! connected)
 			runEncoderButtonsSensitive(true);
@@ -268,14 +323,43 @@ public partial class ChronoJumpWindow
 	{
 		currentRunEncoder = new RunEncoder();
 
+		//draw the capture graphs empty:
+		//a) radial
+		runEncoderShouldShowCaptureGraphsWithData = false;
+		drawingarea_race_analyzer_capture.QueueDraw(); //will fire ExposeEvent
+		//b) scatterplots
+		cairoGraphRaceAnalyzerPoints_dt_l = new List<PointF>();
+		cairoGraphRaceAnalyzerPoints_st_l = new List<PointF>();
+		cairoGraphRaceAnalyzerPoints_at_l = new List<PointF>();
+		drawingarea_race_analyzer_capture_position_time.QueueDraw(); //will fire ExposeEvent
+		drawingarea_race_analyzer_capture_speed_time.QueueDraw(); //will fire ExposeEvent
+		drawingarea_race_analyzer_capture_accel_time.QueueDraw(); //will fire ExposeEvent
+
 		button_contacts_exercise_close_and_recalculate.Sensitive = false;
 		textview_contacts_signal_comment.Buffer.Text = "";
-		image_run_encoder_graph.Sensitive = false;
 
-		button_run_encoder_analyze_options.Sensitive = false;
+		//image_run_encoder_graph.Sensitive = false; //this is not useful at all
+		image_run_encoder_graph.Visible = false;
+
+		treeview_raceAnalyzer = UtilGtk.RemoveColumns(treeview_raceAnalyzer);
+		button_raceAnalyzer_table_save.Sensitive = false;
+		clearRaceAnalyzerTriggers();
+
+		button_run_encoder_analyze_options_close_and_analyze.Sensitive = false;
 		button_run_encoder_analyze_analyze.Sensitive = false;
 		button_delete_last_test.Sensitive = false;
 		button_run_encoder_image_save.Sensitive = false;
+
+		if(radio_run_encoder_analyze_individual_current_session.Active)
+		{
+			if(currentPerson != null)
+				label_run_encoder_export_data.Text = currentPerson.Name;
+			else
+				label_run_encoder_export_data.Text = "";
+		}
+
+		label_run_encoder_export_result.Text = "";
+		button_run_encoder_export_result_open.Visible = false;
 	}
 
 	private void raceEncoderReadWidgets()
@@ -376,15 +460,32 @@ public partial class ChronoJumpWindow
 		event_execute_ButtonCancel.Clicked -= new EventHandler(on_cancel_clicked);
 		event_execute_ButtonCancel.Clicked += new EventHandler(on_cancel_clicked);
 
+		cairoGraphRaceAnalyzerPoints_dt_l = new List<PointF>();
+		cairoGraphRaceAnalyzerPoints_st_l = new List<PointF>();
+		cairoGraphRaceAnalyzerPoints_at_l = new List<PointF>();
+
+		//RunEncoderCaptureGetSpeedAndDisplacement reCGSD = new RunEncoderCaptureGetSpeedAndDisplacement();
+		reCGSD = new RunEncoderCaptureGetSpeedAndDisplacement();
+		runEncoderShouldShowCaptureGraphsWithData = true;
+
 		runEncoderCaptureThread = new Thread(new ThreadStart(runEncoderCaptureDo));
 		GLib.Idle.Add (new GLib.IdleHandler (pulseGTKRunEncoderCapture));
 
+		if(preferences.debugMode)
+			LogB.Information("Debug mode active. Logs active while race analyzer capture");
+		else
+			LogB.Information("Debug mode inactive. Logs INactive while race analyzer capture");
+
+		//mute logs if ! debug mode
+		LogB.Mute = ! preferences.debugMode;
+
 		LogB.ThreadStart();
 		runEncoderCaptureThread.Start();
 		return true;
 	}
 
 	string capturingMessage = "Capturing ...";
+	static RunEncoderCaptureGetSpeedAndDisplacement reCGSD;
 
 	//non GTK on this method
 	private void runEncoderCaptureDo()
@@ -397,6 +498,17 @@ public partial class ChronoJumpWindow
 
 		lastChangedTime = 0;
 
+                double versionDouble = Convert.ToDouble(Util.ChangeDecimalSeparator(runEncoderFirmwareVersion));
+		if(versionDouble >= Convert.ToDouble(Util.ChangeDecimalSeparator("0.3")))
+		{
+			if(! runEncoderSendCommand(string.Format("set_pps:{0};", preferences.runEncoderPPS), "Sending pps", "Catched at set_pps"))
+				return;
+
+			//read confirmation data
+			if(runEncoderReceiveFeedback("pps set to") == "")
+				return;
+		}
+
 		string command = "start_capture:";
 		if(runEncoderCaptureSimulated)
 			command = "start_simulation:";
@@ -453,8 +565,14 @@ public partial class ChronoJumpWindow
 		writer.WriteLine("Pulses;Time(useconds);Force(N)");
 
 		triggerListRunEncoder = new TriggerList();
-		str = "";
-		int firstTime = 0;
+		Stopwatch sw = new Stopwatch();
+
+		//to measure accel (having 3 samples)
+		//TODO: store on reCGSD
+		double speedPre2 = -1;
+		double timePre2 = -1;
+		double speedPre = -1;
+		double timePre = -1;
 
 		int rowsCount = 0;
 		while(! runEncoderProcessFinish && ! runEncoderProcessCancel && ! runEncoderProcessError)
@@ -474,31 +592,74 @@ public partial class ChronoJumpWindow
 			 */
 
 			if (portRE.BytesToRead == 0)
+			{
+				//runEncoder sends changes. If there is no movement in certain time, just show a 0 on screen and capture graph
+				if(sw.ElapsedMilliseconds > 500)
+				{
+					reCGSD.RunEncoderCaptureSpeed = 0;
+					sw.Stop();
+				}
+
 				continue;
+			}
 
 			//time (4 bytes: long at Arduino, uint at c-sharp), force (2 bytes: uint)
 			List<int> binaryReaded = readBinaryRunEncoderValues();
-			int encoderDisplacement = binaryReaded[0];
-			int time = binaryReaded[1];
-			int force = binaryReaded[2];
-			int encoderOrRCA = binaryReaded[3];
+			reCGSD.PassCapturedRow (binaryReaded);
+			if(reCGSD.Calcule() && reCGSD.EncoderDisplacement != 0) //this 0s are triggers without displacement
+			{
+				//distance/time
+				cairoGraphRaceAnalyzerPoints_dt_l.Add(new PointF(
+							UtilAll.DivideSafe(reCGSD.Time, 1000000),
+							reCGSD.RunEncoderCaptureDistance));
+				//speed/time
+				cairoGraphRaceAnalyzerPoints_st_l.Add(new PointF(
+							UtilAll.DivideSafe(reCGSD.Time, 1000000),
+							reCGSD.RunEncoderCaptureSpeed));
 
-			LogB.Information(string.Format("{0};{1};{2};{3};{4}", pps, encoderDisplacement, time, force, encoderOrRCA));
-			writer.WriteLine(string.Format("{0};{1};{2}", encoderDisplacement, time, force));
-			if(encoderOrRCA == 0)
+				speedPre2 = speedPre;
+				timePre2 = timePre;
+				speedPre = reCGSD.RunEncoderCaptureSpeed;
+				timePre = UtilAll.DivideSafe(reCGSD.Time, 1000000);
+
+				if(timePre2 > 0)
+				{
+					LogB.Information(string.Format("accel at capture is: {0} m/s",
+								UtilAll.DivideSafe(reCGSD.RunEncoderCaptureSpeed - speedPre2,
+									UtilAll.DivideSafe(reCGSD.Time, 1000000) - timePre2)));
+
+					//accel/time
+					cairoGraphRaceAnalyzerPoints_at_l.Add(new PointF(
+								UtilAll.DivideSafe(reCGSD.Time, 1000000),
+								UtilAll.DivideSafe(reCGSD.RunEncoderCaptureSpeed - speedPre2,
+									UtilAll.DivideSafe(reCGSD.Time, 1000000) - timePre2)));
+				}
+
+				sw.Restart();
+			}
+
+			LogB.Information(string.Format("{0};{1};{2};{3};{4}", pps, reCGSD.EncoderDisplacement, reCGSD.Time, reCGSD.Force, reCGSD.EncoderOrRCA));
+
+			if(reCGSD.EncoderDisplacement == 0)
+				LogB.Information("It is a trigger and without displacement, do not write it to file");
+			else
+				writer.WriteLine(string.Format("{0};{1};{2}", reCGSD.EncoderDisplacement, reCGSD.Time, reCGSD.Force));
+
+			if(reCGSD.EncoderOrRCA == 0)
 				rowsCount ++; //note this is not used right now, and maybe it will need to be for all cases, not just for encoderOrRCA
 			else {
 				Trigger trigger;
-				if(encoderOrRCA == 1)
-					trigger = new Trigger(Trigger.Modes.RACEANALYZER, time, false);
-				else //(encoderOrRCA == 2)
-					trigger = new Trigger(Trigger.Modes.RACEANALYZER, time, true);
+				if(reCGSD.EncoderOrRCA == 1)
+					trigger = new Trigger(Trigger.Modes.RACEANALYZER, reCGSD.Time, false);
+				else //(reCGSD.EncoderOrRCA == 2)
+					trigger = new Trigger(Trigger.Modes.RACEANALYZER, reCGSD.Time, true);
 
 				if(! triggerListRunEncoder.NewSameTypeThanBefore(trigger) &&
-						! triggerListRunEncoder.IsSpurious(trigger, TriggerList.Type3.BOTH, 50))
+						! triggerListRunEncoder.IsSpurious(trigger, TriggerList.Type3.BOTH, 50000))
 					triggerListRunEncoder.Add(trigger);
 			}
 		}
+		sw.Stop();
 
 		LogB.Information(string.Format("FINISHED WITH conditions: {0}-{1}-{2}",
 						runEncoderProcessFinish, runEncoderProcessCancel, runEncoderProcessError));
@@ -523,7 +684,7 @@ public partial class ChronoJumpWindow
 				 * note this can make the rowsCount differ
 				 */
 			} catch {
-				LogB.Information("Catched waiting end_capture feedback");
+				LogB.Information("Caught waiting end_capture feedback");
 			}
 			LogB.Information("waiting \"Capture ended\" string: " + str);
 		}
@@ -533,7 +694,7 @@ public partial class ChronoJumpWindow
 		string [] strEnded = str.Split(new char[] {':'});
 		if(strEnded.Length == 2 && Util.IsNumber(strEnded[1], false))
 		{
-			LogB.Information(string.Format("Readed {0} rows, sended {1} rows, match: {2}",
+			LogB.Information(string.Format("Read {0} rows, sent {1} rows, match: {2}",
 						rowsCount, strEnded[1], rowsCount == Convert.ToInt32(strEnded[1]) ));
 		}
 
@@ -551,7 +712,7 @@ public partial class ChronoJumpWindow
 			File.Copy(fileName, RunEncoder.GetCSVFileName(), true); //can be overwritten
 			lastRunEncoderFullPath = fileName;
 
-			//raceEncoderCaptureGraphDo(); moved to pulseGTKRunEncoderCapture () where currentRunEncoder is created
+			//raceEncoderCaptureRGraphDo(); moved to pulseGTKRunEncoderCapture () where currentRunEncoder is created
 
 			capturingRunEncoder = arduinoCaptureStatus.COPIED_TO_TMP;
 		}
@@ -646,18 +807,18 @@ public partial class ChronoJumpWindow
 
 	private void run_encoder_load ()
 	{
-		ArrayList data = SqliteRunEncoder.Select(false, -1, currentPerson.UniqueID, currentSession.UniqueID);
+		List<RunEncoder> data = SqliteRunEncoder.Select(false, -1, currentPerson.UniqueID, currentSession.UniqueID);
 
 		ArrayList dataPrint = new ArrayList();
 		int count = 1;
 		foreach(RunEncoder re in data)
-			dataPrint.Add(re.ToStringArray(count++));
+			dataPrint.Add(re.ToStringArray(false, count++));
 
 		string [] columnsString = {
 			Catalog.GetString("ID"),
 			Catalog.GetString("Set"),
 			Catalog.GetString("Exercise"),
-			Catalog.GetString("Device"),
+			//Catalog.GetString("Device"),
 			Catalog.GetString("Distance"),
 			Catalog.GetString("Date"),
 			Catalog.GetString("Video"),
@@ -724,9 +885,9 @@ public partial class ChronoJumpWindow
 		int uniqueID = genericWin.TreeviewSelectedRowID();
 
 		genericWin.HideAndNull();
+		radio_run_encoder_analyze_individual_current_set.Active = true;
 
-		ArrayList data = SqliteRunEncoder.Select(false, uniqueID, currentPerson.UniqueID, currentSession.UniqueID);
-		RunEncoder re = (RunEncoder) data[0];
+		RunEncoder re = (RunEncoder) SqliteRunEncoder.Select(false, uniqueID, currentPerson.UniqueID, currentSession.UniqueID)[0];
 		if(re == null)
 		{
 			new DialogMessage(Constants.MessageTypes.WARNING, Constants.FileNotFoundStr());
@@ -740,6 +901,7 @@ public partial class ChronoJumpWindow
 		}
 
 		List<string> contents = Util.ReadFileAsStringList(re.FullURL);
+		LogB.Information("FullURL: " + re.FullURL);
 		if(contents.Count < 3)
 		{
 			new DialogMessage(Constants.MessageTypes.WARNING, Constants.FileEmptyStr());
@@ -768,7 +930,83 @@ public partial class ChronoJumpWindow
 				);
 		showRaceAnalyzerTriggers ();
 
-		raceEncoderCopyTempAndDoGraphs();
+		// ---- capture tab graphs start ---->
+
+		int count = 0;
+		reCGSD = new RunEncoderCaptureGetSpeedAndDisplacement();
+		runEncoderShouldShowCaptureGraphsWithData = true;
+
+		cairoGraphRaceAnalyzer_dt = null;
+		cairoGraphRaceAnalyzer_st = null;
+		cairoGraphRaceAnalyzer_at = null;
+		cairoGraphRaceAnalyzerPoints_dt_l = new List<PointF>();
+		cairoGraphRaceAnalyzerPoints_st_l = new List<PointF>();
+		cairoGraphRaceAnalyzerPoints_at_l = new List<PointF>();
+
+		//to measure accel (having 3 samples)
+		//TODO: store on reCGSD
+		double speedPre2 = -1;
+		double timePre2 = -1;
+		double speedPre = -1;
+		double timePre = -1;
+
+		foreach(string row in contents)
+		{
+			LogB.Information("row: " + row);
+			if(count < 3)
+			{
+				count ++;
+				continue;
+			}
+
+			if(reCGSD.PassLoadedRow (row))
+				reCGSD.Calcule();
+
+			//distance/time
+			cairoGraphRaceAnalyzerPoints_dt_l.Add(new PointF(
+						UtilAll.DivideSafe(reCGSD.Time, 1000000),
+						reCGSD.RunEncoderCaptureDistance));
+			//speed/time
+			cairoGraphRaceAnalyzerPoints_st_l.Add(new PointF(
+						UtilAll.DivideSafe(reCGSD.Time, 1000000),
+						reCGSD.RunEncoderCaptureSpeed));
+
+			speedPre2 = speedPre;
+			timePre2 = timePre;
+			speedPre = reCGSD.RunEncoderCaptureSpeed;
+			timePre = UtilAll.DivideSafe(reCGSD.Time, 1000000);
+
+			if(timePre2 > 0)
+			{
+				LogB.Information(string.Format("accel at load is: {0} m/s",
+							UtilAll.DivideSafe(reCGSD.RunEncoderCaptureSpeed - speedPre2,
+								UtilAll.DivideSafe(reCGSD.Time, 1000000) - timePre2)));
+
+				//accel/time
+				cairoGraphRaceAnalyzerPoints_at_l.Add(new PointF(
+							UtilAll.DivideSafe(reCGSD.Time, 1000000),
+							UtilAll.DivideSafe(reCGSD.RunEncoderCaptureSpeed - speedPre2,
+								UtilAll.DivideSafe(reCGSD.Time, 1000000) - timePre2)));
+			}
+
+		}
+		if(reCGSD.RunEncoderCaptureSpeedMax > 0)
+		{
+			if(cairoRadial == null)
+				cairoRadial = new CairoRadial(drawingarea_race_analyzer_capture, preferences.fontType.ToString());
+			cairoRadial.GraphSpeedMaxAndDistance(reCGSD.RunEncoderCaptureSpeedMax, reCGSD.RunEncoderCaptureDistance);
+
+			updateRaceAnalyzerCapturePositionTime(true);
+			updateRaceAnalyzerCaptureSpeedTime(true);
+			updateRaceAnalyzerCaptureAccelTime(true);
+		}
+
+		// <---- capture tab graphs end ----
+
+		//on load do the R graph, but not on capture, to show on capture the label related to lack of person height
+		//raceEncoderCopyToTempAndDoRGraph();
+		//no do not do it automatically, just make user click on analyze button
+		//also showing that graph while analyze tab has not shown first time is buggy
 
 		button_contacts_exercise_close_and_recalculate.Sensitive = true;
 
@@ -776,7 +1014,9 @@ public partial class ChronoJumpWindow
 		sensitiveLastTestButtons(true);
 
 		event_execute_label_message.Text = "Loaded: " + Util.GetLastPartOfPath(re.Filename);
-		button_run_encoder_analyze_options.Sensitive = true;
+		image_run_encoder_graph.Visible = false;
+		button_run_encoder_analyze_analyze.Sensitive = true;
+		button_run_encoder_analyze_options_close_and_analyze.Sensitive = true;
 		button_run_encoder_image_save.Sensitive = true;
 	}
 
@@ -919,7 +1159,7 @@ public partial class ChronoJumpWindow
 
 		raceEncoderReadWidgets();
 		if(lastRunEncoderFullPath != null && lastRunEncoderFullPath != "")
-			raceEncoderCopyTempAndDoGraphs();
+			raceEncoderCopyToTempAndDoRGraph();
 
 		event_execute_label_message.Text = "Recalculated.";
 		radio_mode_contacts_analyze.Active = true;
@@ -937,21 +1177,41 @@ public partial class ChronoJumpWindow
 		currentRunEncoder.UpdateSQL(false);
 	}
 
-	private void raceEncoderCopyTempAndDoGraphs()
+	private void raceEncoderCopyToTempAndDoRGraph()
 	{
+		// 0) delete results file
+		Util.FileDelete(RunEncoder.GetCSVResultsURL());
+
+		// 1) copy file
 		File.Copy(lastRunEncoderFullPath, RunEncoder.GetCSVFileName(), true); //can be overwritten
 
-		raceEncoderCaptureGraphDo();
+		// 2) create and open graph
+		raceEncoderCaptureRGraphDo();
 
 		Thread.Sleep (250); //Wait a bit to ensure is copied
 
 		runEncoderAnalyzeOpenImage();
 		notebook_analyze.CurrentPage = Convert.ToInt32(notebook_analyze_pages.RACEENCODER);
-		radio_mode_contacts_analyze.Active = true;
+		//radio_mode_contacts_analyze.Active = true;
 		button_run_encoder_analyze_analyze.Sensitive = true;
+
+		// 3) display table
+		treeview_raceAnalyzer = UtilGtk.RemoveColumns(treeview_raceAnalyzer);
+
+		string contents = Util.ReadFile(RunEncoder.GetCSVResultsURL(), false);
+
+		//maybe captured data was too low or two different than an sprint.
+		//then we have image but maybe we have no sprintResults.csv
+
+		if(contents == null || contents == "")
+			return;
+		else {
+			createTreeViewRaceEncoder(contents);
+			button_raceAnalyzer_table_save.Sensitive = true;
+		}
 	}
 
-	private void raceEncoderCaptureGraphDo()
+	private void raceEncoderCaptureRGraphDo()
 	{
 		if(File.Exists(UtilEncoder.GetSprintEncoderImage()))
 			Util.FileDelete(UtilEncoder.GetSprintEncoderImage());
@@ -962,25 +1222,6 @@ public partial class ChronoJumpWindow
 		string title = Util.ChangeSpaceAndMinusForUnderscore(currentPerson.Name) + "-" +
 			Util.ChangeSpaceAndMinusForUnderscore(UtilGtk.ComboGetActive(combo_run_encoder_exercise));
 
-		bool plotRawAccel =
-			( Preferences.runEncoderAnalyzeAccel.SqlCurrentName ==  Preferences.runEncoderAnalyzeAFPSqlRAW ||
-			 Preferences.runEncoderAnalyzeAccel.SqlCurrentName == Preferences.runEncoderAnalyzeAFPSqlBOTH );
-		bool plotFittedAccel =
-			( Preferences.runEncoderAnalyzeAccel.SqlCurrentName == Preferences.runEncoderAnalyzeAFPSqlFITTED ||
-			 Preferences.runEncoderAnalyzeAccel.SqlCurrentName == Preferences.runEncoderAnalyzeAFPSqlBOTH );
-		bool plotRawForce =
-			( Preferences.runEncoderAnalyzeForce.SqlCurrentName ==  Preferences.runEncoderAnalyzeAFPSqlRAW ||
-			 Preferences.runEncoderAnalyzeForce.SqlCurrentName == Preferences.runEncoderAnalyzeAFPSqlBOTH );
-		bool plotFittedForce =
-			( Preferences.runEncoderAnalyzeForce.SqlCurrentName == Preferences.runEncoderAnalyzeAFPSqlFITTED ||
-			 Preferences.runEncoderAnalyzeForce.SqlCurrentName == Preferences.runEncoderAnalyzeAFPSqlBOTH );
-		bool plotRawPower =
-			( Preferences.runEncoderAnalyzePower.SqlCurrentName ==  Preferences.runEncoderAnalyzeAFPSqlRAW ||
-			 Preferences.runEncoderAnalyzePower.SqlCurrentName == Preferences.runEncoderAnalyzeAFPSqlBOTH );
-		bool plotFittedPower =
-			( Preferences.runEncoderAnalyzePower.SqlCurrentName == Preferences.runEncoderAnalyzeAFPSqlFITTED ||
-			 Preferences.runEncoderAnalyzePower.SqlCurrentName == Preferences.runEncoderAnalyzeAFPSqlBOTH );
-
 		//create graph
 		RunEncoderGraph reg = new RunEncoderGraph(
 				race_analyzer_distance,
@@ -992,12 +1233,15 @@ public partial class ChronoJumpWindow
 				title,
 				currentRunEncoder.DateTimePublic,
 				preferences.runEncoderMinAccel,
-				plotRawAccel, plotFittedAccel,
-				plotRawForce, plotFittedForce,
-				plotRawPower, plotFittedPower,
+				Preferences.RunEncoderShouldPlotVariable(Preferences.RunEncoderPlotVariables.RAWACCEL),
+				Preferences.RunEncoderShouldPlotVariable(Preferences.RunEncoderPlotVariables.FITTEDACCEL),
+				Preferences.RunEncoderShouldPlotVariable(Preferences.RunEncoderPlotVariables.RAWFORCE),
+				Preferences.RunEncoderShouldPlotVariable(Preferences.RunEncoderPlotVariables.FITTEDFORCE),
+				Preferences.RunEncoderShouldPlotVariable(Preferences.RunEncoderPlotVariables.RAWPOWER),
+				Preferences.RunEncoderShouldPlotVariable(Preferences.RunEncoderPlotVariables.FITTEDPOWER),
 				triggerListRunEncoder);
 
-		reg.CallR(imageWidth, imageHeight);
+		reg.CallR(imageWidth, imageHeight, true);
 
 		DateTime runEncoderGraphStarted = DateTime.Now;
 		//TODO: check better if png is saved and have a cancel button
@@ -1026,6 +1270,85 @@ public partial class ChronoJumpWindow
 		}
 	}
 
+	private void createTreeViewRaceEncoder (string contents)
+	{
+		string [] columnsString = getTreeviewRaceAnalyzerHeaders();
+		int count = 0;
+		foreach(string column in columnsString)
+			treeview_raceAnalyzer.AppendColumn (column, new CellRendererText(), "text", count++);
+
+		TreeStore store = new TreeStore(
+				typeof (string), typeof (string), typeof (string),
+				typeof (string), typeof (string), typeof (string),
+				typeof (string), typeof (string), typeof (string),
+				typeof (string), typeof (string), typeof (string),
+				typeof (string), typeof (string), typeof (string),
+				typeof (string), typeof (string), typeof (string),
+				typeof (string), typeof (string), typeof (string),
+				typeof (string)
+				);
+
+		RunEncoderCSV recsv = readRunEncoderCSVContents (contents);
+		store.AppendValues (recsv.ToTreeView());
+
+		treeview_raceAnalyzer.Model = store;
+		treeview_raceAnalyzer.Selection.Mode = SelectionMode.None;
+                treeview_raceAnalyzer.HeadersVisible=true;
+	}
+
+	private string [] getTreeviewRaceAnalyzerHeaders ()
+        {
+                string [] headers = {
+			"Mass\n\n(Kg)", "Height\n\n(m)", "Temperature\n\n(ºC)",
+			"V (wind)\n\n(m/s)", "Ka\n\n", "K\nfitted\n(s^-1)",
+			"Vmax\nfitted\n(m/s)", "Amax\nfitted\n(m/s^2)", "Fmax\nfitted\n(N)",
+			"Fmax\nrel fitted\n(N/Kg)", "Sfv\nfitted\n", "Sfv\nrel fitted\n",
+			"Sfv\nlm\n", "Sfv\nrel lm\n", "Pmax\nfitted\n(W)",
+			"Pmax\nrel fitted\n(W/Kg)", "Time to pmax\nfitted\n(s)", "F0\n\n(N)",
+			"F0\nrel\n(N/Kg)", "V0\n\n(m/s)", "Pmax\nlm\n(W)",
+			"Pmax\nrel lm\n(W/Kg)"
+		};
+		return headers;
+	}
+
+	//right now it only returns one line
+	private RunEncoderCSV readRunEncoderCSVContents (string contents)
+	{
+		RunEncoderCSV recsv = new RunEncoderCSV();
+		string line;
+		using (StringReader reader = new StringReader (contents))
+		{
+			line = reader.ReadLine ();      //headers
+			//LogB.Information(line);
+			do {
+				line = reader.ReadLine ();
+				LogB.Information(line);
+				if (line == null)
+					break;
+
+				string [] cells = line.Split(new char[] {';'});
+
+				recsv = new RunEncoderCSV(
+						Convert.ToDouble(cells[0]), Convert.ToDouble(cells[1]), Convert.ToInt32(cells[2]),
+						Convert.ToDouble(cells[3]), Convert.ToDouble(cells[4]), Convert.ToDouble(cells[5]),
+						Convert.ToDouble(cells[6]), Convert.ToDouble(cells[7]), Convert.ToDouble(cells[8]),
+						Convert.ToDouble(cells[9]), Convert.ToDouble(cells[10]), Convert.ToDouble(cells[11]),
+						Convert.ToDouble(cells[12]), Convert.ToDouble(cells[13]), Convert.ToDouble(cells[14]),
+						Convert.ToDouble(cells[15]), Convert.ToDouble(cells[16]), Convert.ToDouble(cells[17]),
+						Convert.ToDouble(cells[18]), Convert.ToDouble(cells[19]), Convert.ToDouble(cells[20]),
+						Convert.ToDouble(cells[21])
+						);
+			} while(true);
+		}
+
+		return recsv;
+	}
+
+	private void on_button_raceAnalyzer_table_save_clicked (object o, EventArgs args)
+	{
+		checkFile(Constants.CheckFileOp.RUNENCODER_SAVE_TABLE);
+	}
+
 	private string readFromRunEncoderIfDataArrived()
 	{
 		string str = "";
@@ -1077,7 +1400,7 @@ public partial class ChronoJumpWindow
 
 		LogB.Information(" re B ");
 		//LogB.Information(capturingRunEncoder.ToString())
-		if(! runEncoderCaptureThread.IsAlive || runEncoderProcessFinish || runEncoderProcessCancel || runEncoderProcessError)
+		if(! runEncoderCaptureThread.IsAlive || runEncoderProcessFinish || runEncoderProcessCancel || runEncoderProcessError) //capture ends
 		{
 			LogB.Information(" re C ");
 			button_video_play_this_test_contacts.Sensitive = false;
@@ -1092,6 +1415,10 @@ public partial class ChronoJumpWindow
 				else
 				{
 					event_execute_label_message.Text = "Saved." + captureEndedMessage;
+					if(currentPersonSession.Height == 0)
+						event_execute_label_message.Text += " " + "Person height is 0!";
+					if(runEncoderCaptureSimulated)
+						event_execute_label_message.Text += " SIMULATED TEST!";
 
 					currentRunEncoder = new RunEncoder(-1, currentPerson.UniqueID, currentSession.UniqueID,
 							currentRunEncoderExercise.UniqueID, raceEncoderGetDevice(),
@@ -1105,7 +1432,7 @@ public partial class ChronoJumpWindow
 							currentRunEncoderExercise.Name);
 
 					currentRunEncoder.UniqueID = currentRunEncoder.InsertSQL(false);
-					SaveTriggers(currentRunEncoder.UniqueID);
+					triggerListRunEncoder.SQLInsert(currentRunEncoder.UniqueID);
 					showRaceAnalyzerTriggers ();
 
 					//stop camera
@@ -1124,13 +1451,17 @@ public partial class ChronoJumpWindow
 					sensitiveLastTestButtons(true);
 					contactsShowCaptureDoingButtons(false);
 
-					raceEncoderCaptureGraphDo();
+					//do not analyze after capture, to be able to show the message: no person height
+					/*
+					raceEncoderCaptureRGraphDo();
 
 					runEncoderAnalyzeOpenImage();
 					notebook_analyze.CurrentPage = Convert.ToInt32(notebook_analyze_pages.RACEENCODER);
 					radio_mode_contacts_analyze.Active = true;
+					*/
+
 					button_contacts_exercise_close_and_recalculate.Sensitive = true;
-					button_run_encoder_analyze_options.Sensitive = true;
+					button_run_encoder_analyze_options_close_and_analyze.Sensitive = true;
 					button_run_encoder_analyze_analyze.Sensitive = true;
 					button_run_encoder_image_save.Sensitive = true;
 					button_delete_last_test.Sensitive = true;
@@ -1143,7 +1474,11 @@ public partial class ChronoJumpWindow
 					//if drawingarea has still not shown, don't paint graph because GC screen is not defined
 					if(force_sensor_ai_drawingareaShown)
 						forceSensorDoGraphAI();
-					*/
+					 */
+
+					updateRaceAnalyzerCapturePositionTime(true);
+					updateRaceAnalyzerCaptureSpeedTime(true);
+					updateRaceAnalyzerCaptureAccelTime(true);
 				}
 				LogB.Information(" re C finish 2");
 			} else if(runEncoderProcessCancel || runEncoderProcessError)
@@ -1153,7 +1488,7 @@ public partial class ChronoJumpWindow
 				webcamEnd (Constants.TestTypes.RACEANALYZER, -1);
 				sensitiveLastTestButtons(false);
 				contactsShowCaptureDoingButtons(false);
-				button_run_encoder_analyze_options.Sensitive = false;
+				button_run_encoder_analyze_options_close_and_analyze.Sensitive = false;
 				button_run_encoder_analyze_analyze.Sensitive = false;
 				button_run_encoder_image_save.Sensitive = false;
 				button_delete_last_test.Sensitive = false;
@@ -1178,9 +1513,28 @@ public partial class ChronoJumpWindow
 				Thread.Sleep (250);
 			LogB.Information(" re D ");
 
+			LogB.Mute = preferences.muteLogs;
+			if(! preferences.muteLogs)
+				LogB.Information("muteLogs INactive. Logs active active again");
+
+			if(reCGSD != null)
+				cairoRadial.GraphSpeedMaxAndDistance(reCGSD.RunEncoderCaptureSpeedMax, reCGSD.RunEncoderCaptureDistance);
+
+			/*
+			LogB.Information("cairoGraphRaceAnalyzerPoints_dt_l: ");
+			foreach(PointF p in cairoGraphRaceAnalyzerPoints_dt_l)
+				LogB.Information(p.ToString());
+
+			LogB.Information("cairoGraphRaceAnalyzerPoints_st_l: ");
+			foreach(PointF p in cairoGraphRaceAnalyzerPoints_st_l)
+				LogB.Information(p.ToString());
+			*/
+
 			LogB.ThreadEnded(); 
 
 			runEncoderButtonsSensitive(true);
+			radio_run_encoder_analyze_individual_current_set.Active = true;
+
 			/*
 			button_force_sensor_image_save_signal.Sensitive = true;
 			button_force_sensor_analyze_recalculate.Sensitive = true;
@@ -1194,10 +1548,19 @@ public partial class ChronoJumpWindow
 
 			return false;
 		}
-		else
+		else //capture continues
 		{
 			event_execute_label_message.Text = runEncoderPulseMessage;
 
+			if(cairoRadial != null && reCGSD != null)
+				cairoRadial.GraphSpeedAndDistance(reCGSD.RunEncoderCaptureSpeed, reCGSD.RunEncoderCaptureDistance);
+
+			//TODO: activate again when there's a real time update (not repaint all) method
+			//false: it will not be redrawn if there are no new points
+			updateRaceAnalyzerCapturePositionTime(false);
+			updateRaceAnalyzerCaptureSpeedTime(false);
+			updateRaceAnalyzerCaptureAccelTime(false);
+
 			if(runEncoderPulseMessage == capturingMessage)
 				event_execute_button_finish.Sensitive = true;
 		}
@@ -1243,18 +1606,11 @@ public partial class ChronoJumpWindow
 		}
 		LogB.Information(" re R ");
 
-		Thread.Sleep (25);
+		Thread.Sleep (50);
 		//LogB.Information(" RunEncoder:"+ runEncoderCaptureThread.ThreadState.ToString());
 		return true;
 	}
 
-	public void SaveTriggers(int signalID)
-	{
-		triggerListRunEncoder.SQLInsert(signalID);
-	}
-
-	private bool button_run_encoder_analyze_analyze_was_sensitive; //needed this temp variable
-
 	void runEncoderButtonsSensitive(bool sensitive)
 	{
 		//runEncoder related buttons
@@ -1262,14 +1618,6 @@ public partial class ChronoJumpWindow
 		vbox_run_encoder_capture_options.Sensitive = sensitive;
 		button_contacts_exercise.Sensitive = sensitive;
 		button_execute_test.Sensitive = sensitive;
-
-		if(sensitive)
-			button_run_encoder_analyze_analyze.Sensitive = button_run_encoder_analyze_analyze_was_sensitive;
-		else {
-			button_run_encoder_analyze_analyze_was_sensitive = button_run_encoder_analyze_analyze.Sensitive;
-			button_run_encoder_analyze_analyze.Sensitive = false;
-		}
-
 		hbox_contacts_camera.Sensitive = sensitive;
 
 		//other gui buttons
@@ -1288,7 +1636,9 @@ public partial class ChronoJumpWindow
 		image_run_encoder_graph = UtilGtk.OpenImageSafe(
 				imagePath,
 				image_run_encoder_graph);
-		image_run_encoder_graph.Sensitive = true;
+
+		//image_run_encoder_graph.Sensitive = true; //not useful
+		image_run_encoder_graph.Visible = true;
 	}
 
 	/*
@@ -1338,9 +1688,27 @@ public partial class ChronoJumpWindow
 		hbox_combo_run_encoder_exercise.ShowAll();
 	}
 
+	//left-right buttons on run_encoder combo exercise selection
+	private void on_button_combo_run_encoder_exercise_capture_left_clicked (object o, EventArgs args)
+	{
+		contacts_exercise_left_button (combo_run_encoder_exercise,
+				button_combo_run_encoder_exercise_capture_left,
+				button_combo_run_encoder_exercise_capture_right);
+	}
+	private void on_button_combo_run_encoder_exercise_capture_right_clicked (object o, EventArgs args)
+	{
+		contacts_exercise_right_button (combo_run_encoder_exercise,
+				button_combo_run_encoder_exercise_capture_left,
+				button_combo_run_encoder_exercise_capture_right);
+	}
+
 	private void on_combo_run_encoder_exercise_changed(object o, EventArgs args)
 	{
 		setLabelContactsExerciseSelected(Constants.Menuitem_modes.RUNSENCODER);
+
+		//sensitivity of left/right buttons
+		button_combo_run_encoder_exercise_capture_left.Sensitive = (combo_run_encoder_exercise.Active > 0);
+		button_combo_run_encoder_exercise_capture_right.Sensitive = ! UtilGtk.ComboSelectedIsLast(combo_run_encoder_exercise);
 	}
 
 	private void fillRunEncoderExerciseCombo(string name)
@@ -1402,7 +1770,7 @@ public partial class ChronoJumpWindow
 		bigArray.Add(a3);
 
 		genericWin = GenericWindow.Show(Catalog.GetString("Exercise"), false,	//don't show now
-				Catalog.GetString("Force sensor exercise:"), bigArray);
+				Catalog.GetString("Race analyzer exercise:"), bigArray);
 		genericWin.LabelEntry2 = Catalog.GetString("Description");
 
 		genericWin.ShowButtonCancel(false);
@@ -1576,4 +1944,80 @@ public partial class ChronoJumpWindow
 	}
 	// -------------------------------- end of exercise stuff --------------------
 
+	CairoRadial cairoRadial;
+	private void on_drawingarea_race_analyzer_capture_expose_event (object o, ExposeEventArgs args)
+	{
+		if(cairoRadial == null)
+			cairoRadial = new CairoRadial(drawingarea_race_analyzer_capture, preferences.fontType.ToString());
+
+		//when person or session changes
+		if(! runEncoderShouldShowCaptureGraphsWithData)
+		{
+			cairoRadial.GraphBlank();
+			return;
+		}
+
+		if(reCGSD == null)
+		{
+			cairoRadial.GraphBlank();
+			return;
+		}
+
+		if(runEncoderCaptureThread != null && runEncoderCaptureThread.IsAlive)
+			cairoRadial.GraphSpeedAndDistance(reCGSD.RunEncoderCaptureSpeed, reCGSD.RunEncoderCaptureDistance);
+		else
+			cairoRadial.GraphSpeedMaxAndDistance(reCGSD.RunEncoderCaptureSpeedMax, reCGSD.RunEncoderCaptureDistance);
+	}
+
+	CairoGraphRaceAnalyzer cairoGraphRaceAnalyzer_dt;
+	static List<PointF> cairoGraphRaceAnalyzerPoints_dt_l; //distancetime
+	private void on_drawingarea_race_analyzer_capture_position_time_expose_event (object o, ExposeEventArgs args)
+	{
+		updateRaceAnalyzerCapturePositionTime(true);
+	}
+
+	CairoGraphRaceAnalyzer cairoGraphRaceAnalyzer_st;
+	static List<PointF> cairoGraphRaceAnalyzerPoints_st_l;	//speed/time
+	private void on_drawingarea_race_analyzer_capture_speed_time_expose_event (object o, ExposeEventArgs args)
+	{
+		updateRaceAnalyzerCaptureSpeedTime(true);
+	}
+
+	CairoGraphRaceAnalyzer cairoGraphRaceAnalyzer_at;
+	static List<PointF> cairoGraphRaceAnalyzerPoints_at_l;	//accel/time
+	private void on_drawingarea_race_analyzer_capture_accel_time_expose_event (object o, ExposeEventArgs args)
+	{
+		updateRaceAnalyzerCaptureAccelTime(true);
+	}
+
+	private void updateRaceAnalyzerCapturePositionTime(bool forceRedraw)
+	{
+		if(cairoGraphRaceAnalyzer_dt == null)
+			cairoGraphRaceAnalyzer_dt = new CairoGraphRaceAnalyzer(
+					drawingarea_race_analyzer_capture_position_time, "title",
+					Catalog.GetString("Distance"), "m");
+
+		cairoGraphRaceAnalyzer_dt.DoSendingList (preferences.fontType.ToString(),
+				cairoGraphRaceAnalyzerPoints_dt_l, forceRedraw, CairoXY.PlotTypes.POINTSLINES);
+	}
+	private void updateRaceAnalyzerCaptureSpeedTime(bool forceRedraw)
+	{
+		if(cairoGraphRaceAnalyzer_st == null)
+			cairoGraphRaceAnalyzer_st = new CairoGraphRaceAnalyzer(
+					drawingarea_race_analyzer_capture_speed_time, "title",
+					Catalog.GetString("Speed"), "m/s");
+
+		cairoGraphRaceAnalyzer_st.DoSendingList (preferences.fontType.ToString(),
+				cairoGraphRaceAnalyzerPoints_st_l, forceRedraw, CairoXY.PlotTypes.POINTSLINES);
+	}
+	private void updateRaceAnalyzerCaptureAccelTime(bool forceRedraw)
+	{
+		if(cairoGraphRaceAnalyzer_at == null)
+			cairoGraphRaceAnalyzer_at = new CairoGraphRaceAnalyzer(
+					drawingarea_race_analyzer_capture_accel_time, "title",
+					Catalog.GetString("Accel"), "m/s^2");
+
+		cairoGraphRaceAnalyzer_at.DoSendingList (preferences.fontType.ToString(),
+				cairoGraphRaceAnalyzerPoints_at_l, forceRedraw, CairoXY.PlotTypes.LINES);
+	}
 }
