@@ -23,6 +23,7 @@ using Gtk;
 using Glade;
 using GLib; //for Value
 using System.Text; //StringBuilder
+using System.Collections.Generic; //List<T>
 using System.Collections; //ArrayList
 using Mono.Unix;
 
@@ -49,6 +50,11 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_session_import1_yellow;
 	[Widget] Gtk.Label app1s_label_load;
 	[Widget] Gtk.Label app1s_label_import;
+	[Widget] Gtk.ScrolledWindow scrolledwin_session_load;
+
+	[Widget] Gtk.HBox app1s_hbox_combo_tags;
+	[Widget] Gtk.ComboBox app1s_combo_tags;
+	CjComboGeneric app1sComboTags;
 
 	/*
 	 * when fillTreeView() is called, it executes:
@@ -65,6 +71,7 @@ public partial class ChronoJumpWindow
 	 */
 
 	private app1s_windowType app1s_type;
+	private bool sessionLoadWinSignals; //to be able to set radiobuttons at first without recreating the treeview
 
 	private void app1s_initializeGui()
 	{
@@ -92,6 +99,7 @@ public partial class ChronoJumpWindow
 			app1s_hbox_frame_import.Visible = false;
 			app1s_notebook.CurrentPage = app1s_PAGE_SELECT_SESSION;
 			app1s_notebook_load_button_animation.CurrentPage = 0;
+			app1s_hbox_manage.Visible = true;
 		} else {
 			app1s_file_path_import.Visible = true;
 			app1s_notebook_load_button_animation.Visible = false;
@@ -102,18 +110,67 @@ public partial class ChronoJumpWindow
 			app1s_hbox_frame_import.Visible = true;
 			app1s_button_select_file_import_same_database.Visible = false; //is shown when user want to import a second session
 			app1s_notebook.CurrentPage = app1s_PAGE_IMPORT_START;
+			app1s_hbox_manage.Visible = false;
 		}
-		app1s_entry_search_filter.Text = "";
 
-		app1s_createTreeView(app1s_treeview_session_load, false, false, false);
-		app1s_store = app1s_getStore(false, false, false);
+		createComboSessionLoadTags (false); //TODO: care because this is only related to load (not report)
+		app1s_entry_search_filter.Text = "";
+		app1s_button_manage_tags.Sensitive = (app1s_selected != "-1");
+
+		//radio buttons
+		sessionLoadWinSignals = false;
+		/*
+		app1s_checkbutton_show_data_persons.Active = preferences.sessionLoadDisplay.ShowAthletesInfo;
+		app1s_checkbutton_show_data_jump_run.Active = preferences.sessionLoadDisplay.ShowJumpsRaces;
+		app1s_checkbutton_show_data_other_tests.Active = preferences.sessionLoadDisplay.ShowOtherTests;
+		*/
+		app1s_checkbutton_show_data_jumps.Active = (current_menuitem_mode == Constants.Menuitem_modes.JUMPSSIMPLE ||
+				current_menuitem_mode == Constants.Menuitem_modes.JUMPSREACTIVE);
+		app1s_checkbutton_show_data_runs.Active = (current_menuitem_mode == Constants.Menuitem_modes.RUNSSIMPLE ||
+				current_menuitem_mode == Constants.Menuitem_modes.RUNSINTERVALLIC ||
+				current_menuitem_mode == Constants.Menuitem_modes.RUNSENCODER);
+		app1s_checkbutton_show_data_force_sensor.Active = (current_menuitem_mode == Constants.Menuitem_modes.FORCESENSOR);
+		app1s_checkbutton_show_data_encoder.Active = (current_menuitem_mode == Constants.Menuitem_modes.POWERGRAVITATORY ||
+				current_menuitem_mode == Constants.Menuitem_modes.POWERINERTIAL);
+
+		sessionLoadWinSignals = true;
+
+		app1s_createTreeView(app1s_treeview_session_load, app1s_type == app1s_windowType.LOAD_SESSION,
+				app1s_checkbutton_show_data_persons.Active,
+				app1s_checkbutton_show_data_jumps.Active,
+				app1s_checkbutton_show_data_runs.Active,
+				app1s_checkbutton_show_data_force_sensor.Active,
+				app1s_checkbutton_show_data_encoder.Active);/*,
+				app1s_checkbutton_show_data_rt.Active,
+				app1s_checkbutton_show_data_other.Active
+				);*/
+
+		app1s_store = app1s_getStore(true,
+				app1s_checkbutton_show_data_persons.Active,
+				app1s_checkbutton_show_data_jumps.Active,
+				app1s_checkbutton_show_data_runs.Active,
+				app1s_checkbutton_show_data_force_sensor.Active,
+				app1s_checkbutton_show_data_encoder.Active);/*,
+				app1s_checkbutton_show_data_rt.Active,
+				app1s_checkbutton_show_data_other.Active
+				);*/
+
 		app1s_treeview_session_load.Model = app1s_store;
-		app1s_fillTreeView(app1s_treeview_session_load, app1s_store, false, false, false);
+
+		app1s_fillTreeView(app1s_treeview_session_load, app1s_store,
+				app1s_checkbutton_show_data_persons.Active,
+				app1s_checkbutton_show_data_jumps.Active,
+				app1s_checkbutton_show_data_runs.Active,
+				app1s_checkbutton_show_data_force_sensor.Active,
+				app1s_checkbutton_show_data_encoder.Active);/*,
+				app1s_checkbutton_show_data_rt.Active,
+				app1s_checkbutton_show_data_other.Active
+				);*/
 
 		app1s_store.SetSortColumnId(1, Gtk.SortType.Descending); //date
 		app1s_store.ChangeSortColumn();
 
-		app1s_button_accept.Sensitive = false;
+		app1s_button_load.Sensitive = false;
 		app1s_button_import.Sensitive = false;
 		app1s_entry_search_filter.CanFocus = true;
 		app1s_entry_search_filter.IsFocus = true;
@@ -130,15 +187,29 @@ public partial class ChronoJumpWindow
 		*/
 	}
 
-	private TreeStore app1s_getStore(bool showPersons, bool showContacts, bool showOtherTests)
+	private TreeStore app1s_getStore(bool loadOrImport, bool showPersons,
+			bool showJumps, bool showRuns, bool showForceSensor, bool showEncoder)//, bool showRT, bool showOther)
 	{
 		int columns = 6;
+		if(loadOrImport)
+			columns ++; //on load we have the tags column
+
 		if(showPersons)
 			columns += 3;
-		if(showContacts)
-			columns += 7;
-		if(showOtherTests)
-			columns += 4;
+		if(showJumps)
+			columns += 2;
+		if(showRuns)
+			columns += 3; //includes race analyzer
+		if(showForceSensor)
+			columns ++;
+		if(showEncoder)
+			columns += 2;
+		/*
+		if(showRT)
+			columns ++;
+		if(showOther)
+			columns += 2; //pulses, RT
+			*/
 
 		Type [] types = new Type [columns];
 		for (int i=0; i < columns; i++) {
@@ -177,8 +248,9 @@ public partial class ChronoJumpWindow
 		app1s_initializeGui();
 		app1s_recreateTreeView("loaded the dialog");
 	}
-	
-	private void app1s_createTreeView (Gtk.TreeView tv, bool showPersons, bool showContacts, bool showOtherTests)
+
+	private void app1s_createTreeView (Gtk.TreeView tv, bool loadOrImport, bool showPersons,
+			bool showJumps, bool showRuns, bool showForceSensor, bool showEncoder)//, bool showRT, bool showOther)
 	{
 		tv.HeadersVisible=true;
 		int count = 0;
@@ -199,7 +271,15 @@ public partial class ChronoJumpWindow
 		colName.SortColumnId = count ++;
 		colName.SortIndicator = true;
 		tv.AppendColumn (colName);
-		
+
+		if(loadOrImport)
+		{
+			Gtk.TreeViewColumn colTags = new Gtk.TreeViewColumn(Catalog.GetString ("Tags"), new CellRendererText(), "text", count);
+			colTags.SortColumnId = count ++;
+			colTags.SortIndicator = true;
+			tv.AppendColumn (colTags);
+		}
+
 		tv.AppendColumn ( Catalog.GetString ("Place"), new CellRendererText(), "text", count++);
 		tv.AppendColumn ( Catalog.GetString ("Persons"), new CellRendererText(), "text", count++);
 		if(showPersons) {
@@ -207,28 +287,59 @@ public partial class ChronoJumpWindow
 			tv.AppendColumn ( Catalog.GetString ("Specialty"), new CellRendererText(), "text", count++);
 			tv.AppendColumn ( Catalog.GetString ("Level"), new CellRendererText(), "text", count++);
 		}
-		if(showContacts) {
+		if(showJumps) {
 			tv.AppendColumn ( Catalog.GetString ("Jumps simple"), new CellRendererText(), "text", count++);
 			tv.AppendColumn ( Catalog.GetString ("Jumps reactive"), new CellRendererText(), "text", count++);
+		}
+		if(showRuns) {
 			tv.AppendColumn ( Catalog.GetString ("Races simple"), new CellRendererText(), "text", count++);
 			tv.AppendColumn ( Catalog.GetString ("Races interval"), new CellRendererText(), "text", count++);
-			tv.AppendColumn ( Catalog.GetString ("Reaction time"), new CellRendererText(), "text", count++);
-			tv.AppendColumn ( Catalog.GetString ("Pulses"), new CellRendererText(), "text", count++);
-			tv.AppendColumn ( Catalog.GetString ("MultiChronopic"), new CellRendererText(), "text", count++);
+			tv.AppendColumn ( Catalog.GetString ("Race analyzer"), new CellRendererText(), "text", count++);
 		}
-		if(showOtherTests) {
+		if(showForceSensor) {
+			tv.AppendColumn ( Catalog.GetString ("Force sensor"), new CellRendererText(), "text", count++);
+		}
+		if(showEncoder) {
 			tv.AppendColumn ( Catalog.GetString ("Gravitatory encoder") + "\n" +
 					Catalog.GetString("Sets") + " ; " + Catalog.GetString("Repetitions"),
 					new CellRendererText(), "text", count++);
 			tv.AppendColumn ( Catalog.GetString ("Inertial encoder") + "\n" +
 					Catalog.GetString("Sets") + " ; " + Catalog.GetString("Repetitions"),
 					new CellRendererText(), "text", count++);
-			tv.AppendColumn ( Catalog.GetString ("Force sensor"), new CellRendererText(), "text", count++);
-			tv.AppendColumn ( Catalog.GetString ("Race analyzer"), new CellRendererText(), "text", count++);
 		}
+		/*
+		if(showRT) {
+			tv.AppendColumn ( Catalog.GetString ("Reaction time"), new CellRendererText(), "text", count++);
+		}
+		if(showOther) {
+			tv.AppendColumn ( Catalog.GetString ("Pulses"), new CellRendererText(), "text", count++);
+			tv.AppendColumn ( Catalog.GetString ("MultiChronopic"), new CellRendererText(), "text", count++);
+		}
+		*/
 		tv.AppendColumn ( Catalog.GetString ("Comments"), new CellRendererText(), "text", count++);
 	}
-	
+
+        private void createComboSessionLoadTags (bool create)
+        {
+                if(create)
+                {
+                        app1sComboTags = new CjComboGeneric(app1s_combo_tags, app1s_hbox_combo_tags);
+                        app1s_combo_tags = app1sComboTags.Combo;
+                        app1s_combo_tags.Changed += new EventHandler (app1s_on_combo_tags_changed);
+                } else {
+			app1sComboTags.L_types = TagSession.ListSelectTypesOnSQL();
+                        app1s_combo_tags.Changed -= new EventHandler (app1s_on_combo_tags_changed);
+                        app1sComboTags.Fill();
+                        app1s_combo_tags.Changed += new EventHandler (app1s_on_combo_tags_changed);
+                        app1s_combo_tags = app1sComboTags.Combo;
+                }
+                app1s_combo_tags.Sensitive = true;
+        }
+
+	private void app1s_on_combo_tags_changed (object o, EventArgs args) {
+		app1s_recreateTreeView("changed tag");
+	}
+
 	protected void app1s_on_entry_search_filter_changed (object o, EventArgs args) {
 		app1s_recreateTreeView("changed search filter");
 	}
@@ -257,15 +368,35 @@ public partial class ChronoJumpWindow
 		app1s_recreateTreeView ("file path changed");
 	}
 
-	void app1s_on_checkbutton_show_data_persons_toggled (object o, EventArgs args) {
-		app1s_recreateTreeView("persons " + app1s_checkbutton_show_data_persons.Active.ToString());
+	void app1s_on_checkbutton_show_data_toggled (object o, EventArgs args)
+	{
+		if(! sessionLoadWinSignals)
+			return;
+
+		//on import this call will be done t end to affect to our desired database
+		if (app1s_type == app1s_windowType.LOAD_SESSION)
+			sqlChangeSessionLoadDisplay();
+
+		app1s_recreateTreeView("show_data_toggled " + app1s_checkbutton_show_data_persons.Active.ToString());
 	}
-	void app1s_on_checkbutton_show_data_jump_run_toggled (object o, EventArgs args) {
-		app1s_recreateTreeView("jump run " + app1s_checkbutton_show_data_jump_run.Active.ToString());
-	}
-	void app1s_on_checkbutton_show_data_other_tests_toggled (object o, EventArgs args) {
-		app1s_recreateTreeView("other tests " + app1s_checkbutton_show_data_other_tests.Active.ToString());
+
+	private void sqlChangeSessionLoadDisplay ()
+	{
+		/*
+		preferences.sessionLoadDisplay = new SessionLoadDisplay(
+				app1s_checkbutton_show_data_persons.Active,
+				app1s_checkbutton_show_data_jumps.Active,
+				app1s_checkbutton_show_data_runs.Active,
+				app1s_checkbutton_show_data_force_sensor.Active,
+				app1s_checkbutton_show_data_encoder.Active,
+				app1s_checkbutton_show_data_rt.Active,
+				app1s_checkbutton_show_data_other.Active);
+
+		SqlitePreferences.Update (SqlitePreferences.SessionLoadDisplay,
+				preferences.sessionLoadDisplay.GetInt.ToString(), false);
+				*/
 	}
+
 	void app1s_recreateTreeView(string message)
 	{
 		LogB.Information("Recreate treeview: " + message);
@@ -273,18 +404,35 @@ public partial class ChronoJumpWindow
 		UtilGtk.RemoveColumns(app1s_treeview_session_load);
 		
 		app1s_createTreeView(app1s_treeview_session_load,
+				app1s_type == app1s_windowType.LOAD_SESSION,
 				app1s_checkbutton_show_data_persons.Active,
-				app1s_checkbutton_show_data_jump_run.Active,
-				app1s_checkbutton_show_data_other_tests.Active);
+				app1s_checkbutton_show_data_jumps.Active,
+				app1s_checkbutton_show_data_runs.Active,
+				app1s_checkbutton_show_data_force_sensor.Active,
+				app1s_checkbutton_show_data_encoder.Active);/*,
+				app1s_checkbutton_show_data_rt.Active,
+				app1s_checkbutton_show_data_other.Active
+				);*/
 		app1s_store = app1s_getStore(
+				true,
 				app1s_checkbutton_show_data_persons.Active,
-				app1s_checkbutton_show_data_jump_run.Active,
-				app1s_checkbutton_show_data_other_tests.Active);
+				app1s_checkbutton_show_data_jumps.Active,
+				app1s_checkbutton_show_data_runs.Active,
+				app1s_checkbutton_show_data_force_sensor.Active,
+				app1s_checkbutton_show_data_encoder.Active);/*,
+				app1s_checkbutton_show_data_rt.Active,
+				app1s_checkbutton_show_data_other.Active
+				);*/
 		app1s_treeview_session_load.Model = app1s_store;
 		app1s_fillTreeView(app1s_treeview_session_load, app1s_store,
 				app1s_checkbutton_show_data_persons.Active,
-				app1s_checkbutton_show_data_jump_run.Active,
-				app1s_checkbutton_show_data_other_tests.Active);
+				app1s_checkbutton_show_data_jumps.Active,
+				app1s_checkbutton_show_data_runs.Active,
+				app1s_checkbutton_show_data_force_sensor.Active,
+				app1s_checkbutton_show_data_encoder.Active);/*,
+				app1s_checkbutton_show_data_rt.Active,
+				app1s_checkbutton_show_data_other.Active
+				);*/
 		
 		app1s_store.SetSortColumnId(1, Gtk.SortType.Descending); //date
 		app1s_store.ChangeSortColumn();
@@ -298,8 +446,8 @@ public partial class ChronoJumpWindow
 		app1s_onSelectionEntry (app1s_treeview_session_load.Selection, new EventArgs ());
 	}
 
-	private void app1s_fillTreeView (Gtk.TreeView tv, TreeStore store,
-			bool showPersons, bool showContacts, bool showOtherTests)
+	private void app1s_fillTreeView (Gtk.TreeView tv, TreeStore store, bool showPersons,
+			bool showJumps, bool showRuns, bool showForceSensor, bool showEncoder)//, bool showRT, bool showOther)
 	{
 		string filterName = "";
 		if(app1s_entry_search_filter.Text.ToString().Length > 0)
@@ -314,6 +462,34 @@ public partial class ChronoJumpWindow
 		SqliteSessionSwitcher sessionSwitcher = new SqliteSessionSwitcher (databaseType, app1s_import_file_path);
 		
 		string [] mySessions = sessionSwitcher.SelectAllSessions(filterName); //returns a string of values separated by ':'
+
+		//new 2.0 code
+		int columns = 6;
+		if(showPersons)
+			columns += 3;
+		if(showJumps)
+			columns += 2;
+		if(showRuns)
+			columns += 3; //includes race analyzer
+		if(showForceSensor)
+			columns ++;
+		if(showEncoder)
+			columns += 2;
+		/*
+		if(showRT)
+			columns ++;
+		if(showOther)
+			columns += 2; //pulses, RT
+			*/
+
+		//tags are not going to be imported right now, so use only on load session
+		List<SessionTagSession> tagsOfAllSessions = new List<SessionTagSession>();
+		if (app1s_type == app1s_windowType.LOAD_SESSION)
+		{
+			tagsOfAllSessions = SqliteSessionTagSession.SelectTagsOfAllSessions(false);
+			columns ++;
+		}
+
 		foreach (string session in mySessions)
 		{
 			string [] myStringFull = session.Split(new char[] {':'});
@@ -331,15 +507,6 @@ public partial class ChronoJumpWindow
 			if (myStringFull[6] != Catalog.GetString(Constants.LevelUndefined)) 
 				myLevel = Catalog.GetString(myStringFull[6]);
 
-			//new 2.0 code
-			int columns = 6;
-			if(showPersons)
-				columns += 3;
-			if(showContacts)
-				columns += 7;
-			if(showOtherTests)
-				columns += 4;
-
 			string [] strings = new string [columns];
 			//for (int i=0; i < columns; i++) {
 			//	types[i] = typeof (string);
@@ -348,6 +515,28 @@ public partial class ChronoJumpWindow
 			strings[i ++] = myStringFull[0]; 	//session num
 			strings[i ++] = myStringFull[3];	//session date
 			strings[i ++] = myStringFull[1]; 	//session name
+
+			//to show tag column
+			if (app1s_type == app1s_windowType.LOAD_SESSION)
+			{
+				List<TagSession> tagSession_list = SessionTagSession.FindTagSessionsOfSession(
+						Convert.ToInt32(myStringFull[0]),
+						tagsOfAllSessions);
+				strings[i ++] = SessionTagSession.PrintTagNamesOfSession(tagSession_list);
+
+				//do not show this session depending on tags
+				if(app1sComboTags.GetSelectedId() > 0)
+				{
+					bool found = false;
+					foreach(TagSession ts in tagSession_list)
+						if(ts.UniqueID == app1sComboTags.GetSelectedId())
+							found = true;
+
+					if(! found)
+						continue;
+				}
+			}
+
 			strings[i ++] = myStringFull[2]; 	//session place
 			strings[i ++] = myStringFull[8];	//number of jumpers x session
 
@@ -356,21 +545,31 @@ public partial class ChronoJumpWindow
 				strings[i ++] = mySpeciallity;		//personsSpeciallity
 				strings[i ++] = myLevel;		//personsLevel
 			}
-			if(showContacts) {
+			if(showJumps) {
 				strings[i ++] = myStringFull[9];	//number of jumps x session
 				strings[i ++] = myStringFull[10];	//number of jumpsRj x session
+			}
+			if(showRuns) {
 				strings[i ++] = myStringFull[11]; 	//number of runs x session
 				strings[i ++] = myStringFull[12]; 	//number of runsInterval x session
+				strings[i ++] = myStringFull[19]; 	//number of runEncoder
+			}
+			if(showForceSensor) {
+				strings[i ++] = myStringFull[18]; 	//number of forceSensor
+			}
+			if(showEncoder) {
+				strings[i ++] = myStringFull[16]; 	//number of encoder signal x session
+				strings[i ++] = myStringFull[17]; 	//number of encoder curve x session
+			}
+			/*
+			if(showRT) {
 				strings[i ++] = myStringFull[13]; 	//number of reaction times x session
+			}
+			if(showOther) {
 				strings[i ++] = myStringFull[14]; 	//number of pulses x session
 				strings[i ++] = myStringFull[15]; 	//number of multiChronopics x session
 			}
-			if(showOtherTests) {
-				strings[i ++] = myStringFull[16]; 	//number of encoder signal x session
-				strings[i ++] = myStringFull[17]; 	//number of encoder curve x session
-				strings[i ++] = myStringFull[18]; 	//number of forceSensor
-				strings[i ++] = myStringFull[19]; 	//number of runEncoder
-			}
+			*/
 			strings[i ++] = myStringFull[7];		//description of session (comments)
 
 			app1s_store.AppendValues (strings);
@@ -407,12 +606,18 @@ public partial class ChronoJumpWindow
 
 		if (((TreeSelection)o).GetSelected(out model, out iter)) {
 			app1s_selected = (string)model.GetValue (iter, 0);
-			app1s_button_accept.Sensitive = true;
+			app1s_button_load.Sensitive = true;
 			app1s_button_import.Sensitive = true;
+			app1s_button_edit.Sensitive = true;
+			app1s_button_delete.Sensitive = true;
 		} else {
-			app1s_button_accept.Sensitive = false;
+			app1s_button_load.Sensitive = false;
 			app1s_button_import.Sensitive = false;
+			app1s_button_edit.Sensitive = false;
+			app1s_button_delete.Sensitive = false;
 		}
+
+		app1s_button_manage_tags.Sensitive = (app1s_selected != "-1");
 	}
 
 	//TODO: do not need to be public ? maybe for import
@@ -426,6 +631,15 @@ public partial class ChronoJumpWindow
 		}
 		return -1;
 	}
+	private string app1s_CurrentSessionName() {
+		TreeModel model;
+		TreeIter iter;
+
+		if (app1s_treeview_session_load.Selection.GetSelected (out model, out iter)) {
+			return (string)model.GetValue (iter, 2);
+		}
+		return "";
+	}
 
 	//TODO: do not need to be public ? maybe for import
 	public string app1s_ImportDatabasePath() {
@@ -477,7 +691,7 @@ public partial class ChronoJumpWindow
 	public void app1s_ShowLabelImportedOk()
 	{
 		if(app1s_radio_import_new_session.Active)
-			app1s_label_import_done_at_new_session.Visible = true;
+			app1s_hbox_import_done_at_new_session.Visible = true;
 		else
 			app1s_label_import_done_at_current_session.Visible = true;
 	}
@@ -519,6 +733,48 @@ public partial class ChronoJumpWindow
 	}
 
 	// ---- notebook page 2 (load sesion) buttons ----
+
+	private void on_app1s_button_edit_clicked (object o, EventArgs args)
+	{
+		/*
+		 *
+		 * hi ha dos opcions, o fem load de la sessió aquell, fem el edit i tornem després:
+		 * o cridem al sessionAddEdit amb opcio de edit des de fora
+		 * i allà treiem totes les refs a currentSession, i que usi algo temp
+
+		 */
+		Session s = SqliteSession.Select (app1s_selected);
+
+		//just care if for any reason the session cannot be found
+		if(s.UniqueID == -1)
+			return;
+
+		if(s.Name == Constants.SessionSimulatedName)
+			new DialogMessage(Constants.MessageTypes.INFO, Constants.SessionProtectedStr());
+		else {
+			sessionAddEditUseSession (s);
+			sessionAddEditShow (App1saeModes.EDITOTHERSESSION);
+		}
+	}
+
+	private void on_app1s_button_delete_clicked (object o, EventArgs args)
+	{
+		Session s = SqliteSession.Select (app1s_selected);
+
+		//just care if for any reason the session cannot be found
+		if(s.UniqueID == -1)
+			return;
+
+		if(s.Name == Constants.SessionSimulatedName)
+			new DialogMessage(Constants.MessageTypes.INFO, Constants.SessionProtectedStr());
+		else {
+			deleteSessionCalledFromLoad = true;
+			tempDeletingSession = s;
+
+			on_app1s_delete_session_confirm_start_do ();
+		}
+	}
+
 	void app1s_on_button_cancel2_clicked (object o, EventArgs args)
 	{
 		menus_and_mode_sensitive(true);
@@ -537,23 +793,23 @@ public partial class ChronoJumpWindow
 			app1s_selected = (string) model.GetValue (iter, 0);
 
 			if (app1s_type == app1s_windowType.LOAD_SESSION) {
-				//activate on_button_accept_clicked()
-				app1s_button_accept.Activate();
+				//activate on_button_load_clicked()
+				app1s_button_load.Activate();
 			} else {
 				app1s_button_import.Activate();
 			}
 		}
 	}
 	
-	private void app1s_on_button_accept_clicked (object o, EventArgs args)
+	private void app1s_on_button_load_clicked (object o, EventArgs args)
 	{
 		if(app1s_selected != "-1")
 		{
 			app1s_notebook_load_button_animation.CurrentPage = 1;
-			GLib.Timeout.Add(1000, new GLib.TimeoutHandler(app1s_on_button_accept_clicked_do));
+			GLib.Timeout.Add(1000, new GLib.TimeoutHandler(app1s_on_button_load_clicked_do));
 		}
 	}
-	private bool app1s_on_button_accept_clicked_do ()
+	private bool app1s_on_button_load_clicked_do ()
 	{
 		currentSession = SqliteSession.Select (app1s_selected);
 		on_load_session_accepted();
@@ -563,6 +819,46 @@ public partial class ChronoJumpWindow
 		return false; //do not call this again
 	}
 
+	private void on_button_sessions_raspberry_up_clicked (object o, EventArgs args)
+	{
+		Gtk.Scrollbar sb = (Gtk.Scrollbar) scrolledwin_session_load.VScrollbar;
+		sb.Value -= sb.Adjustment.PageIncrement; //or StepIncrement if want small steps
+	}
+	private void on_button_sessions_raspberry_down_clicked (object o, EventArgs args)
+	{
+		Gtk.Scrollbar sb = (Gtk.Scrollbar) scrolledwin_session_load.VScrollbar;
+		sb.Value += sb.Adjustment.PageIncrement;
+	}
+
+	private void on_app1s_button_manage_tags_clicked (object o, EventArgs args)
+	{
+		if(app1s_selected == "" || app1s_selected == "-1")
+			return;
+
+		int sessionID = app1s_CurrentSessionId();
+		if(sessionID == -1)
+			return;
+
+		tagSessionSelect = new TagSessionSelect();
+
+		tagSessionSelect.PassVariables(false, sessionID, app1s_CurrentSessionName(), preferences.askDeletion);
+
+		tagSessionSelect.FakeButtonDone.Clicked -= new EventHandler(on_select_tags_clicked_done_loadSession);
+		tagSessionSelect.FakeButtonDone.Clicked += new EventHandler(on_select_tags_clicked_done_loadSession);
+
+		tagSessionSelect.Do();
+		tagSessionSelect.Show();
+	}
+	private void on_select_tags_clicked_done_loadSession (object o, EventArgs args)
+	{
+		tagSessionSelect.FakeButtonDone.Clicked -= new EventHandler(on_select_tags_clicked_done_loadSession);
+
+		//update combo tags
+		createComboSessionLoadTags (false);
+
+		app1s_recreateTreeView("changed tags on manage");
+	}
+
 	// ---- notebook page 3 (import) buttons ----
 	void app1s_on_button_back_clicked (object o, EventArgs args)
 	{
@@ -587,13 +883,26 @@ public partial class ChronoJumpWindow
 	}
 
 	//import notebook page 4 buttons
+	private void on_app1s_button_import_at_new_done_do_load_clicked (object o, EventArgs args)
+	{
+		//ID has to be the last one, get the last session
+		List<Session> session_l = SqliteSession.SelectAll(Sqlite.Orders_by.ID_DESC);
+		if(session_l == null && session_l.Count == 0)
+			return;
+
+		currentSession = session_l[0];
+		on_load_session_accepted();
+		notebook_supSetOldPage();
+	}
+
 	private void app1s_on_button_import_close_clicked(object o, EventArgs args)
 	{
 		app1s_notebook.CurrentPage = app1s_PAGE_MODES;
 	}
+
 	private void app1s_on_button_import_again_clicked(object o, EventArgs args)
 	{
-		app1s_label_import_done_at_new_session.Visible = false;
+		app1s_hbox_import_done_at_new_session.Visible = false;
 		app1s_label_import_done_at_current_session.Visible = false;
 		app1s_scrolledwindow_import_error.Visible = false;
 
@@ -604,9 +913,66 @@ public partial class ChronoJumpWindow
 		app1s_notebook.CurrentPage = app1s_PAGE_IMPORT_START;
 	}
 
-	public Button app1s_Button_accept
+	public Button app1s_Button_load
 	{
-		set { app1s_button_accept = value; }
-		get { return app1s_button_accept; }
+		set { app1s_button_load = value; }
+		get { return app1s_button_load; }
+	}
+}
+
+
+/*
+   manage if show athletes info, jumps/races or other tests
+1: athletes
+2: jumps/races
+4: other tests
+
+eg 6 will be jumps and races
+tested with:
+for(int i = 0; i <= 7; i++)
+	LogB.Information(new SessionLoadDisplay(i).ToString());
+*/
+public class SessionLoadDisplay : BooleansInt
+{
+//	private int selection;
+
+	//constructor when we have the 0-7 value
+	public SessionLoadDisplay(int selection)
+	{
+		this.i = selection;
+	}
+
+	//constructo with the 3 booleans
+	public SessionLoadDisplay(bool showBit1, bool showBit2, bool showBit3)
+	{
+		this.i = 0;
+		if(showBit1)
+			i ++;
+		if(showBit2)
+			i += 2;
+		if(showBit3)
+			i += 4;
+	}
+
+	public bool ShowOtherTests
+	{
+		get { return Bit3; }
+	}
+
+	public bool ShowJumpsRaces
+	{
+		get { return Bit2; }
+	}
+
+	public bool ShowAthletesInfo
+	{
+		get { return Bit1; }
+	}
+
+	//just to debug
+	public override string ToString()
+	{
+		return string.Format("selected: {0} (AthletesInfo: {1}, JumpsRaces: {2}, Other: {3})",
+				i, ShowAthletesInfo, ShowJumpsRaces, ShowOtherTests);
 	}
 }
