@@ -49,18 +49,42 @@ public partial class ChronoJumpWindow
 
 	//notebook tab 2
 	[Widget] Gtk.TreeView app1s_treeview_session_load;
-	[Widget] Gtk.Button app1s_button_accept;
+	[Widget] Gtk.Button app1s_button_edit;
+	[Widget] Gtk.Button app1s_button_delete;
+	[Widget] Gtk.Button app1s_button_load;
 	[Widget] Gtk.Button app1s_button_import;
+	[Widget] Gtk.Image app1s_image_edit;
+	[Widget] Gtk.Image app1s_image_delete;
+	[Widget] Gtk.Image app1s_image_cancel;
+	[Widget] Gtk.Image app1s_image_load;
 	[Widget] Gtk.Image app1s_image_import;
 	[Widget] Gtk.Entry app1s_entry_search_filter;
+	[Widget] Gtk.HBox app1s_hbox_manage;
+	[Widget] Gtk.Button app1s_button_manage_tags;
 	[Widget] Gtk.CheckButton app1s_checkbutton_show_data_persons;
-	[Widget] Gtk.CheckButton app1s_checkbutton_show_data_jump_run;
-	[Widget] Gtk.CheckButton app1s_checkbutton_show_data_other_tests;
+	[Widget] Gtk.CheckButton app1s_checkbutton_show_data_jumps;
+	[Widget] Gtk.CheckButton app1s_checkbutton_show_data_runs;
+	[Widget] Gtk.CheckButton app1s_checkbutton_show_data_force_sensor;
+	[Widget] Gtk.CheckButton app1s_checkbutton_show_data_encoder;
+	//[Widget] Gtk.CheckButton app1s_checkbutton_show_data_rt;
+	//[Widget] Gtk.CheckButton app1s_checkbutton_show_data_other;
+	[Widget] Gtk.Image app1s_image_show_data_persons;
+	[Widget] Gtk.Image app1s_image_show_data_jumps;
+	[Widget] Gtk.Image app1s_image_show_data_runs;
+	[Widget] Gtk.Image app1s_image_show_data_run_encoder;
+	[Widget] Gtk.Image app1s_image_show_data_rt;
+	[Widget] Gtk.Image app1s_image_show_data_force_sensor;
+	[Widget] Gtk.Image app1s_image_show_data_encoder_grav;
+	[Widget] Gtk.Image app1s_image_show_data_encoder_inertial;
+	[Widget] Gtk.Image app1s_image_show_data_other;
+
 	[Widget] Gtk.Label app1s_file_path_import;
 	[Widget] Gtk.Notebook app1s_notebook_load_button_animation;
 	[Widget] Gtk.HButtonBox app1s_hbuttonbox_page2_import;
+	[Widget] Gtk.EventBox app1s_eventbox_button_edit;
+	[Widget] Gtk.EventBox app1s_eventbox_button_delete;
 	[Widget] Gtk.EventBox app1s_eventbox_button_cancel;
-	[Widget] Gtk.EventBox app1s_eventbox_button_accept;
+	[Widget] Gtk.EventBox app1s_eventbox_button_load;
 	[Widget] Gtk.EventBox app1s_eventbox_button_back;
 	[Widget] Gtk.EventBox app1s_eventbox_button_import;
 
@@ -73,7 +97,7 @@ public partial class ChronoJumpWindow
 
 	//notebook tab 4
 	[Widget] Gtk.ProgressBar app1s_progressbarImport;
-	[Widget] Gtk.Label app1s_label_import_done_at_new_session;
+	[Widget] Gtk.HBox app1s_hbox_import_done_at_new_session;
 	[Widget] Gtk.Label app1s_label_import_done_at_current_session;
 	[Widget] Gtk.ScrolledWindow app1s_scrolledwindow_import_error;
 	[Widget] Gtk.TextView app1s_textview_import_error;
@@ -86,12 +110,12 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.EventBox app1s_eventbox_button_delete_close;
 
 	//notebook tab 6 (add/edit)
-	[Widget] Gtk.Window app1sae_session_add_edit;
 	[Widget] Gtk.Notebook app1sae_notebook_add_edit;
 	[Widget] Gtk.Entry app1sae_entry_name;
 	[Widget] Gtk.Entry app1sae_entry_place;
 	[Widget] Gtk.HBox hbox_session_add;
 	[Widget] Gtk.HBox hbox_session_more_edit;
+	[Widget] Gtk.TextView app1sae_textview_tags;
 	[Widget] Gtk.Label app1sae_label_name;
 	[Widget] Gtk.Label app1sae_label_date;
 	[Widget] Gtk.Image image_session_new_blue;
@@ -138,9 +162,10 @@ public partial class ChronoJumpWindow
 	//notebook tab 8 (export)
 	[Widget] Gtk.Button app1s_button_export_select;
 	[Widget] Gtk.Button app1s_button_export_start;
-	[Widget] Gtk.Button app1s_button_export_cancel_close;
-	[Widget] Gtk.EventBox app1s_eventbox_button_export_cancel_close;
-	[Widget] Gtk.Label app1s_label_export_cancel_close;
+	[Widget] Gtk.Button app1s_button_export_cancel;
+	[Widget] Gtk.Button app1s_button_export_close;
+	[Widget] Gtk.EventBox app1s_eventbox_button_export_cancel;
+	[Widget] Gtk.EventBox app1s_eventbox_button_export_close;
 	[Widget] Gtk.Image app1s_image_button_export_select;
 	[Widget] Gtk.Label app1s_label_export_destination;
 	[Widget] Gtk.Label app1s_label_export_progress;
@@ -178,8 +203,10 @@ public partial class ChronoJumpWindow
 	{
 		UtilGtk.EventBoxColorBackgroundActive (app1s_eventbox_button_close0, UtilGtk.YELLOW, UtilGtk.YELLOW_LIGHT);
 		UtilGtk.EventBoxColorBackgroundActive (app1s_eventbox_button_cancel1, UtilGtk.YELLOW, UtilGtk.YELLOW_LIGHT);
+		UtilGtk.EventBoxColorBackgroundActive (app1s_eventbox_button_edit, UtilGtk.YELLOW, UtilGtk.YELLOW_LIGHT);
+		UtilGtk.EventBoxColorBackgroundActive (app1s_eventbox_button_delete, UtilGtk.YELLOW, UtilGtk.YELLOW_LIGHT);
 		UtilGtk.EventBoxColorBackgroundActive (app1s_eventbox_button_cancel, UtilGtk.YELLOW, UtilGtk.YELLOW_LIGHT);
-		UtilGtk.EventBoxColorBackgroundActive (app1s_eventbox_button_accept, UtilGtk.YELLOW, UtilGtk.YELLOW_LIGHT);
+		UtilGtk.EventBoxColorBackgroundActive (app1s_eventbox_button_load, UtilGtk.YELLOW, UtilGtk.YELLOW_LIGHT);
 		UtilGtk.EventBoxColorBackgroundActive (app1s_eventbox_button_back, UtilGtk.YELLOW, UtilGtk.YELLOW_LIGHT);
 		UtilGtk.EventBoxColorBackgroundActive (app1s_eventbox_button_import_confirm_back, UtilGtk.YELLOW, UtilGtk.YELLOW_LIGHT);
 		UtilGtk.EventBoxColorBackgroundActive (app1s_eventbox_button_import_confirm_accept, UtilGtk.YELLOW, UtilGtk.YELLOW_LIGHT);
@@ -188,7 +215,8 @@ public partial class ChronoJumpWindow
 		UtilGtk.EventBoxColorBackgroundActive (app1s_eventbox_button_import_again, UtilGtk.YELLOW, UtilGtk.YELLOW_LIGHT);
 		UtilGtk.EventBoxColorBackgroundActive (app1s_eventbox_button_delete_close, UtilGtk.YELLOW, UtilGtk.YELLOW_LIGHT);
 		UtilGtk.EventBoxColorBackgroundActive (app1s_eventbox_button_backup_cancel_close, UtilGtk.YELLOW, UtilGtk.YELLOW_LIGHT);
-		UtilGtk.EventBoxColorBackgroundActive (app1s_eventbox_button_export_cancel_close, UtilGtk.YELLOW, UtilGtk.YELLOW_LIGHT);
+		UtilGtk.EventBoxColorBackgroundActive (app1s_eventbox_button_export_cancel, UtilGtk.YELLOW, UtilGtk.YELLOW_LIGHT);
+		UtilGtk.EventBoxColorBackgroundActive (app1s_eventbox_button_export_close, UtilGtk.YELLOW, UtilGtk.YELLOW_LIGHT);
 	}
 
 	private void app1s_label_session_set_name()
@@ -216,7 +244,7 @@ public partial class ChronoJumpWindow
 		else if(file2.Exists)
 			dir = Util.GetDatabaseTempDir();
 
-		if(! Util.OpenFolder(dir))
+		if(! Util.OpenURL (dir))
 			new DialogMessage(Constants.MessageTypes.WARNING,
 					Catalog.GetString("Error. Cannot open directory.") + "\n\n" + dir);
 	}
