@@ -43,11 +43,11 @@ public class JumpsWeightFVProfileGraph : CairoXY
 		this.area = area;
 		this.errorMessage = errorMessage;
 
-		initGraph(font);
+		initGraph(font, .8);
 
 		plotError();
 
-		endGraphDisposing();
+		endGraphDisposing(g);
 	}
 
 	//regular constructor
@@ -126,7 +126,7 @@ public class JumpsWeightFVProfileGraph : CairoXY
 	public override void Do(string font)
 	{
 		LogB.Information("at JumpsWeightFVProfileGraph.Do");
-		initGraph(font);
+		initGraph(font, .8);
 
 		if(showFullGraph)
 			findPointMaximums(true);
@@ -155,14 +155,14 @@ public class JumpsWeightFVProfileGraph : CairoXY
 			}
 		}
 
-		plotRealPoints(false);
+		plotRealPoints(PlotTypes.POINTS);
 
 		writeTitle();
 
 		if(errorMessage != ErrorAtStart.ALLOK)
 			plotError();
 
-		endGraphDisposing();
+		endGraphDisposing(g);
 	}
 
 	protected override void writeTitle()
@@ -174,7 +174,7 @@ public class JumpsWeightFVProfileGraph : CairoXY
 		writeTextAtRight(ypos++, date, false);
 
 		ypos++;
-		writeTextAtRight(ypos++, string.Format("F0: {0} N", Math.Round(f0Rel,2)), false);
+		writeTextAtRight(ypos++, string.Format("F0: {0} N/Kg", Math.Round(f0Rel,2)), false);
 		writeTextAtRight(ypos++, string.Format("V0: {0} m/s", Math.Round(v0,2)), false);
 		writeTextAtRight(ypos++, string.Format("Pmax: {0} W", Math.Round(pmax,1)), false);
 
