@@ -32,6 +32,19 @@ public static class CairoUtil
 	 * public methods
 	 */
 
+	public static void PaintSegment (Gtk.DrawingArea darea, Cairo.Color color, int x1, int y1, int x2, int y2)
+	{
+		using (Cairo.Context g = Gdk.CairoHelper.Create (darea.GdkWindow))
+		{
+			g.Color = color;
+			g.MoveTo(x1, y1);
+			g.LineTo(x2, y2);
+			g.Stroke();
+
+			g.GetTarget ().Dispose ();
+		}
+	}
+
 	public static void PaintVerticalLinesAndRectangle (
 			Gtk.DrawingArea darea, int xposA, int xposB, bool posBuse, int topRect, int bottomRect)
 	{
@@ -86,7 +99,7 @@ public static class CairoUtil
 			paintVerticalLine(g, xposB, height, "B");
 
 			//g.SetSourceRGBA(0.906, 0.745, 0.098, .5); //Chronojump yellow, half transp
-			g.SetSourceRGBA(0.9, 0.9, 0.01, .33); //More yellow and very transp
+			g.SetSourceRGBA(0.9, 0.9, 0.01, .15); //More yellow and very transp
 
 			//create rectangle
 			int min = Math.Min(xposA, xposB) +1;
