@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2021   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -25,7 +25,7 @@ using Gtk;
 using Cairo;
 using Mono.Unix;
 
-public abstract class CairoXY
+public abstract class CairoXY : CairoGeneric
 {
 	//used on construction
 	protected List<PointF> point_l;
@@ -50,12 +50,13 @@ public abstract class CairoXY
 	protected DrawingArea area;
 	protected string title;
 	protected string jumpType;
+	protected string runType;
 	protected string date;
 	protected Cairo.Color colorBackground;
 
 	protected Cairo.Context g;
 	protected const int textHeight = 12;
-	protected const int pointsRadius = 6;
+	protected int pointsRadius = 6;
 	protected string xVariable = "";
 	protected string yVariable = "";
 	protected string xUnits = "";
@@ -66,8 +67,8 @@ public abstract class CairoXY
 	protected double minY = 1000000;
 	protected double maxY = 0;
 	double yAtMMaxY;
-	double absoluteMaxX;
-	double absoluteMaxY;
+	protected double absoluteMaxX;
+	protected double absoluteMaxY;
 	protected int graphWidth;
 	protected int graphHeight;
 
@@ -88,6 +89,7 @@ public abstract class CairoXY
 	//done to use Catalog just only on gui/cairo/xy.cs
 	//but jumpsWeightFVProfile has many messages, so done also there
 	protected string needToExecuteJumpsStr = Catalog.GetString("Need to execute jumps:");
+	protected string needToExecuteRunsStr = Catalog.GetString("Need to execute races:");
 	protected string optimalFallHeightStr = Catalog.GetString("Optimal fall height");
 	protected string heightStr = Catalog.GetString("Height");
 	protected string extraWeightStr = Catalog.GetString("Extra weight");
@@ -95,15 +97,33 @@ public abstract class CairoXY
 	protected string speedStr = Catalog.GetString("Speed");
 	protected string forceStr = Catalog.GetString("Force");
 	protected string dateStr = Catalog.GetString("Date");
+	protected string timeStr = Catalog.GetString("Time");
+	protected string distanceStr = Catalog.GetString("Distance");
 	protected string tfStr = Catalog.GetString("TF");
 	protected string tcStr = Catalog.GetString("TC");
 	protected string countStr = Catalog.GetString("Num");
 	protected string jumpTypeStr = Catalog.GetString("Jump type:");
+	protected string runTypeStr = Catalog.GetString("Race type:");
 	protected string font;
+	//protected static int lastPointPainted;
 
-	public abstract void Do(string font);
+	public virtual bool PassData (List<PointF> point_l)
+	{
+		return false;
+	}
 
-	protected void initGraph(string font)
+	public virtual void Do(string font)
+	{
+	}
+	public virtual void DoSendingList(string font, List<PointF> points_list, bool forceRedraw, PlotTypes plotType)
+	{
+	}
+
+	protected void initGraph(string font, double widthPercent1)
+	{
+		initGraph(font, widthPercent1, true);
+	}
+	protected void initGraph(string font, double widthPercent1, bool clearDrawingArea)
 	{
 		this.font = font;
 		LogB.Information("Font: " + font);
@@ -112,12 +132,15 @@ public abstract class CairoXY
 
 		//1 create context
 		g = Gdk.CairoHelper.Create (area.GdkWindow);
-		
-		//2 clear DrawingArea (white)
-		g.SetSourceRGB(1,1,1);
-		g.Paint();
 
-		graphWidth = Convert.ToInt32(area.Allocation.Width *.8);
+		if(clearDrawingArea)
+		{
+			//2 clear DrawingArea (white)
+			g.SetSourceRGB(1,1,1);
+			g.Paint();
+		}
+
+		graphWidth = Convert.ToInt32(area.Allocation.Width * widthPercent1);
 		graphHeight = area.Allocation.Height;
 
 		g.SetSourceRGB(0,0,0);
@@ -139,10 +162,29 @@ public abstract class CairoXY
 
 	//showFullGraph means that has to plot both axis at 0 and maximums have to be f0,v0
 	//used by default on jumpsWeightFVProfile
-	protected void findPointMaximums(bool showFullGraph)
+	//called from almost all methods
+	//true if changed
+	protected bool findPointMaximums(bool showFullGraph)
 	{
-		foreach(PointF p in point_l)
+		return findPointMaximums(showFullGraph, point_l);
+	}
+
+	//called from raceAnalyzer (sending it own list of points)
+	//true if changed
+	protected bool findPointMaximums(bool showFullGraph, List<PointF> points_list)
+	{
+		//foreach(PointF p in points_list)
+		/*
+		int start = lastPointPainted;
+		if(lastPointPainted < 0)
+			start = 0;
+
+		//for(int i = start; i < points_list.Count; i ++)
+		*/
+		for(int i = 0; i < points_list.Count; i ++)
 		{
+			PointF p = points_list[i];
+
 			if(p.X < minX)
 				minX = p.X;
 			if(p.X > maxX)
@@ -179,8 +221,19 @@ public abstract class CairoXY
 		separateMinXMaxXIfNeeded();
 		separateMinYMaxYIfNeeded();
 
-		absoluteMaxX = maxX;
-		absoluteMaxY = maxY;
+		bool changed = false;
+		if(maxX != absoluteMaxX)
+		{
+			absoluteMaxX = maxX;
+			changed = true;
+		}
+		if(maxY != absoluteMaxY)
+		{
+			absoluteMaxY = maxY;
+			changed = true;
+		}
+
+		return changed;
 	}
 
 	protected void plotAlternativeLineWithRealPoints (double ax, double ay, double bx, double by, bool showFullGraph)
@@ -302,13 +355,18 @@ public abstract class CairoXY
 		g.LineTo(graphWidth - outerMargins, graphHeight - outerMargins);
 		g.Stroke ();
 		printText(2, Convert.ToInt32(outerMargins/2), 0, textHeight, getYAxisLabel(), g, alignTypes.LEFT);
-		printText(graphWidth - Convert.ToInt32(outerMargins/2), graphHeight - outerMargins, 0, textHeight, getXAxisLabel(), g, alignTypes.LEFT);
-
+		printXAxisText();
 		g.Stroke ();
 		g.LineWidth = 2;
 	}
 
-	private string getXAxisLabel()
+	//this combined with paintVerticalGridLine is different on RaceAnalyzer
+	protected virtual void printXAxisText()
+	{
+		printText(graphWidth - Convert.ToInt32(outerMargins/2), graphHeight - outerMargins, 0, textHeight, getXAxisLabel(), g, alignTypes.LEFT);
+	}
+
+	protected string getXAxisLabel()
 	{
 		return getAxisLabel(xVariable, xUnits);
 	}
@@ -390,13 +448,25 @@ public abstract class CairoXY
 		g.Stroke ();
 	}
 
-	protected void plotRealPoints(bool joinByLine)
+	public enum PlotTypes { POINTS, LINES, POINTSLINES }
+
+	//called from almost all methods
+	protected void plotRealPoints (PlotTypes plotType)
 	{
-		if(joinByLine) //draw line first to not overlap the points
+		plotRealPoints (plotType, point_l, 0);
+	}
+
+	//called from raceAnalyzer (sending it own list of points)
+	protected void plotRealPoints (PlotTypes plotType, List<PointF> points_list, int startAt)
+	{
+		if(plotType == PlotTypes.LINES || plotType == PlotTypes.POINTSLINES) //draw line first to not overlap the points
 		{
 			bool firstDone = false;
-			foreach(PointF p in point_l)
+			//foreach(PointF p in points_list)
+			for(int i = startAt; i < points_list.Count; i ++)
 			{
+				PointF p = points_list[i];
+
 				double xgraph = calculatePaintX(p.X);
 				double ygraph = calculatePaintY(p.Y);
 
@@ -410,21 +480,42 @@ public abstract class CairoXY
 			g.Stroke ();
 		}
 
-		foreach(PointF p in point_l)
+//		lock (point_l) {
+//		List<PointF> point_l_copy = point_l>;
+//		foreach(PointF p in point_l_copy)
+		//foreach(PointF p in points_list)
+		/*
+		int start = lastPointPainted;
+		if(lastPointPainted < 0)
+			start = 0;
+
+		//for(int i = start; i < points_list.Count; i ++)
+		*/
+
+		if(plotType == PlotTypes.LINES)
+			return;
+
+		for(int i = startAt; i < points_list.Count; i ++)
 		{
+			PointF p = points_list[i];
+
+			//LogB.Information("point: " + p.ToString());
 			double xgraph = calculatePaintX(p.X);
 			double ygraph = calculatePaintY(p.Y);
 			g.Arc(xgraph, ygraph, pointsRadius, 0.0, 2.0 * Math.PI); //full circle
 			g.Color = colorBackground;
 			g.FillPreserve();
 			g.SetSourceRGB(0, 0, 0);
-			g.Stroke ();
+			g.Stroke (); 	//can this be done at the end?
+
+			//lastPointPainted ++;
 
 			/*
 			//print X, Y of each point
 			printText(xgraph, graphHeight - Convert.ToInt32(bottomMargin/2), 0, textHeight, Util.TrimDecimals(p.X, 2), g, true);
 			printText(Convert.ToInt32(leftMargin/2), ygraph, 0, textHeight, Util.TrimDecimals(p.Y, 2), g, true);
 			*/
+//		}
 		}
 		//getMinMaxXDrawable(graphWidth, absoluteMaxX, minX, totalMargins, totalMargins);
 	}
@@ -536,7 +627,7 @@ public abstract class CairoXY
 		g.Color = black;
 		LogB.Information("writeCoordinatesOfMouseClick done! disposing");
 
-		endGraphDisposing();
+		endGraphDisposing(g);
 
 		LogB.Information("writeCoordinatesOfMouseClick disposed!");
 	}
@@ -576,18 +667,6 @@ public abstract class CairoXY
 		writeTextAtRight(line +2, string.Format("- {0}: {1} {2}", yVariable, Util.TrimDecimals(pClosest.Y, 2), yUnits), false);
 	}
 
-	/*
-	   need to dispose because Cairo does not clean ok on win and mac:
-	   Don’t forget to manually dispose the Context and the target Surface at the end of the expose event. Automatic garbage collecting is not yet 100% working in Cairo.
-		https://www.mono-project.com/docs/tools+libraries/libraries/Mono.Cairo/
-		eg. on Linux can do the writeCoordinatesOfMouseClick() without disposing, but on win and mac does not work, so dispose always.
-	 */
-	protected void endGraphDisposing()
-	{
-		g.GetTarget().Dispose ();
-		g.Dispose ();
-	}
-
 	//TODO: fix if min == max (crashes)
 	protected enum gridTypes { BOTH, HORIZONTALLINES, VERTICALLINES }
 	protected void paintGridNiceAutoValues (double minX, double maxX, double minY, double maxY, int seps, gridTypes gridType)
@@ -654,7 +733,8 @@ public abstract class CairoXY
 		g.LineTo(graphWidth - outerMargins, ytemp);
 		printText(Convert.ToInt32(outerMargins/2), ytemp, 0, textHeight, text, g, alignTypes.CENTER);
 	}
-	protected void paintVerticalGridLine(int xtemp, string text)
+	//this combined with printXAxisText is different on RaceAnalyzer
+	protected virtual void paintVerticalGridLine(int xtemp, string text)
 	{
 		g.MoveTo(xtemp, graphHeight - outerMargins);
 		g.LineTo(xtemp, outerMargins);
@@ -781,17 +861,6 @@ public abstract class CairoXY
 	}
 	*/
 
-	//0 - 255
-	protected Cairo.Color colorFromRGB(int red, int green, int blue)
-	{
-		return new Cairo.Color(red/256.0, green/256.0, blue/256.0);
-	}
-	//0 - 65535
-	protected Cairo.Color colorFromGdk(Gdk.Color color)
-	{
-		return new Cairo.Color(color.Red/65536.0, color.Green/65536.0, color.Blue/65536.0);
-	}
-
 	protected enum alignTypes { LEFT, CENTER, RIGHT }
 	protected void printText (int x, int y, int height, int textHeight, string text, Cairo.Context g, alignTypes align)
 	{
