@@ -15,7 +15,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2019-2020   Xavier de Blas <xaviblas@gmail.com>
+ * Copyright (C) 2019-2021   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using Gtk;
@@ -112,6 +112,9 @@ public partial class ChronoJumpWindow
 			//to not allow to load a session or create a new session until close session/more
 			menus_sensitive_import_not_danger(false);
 
+			//change here SQL because radios changed before done on importing session
+			sqlChangeSessionLoadDisplay();
+
 			LogB.ThreadEnded();
 			return false;
 		}
@@ -184,6 +187,7 @@ public partial class ChronoJumpWindow
 
 			//3) simple run
 			createComboSelectRuns(false);
+			createComboSelectRunsEvolution(false);
 			UtilGtk.ComboUpdate(combo_result_runs,
 					SqliteRunType.SelectRunTypes(Constants.AllRunsNameStr(), true), ""); //without filter, only select name
 			combo_select_runs.Active = 0;
@@ -210,6 +214,8 @@ public partial class ChronoJumpWindow
 
 			reloadSession ();
 
+			app1s_scrolledwindow_import_error.Visible = false;
+
 			//chronojumpImporter.showImportCorrectlyFinished ();
 			app1s_ShowLabelImportedOk();
 		} else {
