@@ -589,7 +589,7 @@ public partial class ChronoJumpWindow
 
 
 	//on screen shown on s but export is in ms
-	public string [] GetTreeviewEncoderAnalyzeHeaders(bool screenOrCSV)
+	public string [] GetTreeviewEncoderAnalyzeHeaders(bool screenOrCSV, Constants.Menuitem_modes encoderMode)
 	{
 		string timeUnits = "(s)";
 		string distanceUnits = "(cm)";
@@ -605,14 +605,22 @@ public partial class ChronoJumpWindow
 		else
 			workString += "\n (J)";
 
-		string [] treeviewEncoderAnalyzeHeaders = {
+		string [] startArray = {
 			Catalog.GetString("Repetition") + "\n",
 			Catalog.GetString("Series") + "\n",
 			Catalog.GetString("Exercise") + "\n",
 			Catalog.GetString("Laterality") + "\n",
 			Catalog.GetString("Extra weight") + "\n(Kg)",
-			Catalog.GetString("Total weight") + "\n(Kg)",
-			Catalog.GetString("Inertia M.") + "\n(Kg*cm^2)",
+			Catalog.GetString("Total weight") + "\n(Kg)"
+		};
+
+		string [] inertiaArray = {
+			Catalog.GetString("Inertia M.") + "\n(Kg*cm^2)", 	//inertial
+			Catalog.GetString("Diameter") + "\n(cm)",		//inertial
+			Catalog.GetString("Equivalent mass") + "\n(Kg)"		//inertial
+		};
+
+		string [] endArray = {
 			Catalog.GetString("Start") + "\n" + timeUnits,
 			Catalog.GetString("Duration") + "\n" + timeUnits,
 			Catalog.GetString("Distance") + "\n" + distanceUnits,
@@ -630,13 +638,30 @@ public partial class ChronoJumpWindow
 			workString,
 			Catalog.GetString("Impulse") + "\n (N*s)"
 		};
-		return treeviewEncoderAnalyzeHeaders;
+
+		if(encoderMode == Constants.Menuitem_modes.POWERGRAVITATORY)
+		{
+			string [] headers = new string[startArray.Length + endArray.Length];
+			startArray.CopyTo(headers, 0);
+			endArray.CopyTo(headers, startArray.Length);
+			return headers;
+		} else {
+			string [] headers = new string[startArray.Length + inertiaArray.Length + endArray.Length];
+			startArray.CopyTo(headers, 0);
+			inertiaArray.CopyTo(headers, startArray.Length);
+			endArray.CopyTo(headers, startArray.Length + inertiaArray.Length);
+			return headers;
+		}
 	}
 
 	bool lastTreeviewEncoderAnalyzeIsNeuromuscular = false;
 
-	private int createTreeViewEncoderAnalyze(string contents) {
-		string [] columnsString = GetTreeviewEncoderAnalyzeHeaders(true); //screen
+	private int createTreeViewEncoderAnalyze(string contents, Constants.Menuitem_modes encoderMode)
+	{
+		//note we pass powerinertial because we want here all columns but only relevant will shown
+		//on the other hand, on_button_encoder_save_table_file_selected will need to show the relevant columns
+		string [] columnsString = GetTreeviewEncoderAnalyzeHeaders(true, //screen
+				Constants.Menuitem_modes.POWERINERTIAL);
 
 		ArrayList encoderAnalyzeCurves = new ArrayList ();
 
@@ -708,7 +733,9 @@ public partial class ChronoJumpWindow
 							cells[21],	//laterality
 							Convert.ToDouble(Util.ChangeDecimalSeparator(cells[4])), 	//extraWeight
 							totalMass, 							//displaceWeight
-							Convert.ToInt32(cells[22]), 					//inertia
+							Convert.ToInt32(cells[22]), 					//inertia M. (inertial)
+							Convert.ToDouble(cells[23]), 					//diameter (inertial)
+							Convert.ToDouble(cells[24]), 					//equivalent mass (inertial)
 							cells[5], cells[6], cells[7], 
 							cells[8], cells[9], cells[10], 
 							cells[11], cells[12], cells[13],
@@ -745,7 +772,15 @@ public partial class ChronoJumpWindow
 		treeview_encoder_analyze_curves.HeadersVisible=true;
 
 		int i=0;
-		foreach(string myCol in columnsString) {
+		foreach(string myCol in columnsString)
+		{
+			//do not show inertia moment, diameter, equivalent mass on powergravitatory
+			if(encoderMode == Constants.Menuitem_modes.POWERGRAVITATORY && (i == 6 || i == 7 || i == 8))
+			{
+				i ++;
+				continue;
+			}
+
 			Gtk.TreeViewColumn aColumn = new Gtk.TreeViewColumn ();
 			CellRendererText aCell = new CellRendererText();
 			aColumn.Title=myCol;
@@ -753,8 +788,7 @@ public partial class ChronoJumpWindow
 
 			//crt1.Foreground = "red";
 			//crt1.Background = "blue";
-		
-		
+
 			switch(i){	
 				case 0:
 					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderNAnalyze));
@@ -775,54 +809,60 @@ public partial class ChronoJumpWindow
 					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderDisplacedWeight));
 					break;
 				case 6:
-					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderInertia));
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderInertia)); 	//inertial
 					break;
 				case 7:
-					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderStart));
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderDiameter)); 	//inertial
 					break;
 				case 8:
-					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderDuration));
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderEquivalentMass)); 	//inertial
 					break;
 				case 9:
-					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderHeight));
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderStart));
 					break;
 				case 10:
-					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderMeanSpeed));
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderDuration));
 					break;
 				case 11:
-					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderMaxSpeed));
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderHeight));
 					break;
 				case 12:
-					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderMaxSpeedT));
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderMeanSpeed));
 					break;
 				case 13:
-					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderMeanPower));
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderMaxSpeed));
 					break;
 				case 14:
-					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderPeakPower));
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderMaxSpeedT));
 					break;
 				case 15:
-					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderPeakPowerT));
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderMeanPower));
 					break;
 				case 16:
-					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderPP_PPT));
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderPeakPower));
 					break;
 				case 17:
-					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderMeanForce));
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderPeakPowerT));
 					break;
 				case 18:
-					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderMaxForce));
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderPP_PPT));
 					break;
 				case 19:
-					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderMaxForceT));
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderMeanForce));
 					break;
 				case 20:
-					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderMaxForce_maxForceT));
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderMaxForce));
 					break;
 				case 21:
-					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderWork));
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderMaxForceT));
 					break;
 				case 22:
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderMaxForce_maxForceT));
+					break;
+				case 23:
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderWork));
+					break;
+				case 24:
 					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderImpulse));
 					break;
 			}
@@ -1013,7 +1053,7 @@ public partial class ChronoJumpWindow
 		//Check if it's number
 		if(! curve.IsNumberN()) {
 			(cell as Gtk.CellRendererText).Text = "";
-			LogB.Error("Curve is not number at RenderN:" + curve.ToCSV(true, "COMMA", preferences.encoderWorkKcal, ""));
+			LogB.Error("Curve is not number at RenderN:" + curve.ToCSV(true, current_menuitem_mode, "COMMA", preferences.encoderWorkKcal, ""));
 			return;
 		}
 		
@@ -1050,7 +1090,7 @@ public partial class ChronoJumpWindow
 		//Check if it's valid
 		if(! curve.IsValidN()) {
 			(cell as Gtk.CellRendererText).Text = "";
-			LogB.Error("Curve is not valid at RenderNAnalyze:" + curve.ToCSV(false, "COMMA", preferences.encoderWorkKcal, ""));
+			LogB.Error("Curve is not valid at RenderNAnalyze:" + curve.ToCSV(false, current_menuitem_mode, "COMMA", preferences.encoderWorkKcal, ""));
 			return;
 		}
 			
@@ -1158,6 +1198,23 @@ public partial class ChronoJumpWindow
 		renderBoldIfNeeded(cell, curve, str);
 	}
 
+	private void RenderDiameter (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
+	{
+		EncoderCurve curve = (EncoderCurve) model.GetValue (iter, 0);
+
+		string str = String.Format(UtilGtk.TVNumPrint(curve.Diameter.ToString(),1,0),Convert.ToDouble(curve.Diameter));
+
+		renderBoldIfNeeded(cell, curve, str);
+	}
+
+	private void RenderEquivalentMass (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
+	{
+		EncoderCurve curve = (EncoderCurve) model.GetValue (iter, 0);
+
+		string str = String.Format(UtilGtk.TVNumPrint(curve.EquivalentMass.ToString(),6,2),Convert.ToDouble(curve.EquivalentMass));
+
+		renderBoldIfNeeded(cell, curve, str);
+	}
 
 	private void RenderStart (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
 	{
@@ -1582,7 +1639,7 @@ public partial class ChronoJumpWindow
 		//LogB.Information(string.Format("cellsString: {0}", Util.StringArrayToString(cells, ";")));
 		if(captureOrAnalyze && cells.Length < 21) 		//from 0 to 20
 			return false;
-		else if(! captureOrAnalyze && cells.Length < 23) 	//from 0 to 22
+		else if(! captureOrAnalyze && cells.Length < 25) 	//from 0 to 24
 			return false;
 
 		return true;
@@ -1622,9 +1679,12 @@ public partial class ChronoJumpWindow
 
 		//capture does not return inerta
 		//analyze returns inertia (can be different on "saved curves") comes as Kg*m^2, convert it to Kg*cm^2
+		//analyze returns also diameter and equivalentMass (both used on inertial)
 		if(! captureOrAnalyze) {
 			double inertiaInM = Convert.ToDouble(Util.ChangeDecimalSeparator(cells[22]));
 			cells[22] = (Convert.ToInt32(inertiaInM * 10000)).ToString();
+			cells[23] = Util.ChangeDecimalSeparator(cells[23]);
+			cells[24] = Util.ChangeDecimalSeparator(cells[24]);
 		}
 
 		return cells;
