@@ -55,7 +55,7 @@ public class ForceSensorExerciseWindow
 	//force tab
 	[Widget] Gtk.Label label_force;
 	[Widget] Gtk.TextView textview_force_explanation;
-	[Widget] Gtk.RadioButton radio_force_sensor;
+	[Widget] Gtk.RadioButton radio_force_sensor_raw;
 	[Widget] Gtk.RadioButton radio_force_resultant;	
 
 	//fixation tab
@@ -73,9 +73,10 @@ public class ForceSensorExerciseWindow
 	[Widget] Gtk.HBox hbox_body_mass_add;
 	[Widget] Gtk.SpinButton spin_body_mass_add;
 
-	//repetitions tab
-	[Widget] Gtk.CheckButton check_show_ecc;
-	[Widget] Gtk.CheckButton check_detect_repetitions_from_prefs;
+	//repetitions detect tab
+	[Widget] Gtk.Label label_detect_repetitions;
+	[Widget] Gtk.RadioButton radio_detect_repetitions_from_prefs;
+	[Widget] Gtk.RadioButton radio_detect_repetitions_custom;
 	[Widget] Gtk.HBox hbox_detect_repetitions_preferences;
 	[Widget] Gtk.HBox hbox_detect_repetitions_elastic;
 	[Widget] Gtk.HBox hbox_detect_repetitions_not_elastic;
@@ -88,6 +89,14 @@ public class ForceSensorExerciseWindow
 	[Widget] Gtk.SpinButton spin_force_sensor_not_elastic_ecc_min_force;
 	[Widget] Gtk.SpinButton spin_force_sensor_not_elastic_con_min_force;
 
+	//repetitions show tab
+	//[Widget] Gtk.CheckButton check_show_ecc;
+	[Widget] Gtk.RadioButton radio_reps_show_concentric;
+	[Widget] Gtk.RadioButton radio_reps_show_both;
+	[Widget] Gtk.Alignment alignment_reps_show_both;
+	[Widget] Gtk.RadioButton radio_reps_show_both_together;
+	[Widget] Gtk.RadioButton radio_reps_show_both_separated;
+
 	//other tab
 	[Widget] Gtk.Label label_other;
 	[Widget] Gtk.TextView textview_other_explanation;
@@ -100,7 +109,7 @@ public class ForceSensorExerciseWindow
 	public bool Success;
 	private ForceSensorExercise exercise;
 
-	//values on preferences, useful to show them unsensitive if the user clicks on check_detect_repetitions_from_prefs
+	//values on preferences, useful to show them unsensitive if the radio_detect_repetitions_from_prefs.Active
 	//on add and on edit exercise
 	private double prefsForceSensorElasticEccMinDispl;
 	private double prefsForceSensorElasticConMinDispl;
@@ -109,9 +118,10 @@ public class ForceSensorExerciseWindow
 
 	private enum modesEnum { EDIT, ADD }
 	private modesEnum modeEnum;
-	private enum Pages { FORCE, FIXATION, MASS, REPETITIONS, OTHER }
+	private enum Pages { FORCE, FIXATION, MASS, REPSDETECT, REPSSHOW, OTHER }
 	private enum Options { FORCE_SENSOR, FORCE_RESULTANT, FIXATION_ELASTIC, FIXATION_NOT_ELASTIC,
-		MASS_ADD, MASS_SUBTRACT, MASS_NOTHING, REPETITIONS_PREFS, REPETITIONS_NO_PREFS, OTHER }
+		MASS_ADD, MASS_SUBTRACT, MASS_NOTHING,
+		REPETITIONS_PREFS, REPETITIONS_NO_PREFS, REPETITIONS_SHOW, OTHER }
 
 	static ForceSensorExerciseWindow ForceSensorExerciseWindowBox;
 
@@ -135,6 +145,7 @@ public class ForceSensorExerciseWindow
 			UtilGtk.WindowColor(force_sensor_exercise, Config.ColorBackground);
 			UtilGtk.ContrastLabelsLabel (Config.ColorBackgroundIsDark, label_header);
 			UtilGtk.ContrastLabelsLabel (Config.ColorBackgroundIsDark, label_help);
+			UtilGtk.ContrastLabelsLabel (Config.ColorBackgroundIsDark, label_error);
 			UtilGtk.ContrastLabelsLabel (Config.ColorBackgroundIsDark, label_radio_desc_examples_desc);
 			UtilGtk.ContrastLabelsLabel (Config.ColorBackgroundIsDark, label_radio_desc_examples_examples);
 		}
@@ -189,7 +200,7 @@ public class ForceSensorExerciseWindow
 			}
 
 			ForceSensorExerciseWindowBox.repetitionsToGUI(
-					exercise.EccReps, repsFromPrefs,
+					exercise.RepetitionsShow, repsFromPrefs,
 					em, cm,
 					prefsForceSensorNotElasticEccMinForce, prefsForceSensorNotElasticConMinForce);
 		} else {
@@ -207,7 +218,7 @@ public class ForceSensorExerciseWindow
 			}
 
 			ForceSensorExerciseWindowBox.repetitionsToGUI(
-					exercise.EccReps, repsFromPrefs,
+					exercise.RepetitionsShow, repsFromPrefs,
 					prefsForceSensorElasticEccMinDispl, prefsForceSensorElasticConMinDispl,
 					Convert.ToInt32(em), Convert.ToInt32(cm));
 		}
@@ -239,7 +250,7 @@ public class ForceSensorExerciseWindow
 		ForceSensorExerciseWindowBox.prefsForceSensorNotElasticConMinForce = prefsForceSensorNotElasticConMinForce;
 
 		ForceSensorExerciseWindowBox.repetitionsToGUI(
-				false, true, //show ecc, repsFromPrefs
+				ForceSensorExercise.RepetitionsShowTypes.BOTHTOGETHER, true, //repsFromPrefs
 				prefsForceSensorElasticEccMinDispl, prefsForceSensorElasticConMinDispl,
 				prefsForceSensorNotElasticEccMinForce, prefsForceSensorNotElasticConMinForce);
 
@@ -261,11 +272,13 @@ public class ForceSensorExerciseWindow
 		label_force.Text = "<b>" + label_force.Text + "</b>";
 		label_fixation.Text = "<b>" + label_fixation.Text + "</b>";
 		label_mass.Text = "<b>" + label_mass.Text + "</b>";
+		label_detect_repetitions.Text = "<b>" + label_detect_repetitions.Text + "</b>";
 		label_other.Text = "<b>" + label_other.Text + "</b>";
 
 		label_force.UseMarkup = true;
 		label_fixation.UseMarkup = true;
 		label_mass.UseMarkup = true;
+		label_detect_repetitions.UseMarkup = true;
 		label_other.UseMarkup = true;
 
 		// 2. textviews of explanations of each page
@@ -294,7 +307,7 @@ public class ForceSensorExerciseWindow
 		if(exercise.ForceResultant)
 			radio_force_resultant.Active = true;
 		else
-			radio_force_sensor.Active = true;
+			radio_force_sensor_raw.Active = true;
 
 		if(exercise.Elastic)
 			radio_fixation_elastic.Active = true;
@@ -315,16 +328,37 @@ public class ForceSensorExerciseWindow
 	}
 
 	private void repetitionsToGUI(
-			bool showEcc, bool repsFromPrefs,
+			ForceSensorExercise.RepetitionsShowTypes repetitionsShow, bool repsFromPrefs,
 			double forceSensorElasticEccMinDispl, double forceSensorElasticConMinDispl,
 			int forceSensorNotElasticEccMinForce, int forceSensorNotElasticConMinForce)
 	{
-		check_show_ecc.Active = showEcc;
-		check_detect_repetitions_from_prefs.Active = repsFromPrefs;
+		//reps detect tab
+		if(repsFromPrefs)
+			radio_detect_repetitions_from_prefs.Active = true;
+		else
+			radio_detect_repetitions_custom.Active =true;
+
 		spin_force_sensor_elastic_ecc_min_displ.Value = forceSensorElasticEccMinDispl;
 		spin_force_sensor_elastic_con_min_displ.Value = forceSensorElasticConMinDispl;
 		spin_force_sensor_not_elastic_ecc_min_force.Value = forceSensorNotElasticEccMinForce;
 		spin_force_sensor_not_elastic_con_min_force.Value = forceSensorNotElasticConMinForce;
+
+
+		//reps show tab
+		if(repetitionsShow == ForceSensorExercise.RepetitionsShowTypes.CONCENTRIC)
+		{
+			radio_reps_show_concentric.Active = true;
+			alignment_reps_show_both.Visible = false;
+		} else
+		{
+			radio_reps_show_both.Active = true;
+			alignment_reps_show_both.Visible = true;
+
+			if(repetitionsShow == ForceSensorExercise.RepetitionsShowTypes.BOTHTOGETHER)
+				radio_reps_show_both_together.Active = true;
+			else
+				radio_reps_show_both_separated.Active = true;
+		}
 	}
 
 	private string getTopExplanations (Pages p)
@@ -336,7 +370,9 @@ public class ForceSensorExerciseWindow
 			str = Catalog.GetString("How the force is transmitted to the sensor");
 		else if(p == Pages.MASS)
 			str = Catalog.GetString("Depending on the exercise and configuration of the test, the total mass (mass of the person and the extra load) can affect the sensor measuring. Select how to manage this effect.");
-		else if(p == Pages.REPETITIONS)
+		else if(p == Pages.REPSDETECT)
+			str = ""; //not shown
+		else if(p == Pages.REPSSHOW)
 			str = ""; //not shown
 		else { //if(p == Pages.OTHER)
 			if(radio_force_resultant.Active && radio_mass_add.Active)
@@ -354,7 +390,7 @@ public class ForceSensorExerciseWindow
 		if(o == Options.FORCE_SENSOR)
 			str = Catalog.GetString("When you are interested only in the force transmitted to the force sensor. This option do NOT take into account the effect of the weight or the acceleration of a mass.");
 		else if(o == Options.FORCE_RESULTANT)
-			str = Catalog.GetString("When you want the resultant of all the forces exerted by the person. This value is the vector module of the resultant force vector. This option allows to take into account the effect of the weight or the acceleration of a mass.");
+			str = Catalog.GetString("When you want the resultant of all the forces exerted by the person. This value is the vector module of the resultant force vector. This option allows to take into account the effect of the weight or the acceleration of a mass.") + " " + Catalog.GetString("The result will always be in absolute values.");
 		else if(o == Options.FIXATION_ELASTIC)
 			str = Catalog.GetString("If, exerting a force, some element is significantly elongated it means that you are using elastic elements. Knowing the characteristics of the elastic elements allows to calculate positions, velocities and accelerations during the exercise");
 		else if(o == Options.FIXATION_NOT_ELASTIC)
@@ -369,6 +405,8 @@ public class ForceSensorExerciseWindow
 			str = Catalog.GetString("If user changes values on preferences, these values will automatically change.");
 		else if(o == Options.REPETITIONS_NO_PREFS)
 			str = Catalog.GetString("These values will be used to detect repetitions.");
+		else if(o == Options.REPETITIONS_SHOW)
+			str = Catalog.GetString("Detected repetitions will show only concentric phase or both.");
 		else //if(o == Options.OTHER)
 			str = Catalog.GetString("0 means horizontally") + "\n" +
 				Catalog.GetString("90 means vertically with the person above the sensor") + "\n" +
@@ -386,9 +424,9 @@ public class ForceSensorExerciseWindow
 		else if(o == Options.FORCE_RESULTANT)
 			str = "1.- " + Catalog.GetString("Isometric squat with the force sensor fixed between the floor and the body.") +
 				"\n2.- " + Catalog.GetString("Movements where a significant mass is accelerated.") +
-				"\n3.- " + Catalog.GetString("Horizontal movements where the sensor don't measure the gravitational vertical forces...)");
+				"\n3.- " + Catalog.GetString("Horizontal movements where the sensor don't measure the gravitational vertical forces …)");
 		else if(o == Options.FIXATION_ELASTIC)
-			str =  Catalog.GetString("Rubber bands, springs, flexible material ...");
+			str =  Catalog.GetString("Rubber bands, springs, flexible material …");
 		else if(o == Options.FIXATION_NOT_ELASTIC)
 			str = "1.- " + Catalog.GetString("In an isometric squat with the force sensor fixed between the floor and the body, increasing the mass don't affect the measure of the sensor because the weight is supported by the lower limbs, not the sensor.") +
 				"\n2.- " + Catalog.GetString("Running in a threadmill against a rubber. The sensor is measuring the force that a rubber is transmitting horizontally to a subject running in a threadmill. The body weight is added to the total force exerted by the subject.");
@@ -400,7 +438,9 @@ public class ForceSensorExerciseWindow
 		else if(o == Options.MASS_NOTHING)
 			str = "1.- " + Catalog.GetString("Nordic hamstring. In a Nordic hamstring with the sensor attached to the ankle, the weight affects the values of the sensor but this weight is supported by the hamstrings we are measuring.") +
 				"\n2.- " + Catalog.GetString("Pulling on a TRX. Pulling from a TRX implies overcome the body weight. This body weight is also measured by the sensor.");
-		//else if(o == Options.REPETITIONS)
+		//else if(o == Options.REPSDETECT)
+		//	str = ""; //not shown
+		//else if(o == Options.REPSSHOW)
 		//	str = ""; //not shown
 		else //if(o == Options.OTHER)
 			str = "";
@@ -430,6 +470,8 @@ public class ForceSensorExerciseWindow
 			str = Catalog.GetString("Repetitions according to preferences");
 		else if(o == Options.REPETITIONS_NO_PREFS)
 			str = Catalog.GetString("Repetitions using custom values");
+		else if(o == Options.REPETITIONS_SHOW)
+			str = Catalog.GetString("Show repetitions");
 		else //if(o == Options.OTHER)
 			str = Catalog.GetString("Angle explanation");
 
@@ -459,7 +501,7 @@ public class ForceSensorExerciseWindow
 		{
 			button_back.Sensitive = false;
 
-			if(radio_force_sensor.Active) {
+			if(radio_force_sensor_raw.Active) {
 				desc = getDescription(Options.FORCE_SENSOR);
 				ex = getExample(Options.FORCE_SENSOR);
 				set_notebook_desc_example_labels(Options.FORCE_SENSOR);
@@ -499,9 +541,9 @@ public class ForceSensorExerciseWindow
 			}
 			hbox_body_mass_add.Sensitive = radio_mass_add.Active;
 		}
-		else if(p == Pages.REPETITIONS)
+		else if(p == Pages.REPSDETECT)
 		{
-			if(radio_force_sensor.Active || ! radio_fixation_elastic.Active)
+			if(radio_force_sensor_raw.Active || ! radio_fixation_elastic.Active)
 			{
 				label_repetitions_prefs_ecc_value.Text = prefsForceSensorNotElasticEccMinForce.ToString();
 				label_repetitions_prefs_con_value.Text = prefsForceSensorNotElasticConMinForce.ToString();
@@ -514,24 +556,31 @@ public class ForceSensorExerciseWindow
 				label_repetitions_prefs_con_units.Text = "m";
 			}
 
-			if(check_detect_repetitions_from_prefs.Active)
+
+			//visibilities
+			if(radio_force_sensor_raw.Active || ! radio_fixation_elastic.Active)
 			{
-				hbox_detect_repetitions_preferences.Visible = true;
+				hbox_detect_repetitions_not_elastic.Visible = true;
 				hbox_detect_repetitions_elastic.Visible = false;
-				hbox_detect_repetitions_not_elastic.Visible = false;
 			} else {
-				hbox_detect_repetitions_preferences.Visible = false;
-				if(radio_force_sensor.Active || ! radio_fixation_elastic.Active) {
-					hbox_detect_repetitions_not_elastic.Visible = true;
-					hbox_detect_repetitions_elastic.Visible = false;
-				} else {
-					hbox_detect_repetitions_not_elastic.Visible = false;
-					hbox_detect_repetitions_elastic.Visible = true;
-				}
+				hbox_detect_repetitions_not_elastic.Visible = false;
+				hbox_detect_repetitions_elastic.Visible = true;
+			}
+
+			//sensitiveness
+			if(radio_detect_repetitions_from_prefs.Active)
+			{
+				hbox_detect_repetitions_preferences.Sensitive = true;
+				hbox_detect_repetitions_elastic.Sensitive = false;
+				hbox_detect_repetitions_not_elastic.Sensitive = false;
+			} else {
+				hbox_detect_repetitions_preferences.Sensitive = false;
+				hbox_detect_repetitions_elastic.Sensitive = true;
+				hbox_detect_repetitions_not_elastic.Sensitive = true;
 			}
 
 			Options o = Options.REPETITIONS_PREFS;
-			if(! check_detect_repetitions_from_prefs.Active)
+			if(! radio_detect_repetitions_from_prefs.Active)
 				o = Options.REPETITIONS_NO_PREFS;
 
 			desc = getDescription(o);
@@ -543,6 +592,21 @@ public class ForceSensorExerciseWindow
 			//notebook_desc_examples.CurrentPage = 0;
 			notebook_desc_examples.GetNthPage(1).Hide();
 		}
+		else if(p == Pages.REPSSHOW)
+		{
+			if(radio_reps_show_concentric.Active)
+				alignment_reps_show_both.Visible = false;
+			else if(radio_reps_show_both.Active)
+				alignment_reps_show_both.Visible = true;
+
+			desc = getDescription(Options.REPETITIONS_SHOW);
+			ex = getExample(Options.REPETITIONS_SHOW);
+			set_notebook_desc_example_labels(Options.REPETITIONS_SHOW);
+
+			radio_desc_examples_desc.Active = true;
+			radio_desc_examples_examples.Hide();
+			notebook_desc_examples.GetNthPage(1).Hide();
+		}
 		else // if(p == Pages.OTHER)
 		{
 			button_next.Visible = false;
@@ -574,8 +638,8 @@ public class ForceSensorExerciseWindow
 
 	private void on_button_next_clicked (object o, EventArgs args)
 	{
-		if(notebook_main.CurrentPage == Convert.ToInt32(Pages.FORCE) && radio_force_sensor.Active)
-			notebook_main.CurrentPage = Convert.ToInt32(Pages.REPETITIONS);
+		if(notebook_main.CurrentPage == Convert.ToInt32(Pages.FORCE) && radio_force_sensor_raw.Active)
+			notebook_main.CurrentPage = Convert.ToInt32(Pages.REPSDETECT);
 		else if(notebook_main.CurrentPage < Convert.ToInt32(Pages.OTHER))
 			notebook_main.CurrentPage ++;
 		else
@@ -585,7 +649,7 @@ public class ForceSensorExerciseWindow
 	}
 	private void on_button_back_clicked (object o, EventArgs args)
 	{
-		if(notebook_main.CurrentPage == Convert.ToInt32(Pages.REPETITIONS) && radio_force_sensor.Active)
+		if(notebook_main.CurrentPage == Convert.ToInt32(Pages.REPSDETECT) && radio_force_sensor_raw.Active)
 			notebook_main.CurrentPage = Convert.ToInt32(Pages.FORCE);
 		else if(notebook_main.CurrentPage > Convert.ToInt32(Pages.FORCE))
 			notebook_main.CurrentPage --;
@@ -608,14 +672,24 @@ public class ForceSensorExerciseWindow
 		managePage(Pages.MASS);
 	}
 
+	private void on_radio_detect_repetitions_toggled (object o, EventArgs args)
+	{
+		managePage(Pages.REPSDETECT);
+	}
+
+	/*
 	private void on_check_show_ecc_toggled (object o, EventArgs args)
 	{
 		managePage(Pages.REPETITIONS);
 	}
-
-	private void on_check_detect_repetitions_from_prefs_toggled (object o, EventArgs args)
+	*/
+	private void on_radio_reps_show_concentric_toggled (object o, EventArgs args)
 	{
-		managePage(Pages.REPETITIONS);
+		managePage(Pages.REPSSHOW);
+	}
+	private void on_radio_reps_show_both_toggled (object o, EventArgs args)
+	{
+		managePage(Pages.REPSSHOW);
 	}
 
 	private void on_entry_name_changed (object o, EventArgs args)
@@ -666,14 +740,14 @@ public class ForceSensorExerciseWindow
 
 		double eccMin = -1;
 		double conMin = -1;
-		if(! check_detect_repetitions_from_prefs.Active)
+		if(! radio_detect_repetitions_from_prefs.Active)
 		{
-			if(radio_fixation_elastic.Active) {
-				eccMin = spin_force_sensor_elastic_ecc_min_displ.Value;
-				conMin = spin_force_sensor_elastic_con_min_displ.Value;
-			} else {
+			if(radio_force_sensor_raw.Active || ! radio_fixation_elastic.Active) {
 				eccMin = spin_force_sensor_not_elastic_ecc_min_force.Value;
 				conMin = spin_force_sensor_not_elastic_con_min_force.Value;
+			} else {
+				eccMin = spin_force_sensor_elastic_ecc_min_displ.Value;
+				conMin = spin_force_sensor_elastic_con_min_displ.Value;
 			}
 		}
 
@@ -688,6 +762,14 @@ public class ForceSensorExerciseWindow
 		if(modeEnum == modesEnum.EDIT)
 			myID = exercise.UniqueID;
 
+		ForceSensorExercise.RepetitionsShowTypes repetitionsShow;
+		if(radio_reps_show_concentric.Active)
+			repetitionsShow = ForceSensorExercise.RepetitionsShowTypes.CONCENTRIC;
+		else if(radio_reps_show_both.Active && radio_reps_show_both_together.Active)
+			repetitionsShow = ForceSensorExercise.RepetitionsShowTypes.BOTHTOGETHER;
+		else //if(radio_reps_show_both.Active && radio_reps_show_both_separated.Active)
+			repetitionsShow = ForceSensorExercise.RepetitionsShowTypes.BOTHSEPARATED;
+
 		ForceSensorExercise exerciseTemp = new ForceSensorExercise(
 				myID, entry_name.Text,
 				percentBodyWeight,
@@ -697,7 +779,7 @@ public class ForceSensorExerciseWindow
 				radio_mass_subtract.Active, 	//tareBeforeCapture
 				radio_force_resultant.Active,
 				radio_fixation_elastic.Active,
-				check_show_ecc.Active, eccMin, conMin);
+				repetitionsShow, eccMin, conMin);
 
 		if(modeEnum == modesEnum.ADD)
 		{
