@@ -69,6 +69,7 @@ public class GenericWindow
 	[Widget] Gtk.ComboBox combo_all_none_selected;
 	[Widget] Gtk.SpinButton spin_feet;
 	[Widget] Gtk.SpinButton spin_inches;
+	[Widget] Gtk.Label label_before_textview_treeview;
 	[Widget] Gtk.ScrolledWindow scrolled_window_textview;
 	[Widget] Gtk.TextView textview;
 	[Widget] Gtk.ScrolledWindow scrolled_window_treeview;
@@ -81,6 +82,7 @@ public class GenericWindow
 	[Widget] Gtk.Button button_row_play;
 	[Widget] Gtk.Button button_row_delete;
 
+	[Widget] Gtk.Label label_treeviewload_row;
 	[Widget] Gtk.Button button_treeviewload_row_edit;
 	[Widget] Gtk.Button button_treeviewload_row_delete;
 	[Widget] Gtk.Button button_treeviewload_row_play;
@@ -104,7 +106,7 @@ public class GenericWindow
 	private TreeStore store;
 	private bool textviewChanging = false;
 
-	public enum EditActions { NONE, EDITPLAYDELETE, DELETE }
+	public enum EditActions { NONE, EDITDELETE, EDITPLAYDELETE, DELETE }
 
 	//used to read data, see if it's ok, and print an error message.
 	//if all is ok, destroy it with HideAndNull()
@@ -120,7 +122,7 @@ public class GenericWindow
 	public int uniqueID; 			//used on encoder & forceSensor edit exercise
 
 	public enum Types { UNDEFINED, ENCODER_SESSION_LOAD, 
-		ENCODER_SEL_REPS_IND_CURRENT_SESS, ENCODER_SEL_REPS_IND_ALL_SESS, ENCODER_SEL_REPS_GROUP_CURRENT_SESS };
+		ENCODER_SEL_REPS_IND_CURRENT_SESS, ENCODER_SEL_REPS_IND_ALL_SESS, ENCODER_SEL_REPS_GROUP_CURRENT_SESS, TAGSESSION };
 	//used to decide if a genericWin has to be recreated
 	public Types Type;
 
@@ -141,6 +143,7 @@ public class GenericWindow
 			UtilGtk.ContrastLabelsLabel (Config.ColorBackgroundIsDark, label_error);
 			UtilGtk.ContrastLabelsLabel (Config.ColorBackgroundIsDark, hbox_combo_label);
 			UtilGtk.ContrastLabelsLabel (Config.ColorBackgroundIsDark, label_comment);
+			UtilGtk.ContrastLabelsLabel (Config.ColorBackgroundIsDark, label_treeviewload_row);
 		}
 		
 		generic_window.Resizable = false;
@@ -225,12 +228,14 @@ public class GenericWindow
 		hbox_height_metric.Hide();
 		check1.Hide();
 		hbox_edit_row.Hide();
+		label_treeviewload_row.Hide();
 		button_treeviewload_row_edit.Hide();
 		button_treeviewload_row_play.Hide();
 		button_treeviewload_row_delete.Hide();
 		hbox_all_none_selected.Hide();
 		hbox_combo_all_none_selected.Hide();
 		hbuttonbox_middle.Hide();
+		label_before_textview_treeview.Hide();
 		scrolled_window_textview.Hide();
 		scrolled_window_treeview.Hide();
 	}
@@ -303,6 +308,9 @@ public class GenericWindow
 		else if(stuff == Constants.GenericWindowShow.BUTTONMIDDLE) {
 			hbuttonbox_middle.Show();
 		}
+		else if(stuff == Constants.GenericWindowShow.LABELBEFORETEXTVIEWTREEVIEW) {
+			label_before_textview_treeview.Show();
+		}
 		else if(stuff == Constants.GenericWindowShow.TEXTVIEW) {
 			scrolled_window_textview.Show();
 		}
@@ -627,8 +635,20 @@ public class GenericWindow
 
 		this.activateRowAcceptsWindow = activateRowAcceptsWindow;
 
-		if(editAction == EditActions.EDITPLAYDELETE)
+		if(editAction == EditActions.EDITDELETE)
 		{
+			label_treeviewload_row.Sensitive = false;
+			label_treeviewload_row.Visible = true;
+			button_treeviewload_row_edit.Sensitive = false;
+			button_treeviewload_row_edit.Visible = true;
+			button_treeviewload_row_delete.Sensitive = false;
+			button_treeviewload_row_delete.Visible = true;
+			button_row_edit = new Gtk.Button();
+			button_row_delete = new Gtk.Button();
+		} else if(editAction == EditActions.EDITPLAYDELETE)
+		{
+			label_treeviewload_row.Sensitive = false;
+			label_treeviewload_row.Visible = true;
 			button_treeviewload_row_edit.Sensitive = false;
 			button_treeviewload_row_edit.Visible = true;
 			button_treeviewload_row_play.Sensitive = false;
@@ -640,6 +660,8 @@ public class GenericWindow
 			button_row_delete = new Gtk.Button();
 		} else if(editAction == EditActions.DELETE)
 		{
+			label_treeviewload_row.Sensitive = false;
+			label_treeviewload_row.Visible = true;
 			button_row_delete = new Gtk.Button();
 			button_treeviewload_row_delete.Sensitive = false;
 			button_treeviewload_row_delete.Visible = true;
@@ -716,6 +738,7 @@ public class GenericWindow
 		if (treeview.Selection.GetSelected (out myModel, out iter))
 		{
 			SetButtonAcceptSensitive(true);
+			label_treeviewload_row.Sensitive = true;
 			button_treeviewload_row_edit.Sensitive = true;
 			button_treeviewload_row_delete.Sensitive = true;
 
@@ -725,6 +748,7 @@ public class GenericWindow
 		else
 		{
 			SetButtonAcceptSensitive(false);
+			label_treeviewload_row.Sensitive = false;
 			button_treeviewload_row_edit.Sensitive = false;
 			button_treeviewload_row_delete.Sensitive = false;
 			button_treeviewload_row_play.Sensitive = false;
@@ -739,6 +763,7 @@ public class GenericWindow
 		TreeModel myModel = treeview.Model;
 		if (treeview.Selection.GetSelected (out myModel, out iter))
 		{
+			label_treeviewload_row.Sensitive = false;
 			button_treeviewload_row_edit.Sensitive = true;
 			button_treeviewload_row_play.Sensitive = true;
 			button_treeviewload_row_delete.Sensitive = true;
@@ -841,7 +866,7 @@ public class GenericWindow
 			if(! Util.FoundInArrayList(nonSensitiveRows, 
 						Convert.ToInt32(args.Path))) {
 				bool val = (bool) store.GetValue (iter, column);
-				//Log.WriteLine (string.Format("toggled {0} with value {1}", args.Path, !val));
+				LogB.Information (string.Format("toggled {0} with value {1}", args.Path, !val));
 
 				store.SetValue (iter, column, !val);
 
@@ -885,6 +910,7 @@ public class GenericWindow
 
 		entry_edit_row.Text = (string) model.GetValue (iter, commentColumn);
 
+		label_treeviewload_row.Sensitive = false;
 		button_treeviewload_row_edit.Sensitive = false;
 		button_treeviewload_row_play.Sensitive = false;
 		button_treeviewload_row_delete.Sensitive = false;
@@ -916,6 +942,7 @@ public class GenericWindow
 
 	public void on_hbox_combo_button_cancel_clicked (object o, EventArgs args)
 	{
+		label_treeviewload_row.Sensitive = true;
 		button_treeviewload_row_edit.Sensitive = true;
 		button_treeviewload_row_play.Sensitive = true;
 		button_treeviewload_row_delete.Sensitive = true;
@@ -947,6 +974,7 @@ public class GenericWindow
 			return;
 
 		TreeviewSelectedUniqueID = Convert.ToInt32((string) store.GetValue (iter, 0));
+		label_treeviewload_row.Sensitive = false;
 		button_treeviewload_row_edit.Sensitive = false;
 		button_treeviewload_row_play.Sensitive = false;
 		button_treeviewload_row_delete.Sensitive = false;
@@ -960,12 +988,36 @@ public class GenericWindow
 		//remove selected row from treeview
 		store = UtilGtk.RemoveRow(treeview, store);
 	}
-	
-	public void Row_add(string [] row) {
-		//add row to treeview
-		UtilGtk.TreeviewAddRow(treeview, store, row, true); //insert at beginning
+
+	//add row to treeview
+	public void Row_add_beginning_or_end (string [] row, bool atBeginning)
+	{
+		if(atBeginning)
+			UtilGtk.TreeviewAddRow(treeview, store, row, 0);
+		else
+			UtilGtk.TreeviewAddRow(treeview, store, row, -1);
+	}
+	//columnAlphabetical is the column that is going to be checked
+	public void Row_add_alphabetical (string [] row, int columnAlphabetical)
+	{
+		int rowToInsert = 0;
+		Gtk.TreeIter iter;
+		bool okIter = store.GetIterFirst(out iter);
+		if(okIter) {
+			do {
+				string word = (string) store.GetValue (iter, columnAlphabetical);
+				LogB.Information(string.Format("row[columnAphabetical]: {0}, word: {1}, compare: {2}",
+							row[columnAlphabetical], word, row[columnAlphabetical].ToLower().CompareTo(word.ToLower()) > 0));
+				if(row[columnAlphabetical].ToLower().CompareTo(word.ToLower()) > 0)
+					rowToInsert ++;
+				else
+					break;
+			} while ( store.IterNext(ref iter) );
+		}
+
+		LogB.Information("Row to insert: " + rowToInsert.ToString());
+		UtilGtk.TreeviewAddRow(treeview, store, row, rowToInsert);
 	}
-	
 	
 	public void ShowTextview() {
 		scrolled_window_textview.Show();
@@ -1067,6 +1119,16 @@ public class GenericWindow
 		set { commentColumn = value; }
 	}
 
+	public void HideEditRowCombo()
+	{
+		hbox_combo.Visible = false;
+		hbox_combo_label.Visible = false;
+	}
+
+	public void SetLabelComment(string l) {
+		label_comment.Text = l;
+	}
+
 	public Button Button_row_delete {
 		set { button_row_delete = value; }
 		get { return button_row_delete; }
@@ -1093,6 +1155,10 @@ public class GenericWindow
 		get { return entry3.Text.ToString(); }
 	}
 
+	public string LabelBeforeTextViewTreeView {
+		set { label_before_textview_treeview.Text = value; }
+	}
+
 	public string EntryEditRow {
 		get { return entry_edit_row.Text.ToString(); }
 	}
