@@ -49,6 +49,8 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Label label_logout_seconds_encoder;
 	
 	//better raspberry controls
+	[Widget] Gtk.HBox hbox_sessions_raspberry;
+	[Widget] Gtk.HBox hbox_persons_raspberry;
 	[Widget] Gtk.Box hbox_encoder_capture_extra_mass_no_raspberry;
 	[Widget] Gtk.Box hbox_encoder_capture_extra_mass_raspberry;
 	[Widget] Gtk.HBox hbox_encoder_im_weights_n;
@@ -76,6 +78,8 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.VBox vbox_treeview_encoder_at_second_page;
 
 	//encoder ...
+	[Widget] Gtk.Alignment alignment_check_encoder_networks_upload;
+	[Widget] Gtk.CheckButton check_encoder_networks_upload;
 	[Widget] Gtk.Button button_encoder_monthly_change_current_session;
 	[Widget] Gtk.Button button_encoder_analyze_image_compujump_send_email;
 	/*
@@ -132,7 +136,11 @@ public partial class ChronoJumpWindow
 		if(configChronojump.CompujumpStationMode != Constants.Menuitem_modes.UNDEFINED)
 		{
 			button_show_modes_contacts.Visible = false;
-			button_show_modes_encoder.Visible = false;
+
+			//button_show_modes_encoder.Visible = false;
+			//do not allow to change modes
+			hbox_change_modes_encoder.Visible = false;
+
 		}
 
 		if(
@@ -155,6 +163,10 @@ public partial class ChronoJumpWindow
 			//dont't show persons_bottom hbox where users can be edited, deleted if persons at lateral is selected on preferences
 			vbox_persons_bottom.Visible = false;
 
+			//do not show new products on networks
+			button_menu_news.Visible = false;
+			button_menu_news1.Visible = false;
+
 			//don't allow to change encoderConfiguration
 			label_encoder_exercise_encoder.Visible = false;
 			hbox_encoder_exercise_encoder.Visible = false;
@@ -179,6 +191,8 @@ public partial class ChronoJumpWindow
 			showWebcamCaptureContactsControls (false); //contacts
 			hbox_video_encoder.Visible = false;
 
+			alignment_check_encoder_networks_upload.Visible = true;
+
 			//networks always without lateral person win
 			//also this is important for seing label_rfid_encoder_wait
 			SqlitePreferences.Update("personWinHide", "True", false);
@@ -188,9 +202,13 @@ public partial class ChronoJumpWindow
 
 			if(configChronojump.CompujumpStationMode != Constants.Menuitem_modes.UNDEFINED)
 			{
-				//changeMode (configChronojump.CompujumpStationMode);
+				//changeModeCheckRadios (configChronojump.CompujumpStationMode);
 				//better do like this because radiobuttons are not set. TODO: remove radiobuttons checks
-				if(configChronojump.CompujumpStationMode == Constants.Menuitem_modes.RUNSINTERVALLIC)
+				if(configChronojump.CompujumpStationMode == Constants.Menuitem_modes.JUMPSSIMPLE)
+					on_button_selector_start_jumps_simple_clicked(new object (), new EventArgs());
+				else if(configChronojump.CompujumpStationMode == Constants.Menuitem_modes.JUMPSREACTIVE)
+					on_button_selector_start_jumps_reactive_clicked(new object (), new EventArgs());
+				else if(configChronojump.CompujumpStationMode == Constants.Menuitem_modes.RUNSINTERVALLIC)
 					on_button_selector_start_runs_intervallic_clicked(new object (), new EventArgs());
 				else if(configChronojump.CompujumpStationMode == Constants.Menuitem_modes.POWERGRAVITATORY)
 					on_button_selector_start_encoder_gravitatory_clicked(new object (), new EventArgs());
@@ -231,6 +249,42 @@ public partial class ChronoJumpWindow
 				button_encoder_analyze_image_compujump_send_email.Visible = true;
 		}
 
+		if(configChronojump.Raspberry)
+		{
+			//make easiers to use some treeviews
+			hbox_sessions_raspberry.Visible = true;
+
+			//on raspberry with VNC the main hpaned cannot be moved, so show this buttons
+			hbox_persons_raspberry.Visible = true;
+		}
+
+		if(configChronojump.LowHeight)
+		{
+			Pixbuf pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "selector-jumps-small.png");
+			image_selector_start_jumps.Pixbuf = pixbuf;
+			pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "selector-runs-small.png");
+			image_selector_start_runs.Pixbuf = pixbuf;
+			pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "selector-encoder-small.png");
+			image_selector_start_encoder.Pixbuf = pixbuf;
+			pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "selector-force-small.png");
+			image_selector_start_force_sensor.Pixbuf = pixbuf;
+			pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "selector-rt-small.png");
+			image_selector_start_rt.Pixbuf = pixbuf;
+			pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "selector-multichronopic-small.png");
+			image_selector_start_other.Pixbuf = pixbuf;
+
+
+			vbox_menu_tiny_menu.Spacing = 14; //spacing 10 or 14 is the same. 20 makes window higher
+
+			image_encoder_inertial_instructions.Visible = false;
+		}
+
+		if(configChronojump.GuiTest)
+		{
+			button_menu_guiTest.Visible = true;
+			button_menu_guiTest1.Visible = true;
+		}
+
 		if(configChronojump.Exhibition)
 		{
 			exhibitionGuiAtStart(configChronojump.ExhibitionStationType);
@@ -461,7 +515,7 @@ public partial class ChronoJumpWindow
 		/*
 		if(linuxType == linuxTypeEnum.NETWORKS) {
 			//mostrar directament el power
-			changeMode (Constants.Menuitem_modes.POWER);
+			changeModeCheckRadios (Constants.Menuitem_modes.POWER);
 			
 			//no mostrar menu
 			
@@ -620,9 +674,9 @@ public partial class ChronoJumpWindow
 			return true;
 		}
 
-		//show a Readed message nice if the network is slow or there is any problem with the web services
-		label_rfid_wait.Text = Catalog.GetString("Readed");
-		label_rfid_encoder_wait.Text = Catalog.GetString("Readed");
+		//show a Read message nice if the network is slow or there is any problem with the web services
+		label_rfid_wait.Text = Catalog.GetString("Read");
+		label_rfid_encoder_wait.Text = Catalog.GetString("Read");
 		label_rfid_wait.Visible = true;
 		label_rfid_encoder_wait.Visible = true;
 
@@ -643,12 +697,12 @@ public partial class ChronoJumpWindow
 
 		//select person by RFID
 		Person pLocal = SqlitePerson.SelectByRFID(capturedRFID);
+		Person pServer = json.GetPersonByRFID(capturedRFID); //needed to check if photo changed (or in the future height,weight, ...)
+
 		if(pLocal.UniqueID == -1)
 		{
 			LogB.Information("RFID person does not exist locally!!");
 
-			Person pServer = json.GetPersonByRFID(capturedRFID);
-
 			if(! json.Connected) {
 				LogB.Information("Cannot connect with server!");
 				if(dialogMessageNotAtServer == null || ! dialogMessageNotAtServer.Visible)
@@ -699,21 +753,7 @@ public partial class ChronoJumpWindow
 
 				if(json.LastPersonWasInserted)
 				{
-					string imageFile = json.LastPersonByRFIDImageURL;
-					if(imageFile != null && imageFile != "")
-					{
-						string image_dest = Util.GetPhotoFileName(false, currentPerson.UniqueID);
-						if(UtilMultimedia.GetImageType(imageFile) == UtilMultimedia.ImageTypes.PNG)
-							image_dest = Util.GetPhotoPngFileName(false, currentPerson.UniqueID);
-
-						bool downloaded = json.DownloadImage(json.LastPersonByRFIDImageURL, currentPerson.UniqueID);
-						if(downloaded)
-							File.Copy(
-									Path.Combine(Path.GetTempPath(), currentPerson.UniqueID.ToString()),
-									image_dest,
-									true); //overwrite
-					}
-
+					compujumpDownloadImage (json, json.LastPersonByRFIDImageURL, currentPerson.UniqueID);
 					person_added(); //GTK
 				} else {
 					personChanged(); //GTK
@@ -722,8 +762,26 @@ public partial class ChronoJumpWindow
 				pChangedShowTasks = true;
 			}
 		}
-		else {
+		else if(json.Connected && pLocal.UniqueID != pServer.UniqueID)
+		{
+			LogB.Information("PersonID on client does not match personID on server for rfid: " + capturedRFID);
+			if(dialogMessageNotAtServer == null || ! dialogMessageNotAtServer.Visible)
+			{
+				dialogMessageNotAtServer = new DialogMessage(Constants.MessageTypes.WARNING,
+						string.Format("PersonID {0} on client does not match personID {1} on server for rfid: {2}",
+							pLocal.UniqueID, pServer.UniqueID, capturedRFID)); //GTK
+
+				compujumpPersonLogoutDo();
+			}
+		} else {
 			LogB.Information("RFID person exists locally!!");
+
+			//if image changed, download it
+			if( pServer.UniqueID != -1 &&
+					(pServer.LinkServerImage != pLocal.LinkServerImage ||
+					! Util.FileExists(compujumpDownloadImageGetDest (pServer.LinkServerImage, pServer.UniqueID))) )
+				compujumpDownloadImage (json, pServer.LinkServerImage, pServer.UniqueID);
+
 			if(rfidIsDifferent || dialogPersonPopup == null || ! dialogPersonPopup.Visible)
 			{
 				string yearMonthStr = UtilDate.GetCurrentYearMonthStr();
@@ -747,7 +805,9 @@ public partial class ChronoJumpWindow
 		List<UploadEncoderDataFullObject> listEncoderTemp = SqliteJson.SelectTempEncoder(true);
 		List<UploadSprintDataObject> listSprintTemp = SqliteJson.SelectTempSprint(true);
 
+		/*
 		//Upload them
+		TODO: disabled until find why says that database is not open
 		if(listEncoderTemp.Count > 0)
 		{
 			foreach(UploadEncoderDataFullObject uedfo in listEncoderTemp)
@@ -758,6 +818,7 @@ public partial class ChronoJumpWindow
 					SqliteJson.DeleteTempEncoder(true, uedfo.uniqueId); //delete the record
 			}
 		}
+		*/
 		if(listSprintTemp.Count > 0)
 		{
 			foreach(UploadSprintDataObject usdo in listSprintTemp)
@@ -807,13 +868,36 @@ public partial class ChronoJumpWindow
 		return true;
 	}
 
+	private void compujumpDownloadImage (JsonCompujump json, string url, int personID)
+	{
+		if(url == null || url == "")
+			return;
+
+		string image_dest = compujumpDownloadImageGetDest (url, personID);
+
+		if(json.DownloadImage(url, personID))
+			File.Copy(
+					Path.Combine(Path.GetTempPath(), personID.ToString()),
+					image_dest,
+					true); //overwrite
+	}
+	//get destination file of the image: multimedia/photos/uniqueID. (jpg or png)
+	private string compujumpDownloadImageGetDest (string linkServerImage, int personID)
+	{
+		string image_dest = Util.GetPhotoFileName(false, personID);
+		if(UtilMultimedia.GetImageType(linkServerImage) == UtilMultimedia.ImageTypes.PNG)
+			image_dest = Util.GetPhotoPngFileName(false, personID);
+
+		return image_dest;
+	}
+
 	//load current session if MONTHLY and current session is not current month and currentPerson is not compumpAdminID
 	private void compujumpPersonChangedShouldChangeSession()
 	{
 		string yearMonthStr = UtilDate.GetCurrentYearMonthStr();
 		if(
 				configChronojump.SessionMode == Config.SessionModeEnum.MONTHLY &&
-				currentSession.Name != yearMonthStr &&
+				currentSession.Name.ToLower() != yearMonthStr.ToLower() &&
 				! configChronojump.CompujumpUserIsAdmin(currentPerson) )
 		{
 			currentSession = SqliteSession.SelectByName(yearMonthStr);
@@ -861,8 +945,12 @@ public partial class ChronoJumpWindow
 		if(configChronojump.CompujumpStationMode == Constants.Menuitem_modes.POWERGRAVITATORY ||
 				configChronojump.CompujumpStationMode == Constants.Menuitem_modes.POWERINERTIAL)
 		{
-			ArrayList encoderExercisesOnLocal = SqliteEncoder.SelectEncoderExercises(false, -1, false);
-			List<EncoderExercise> exRemote_list = json.GetStationExercises(configChronojump.CompujumpStationID);
+			Constants.EncoderGI type = Constants.EncoderGI.GRAVITATORY;
+			if(configChronojump.CompujumpStationMode == Constants.Menuitem_modes.POWERINERTIAL)
+				type = Constants.EncoderGI.INERTIAL;
+
+			ArrayList encoderExercisesOnLocal = SqliteEncoder.SelectEncoderExercises(false, -1, false, type);
+			List<EncoderExercise> exRemote_list = json.GetStationExercises(configChronojump.CompujumpStationID, type);
 
 			foreach(EncoderExercise exRemote in exRemote_list)
 			{
@@ -878,7 +966,7 @@ public partial class ChronoJumpWindow
 				{
 					SqliteEncoder.InsertExercise(
 							false, exRemote.uniqueID, exRemote.name, exRemote.percentBodyWeight,
-							"", "", ""); //ressitance, description, speed1RM
+							"", "", "", type); //ressitance, description, speed1RM, type (encoderGI)
 					updateEncoderExercisesGui(exRemote.name);
 				}
 			}
@@ -1022,6 +1110,16 @@ public partial class ChronoJumpWindow
 			dialogPersonPopup.DestroyDialog();
 		}
 
+		//close the encoder exercise config win if it was opened
+		if(notebook_hpaned_encoder_or_exercise_config.CurrentPage == 1) //frame_encoder_exercise_config
+		{
+			/*
+			   not only this:
+			notebook_hpaned_encoder_or_exercise_config.CurrentPage = 0;
+			we need also to make menus_sensitive, ..., so do:*/
+			encoder_exercise_show_hide (false);
+		}
+
 		currentPerson = null;
 		currentPersonSession = null;
 		sensitiveGuiNoPerson ();
@@ -1087,8 +1185,6 @@ public partial class ChronoJumpWindow
 	private void networksShowDeviceMissingRFID (bool missing)
 	{
 		if(missing) {
-			hbox_RFID_disconnected.Visible = true;
-
 			/*
 			 * note rfid missing is more important than encoder missing,
 			 * if both messages are active, then user can connect encoder, press check button
@@ -1096,6 +1192,8 @@ public partial class ChronoJumpWindow
 			 * so do not show the encoder message
 			 */
 			notebook_sup.CurrentPage = Convert.ToInt32(notebook_sup_pages.NETWORKSPROBLEMS);
+			hbox_RFID_disconnected.Visible = true;
+
 			button_activate_chronopics_networks_problems.Sensitive = preferences.networksAllowChangeDevices;
 			hbox_encoder_disconnected.Visible = false;
 		}
