@@ -36,9 +36,14 @@ public abstract class OverviewWindow
 	[Widget] protected Gtk.RadioButton radio_sets;
 	[Widget] protected Gtk.RadioButton radio_reps;
 	[Widget] protected Gtk.Button button_select_this_person;
-	
+
+	//used by personIDAtStart, because we need to select the row after showing the window
+	protected TreeStore storeSets;
+	protected TreeStore storeReps; //note this is not used because right now we cannot have both treeviews selected
+
 	protected enum treeviewType { SETS, REPS }
 	protected int sessionID;
+	protected int personIDAtStart;
 	protected int selectedPersonID;
 
 	protected void initialize()
@@ -68,6 +73,11 @@ public abstract class OverviewWindow
 		TreeStore store = getStore(tvType);
 		tv.Model = store;
 
+		if(tvType == treeviewType.SETS)
+			storeSets = store;
+		else if(tvType == treeviewType.REPS)
+			storeReps = store;
+
 		foreach (string [] line in array)
 			store.AppendValues (line);
 
@@ -119,6 +129,12 @@ public abstract class OverviewWindow
 		}
 	}
 
+	protected void selectRowWithID ()
+	{
+		if(personIDAtStart >= 0)
+			UtilGtk.TreeviewSelectRowWithID(treeview_sets, storeSets, 0, personIDAtStart, true); //last boolean is 'scroll to row'
+	}
+
 	protected void on_radio_sets_toggled (object o, EventArgs args)
 	{
 		if(radio_sets.Active)
@@ -148,10 +164,14 @@ public abstract class OverviewWindow
 		return new TreeStore(typeof (string), typeof (string), typeof (string), typeof (string), typeof (string)); //personID (hidden), person name, sex, exercise, sets
 	}
 
-	public void Button_select_this_person_make_unsensitive()
+	public void HideAndNull ()
 	{
-		button_select_this_person.Sensitive = false;
+		on_button_close_clicked (new object (), new EventArgs ());
 	}
+	protected virtual void on_button_close_clicked (object o, EventArgs args)
+	{
+	}
+
 	public Button Button_select_this_person
 	{
 		set { button_select_this_person = value; }
@@ -185,18 +205,23 @@ public class EncoderOverviewWindow : OverviewWindow
 			UtilGtk.WindowColor(overview_win, Config.ColorBackground);
 	}
 
-	static public EncoderOverviewWindow Show (Gtk.Window parent, Constants.EncoderGI encoderGI, int sessionID)
+	//if personIDAtStart == -1, there is not currentPerson
+	static public EncoderOverviewWindow Show (Gtk.Window parent, Constants.EncoderGI encoderGI, int sessionID, int personIDAtStart)
 	{
 		if (EncoderOverviewWindowBox == null)
 			EncoderOverviewWindowBox = new EncoderOverviewWindow (parent);
 
 		EncoderOverviewWindowBox.encoderGI = encoderGI;
 		EncoderOverviewWindowBox.sessionID = sessionID;
+		EncoderOverviewWindowBox.personIDAtStart = personIDAtStart;
 
 		EncoderOverviewWindowBox.initialize();
 		EncoderOverviewWindowBox.hbox_radio_sets_repetitions.Visible = true;
 
 		EncoderOverviewWindowBox.overview_win.Show ();
+
+		//done after Show, to ensure the selected row is shown
+		EncoderOverviewWindowBox.selectRowWithID();
 		
 		return EncoderOverviewWindowBox;
 	}
@@ -275,7 +300,7 @@ public class EncoderOverviewWindow : OverviewWindow
 		return s;
 	}
 
-	void on_button_close_clicked (object o, EventArgs args)
+	protected override void on_button_close_clicked (object o, EventArgs args)
 	{
 		EncoderOverviewWindowBox.overview_win.Hide();
 		EncoderOverviewWindowBox = null;
@@ -308,12 +333,14 @@ public class ForceSensorOverviewWindow : OverviewWindow
 			UtilGtk.WindowColor(overview_win, Config.ColorBackground);
 	}
 
-	static public ForceSensorOverviewWindow Show (Gtk.Window parent, int sessionID)
+	//if personIDAtStart == -1, there is not currentPerson
+	static public ForceSensorOverviewWindow Show (Gtk.Window parent, int sessionID, int personIDAtStart)
 	{
 		if (ForceSensorOverviewWindowBox == null)
 			ForceSensorOverviewWindowBox = new ForceSensorOverviewWindow (parent);
 
 		ForceSensorOverviewWindowBox.sessionID = sessionID;
+		ForceSensorOverviewWindowBox.personIDAtStart = personIDAtStart;
 
 		ForceSensorOverviewWindowBox.initialize();
 
@@ -322,6 +349,9 @@ public class ForceSensorOverviewWindow : OverviewWindow
 
 		ForceSensorOverviewWindowBox.overview_win.Show ();
 
+		//done after Show, to ensure the selected row is shown
+		ForceSensorOverviewWindowBox.selectRowWithID();
+
 		return ForceSensorOverviewWindowBox;
 	}
 
@@ -335,7 +365,7 @@ public class ForceSensorOverviewWindow : OverviewWindow
 		return SqliteForceSensor.SelectSessionOverviewSets(false, sessionID);
 	}
 
-	void on_button_close_clicked (object o, EventArgs args)
+	protected override void on_button_close_clicked (object o, EventArgs args)
 	{
 		ForceSensorOverviewWindowBox.overview_win.Hide();
 		ForceSensorOverviewWindowBox = null;
@@ -368,12 +398,14 @@ public class RunEncoderOverviewWindow : OverviewWindow
 			UtilGtk.WindowColor(overview_win, Config.ColorBackground);
 	}
 
-	static public RunEncoderOverviewWindow Show (Gtk.Window parent, int sessionID)
+	//if personIDAtStart == -1, there is not currentPerson
+	static public RunEncoderOverviewWindow Show (Gtk.Window parent, int sessionID, int personIDAtStart)
 	{
 		if (RunEncoderOverviewWindowBox == null)
 			RunEncoderOverviewWindowBox = new RunEncoderOverviewWindow (parent);
 
 		RunEncoderOverviewWindowBox.sessionID = sessionID;
+		RunEncoderOverviewWindowBox.personIDAtStart = personIDAtStart;
 
 		RunEncoderOverviewWindowBox.initialize();
 
@@ -382,6 +414,9 @@ public class RunEncoderOverviewWindow : OverviewWindow
 
 		RunEncoderOverviewWindowBox.overview_win.Show ();
 
+		//done after Show, to ensure the selected row is shown
+		RunEncoderOverviewWindowBox.selectRowWithID();
+
 		return RunEncoderOverviewWindowBox;
 	}
 
@@ -395,7 +430,7 @@ public class RunEncoderOverviewWindow : OverviewWindow
 		return SqliteRunEncoder.SelectSessionOverviewSets(false, sessionID);
 	}
 
-	void on_button_close_clicked (object o, EventArgs args)
+	protected override void on_button_close_clicked (object o, EventArgs args)
 	{
 		RunEncoderOverviewWindowBox.overview_win.Hide();
 		RunEncoderOverviewWindowBox = null;
