@@ -30,6 +30,7 @@ public class PersonSelectWindow
 {
 	[Widget] Gtk.Window person_select_window;
 	[Widget] Gtk.Notebook notebook;
+	[Widget] Gtk.ScrolledWindow scrolled1;
 	[Widget] Gtk.Viewport viewport1;
 	[Widget] Gtk.Viewport viewport_person_name;
 	[Widget] Gtk.Table table1;
@@ -49,8 +50,11 @@ public class PersonSelectWindow
 	[Widget] Gtk.Image image_all_persons_events;
 	[Widget] Gtk.Image image_person_delete;
 	[Widget] Gtk.Image image_manage_persons_cancel;
-	[Widget] Gtk.HBox hbox_up_down_close;
+	[Widget] Gtk.VBox vbox_corner_controls;
 	[Widget] Gtk.Image image_close;
+	[Widget] Gtk.Label label_manage_persons;
+	[Widget] Gtk.Label label_delete_person;
+	[Widget] Gtk.CheckButton check_show_images;
 	
 	static PersonSelectWindow PersonSelectWindowBox;
 	
@@ -64,17 +68,34 @@ public class PersonSelectWindow
 	public Gtk.Button FakeButtonEditPerson;
 	public Gtk.Button FakeButtonPersonShowAllEvents;
 	public Gtk.Button FakeButtonDeletePerson;
+	public Gtk.Button FakeButtonShowImages;
+	public Gtk.Button FakeButtonHideImages;
 	public Gtk.Button FakeButtonDone;
 
 	private List<PersonPhotoButton> list_ppb;
 
+	private bool showImages;
+	private uint columns;
 	
-	PersonSelectWindow (Gtk.Window parent) {
+	PersonSelectWindow (Gtk.Window parent, bool raspberry, bool lowHeight)
+	{
 		Glade.XML gladeXML;
 		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "person_select_window.glade", "person_select_window", "chronojump");
 		gladeXML.Autoconnect(this);
 		
-		viewport1.HeightRequest = 170 * 3 + 8 * 2 + 4 * 2; //170 is button height, 8 is padding top botton (4+4), 4 the top and bottom of viewport1
+		int slidebarSize = 20;
+		if(raspberry)
+			slidebarSize = 40;
+
+		scrolled1.WidthRequest = 150 * 4 + 8 * 2 + 12 * 2 + slidebarSize; //150 is button width, 8 is padding left and right (4+4), 12 the left and right of scrolled1
+		//if showImages (2 columns) will be 308*2 + 4 * 2 + 12 * 2
+
+		int rowsShown = 3;
+		if(lowHeight)
+			rowsShown = 2;
+
+		//there's no side slidebar for going horizontal, but the last +10 is to have a bit of space for the widget
+		scrolled1.HeightRequest = 170 * rowsShown + 8 * 2 + 12 * 2; //170 is button height, 8 is padding top botton (4+4), 12 the top and bottom of scrolled1
 
 		//put an icon to window
 		UtilGtk.IconWindow(person_select_window);
@@ -83,9 +104,17 @@ public class PersonSelectWindow
 		if(! Config.UseSystemColor)
 		{
 			UtilGtk.WindowColor(person_select_window, Config.ColorBackground);
-			UtilGtk.ContrastLabelsLabel(Config.ColorBackgroundIsDark, label_confirm);
+			//UtilGtk.ContrastLabelsLabel(Config.ColorBackgroundIsDark, label_confirm);
+			UtilGtk.ContrastLabelsLabel(Config.ColorBackgroundIsDark, label_manage_persons);
+			UtilGtk.ContrastLabelsLabel(Config.ColorBackgroundIsDark, label_delete_person);
+			UtilGtk.ContrastLabelsVBox(Config.ColorBackgroundIsDark, vbox_corner_controls);
 		}
 
+		label_manage_persons.Text = "<b>" + label_manage_persons.Text + "</b>";
+		label_manage_persons.UseMarkup = true;
+		label_delete_person.Text = "<b>" + label_delete_person.Text + "</b>";
+		label_delete_person.UseMarkup = true;
+
 		person_select_window.Parent = parent;
 		
 		FakeButtonAddPerson = new Gtk.Button();
@@ -95,6 +124,8 @@ public class PersonSelectWindow
 		FakeButtonEditPerson = new Gtk.Button();
 		FakeButtonPersonShowAllEvents = new Gtk.Button();
 		FakeButtonDeletePerson = new Gtk.Button();
+		FakeButtonShowImages = new Gtk.Button();
+		FakeButtonHideImages = new Gtk.Button();
 		FakeButtonDone = new Gtk.Button();
 
 		Pixbuf pixbuf;
@@ -120,10 +151,10 @@ public class PersonSelectWindow
 		image_close.Pixbuf = pixbuf;
 	}
 	
-	static public PersonSelectWindow Show (Gtk.Window parent, ArrayList persons, Person currentPerson, Gdk.Color colorBackground)
+	static public PersonSelectWindow Show (Gtk.Window parent, ArrayList persons, Person currentPerson, Gdk.Color colorBackground, bool raspberry, bool lowHeight, bool showImages)
 	{
 		if (PersonSelectWindowBox == null) {
-			PersonSelectWindowBox = new PersonSelectWindow (parent);
+			PersonSelectWindowBox = new PersonSelectWindow (parent, raspberry, lowHeight);
 		}
 
 		PersonSelectWindowBox.persons = persons;
@@ -132,12 +163,22 @@ public class PersonSelectWindow
 
 		PersonSelectWindowBox.notebook.CurrentPage = 0;
 		PersonSelectWindowBox.button_manage_persons.Sensitive = true;
-		PersonSelectWindowBox.hbox_up_down_close.Sensitive = true;
+		PersonSelectWindowBox.vbox_corner_controls.Sensitive = true;
+
+		PersonSelectWindowBox.showImages = showImages;
+		if(showImages)
+		{
+			PersonSelectWindowBox.check_show_images.Active = true;
+			PersonSelectWindowBox.columns = 4;
+		} else {
+			PersonSelectWindowBox.check_show_images.Active = false;
+			PersonSelectWindowBox.columns = 2;
+		}
 
 		PersonSelectWindowBox.createTable();
-		
+
 		PersonSelectWindowBox.person_select_window.Show ();
-		
+
 		return PersonSelectWindowBox;
 	}
 
@@ -164,7 +205,7 @@ public class PersonSelectWindow
 		table1.Visible = true;
 		table1.Sensitive = true;
 		button_manage_persons.Sensitive = true;
-		hbox_up_down_close.Sensitive = true;
+		vbox_corner_controls.Sensitive = true;
 
 		if(currentPerson != null)
 			assignPersonSelectedStuff(currentPerson);
@@ -173,6 +214,21 @@ public class PersonSelectWindow
 			person_select_window.Visible = true;
 	}
 
+	private void on_check_show_images_toggled (object o, EventArgs args)
+	{
+		if(check_show_images.Active)
+			FakeButtonShowImages.Click();
+		else
+			FakeButtonHideImages.Click();
+
+		if(check_show_images.Active)
+			columns = 4;
+		else
+			columns = 2;
+
+		Update(persons);
+	}
+
 	private void removeTable() 
 	{
 		Array buttons = table1.Children;
@@ -184,7 +240,7 @@ public class PersonSelectWindow
 	{
 		LogB.Debug("Persons count" + persons.Count.ToString());
 		uint padding = 4;	
-		uint cols = 4; //each row has 4 columns
+		uint cols = columns; //each row has 4 columns
 		uint rows = Convert.ToUInt32(Math.Floor(persons.Count / (1.0 * cols) ) +1);
 		int count = 0;
 
@@ -200,7 +256,7 @@ public class PersonSelectWindow
 		}
 
 		personButtonsSensitive(false);
-		vbox_button_delete_confirm.Visible = false;
+		//vbox_button_delete_confirm.Visible = false;
 		list_ppb = new List<PersonPhotoButton>();
 
 		for (int row_i = 0; row_i < rows; row_i ++)
@@ -212,7 +268,7 @@ public class PersonSelectWindow
 				
 				Person p = (Person) persons[count ++];
 
-				PersonPhotoButton ppb = new PersonPhotoButton(p.UniqueID, p.Name); //creates the button
+				PersonPhotoButton ppb = new PersonPhotoButton(p.UniqueID, p.Name, check_show_images.Active); //creates the button
 
 				//select currentPerson
 				if(selectedFirstClickPersonID != -1 && selectedFirstClickPersonID == p.UniqueID)
@@ -252,7 +308,6 @@ public class PersonSelectWindow
 			{
 				if(ppb.PersonID == selectedFirstClickPersonID)
 				{
-					FakeButtonDone.Click();
 					close_window();
 					return;
 				}
@@ -301,7 +356,7 @@ public class PersonSelectWindow
 
 		personButtonsSensitive (false);
 		button_manage_persons.Sensitive = false;
-		hbox_up_down_close.Sensitive = false;
+		vbox_corner_controls.Sensitive = false;
 	}
 
 	private void on_button_manage_persons_cancel_clicked (object o, EventArgs args)
@@ -310,7 +365,7 @@ public class PersonSelectWindow
 
 		personButtonsSensitive (SelectedPerson != null);
 		button_manage_persons.Sensitive = true;
-		hbox_up_down_close.Sensitive = true;
+		vbox_corner_controls.Sensitive = true;
 	}
 
 	private void on_button_add_clicked (object o, EventArgs args)
@@ -345,12 +400,18 @@ public class PersonSelectWindow
 
 	private void on_button_up_clicked (object o, EventArgs args)
 	{
-		vertical_scroll_change(viewport1.Vadjustment.Value - viewport1.Vadjustment.PageSize);
+		//vertical_scroll_change(viewport1.Vadjustment.Value - viewport1.Vadjustment.PageSize); //this is not very usable, better go row by row
+
+		//row by row
+		vertical_scroll_change(viewport1.Vadjustment.Value - 170 + 8); //a row + its padding (another solution could be viewport height / rows)
 	}
 
 	private void on_button_down_clicked (object o, EventArgs args)
 	{
-		vertical_scroll_change(viewport1.Vadjustment.Value + viewport1.Vadjustment.PageSize);
+		//vertical_scroll_change(viewport1.Vadjustment.Value + viewport1.Vadjustment.PageSize); //this is not very usable, better go row by row
+
+		//row by row
+		vertical_scroll_change(viewport1.Vadjustment.Value + 170 + 8); //a row + its padding
 	}
 
 	private void vertical_scroll_change (double newValue)
@@ -378,17 +439,25 @@ public class PersonSelectWindow
 	}
 	private void button_delete_confirm_focus(bool doFocus, bool sensitivePersonButtons)
 	{
-		vbox_button_delete_confirm.Visible = doFocus;
+		if(doFocus)
+			notebook.CurrentPage = 2;
+		else
+			notebook.CurrentPage = 0;
+
+		//vbox_button_delete_confirm.Visible = doFocus;
 		table1.Sensitive = ! doFocus;
 		button_manage_persons.Sensitive = ! doFocus;
-		hbox_up_down_close.Sensitive = ! doFocus;
+		vbox_corner_controls.Sensitive = ! doFocus;
 
 		personButtonsSensitive(sensitivePersonButtons);
 	}
 	//end of delete person stuff	
 
 
-	private void close_window() {	
+	private void close_window()
+	{
+		FakeButtonDone.Click(); //change person on main gui
+
 		PersonSelectWindowBox.person_select_window.Hide();
 		PersonSelectWindowBox = null;
 	}
@@ -401,8 +470,8 @@ public class PersonSelectWindow
 	
 	private void on_delete_event (object o, DeleteEventArgs args)
 	{
-		PersonSelectWindowBox.person_select_window.Hide();
-		PersonSelectWindowBox = null;
+		args.RetVal = true;
+		close_window();
 	}
 }
 
@@ -428,12 +497,12 @@ public class PersonPhotoButton
 	*/
 
 	//used to create button
-	public PersonPhotoButton (int id, string name)
+	public PersonPhotoButton (int id, string name, bool showImage)
 	{
 		personID = id;
 		personName = name;
 
-		createButton();
+		createButton(showImage);
 		Selected = false;
 	}
 
@@ -482,14 +551,15 @@ public class PersonPhotoButton
 		//LogB.Information("Name: " + l.Text.ToString());
 	}
 
-	private void createButton ()
+	private void createButton (bool showImage)
 	{
 		Gtk.VBox vbox = new Gtk.VBox();
 
 		Gtk.Image image = new Gtk.Image();
 		addUserPhotoIfExists(image);
-		image.HeightRequest = 150;
-		image.Visible = true;
+		if(showImage)
+			image.HeightRequest = 150;
+		image.Visible = showImage;
 
 		Gtk.Label label_select = new Gtk.Label("Select !");
 		label_select.Visible = false; //hide this to the user until button is clicked first time
@@ -500,6 +570,15 @@ public class PersonPhotoButton
 		Gtk.Viewport viewport = new Gtk.Viewport();
 		UtilGtk.ViewportColorDefault(viewport);
 		Gtk.Label label_name = new Gtk.Label(personName);
+		label_name.LineWrap = true;
+
+		if(showImage)
+			label_name.WidthRequest = 140; //same width as label_selected_person_name, to ensure contents are correctly shown on both
+		else
+			label_name.WidthRequest = 298;
+
+		label_name.HeightRequest = -1;
+		label_name.LineWrapMode = Pango.WrapMode.Word;
 		label_name.Visible = true;
 		label_name.Show();
 		viewport.Add(label_name);
@@ -512,8 +591,14 @@ public class PersonPhotoButton
 		vbox.Show();
 
 		button = new Button(vbox);
-		button.WidthRequest = 150;
-		button.HeightRequest = 170;
+
+		if(showImage)
+		{
+			button.WidthRequest = 150; //commenting this will make columns longer with enough space for labels
+			button.HeightRequest = 170; //commenting this will make the rows be of different height depending on image and lines of text
+		}
+		else
+			button.WidthRequest = 308; //commenting this will make columns longer with enough space for labels
 	}
 
 	private Array getButtonBoxElements (Gtk.Button button)
