@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2021   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -44,17 +44,20 @@ using ICSharpCode.SharpZipLib;
 public class PreferencesWindow
 {
 	[Widget] Gtk.Window preferences_win;
+	[Widget] Gtk.Notebook notebook_top;
 	[Widget] Gtk.Notebook notebook;
+	[Widget] Gtk.HBox hbox_buttons_bottom;
 
 	//view more tabs
-	[Widget] Gtk.Button button_view_more_tabs;
-	[Widget] Gtk.HBox hbox_more_tabs;
-	[Widget] Gtk.Label label_view_more_tabs;
 	[Widget] Gtk.CheckButton check_view_jumps;
 	[Widget] Gtk.CheckButton check_view_runs;
 	[Widget] Gtk.CheckButton check_view_encoder;
 	[Widget] Gtk.CheckButton check_view_force_sensor;
 	[Widget] Gtk.CheckButton check_view_race_analyzer;
+	//tabs selection widgets
+	[Widget] Gtk.Image image_view_more_tabs_close;
+	[Widget] Gtk.Label label_mandatory_tabs;
+	[Widget] Gtk.Label label_selectable_tabs;
 
 	//appearance tab
 	[Widget] Gtk.CheckButton check_appearance_maximized;
@@ -74,6 +77,11 @@ public class PreferencesWindow
 	[Widget] Gtk.RadioButton radio_font_courier;
 	[Widget] Gtk.RadioButton radio_font_helvetica;
 	[Widget] Gtk.Label label_radio_font_needs_restart;
+	[Widget] Gtk.CheckButton check_rest_time;
+	[Widget] Gtk.Image image_rest;
+	[Widget] Gtk.HBox hbox_rest_time_values;
+	[Widget] Gtk.SpinButton spinbutton_rest_minutes;
+	[Widget] Gtk.SpinButton spinbutton_rest_seconds;
 
 	[Widget] Gtk.RadioButton radio_color_custom;
 	[Widget] Gtk.RadioButton radio_color_chronojump_blue;
@@ -157,6 +165,10 @@ public class PreferencesWindow
 	[Widget] Gtk.CheckButton checkbutton_encoder_propulsive;
 	[Widget] Gtk.RadioButton radio_encoder_work_kcal;
 	[Widget] Gtk.RadioButton radio_encoder_work_joules;
+	[Widget] Gtk.RadioButton radio_encoder_inertial_analyze_equivalent_mass;
+	[Widget] Gtk.RadioButton radio_encoder_inertial_analyze_inertia_moment;
+	[Widget] Gtk.RadioButton radio_encoder_inertial_analyze_diameter;
+	[Widget] Gtk.Image image_encoder_inertial_analyze_eq_mass_help;
 	[Widget] Gtk.SpinButton spin_encoder_smooth_con;
 	[Widget] Gtk.Label label_encoder_con;
 	[Widget] Gtk.RadioButton radio_encoder_1RM_nonweighted;
@@ -173,9 +185,17 @@ public class PreferencesWindow
 	[Widget] Gtk.SpinButton spin_force_sensor_not_elastic_ecc_min_force;
 	[Widget] Gtk.SpinButton spin_force_sensor_not_elastic_con_min_force;
 	[Widget] Gtk.SpinButton spin_force_sensor_graphs_line_width;
+	[Widget] Gtk.RadioButton radio_force_sensor_variability_rmssd;
+	[Widget] Gtk.RadioButton radio_force_sensor_variability_cvrmssd;
+	[Widget] Gtk.RadioButton radio_force_sensor_variability_old;
+	[Widget] Gtk.SpinButton spin_force_sensor_analyze_ab_slider_increment;
+	[Widget] Gtk.SpinButton spin_force_sensor_analyze_max_avg_force_in_window;
 
 	//runEncoder tab
-	[Widget] Gtk.SpinButton spin_force_sensor_acceleration;
+	[Widget] Gtk.SpinButton spin_run_encoder_acceleration;
+	[Widget] Gtk.SpinButton spin_run_encoder_pps;
+	[Widget] Gtk.Label label_pps_equivalent;
+	[Widget] Gtk.Label label_pps_maximum;
 
 	//multimedia tab
 	[Widget] Gtk.CheckButton checkbutton_volume;
@@ -249,7 +269,6 @@ public class PreferencesWindow
 	[Widget] Gtk.Frame frame_networks;
 	[Widget] Gtk.CheckButton check_networks_devices;
 
-	[Widget] Gtk.RadioButton radio_python_default;
 	[Widget] Gtk.RadioButton radio_python_2;
 	[Widget] Gtk.RadioButton radio_python_3;
 
@@ -282,7 +301,8 @@ public class PreferencesWindow
 	private WebcamFfmpegSupportedModes wfsm;
 
 
-	PreferencesWindow () {
+	PreferencesWindow ()
+	{
 		Glade.XML gladeXML;
 		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "preferences_win.glade", "preferences_win", "chronojump");
 		gladeXML.Autoconnect(this);
@@ -306,6 +326,7 @@ public class PreferencesWindow
 			PreferencesWindowBox = new PreferencesWindow ();
 		}
 
+		PreferencesWindowBox.notebook_top.CurrentPage = 0;
 		PreferencesWindowBox.operatingSystem = UtilAll.GetOSEnum();
 
 		if(compujump)
@@ -344,7 +365,11 @@ public class PreferencesWindow
 		PreferencesWindowBox.createComboLanguage();
 		Pixbuf pixbuf;
 
-		//appearence tab
+		//appearance tab
+
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_rest.png");
+		PreferencesWindowBox.image_rest.Pixbuf = pixbuf;
+
 		if(preferences.maximized == Preferences.MaximizedTypes.NO)
 		{
 			PreferencesWindowBox.check_appearance_maximized.Active = false;
@@ -411,6 +436,18 @@ public class PreferencesWindow
 		else
 			PreferencesWindowBox.radio_font_helvetica.Active = true;
 
+		PreferencesWindowBox.check_rest_time.Active = (preferences.restTimeMinutes >= 0);
+		PreferencesWindowBox.on_check_rest_time_toggled (new object (), new EventArgs ());
+
+		if(preferences.restTimeMinutes >= 0)
+		{
+			PreferencesWindowBox.spinbutton_rest_minutes.Value = preferences.restTimeMinutes;
+			PreferencesWindowBox.spinbutton_rest_seconds.Value = preferences.restTimeSeconds;
+		} else { //min == -1 means no restTime
+			PreferencesWindowBox.spinbutton_rest_minutes.Value = 2;
+			PreferencesWindowBox.spinbutton_rest_seconds.Value = 0;
+		}
+
 		//multimedia tab
 		if(preferences.volumeOn)  
 			PreferencesWindowBox.checkbutton_volume.Active = true; 
@@ -552,6 +589,7 @@ public class PreferencesWindow
 		PreferencesWindowBox.image_run_speed_start_help.Pixbuf = pixbuf;
 		PreferencesWindowBox.image_encoder_inactivity_help.Pixbuf = pixbuf;
 		PreferencesWindowBox.image_encoder_capture_cut_by_triggers_help.Pixbuf = pixbuf;
+		PreferencesWindowBox.image_encoder_inertial_analyze_eq_mass_help.Pixbuf = pixbuf;
 
 		if(menu_mode ==	Constants.Menuitem_modes.RUNSSIMPLE)
 			PreferencesWindowBox.notebook_races_double_contacts.CurrentPage = 0;
@@ -660,7 +698,14 @@ public class PreferencesWindow
 			PreferencesWindowBox.radio_encoder_work_kcal.Active = true;
 		else
 			PreferencesWindowBox.radio_encoder_work_joules.Active = true;
-		
+
+		if(preferences.encoderInertialGraphsX == Preferences.EncoderInertialGraphsXTypes.INERTIA_MOMENT)
+			PreferencesWindowBox.radio_encoder_inertial_analyze_inertia_moment.Active = true;
+		else if(preferences.encoderInertialGraphsX == Preferences.EncoderInertialGraphsXTypes.DIAMETER)
+			PreferencesWindowBox.radio_encoder_inertial_analyze_diameter.Active = true;
+		else
+			PreferencesWindowBox.radio_encoder_inertial_analyze_equivalent_mass.Active = true;
+
 		PreferencesWindowBox.spin_encoder_smooth_con.Value = preferences.encoderSmoothCon;
 
 		if(preferences.encoder1RMMethod == Constants.Encoder1RMMethod.NONWEIGHTED)
@@ -691,8 +736,20 @@ public class PreferencesWindow
 
 		PreferencesWindowBox.spin_force_sensor_graphs_line_width.Value = preferences.forceSensorGraphsLineWidth;
 
+		if(preferences.forceSensorVariabilityMethod == Preferences.VariabilityMethodEnum.RMSSD)
+			PreferencesWindowBox.radio_force_sensor_variability_rmssd.Active = true;
+		else if(preferences.forceSensorVariabilityMethod == Preferences.VariabilityMethodEnum.CVRMSSD)
+			PreferencesWindowBox.radio_force_sensor_variability_cvrmssd.Active = true;
+		else
+			PreferencesWindowBox.radio_force_sensor_variability_old.Active = true;
+
+		PreferencesWindowBox.spin_force_sensor_analyze_ab_slider_increment.Value = preferences.forceSensorAnalyzeABSliderIncrement;
+		PreferencesWindowBox.spin_force_sensor_analyze_max_avg_force_in_window.Value = preferences.forceSensorAnalyzeMaxAVGInWindow;
+
 		//runEncoder -->
-		PreferencesWindowBox.spin_force_sensor_acceleration.Value = preferences.runEncoderMinAccel;
+		PreferencesWindowBox.spin_run_encoder_acceleration.Value = preferences.runEncoderMinAccel;
+		PreferencesWindowBox.spin_run_encoder_pps.Value = preferences.runEncoderPPS;
+		PreferencesWindowBox.update_run_encoder_pps_equivalence_and_max ();
 
 		//language -->
 		if(preferences.language == "")
@@ -715,10 +772,8 @@ public class PreferencesWindow
 
 		if(preferences.importerPythonVersion == Preferences.pythonVersionEnum.Python2)
 			PreferencesWindowBox.radio_python_2.Active = true;
-		else if(preferences.importerPythonVersion == Preferences.pythonVersionEnum.Python3)
+		else //if(preferences.importerPythonVersion == Preferences.pythonVersionEnum.Python3)
 			PreferencesWindowBox.radio_python_3.Active = true;
-		else //if(preferences.importerPythonVersion == Preferences.pythonVersionEnum.Python)
-			PreferencesWindowBox.radio_python_default.Active = true;
 
 		if(preferences.colorBackgroundOsColor) {
 			PreferencesWindowBox.radio_color_os.Active = true;
@@ -740,6 +795,13 @@ public class PreferencesWindow
 		PreferencesWindowBox.paintColorDrawingAreaAndBg (PreferencesWindowBox.colorBackground);
 		UtilGtk.PaintColorDrawingArea(PreferencesWindowBox.drawingarea_background_color_chronojump_blue, UtilGtk.BLUE_CHRONOJUMP);
 
+		//tabs selection widgets
+		PreferencesWindowBox.image_view_more_tabs_close.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_close.png");
+		PreferencesWindowBox.label_mandatory_tabs.Text = "<b>" + PreferencesWindowBox.label_mandatory_tabs.Text + "</b>";
+		PreferencesWindowBox.label_mandatory_tabs.UseMarkup = true;
+		PreferencesWindowBox.label_selectable_tabs.Text = "<b>" + PreferencesWindowBox.label_selectable_tabs.Text + "</b>";
+		PreferencesWindowBox.label_selectable_tabs.UseMarkup = true;
+
 		PreferencesWindowBox.preferences_win.Show ();
 		return PreferencesWindowBox;
 	}
@@ -748,8 +810,13 @@ public class PreferencesWindow
 
 	private void on_button_view_more_tabs_clicked (object o, EventArgs args)
 	{
-		button_view_more_tabs.Visible = false;
-		hbox_more_tabs.Visible = true;
+		notebook_top.CurrentPage = 1;
+		hbox_buttons_bottom.Sensitive = false;
+	}
+	private void on_button_view_more_tabs_close_clicked (object o, EventArgs args)
+	{
+		notebook_top.CurrentPage = 0;
+		hbox_buttons_bottom.Sensitive = true;
 	}
 
 	private void on_check_view_jumps_clicked (object o,EventArgs args)
@@ -780,6 +847,7 @@ public class PreferencesWindow
 		if(active) {
 			PreferencesWindowBox.notebook.GetNthPage(page).Show();
 			PreferencesWindowBox.notebook.CurrentPage = page;
+
 		} else
 			PreferencesWindowBox.notebook.GetNthPage(page).Hide();
 	}
@@ -798,10 +866,7 @@ public class PreferencesWindow
 	{
 		UtilGtk.PaintColorDrawingArea(drawingarea_background_color, color);
 		if(! preferences.colorBackgroundOsColor)
-		{
 			UtilGtk.WindowColor(preferences_win, color);
-			UtilGtk.ContrastLabelsLabel (preferences.colorBackgroundIsDark, label_view_more_tabs);
-		}
 	}
 
 	private void on_radio_color_custom_toggled (object o, EventArgs args)
@@ -854,6 +919,21 @@ public class PreferencesWindow
 		label_radio_font_needs_restart.Visible = true;
 	}
 
+	private void on_check_rest_time_toggled (object o, EventArgs args)
+	{
+		Pixbuf pixbuf;
+		if(check_rest_time.Active)
+		{
+			hbox_rest_time_values.Visible = true;
+			pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_rest.png");
+		} else
+		{
+			hbox_rest_time_values.Visible = false;
+			pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_rest_inactive.png");
+		}
+		PreferencesWindowBox.image_rest.Pixbuf = pixbuf;
+	}
+
 	private void on_radio_encoder_capture_show_all_bars_toggled (object o, EventArgs args)
 	{
 		spin_encoder_capture_show_only_some_bars.Sensitive = false;
@@ -913,6 +993,24 @@ public class PreferencesWindow
 	 * end of triggers stuff
 	 */
 
+
+	// ---- race analyzer ---->
+
+	private void on_spin_run_encoder_pps_value_changed (object o, EventArgs args)
+	{
+		update_run_encoder_pps_equivalence_and_max ();
+	}
+	private void update_run_encoder_pps_equivalence_and_max ()
+	{
+		label_pps_equivalent.Text = string.Format(Catalog.GetString("{0} pps is equivalent to a resolution of {1} cm."),
+				spin_run_encoder_pps.Value, 0.3003 * spin_run_encoder_pps.Value);
+
+		label_pps_maximum.Text = string.Format(Catalog.GetString("{0} pps allows to record up to {1} m/s."),
+				spin_run_encoder_pps.Value, spin_run_encoder_pps.Value * 4);
+	}
+
+	// <---- end of race analyzer ----
+
 	private void createComboCamera(string current, string pixelFormat, string resolution, string framerate)
 	{
 		// 1) videoDevice
@@ -1323,8 +1421,8 @@ public class PreferencesWindow
 
 	private void on_button_video_check_ffmpeg_ffplay_running_clicked(object o, EventArgs args)
 	{
-		label_video_check_ffmpeg_running.Text = "Not running";
-		label_video_check_ffplay_running.Text = "Not running";
+		label_video_check_ffmpeg_running.Text = Catalog.GetString("Not running");
+		label_video_check_ffplay_running.Text = Catalog.GetString("Not running");
 		button_video_ffmpeg_kill.Visible = false;
 		button_video_ffplay_kill.Visible = false;
 		label_camera_check_running.Text = "";
@@ -1335,14 +1433,14 @@ public class PreferencesWindow
 		if(ExecuteProcess.IsRunning3 (-1, WebcamFfmpeg.GetExecutableCapture(operatingSystem)))
 		{
 			//runningFfmpeg = true;
-			label_video_check_ffmpeg_running.Text = "Running";
+			label_video_check_ffmpeg_running.Text = Catalog.GetString("Running");
 			button_video_ffmpeg_kill.Visible = true;
 		}
 
 		if(ExecuteProcess.IsRunning3 (-1, WebcamFfmpeg.GetExecutablePlay(operatingSystem)))
 		{
 			//runningFfplay = true;
-			label_video_check_ffplay_running.Text = "Running";
+			label_video_check_ffplay_running.Text = Catalog.GetString("Running");
 			button_video_ffplay_kill.Visible = true;
 		}
 
@@ -1354,7 +1452,7 @@ public class PreferencesWindow
 		if(ExecuteProcess.KillExternalProcess (WebcamFfmpeg.GetExecutableCapture(operatingSystem)))
 		{
 			label_camera_check_running.Text = "Killed camera process";
-			label_video_check_ffmpeg_running.Text = "Not running";
+			label_video_check_ffmpeg_running.Text = Catalog.GetString("Not running");
 			button_video_ffmpeg_kill.Visible = false;
 		}
 		else
@@ -1365,7 +1463,7 @@ public class PreferencesWindow
 		if(ExecuteProcess.KillExternalProcess (WebcamFfmpeg.GetExecutablePlay(operatingSystem)))
 		{
 			label_camera_check_running.Text = "Killed play process";
-			label_video_check_ffplay_running.Text = "Not running";
+			label_video_check_ffplay_running.Text = Catalog.GetString("Not running");
 			button_video_ffplay_kill.Visible = false;
 		}
 		else
@@ -1457,7 +1555,7 @@ public class PreferencesWindow
 				"\n -" +
 				Catalog.GetString("Reaction time is displayed on Description column.") +
 				"\n -" +
-				Catalog.GetString("If first option is choosen, race time includes reaction time.")
+				Catalog.GetString("If first option is chosen, race time includes reaction time.")
 				);
 	}
 
@@ -1523,7 +1621,7 @@ public class PreferencesWindow
 			}
 		}
 
-		if(! Util.OpenFolder(dir))
+		if(! Util.OpenURL (dir))
 			new DialogMessage(Constants.MessageTypes.WARNING, 
 					Constants.DirectoryCannotOpenStr() + "\n\n" + dir);
 	}
@@ -1538,7 +1636,7 @@ public class PreferencesWindow
 			return;
 		}
 
-		if(! Util.OpenFolder(dir))
+		if(! Util.OpenURL (dir))
 			new DialogMessage(Constants.MessageTypes.WARNING, 
 					Constants.DirectoryCannotOpenStr() + "\n\n" + dir);
 	}
@@ -1587,12 +1685,24 @@ public class PreferencesWindow
 				Catalog.GetString("If a repetition has been found, test will end at selected inactivity seconds.") + "\n\n" +
 				Catalog.GetString("If a repetition has not been found, test will end at selected inactivity seconds (x2).") + "\n" +
 				Catalog.GetString("This will let the person to have more time to start movement.") + "\n\n" +
-				"On inertial, to avoid never ending capture because cone is slowly moving at the end, this criteria is added:" + "\n" +
-				"If passed the double of configured inactivity seconds since last phase, capture will end."
+				Catalog.GetString("On inertial, to avoid never ending capture because cone is slowly moving at the end, this criteria is added:") + "\n" +
+				Catalog.GetString("If passed the double of configured inactivity seconds since last phase, capture will end.")
+				);
+	}
+
+	private void on_button_encoder_inertial_analyze_eq_mass_help_clicked (object o, EventArgs args)
+	{
+		new DialogImageTest (
+				Catalog.GetString("Equivalent mass"),
+				Util.GetImagePath(false) + "equivalentMass.png",
+				DialogImageTest.ArchiveType.ASSEMBLY,
+				Catalog.GetString("The equivalent mass is a measure of the resistance of a body to change its linear or rotary velocity.") + "\n" +
+				Catalog.GetString("From the point of view of a person pulling from a rope, the situation in the image is equivalent to a rotary inertial machine.") + "\n" +
+				Catalog.GetString("The equivalent mass takes in account the different configurations of a inertial machine (diameters, inertia momentum, extra weights and force multipliers).") + "\n" +
+				Catalog.GetString("This way it is possible to compare the resistance of diferent configurations on diferent machines.")
 				);
 	}
 
-	
 	// ---- start SQL stress tests ---->
 
 	private void on_SQL_stress_test_safe_short_clicked (object o, EventArgs args) {
@@ -1757,6 +1867,34 @@ public class PreferencesWindow
 			preferences.fontType = Preferences.FontTypes.Courier;
 		}
 
+		//rest time change start ---->
+		bool changeRestTime = false;
+		int minutes = (int) PreferencesWindowBox.spinbutton_rest_minutes.Value;
+		int seconds = (int) PreferencesWindowBox.spinbutton_rest_seconds.Value;
+
+		//if we had some time selected previously and now we selected no rest time
+		if(preferences.restTimeMinutes >= 0 && ! PreferencesWindowBox.check_rest_time.Active)
+		{
+			changeRestTime = true;
+			minutes = -1;
+			seconds = 0;
+		} else
+		{
+			if(preferences.restTimeMinutes != minutes)
+				changeRestTime = true;
+			if(preferences.restTimeSeconds != seconds)
+				changeRestTime = true;
+		}
+
+		if(changeRestTime)
+		{
+				SqlitePreferences.Update(SqlitePreferences.RestTimeMinutes, minutes.ToString(), true);
+				preferences.restTimeMinutes = minutes;
+				SqlitePreferences.Update(SqlitePreferences.RestTimeSeconds, seconds.ToString(), true);
+				preferences.restTimeSeconds = seconds;
+		}
+		//<---- rest time change end
+
 		if( preferences.digitsNumber != Convert.ToInt32(UtilGtk.ComboGetActive(combo_decimals)) ) {
 			SqlitePreferences.Update("digitsNumber", UtilGtk.ComboGetActive(combo_decimals), true);
 			preferences.digitsNumber = Convert.ToInt32(UtilGtk.ComboGetActive(combo_decimals));
@@ -1987,7 +2125,14 @@ public class PreferencesWindow
 				"encoderSmoothCon",
 				preferences.encoderSmoothCon,
 				(double) PreferencesWindowBox.spin_encoder_smooth_con.Value);
-		
+
+		Preferences.EncoderInertialGraphsXTypes encoderInertialGraphsXFromGUI = get_encoderInertialGraphsX_from_gui();
+		if(preferences.encoderInertialGraphsX != encoderInertialGraphsXFromGUI)
+		{
+			SqlitePreferences.Update(SqlitePreferences.EncoderInertialGraphsX, encoderInertialGraphsXFromGUI.ToString(), true);
+			preferences.encoderInertialGraphsX = encoderInertialGraphsXFromGUI;
+		}
+
 		Constants.Encoder1RMMethod encoder1RMMethod;
 		if(PreferencesWindowBox.radio_encoder_1RM_nonweighted.Active)
 			encoder1RMMethod = Constants.Encoder1RMMethod.NONWEIGHTED;
@@ -2038,12 +2183,47 @@ public class PreferencesWindow
 				preferences.forceSensorGraphsLineWidth,
 				Convert.ToInt32(spin_force_sensor_graphs_line_width.Value));
 
+		//variability
+		if(PreferencesWindowBox.radio_force_sensor_variability_rmssd.Active &&
+				preferences.forceSensorVariabilityMethod != Preferences.VariabilityMethodEnum.RMSSD)
+		{
+			SqlitePreferences.Update(SqlitePreferences.ForceSensorVariabilityMethod, Preferences.VariabilityMethodEnum.RMSSD.ToString(), true);
+			preferences.forceSensorVariabilityMethod = Preferences.VariabilityMethodEnum.RMSSD;
+		}
+		else if(PreferencesWindowBox.radio_force_sensor_variability_cvrmssd.Active &&
+				preferences.forceSensorVariabilityMethod != Preferences.VariabilityMethodEnum.CVRMSSD)
+		{
+			SqlitePreferences.Update(SqlitePreferences.ForceSensorVariabilityMethod, Preferences.VariabilityMethodEnum.CVRMSSD.ToString(), true);
+			preferences.forceSensorVariabilityMethod = Preferences.VariabilityMethodEnum.CVRMSSD;
+		}
+		else if(PreferencesWindowBox.radio_force_sensor_variability_old.Active &&
+				preferences.forceSensorVariabilityMethod != Preferences.VariabilityMethodEnum.CHRONOJUMP_OLD)
+		{
+			SqlitePreferences.Update(SqlitePreferences.ForceSensorVariabilityMethod, Preferences.VariabilityMethodEnum.CHRONOJUMP_OLD.ToString(), true);
+			preferences.forceSensorVariabilityMethod = Preferences.VariabilityMethodEnum.CHRONOJUMP_OLD;
+		}
+
+		preferences.forceSensorAnalyzeABSliderIncrement = Preferences.PreferencesChange(
+				SqlitePreferences.ForceSensorAnalyzeABSliderIncrement,
+				preferences.forceSensorAnalyzeABSliderIncrement,
+				Convert.ToDouble(spin_force_sensor_analyze_ab_slider_increment.Value));
+
+		preferences.forceSensorAnalyzeMaxAVGInWindow = Preferences.PreferencesChange(
+				SqlitePreferences.ForceSensorAnalyzeMaxAVGInWindow,
+				preferences.forceSensorAnalyzeMaxAVGInWindow,
+				Convert.ToDouble(spin_force_sensor_analyze_max_avg_force_in_window.Value));
+
 		//runEncoder ----
 
 		preferences.runEncoderMinAccel = Preferences.PreferencesChange(
 				SqlitePreferences.RunEncoderMinAccel,
 				preferences.runEncoderMinAccel,
-				Convert.ToDouble(spin_force_sensor_acceleration.Value));
+				Convert.ToDouble(spin_run_encoder_acceleration.Value));
+
+		preferences.runEncoderPPS = Preferences.PreferencesChange(
+				SqlitePreferences.RunEncoderPPS,
+				preferences.runEncoderPPS,
+				Convert.ToInt32(spin_run_encoder_pps.Value));
 
 		//multimedia ----
 		if( preferences.volumeOn != PreferencesWindowBox.checkbutton_volume.Active ) {
@@ -2168,11 +2348,19 @@ public class PreferencesWindow
 		return Preferences.MaximizedTypes.YESUNDECORATED;
 	}
 
+	private Preferences.EncoderInertialGraphsXTypes get_encoderInertialGraphsX_from_gui()
+	{
+		if(PreferencesWindowBox.radio_encoder_inertial_analyze_inertia_moment.Active)
+			return Preferences.EncoderInertialGraphsXTypes.INERTIA_MOMENT;
+		else if(PreferencesWindowBox.radio_encoder_inertial_analyze_diameter.Active)
+			return Preferences.EncoderInertialGraphsXTypes.DIAMETER;
+		else
+			return Preferences.EncoderInertialGraphsXTypes.EQUIVALENT_MASS;
+	}
+
 	private Preferences.pythonVersionEnum get_pythonVersion_from_gui()
 	{
-		if( PreferencesWindowBox.radio_python_default.Active)
-			return Preferences.pythonVersionEnum.Python;
-		else if( PreferencesWindowBox.radio_python_2.Active)
+		if( PreferencesWindowBox.radio_python_2.Active)
 			return Preferences.pythonVersionEnum.Python2;
 		else //if( PreferencesWindowBox.radio_python_3.Active)
 			return Preferences.pythonVersionEnum.Python3;
