@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2021   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -84,6 +84,7 @@ public class RepetitiveConditionsWindow
 	[Widget] Gtk.RadioButton radio_encoder_eccon_con;
 	[Widget] Gtk.CheckButton check_encoder_inertial_ecc_overload;
 	[Widget] Gtk.CheckButton check_encoder_inertial_ecc_overload_percent;
+	[Widget] Gtk.CheckButton check_encoder_show_loss;
 
 	[Widget] Gtk.Notebook notebook_encoder_conditions;
 	[Widget] Gtk.CheckButton checkbutton_encoder_height_higher;
@@ -185,10 +186,20 @@ public class RepetitiveConditionsWindow
 	[Widget] Gtk.CheckButton check_rhythm_rest_reps;
 
 	//forceSensor
-	[Widget] Gtk.CheckButton check_force_sensor_capture_feedback;
-	[Widget] Gtk.HBox hbox_force_sensor_capture_feedback;
-	[Widget] Gtk.SpinButton spin_force_sensor_capture_feedback_at;
-	[Widget] Gtk.SpinButton spin_force_sensor_capture_feedback_range;
+	[Widget] Gtk.Notebook notebook_force_sensor_feedback;
+	[Widget] Gtk.RadioButton radio_force_sensor_capture_feedback_no;
+	[Widget] Gtk.RadioButton radio_force_sensor_capture_feedback_show_rectangle;
+	[Widget] Gtk.RadioButton radio_force_sensor_capture_feedback_show_path;
+	//rectangle
+	[Widget] Gtk.SpinButton spin_force_sensor_capture_feedback_rectangle_at;
+	[Widget] Gtk.SpinButton spin_force_sensor_capture_feedback_rectangle_range;
+	//path
+	[Widget] Gtk.SpinButton spin_force_sensor_capture_feedback_path_max;
+	[Widget] Gtk.SpinButton spin_force_sensor_capture_feedback_path_min;
+	[Widget] Gtk.SpinButton spin_force_sensor_capture_feedback_path_masters;
+	[Widget] Gtk.SpinButton spin_force_sensor_capture_feedback_path_master_seconds;
+	[Widget] Gtk.SpinButton spin_force_sensor_capture_feedback_path_line_width; //N
+	[Widget] Gtk.Label label_force_sensor_path_recommended;
 
 	const int JUMPSRUNSPAGE = 0;
 	const int ENCODERAUTOPAGE = 1;
@@ -265,10 +276,17 @@ public class RepetitiveConditionsWindow
 				preferences.encoderCaptureMainVariableLowerActive,
 				preferences.encoderCaptureMainVariableLowerValue,
 				preferences.encoderCaptureFeedbackEccon,
+				preferences.encoderCaptureShowLoss,
 				encoderRhythm,
 				preferences.forceSensorCaptureFeedbackActive,
 				preferences.forceSensorCaptureFeedbackAt,
-				preferences.forceSensorCaptureFeedbackRange);
+				preferences.forceSensorCaptureFeedbackRange,
+				preferences.forceSensorFeedbackPathMax,
+				preferences.forceSensorFeedbackPathMin,
+				preferences.forceSensorFeedbackPathMasters,
+				preferences.forceSensorFeedbackPathMasterSeconds,
+				preferences.forceSensorFeedbackPathLineWidth
+				);
 
 		if(viewWindow)
 		{
@@ -294,10 +312,18 @@ public class RepetitiveConditionsWindow
 			bool encoderCaptureMainVariableLowerActive,
 			int encoderCaptureMainVariableLowerValue,
 			Preferences.EncoderPhasesEnum encoderCaptureFeedbackEccon,
+			bool encoderCaptureShowLoss,
 			EncoderRhythm encoderRhythm,
-			bool forceSensorCaptureFeedbackActive,
+			//bool forceSensorCaptureFeedbackActive,
+			Preferences.ForceSensorCaptureFeedbackActiveEnum forceSensorCaptureFeedbackActive,
 			int forceSensorCaptureFeedbackAt,
-			int forceSensorCaptureFeedbackRange)
+			int forceSensorCaptureFeedbackRange,
+			int forceSensorFeedbackPathMax,
+			int forceSensorFeedbackPathMin,
+			int forceSensorFeedbackPathMasters,
+			int forceSensorFeedbackPathMasterSeconds,
+			int forceSensorFeedbackPathLineWidth
+				)
 	{
 		hbox_jump_best_worst.Hide();
 		hbox_run_best_worst.Hide();
@@ -350,6 +376,7 @@ public class RepetitiveConditionsWindow
 				check_encoder_inertial_ecc_overload_percent.Active = true;
 				check_encoder_inertial_ecc_overload_percent.Visible = true;
 			}
+			check_encoder_show_loss.Active = encoderCaptureShowLoss;
 
 			if(encoderSecondaryVariableShow)
 				check_encoder_show_secondary_variable.Active = true;
@@ -402,17 +429,31 @@ public class RepetitiveConditionsWindow
 		}
 		else if(bellMode == Constants.BellModes.FORCESENSOR)
 		{
-			if(forceSensorCaptureFeedbackActive)
+			if(forceSensorCaptureFeedbackActive == Preferences.ForceSensorCaptureFeedbackActiveEnum.NO)
 			{
-				check_force_sensor_capture_feedback.Active = true;
-				hbox_force_sensor_capture_feedback.Sensitive = true;
+				radio_force_sensor_capture_feedback_no.Active = true;
+				notebook_force_sensor_feedback.Page = 0;
+			}
+			else if(forceSensorCaptureFeedbackActive == Preferences.ForceSensorCaptureFeedbackActiveEnum.RECTANGLE)
+			{
+				radio_force_sensor_capture_feedback_show_rectangle.Active = true;
+				notebook_force_sensor_feedback.Page = 1;
 			} else {
-				check_force_sensor_capture_feedback.Active = false;
-				hbox_force_sensor_capture_feedback.Sensitive = false;
+				radio_force_sensor_capture_feedback_show_path.Active = true;
+				notebook_force_sensor_feedback.Page = 2;
 			}
 
-			spin_force_sensor_capture_feedback_at.Value = forceSensorCaptureFeedbackAt;
-			spin_force_sensor_capture_feedback_range.Value = forceSensorCaptureFeedbackRange;
+			//rectangle widgets
+			spin_force_sensor_capture_feedback_rectangle_at.Value = forceSensorCaptureFeedbackAt;
+			spin_force_sensor_capture_feedback_rectangle_range.Value = forceSensorCaptureFeedbackRange;
+
+			//path widgets
+			spin_force_sensor_capture_feedback_path_max.Value = forceSensorFeedbackPathMax;
+			spin_force_sensor_capture_feedback_path_min.Value = forceSensorFeedbackPathMin;
+			spin_force_sensor_capture_feedback_path_masters.Value = forceSensorFeedbackPathMasters;
+			spin_force_sensor_capture_feedback_path_master_seconds.Value = forceSensorFeedbackPathMasterSeconds;
+			spin_force_sensor_capture_feedback_path_line_width.Value = forceSensorFeedbackPathLineWidth;
+			setForceSensorPathRecommendedLabel();
 
 			notebook_main.GetNthPage(FORCESENSORPAGE).Show();
 		}
@@ -582,7 +623,7 @@ public class RepetitiveConditionsWindow
 				return true;
 		}
 		else if(bellMode == Constants.BellModes.FORCESENSOR)
-			return check_force_sensor_capture_feedback.Active;
+			return ! radio_force_sensor_capture_feedback_no.Active;
 
 		return false;
 	}
@@ -941,19 +982,82 @@ public class RepetitiveConditionsWindow
 
 	/* FORCESENSOR */
 
-	private void on_check_force_sensor_capture_feedback_toggled (object o, EventArgs args)
+	private void on_radio_force_sensor_capture_feedback_no_toggled (object o, EventArgs args)
 	{
-		hbox_force_sensor_capture_feedback.Sensitive = check_force_sensor_capture_feedback.Active;
+		notebook_force_sensor_feedback.Page = 0;
+	}
+	private void on_radio_force_sensor_capture_feedback_show_rectangle_toggled (object o, EventArgs args)
+	{
+		notebook_force_sensor_feedback.Page = 1;
+	}
+	private void on_radio_force_sensor_capture_feedback_show_path_toggled (object o, EventArgs args)
+	{
+		notebook_force_sensor_feedback.Page = 2;
 	}
 
-	public bool GetForceSensorFeedbackActive {
-		get { return check_force_sensor_capture_feedback.Active; }
+	public Preferences.ForceSensorCaptureFeedbackActiveEnum GetForceSensorFeedback {
+		get {
+			if(radio_force_sensor_capture_feedback_show_rectangle.Active)
+				return Preferences.ForceSensorCaptureFeedbackActiveEnum.RECTANGLE;
+			else if(radio_force_sensor_capture_feedback_show_path.Active)
+				return Preferences.ForceSensorCaptureFeedbackActiveEnum.PATH;
+			else //if(radio_force_sensor_capture_feedback_no.Active)
+				return Preferences.ForceSensorCaptureFeedbackActiveEnum.NO;
+		}
 	}
-	public int GetForceSensorFeedbackAt {
-		get { return Convert.ToInt32(spin_force_sensor_capture_feedback_at.Value); }
+
+	//force sensor feedback rectangle
+	public bool GetForceSensorFeedbackRectangleActive {
+		get { return radio_force_sensor_capture_feedback_show_rectangle.Active; }
 	}
-	public int GetForceSensorFeedbackRange {
-		get { return Convert.ToInt32(spin_force_sensor_capture_feedback_range.Value); }
+	public int GetForceSensorFeedbackRectangleAt {
+		get { return Convert.ToInt32(spin_force_sensor_capture_feedback_rectangle_at.Value); }
+	}
+	public int GetForceSensorFeedbackRectangleRange {
+		get { return Convert.ToInt32(spin_force_sensor_capture_feedback_rectangle_range.Value); }
+	}
+
+	//force sensor feedback path
+
+	private void setForceSensorPathRecommendedLabel ()
+	{
+		label_force_sensor_path_recommended.Text = string.Format("1/3 * ({0} - {1}) = {2} N",
+				Catalog.GetString("Maximum"), Catalog.GetString("Minimum"),
+				Convert.ToInt32((spin_force_sensor_capture_feedback_path_max.Value - spin_force_sensor_capture_feedback_path_min.Value) /3));
+	}
+
+	private void on_spin_force_sensor_capture_feedback_path_min_value_changed (object o, EventArgs args)
+	{
+		if(spin_force_sensor_capture_feedback_path_min.Value > spin_force_sensor_capture_feedback_path_max.Value)
+			spin_force_sensor_capture_feedback_path_max.Value = spin_force_sensor_capture_feedback_path_min.Value;
+
+		setForceSensorPathRecommendedLabel();
+	}
+	private void on_spin_force_sensor_capture_feedback_path_max_value_changed (object o, EventArgs args)
+	{
+		if(spin_force_sensor_capture_feedback_path_max.Value < spin_force_sensor_capture_feedback_path_min.Value)
+			spin_force_sensor_capture_feedback_path_min.Value = spin_force_sensor_capture_feedback_path_max.Value;
+
+		setForceSensorPathRecommendedLabel();
+	}
+
+	public bool GetForceSensorFeedbackPathActive {
+		get { return radio_force_sensor_capture_feedback_show_path.Active; }
+	}
+	public int GetForceSensorFeedbackPathMax {
+		get { return Convert.ToInt32(spin_force_sensor_capture_feedback_path_max.Value); }
+	}
+	public int GetForceSensorFeedbackPathMin {
+		get { return Convert.ToInt32(spin_force_sensor_capture_feedback_path_min.Value); }
+	}
+	public int GetForceSensorFeedbackPathMasters {
+		get { return Convert.ToInt32(spin_force_sensor_capture_feedback_path_masters.Value); }
+	}
+	public int GetForceSensorFeedbackPathMasterSeconds {
+		get { return Convert.ToInt32(spin_force_sensor_capture_feedback_path_master_seconds.Value); }
+	}
+	public int GetForceSensorFeedbackPathLineWidth {
+		get { return Convert.ToInt32(spin_force_sensor_capture_feedback_path_line_width.Value); } //N
 	}
 
 
@@ -1095,6 +1199,10 @@ public class RepetitiveConditionsWindow
 		}
 	}
 
+	public bool EncoderCaptureShowLoss {
+		get { return check_encoder_show_loss.Active; }
+	}
+
 	public double GetMainVariableHigher(string mainVariable) 
 	{
 		if(mainVariable == Constants.MeanSpeed && EncoderMeanSpeedHigher)
