@@ -62,6 +62,7 @@ public class RunTypeAddWindow
 	[Widget] Gtk.Alignment alignment_vbox_distance_variable;
 	[Widget] Gtk.ComboBox combo_distance_different_tracks;
 	[Widget] Gtk.HBox hbox_distance_variable;
+	[Widget] Gtk.Label label_decimal_separator;
 
 
 	[Widget] Gtk.TextView textview_description;
@@ -145,11 +146,8 @@ public class RunTypeAddWindow
 		alignment_hbox_distance_fixed.Sensitive = false;
 		alignment_vbox_distance_variable.Sensitive = false;
 		if(simple)
-		{
-			alignment_hbox_distance_fixed.Hide();
 			alignment_vbox_distance_variable.Hide();
-		}
-					
+
 		dd0 = new Gtk.Entry(); 	dd0.Changed += new EventHandler(on_entries_required_changed);
 		dd1 = new Gtk.Entry(); 	dd1.Changed += new EventHandler(on_entries_required_changed);
 		dd2 = new Gtk.Entry(); 	dd2.Changed += new EventHandler(on_entries_required_changed);
@@ -164,6 +162,10 @@ public class RunTypeAddWindow
 		combo_distance_different_tracks.Active = 0;
 		reset_hbox_distance_variable (2);
 
+		System.Globalization.NumberFormatInfo localeInfo = new System.Globalization.NumberFormatInfo();
+		localeInfo = System.Globalization.NumberFormatInfo.CurrentInfo;
+		label_decimal_separator.Text += string.Format(Catalog.GetString("(decimal separator: '{0}')"), localeInfo.NumberDecimalSeparator);
+
 		textview_description.Buffer.Changed += new EventHandler(descriptionChanged);
 		descriptionChanging = false;
 	}
@@ -339,8 +341,8 @@ public class RunTypeAddWindow
 		foreach(Gtk.Entry entry in hbox_distance_variable.Children)
 			hbox_distance_variable.Remove(entry);
 
-		int wc = 3; //widthChars (width of the entry)
-		int ml = 3; //maxLength (max chars to entry)
+		int wc = 5; //widthChars (width of the entry)
+		int ml = 5; //maxLength (max chars to entry)
 		for (int i = 0; i < colsNum; i ++) {
 			switch(i) {
 				case 0: 
