@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2017   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2017,2021   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -35,7 +35,26 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_sprint;
 	[Widget] Gtk.Button button_sprint_save_image;
 
-	static Sprint sprint;
+	[Widget] Gtk.HBox hbox_sprint_analyze_top_modes;
+	[Widget] Gtk.RadioButton radio_sprint_analyze_individual_current_session;
+	[Widget] Gtk.RadioButton radio_sprint_analyze_groupal_current_session;
+	[Widget] Gtk.Image image_sprint_analyze_individual_current_set;
+	[Widget] Gtk.Image image_sprint_analyze_individual_current_session;
+	[Widget] Gtk.Image image_sprint_analyze_groupal_current_session;
+	[Widget] Gtk.Notebook notebook_sprint_analyze_top;
+
+	//export
+	[Widget] Gtk.Notebook notebook_sprint_export;
+	[Widget] Gtk.Label label_sprint_export_data;
+	[Widget] Gtk.CheckButton check_sprint_export_images;
+	[Widget] Gtk.HBox hbox_sprint_export_width_height;
+	[Widget] Gtk.SpinButton spinbutton_sprint_export_image_width;
+	[Widget] Gtk.SpinButton spinbutton_sprint_export_image_height;
+	[Widget] Gtk.ProgressBar progressbar_sprint_export;
+	[Widget] Gtk.Label label_sprint_export_result;
+	[Widget] Gtk.Button button_sprint_export_result_open;
+
+	static SprintRGraph sprintRGraph;
 	TreeStore storeSprint;
 
 	private void createTreeView_runs_interval_sprint (Gtk.TreeView tv)
@@ -67,7 +86,7 @@ public partial class ChronoJumpWindow
 		tv.Selection.Changed += onTreeviewSprintSelectionEntry;
 
 		List<object> runITypes = SqliteRunIntervalType.SelectRunIntervalTypesNew("", false);
-		string [] runsArray = SqliteRunInterval.SelectRuns(
+		string [] runsArray = SqliteRunInterval.SelectRunsSA (
 				false, currentSession.UniqueID, currentPerson.UniqueID, "");
 
 		foreach (string line in runsArray)
@@ -78,15 +97,15 @@ public partial class ChronoJumpWindow
 			//get intervalTimes
 			string intervalTimesString = lineSplit[8];
 
-			string positions = getSprintPositions(
+			string positions = RunInterval.GetSprintPositions(
 					Convert.ToDouble(lineSplit[7]), //distanceInterval. == -1 means variable distances
 					intervalTimesString,
-					runIntervalTypeDistances(lineSplit[4], runITypes) 	//distancesString
+					SelectRunITypes.RunIntervalTypeDistances(lineSplit[4], runITypes) 	//distancesString
 					);
 			if(positions == "")
 				continue;
 
-			string splitTimes = getSplitTimes(intervalTimesString);
+			string splitTimes = RunInterval.GetSplitTimes(intervalTimesString, preferences.digitsNumber);
 
 			string [] lineParams = { 
 				lineSplit[4],
@@ -109,7 +128,7 @@ public partial class ChronoJumpWindow
 			return;
 		}
 
-		string positions = getSprintPositions(
+		string positions = RunInterval.GetSprintPositions(
 				runI.DistanceInterval, 		//distanceInterval. == -1 means variable distances
 				runI.IntervalTimesString,
 				runIType.DistancesString 	//distancesString
@@ -126,7 +145,7 @@ public partial class ChronoJumpWindow
 				runI.Type,
 				runI.UniqueID.ToString(),
 				positions,
-				getSplitTimes(runI.IntervalTimesString),
+				RunInterval.GetSplitTimes(runI.IntervalTimesString, preferences.digitsNumber),
 				Util.TrimDecimals(runI.TimeTotal, preferences.digitsNumber)
 				);
 
@@ -136,53 +155,6 @@ public partial class ChronoJumpWindow
 		LogB.Information("SPRINT add END");
 	}
 
-	private string getSprintPositions(double distanceInterval, string intervalTimesString, string distancesString)
-	{
-		string positions = "";
-		string [] intervalTimesSplit = intervalTimesString.Split(new char[] {'='});
-		if(! distancesString.Contains("R") ) 	//discard RSA
-		{
-			string sep = "";
-			for(int i=0; i < intervalTimesSplit.Length; i ++)
-			{
-				positions += sep + Util.GetRunITotalDistance(distanceInterval, distancesString, i+1);
-				sep = ";";
-			}
-
-			//format positions
-			positions = Util.ChangeChars(positions, "-", ";");
-		}
-		return positions;
-	}
-
-	private string getSplitTimes(string intervalTimesString)
-	{
-		string [] intervalTimesSplit = intervalTimesString.Split(new char[] {'='});
-
-		//manage accumulated time
-		double timeAccumulated = 0;
-		string splitTimes = "";
-		string sep = "";
-		foreach(string time in intervalTimesSplit)
-		{
-			double timeD = Convert.ToDouble(time);
-			timeAccumulated += timeD;
-			splitTimes += sep + Util.TrimDecimals(timeAccumulated, preferences.digitsNumber);
-			sep = ";";
-		}
-
-		return splitTimes;
-	}
-
-	private string runIntervalTypeDistances(string runTypeEnglishName, List<object> runITypes)
-	{
-		foreach(SelectRunITypes type in runITypes)
-			if(type.NameEnglish == runTypeEnglishName)
-				return(type.DistancesString);
-
-		return "";
-	}
-
 	private void onTreeviewSprintSelectionEntry (object o, EventArgs args)
 	{
 		TreeModel model;
@@ -190,7 +162,16 @@ public partial class ChronoJumpWindow
 
 		// you get the iter and the model if something is selected
 		if (((TreeSelection)o).GetSelected(out model, out iter))
-			button_sprint.Sensitive = true;
+		{
+			//only allow sprint calculation when there are three tracks
+			string splitTimes = (string) model.GetValue(iter, 3);
+			if(splitTimes.Split(new char[] {';'}).Length >= 3)
+				button_sprint.Sensitive = true;
+			else
+				button_sprint.Sensitive = false;
+		}
+		else
+			button_sprint.Sensitive = false;
 	}
 
 	public static bool GetSelectedSprint (Gtk.TreeView tv)
@@ -208,11 +189,12 @@ public partial class ChronoJumpWindow
 			 splitTimes = Util.ChangeChars(splitTimes, ",", ".");
 			 splitTimes = "0;" + splitTimes;
 
-			 sprint = new Sprint(
+			 sprintRGraph = new SprintRGraph (
 					 positions,
 					 splitTimes,
 					 currentPersonSession.Weight, //TODO: can be more if extra weight
 					 currentPersonSession.Height,
+					 currentPerson.Name,
 					 25);
 			return true;
 		}
@@ -248,11 +230,11 @@ public partial class ChronoJumpWindow
 			return false;
 		}
 
-		if(! sprint.IsDataOk())
+		if(! sprintRGraph.IsDataOk())
 		{
 			new DialogMessage(Constants.MessageTypes.WARNING,
 					Catalog.GetString("This data does not seem a sprint.") + "\n\n" +
-					sprint.ErrorMessage);
+					sprintRGraph.ErrorMessage);
 			return false;
 		}
 
@@ -260,10 +242,10 @@ public partial class ChronoJumpWindow
 
 		image_sprint.Sensitive = false;
 
-		bool success = sprint.CallR(
+		bool success = sprintRGraph.CallR(
 				viewport_sprint.Allocation.Width -5,
 				viewport_sprint.Allocation.Height -5,
-				currentPerson.Name);
+				true); //singleOrMultiple
 
 		if(! success)
 		{
@@ -305,4 +287,163 @@ public partial class ChronoJumpWindow
 		new DialogMessage(Constants.MessageTypes.INFO, myString);
 	}
 
+
+	//move to export gui file
+
+	private void on_check_sprint_export_images_toggled (object o, EventArgs args)
+	{
+		hbox_sprint_export_width_height.Visible = check_sprint_export_images.Active;
+
+		//also hide the label and the open button
+		label_sprint_export_result.Text = "";
+		button_sprint_export_result_open.Visible = false;
+	}
+
+	private void on_radio_sprint_analyze_individual_current_set_toggled (object o, EventArgs args)
+	{
+		notebook_sprint_analyze_top.CurrentPage = 0;
+
+		label_sprint_export_result.Text = "";
+		button_sprint_export_result_open.Visible = false;
+	}
+
+	private void on_radio_sprint_analyze_individual_current_session_toggled (object o, EventArgs args)
+	{
+		notebook_sprint_analyze_top.CurrentPage = 1;
+
+		if(currentPerson != null)
+			label_sprint_export_data.Text = currentPerson.Name;
+		else
+			label_sprint_export_data.Text = "";
+
+		label_sprint_export_result.Text = "";
+		button_sprint_export_result_open.Visible = false;
+	}
+
+	private void on_radio_sprint_analyze_groupal_current_session_toggled (object o, EventArgs args)
+	{
+		notebook_sprint_analyze_top.CurrentPage = 1;
+
+		label_sprint_export_data.Text = currentSession.Name;
+
+		label_sprint_export_result.Text = "";
+		button_sprint_export_result_open.Visible = false;
+	}
+
+	private void on_button_sprint_export_current_session_clicked (object o, EventArgs args)
+	{
+		if(currentSession == null)
+			return;
+
+		if (radio_sprint_analyze_individual_current_session.Active)
+		{
+			if(currentPerson == null)
+				return;
+
+			button_sprint_export_session (currentPerson.UniqueID);
+		}
+		else if (radio_sprint_analyze_groupal_current_session.Active)
+		{
+			button_sprint_export_session (-1);
+		}
+	}
+
+	SprintExport sprintExport;
+	private void button_sprint_export_session (int personID)
+	{
+		//continue based on: private void button_run_encoder_export_session (int personID)
+		//TODO: sensitive stuff (false)
+
+		label_sprint_export_result.Text = "";
+		button_sprint_export_result_open.Visible = false;
+
+		//store new width/height if changed
+		Sqlite.Open();
+		preferences.exportGraphWidth = Preferences.PreferencesChange(
+				SqlitePreferences.ExportGraphWidth,
+				preferences.exportGraphWidth, Convert.ToInt32(spinbutton_sprint_export_image_width.Value));
+		preferences.exportGraphHeight = Preferences.PreferencesChange(
+				SqlitePreferences.ExportGraphHeight,
+				preferences.exportGraphHeight, Convert.ToInt32(spinbutton_sprint_export_image_height.Value));
+		Sqlite.Close();
+
+		//change also spinbuttons of export forceSensor and runEncoder
+		spinbutton_force_sensor_export_image_width.Value = spinbutton_sprint_export_image_width.Value;
+		spinbutton_force_sensor_export_image_height.Value = spinbutton_sprint_export_image_height.Value;
+
+		spinbutton_run_encoder_export_image_width.Value = spinbutton_sprint_export_image_width.Value;
+		spinbutton_run_encoder_export_image_height.Value = spinbutton_sprint_export_image_height.Value;
+
+
+		sprintExport = new SprintExport(
+				notebook_sprint_export,
+				progressbar_sprint_export,
+				label_sprint_export_result,
+				check_sprint_export_images.Active,
+				Convert.ToInt32(spinbutton_sprint_export_image_width.Value),
+				Convert.ToInt32(spinbutton_sprint_export_image_height.Value),
+				UtilAll.IsWindows(),
+				personID,
+				currentSession.UniqueID,
+				preferences.CSVExportDecimalSeparatorChar,      //decimalIsPointAtExport (write)
+				preferences.digitsNumber);
+
+		sprintExport.Button_done.Clicked -= new EventHandler(sprint_export_done);
+		sprintExport.Button_done.Clicked += new EventHandler(sprint_export_done);
+
+		bool selectedFile = false;
+		if(check_sprint_export_images.Active)
+		{
+			if(personID == -1)
+				selectedFile = checkFolder (Constants.CheckFileOp.RUNS_SPRINT_EXPORT_GROUPAL_CURRENT_SESSION_YES_IMAGES);
+			else
+				selectedFile = checkFolder (Constants.CheckFileOp.RUNS_SPRINT_EXPORT_INDIVIDUAL_CURRENT_SESSION_YES_IMAGES);
+		} else {
+			if(personID == -1)
+				selectedFile = checkFile (Constants.CheckFileOp.RUNS_SPRINT_EXPORT_GROUPAL_CURRENT_SESSION_NO_IMAGES);
+			else
+				selectedFile = checkFile (Constants.CheckFileOp.RUNS_SPRINT_EXPORT_INDIVIDUAL_CURRENT_SESSION_NO_IMAGES);
+		}
+
+		//restore the gui if cancelled
+		if(! selectedFile) {
+			//TODO: sensitive stuff (true)
+		}
+	}
+	private void on_button_sprint_export_file_selected (string selectedFileName)
+	{
+		//sprintExport.Start("/tmp/prova_sprintExport.csv");
+		sprintExport.Start(selectedFileName); //file or folder
+	}
+
+	private void on_button_sprint_export_cancel_clicked (object o, EventArgs args)
+	{
+		sprintExport.Cancel();
+	}
+
+	private void sprint_export_done (object o, EventArgs args)
+	{
+		sprintExport.Button_done.Clicked -= new EventHandler(sprint_export_done);
+
+//		sprintButtonsSensitive(true);
+		hbox_sprint_analyze_top_modes.Sensitive = true;
+
+		if(sprintExport != null && sprintExport.AllOk)
+			button_sprint_export_result_open.Visible = true;
+	}
+
+	private void on_button_sprint_export_result_open_clicked (object o, EventArgs args)
+	{
+		if(sprintExport == null || sprintExport.ExportURL == "")
+		{
+			new DialogMessage(Constants.MessageTypes.WARNING,
+					Constants.DirectoryCannotOpenStr());
+			return;
+		}
+
+		if(! Util.OpenURL (sprintExport.ExportURL))
+			new DialogMessage(Constants.MessageTypes.WARNING,
+					Constants.DirectoryCannotOpenStr() + "\n\n" + sprintExport.ExportURL);
+	}
+
 }
