@@ -47,15 +47,12 @@ public class JsonCompujump : Json
 		Person person = new Person(-1);
 
 		// Create a request using a URL that can receive a post.
-		if (! createWebRequest(requestType.GENERIC, "/getPersonByRFID"))
+		if (! createWebRequest(requestType.AUTHENTICATED, "/api/v1/client/getPersonByRFID"))
 			return person;
 
 		// Set the Method property of the request to POST.
 		request.Method = "POST";
 
-		// Set the ContentType property of the WebRequest.
-		request.ContentType = "application/json; Charset=UTF-8"; //but this is not enough, see this line:
-
 		// Creates the json object
 		JsonObject json = new JsonObject();
 
@@ -107,12 +104,12 @@ public class JsonCompujump : Json
 	{
 		JsonValue jsonPerson = JsonValue.Parse(strPerson);
 
-		Int32 id = jsonPerson ["id"];
+		Int32 id = jsonPerson ["user_id"];
 		string player = jsonPerson ["name"];
 		double weight = jsonPerson ["weight"];
 		double height = jsonPerson ["height"];
 		string rfid = jsonPerson ["rfid"];
-		string image = jsonPerson ["imageName"];
+		string image = jsonPerson ["image_thumbnail"];
 
 		LastPersonByRFIDHeight = height;
 		LastPersonByRFIDWeight = weight;
@@ -127,19 +124,22 @@ public class JsonCompujump : Json
 		 */
 		LastPersonWasInserted = (personTemp.UniqueID == -1);
 
-		return new Person(LastPersonWasInserted, id, player, rfid);
+		return new Person(LastPersonWasInserted, id, player, rfid, image);
 	}
 
 
-	//to retrieve images from flask (:5000)
+	//Retrieve images from server
 	private string getImagesUrl()
 	{
+		//Networks v3
+		return serverUrl;
+		/*
 		int posOfLastColon = serverUrl.LastIndexOf(':');
-
-		if(django)
+		if(django) //Networks v2
 			return serverUrl.Substring(0, posOfLastColon) + ":8000/media/";
-		else
+		else //Networks v1
 			return serverUrl.Substring(0, posOfLastColon) + ":5000/static/images/photos/";
+		*/
 	}
 
 	//imageHalfUrl is "jugadors/*.jpg"
@@ -167,24 +167,22 @@ public class JsonCompujump : Json
 		connected = false;
 
 		// Create a request using a URL that can receive a post.
-		if (! createWebRequest(requestType.GENERIC, "/getTasks"))
+		if (! createWebRequest(requestType.AUTHENTICATED, "/api/v1/client/getTasks"))
 			return new List<Task>();
 
 		// Set the Method property of the request to POST.
 		request.Method = "POST";
 
-		// Set the ContentType property of the WebRequest.
-		request.ContentType = "application/json; Charset=UTF-8"; //but this is not enough, see this line:
-
 		// Creates the json object
 		JsonObject json = new JsonObject();
 
-		json.Add("personId", personID.ToString());
-		json.Add("stationId", stationID.ToString());
+		json.Add("person_id", personID.ToString());
+		json.Add("station_id", stationID.ToString());
 
 		// Converts it to a String
 		String js = json.ToString();
 
+		LogB.Debug("GetTasks params: " + js + "\n");
 		// Writes the json object into the request dataStream
 		Stream dataStream;
 		if(! getWebRequestStream (request, out dataStream, "Cannot get tasks."))
@@ -224,17 +222,17 @@ public class JsonCompujump : Json
 
 		foreach (JsonValue jsonTask in jsonTasks) {
 			Int32 id = jsonTask ["id"];
-			char type = jsonTask ["type"];
-			int exerciseId = jsonTask ["exerciseId"];
-			string exerciseName = jsonTask ["exerciseName"];
+			//char type = jsonTask ["type"];
+			int exerciseId = jsonTask ["exercise_id"];
+			string exerciseName = jsonTask ["exercise_name"];
 
-			int personId = jsonTask ["personId"];
-			int stationId = jsonTask ["stationId"];
+			int personId = jsonTask ["person"];
+			int stationId = jsonTask ["station"];
 			int sets = jsonTask ["sets"];
 			int nreps = jsonTask ["nreps"];
 			float load = jsonTask ["load"];
 			float speed = jsonTask ["speed"];
-			float percentMaxSpeed = jsonTask ["percentMaxSpeed"];
+			float percentMaxSpeed = jsonTask ["percent_max_speed"];
 			string laterality = jsonTask ["laterality"];
 			string comment = jsonTask ["comment"];
 			tasks.Add(new Task(id, personId, stationId, exerciseId, exerciseName,
@@ -248,18 +246,15 @@ public class JsonCompujump : Json
 	{
 		LogB.Information("At UpdateTask");
 		// Create a request using a URL that can receive a post.
-		if (! createWebRequest(requestType.GENERIC, "/updateTask"))
+		if (! createWebRequest(requestType.AUTHENTICATED, "/api/v1/client/updateTask"))
 			return false;
 
 		// Set the Method property of the request to POST.
 		request.Method = "POST";
 
-		// Set the ContentType property of the WebRequest.
-		request.ContentType = "application/json; Charset=UTF-8"; //but this is not enough, see this line:
-
 		// Creates the json object
 		JsonObject json = new JsonObject();
-		json.Add("taskId", taskId);
+		json.Add("task_id", taskId);
 		json.Add("done", done);
 
 		// Converts it to a String
@@ -294,19 +289,16 @@ public class JsonCompujump : Json
 	public List<StationCount> GetOtherStationsWithPendingTasks(int personID, int stationID)
 	{
 		// Create a request using a URL that can receive a post.
-		if (! createWebRequest(requestType.GENERIC, "/getOtherStationsWithPendingTasks"))
+		if (! createWebRequest(requestType.AUTHENTICATED, "/api/v1/client/getOtherStationsWithPendingTasks"))
 			return new List<StationCount>();
 
 		// Set the Method property of the request to POST.
 		request.Method = "POST";
 
-		// Set the ContentType property of the WebRequest.
-		request.ContentType = "application/json; Charset=UTF-8"; //but this is not enough, see this line:
-
 		// Creates the json object
 		JsonObject json = new JsonObject();
-		json.Add("personId", personID.ToString());
-		json.Add("stationId", stationID.ToString());
+		json.Add("person_id", personID.ToString());
+		json.Add("station_id", stationID.ToString());
 
 		// Converts it to a String
 		String js = json.ToString();
@@ -343,30 +335,28 @@ public class JsonCompujump : Json
 
 		foreach (JsonValue jsonStation in jsonStations)
 		{
-			string stationName = jsonStation ["stationName"];
-			int tasksCount = jsonStation ["tasksCount"];
+			string stationName = jsonStation ["station_name"];
+			int tasksCount = jsonStation ["tasks_count"];
 			stations.Add(new StationCount(stationName, tasksCount));
 		}
 		return stations;
 	}
 
-	public List<EncoderExercise> GetStationExercises(int stationId)
+	//stationType can be GRAVITATORY or INERTIAL
+	public List<EncoderExercise> GetStationExercises(int stationId, Constants.EncoderGI stationType)
 	{
 		List<EncoderExercise> ex_list = new List<EncoderExercise>();
 
 		// Create a request using a URL that can receive a post.
-		if (! createWebRequest(requestType.GENERIC, "/getStationExercises"))
+		if (! createWebRequest(requestType.AUTHENTICATED, "/api/v1/client/getStationExercises"))
 			return ex_list;
 
 		// Set the Method property of the request to POST.
 		request.Method = "POST";
 
-		// Set the ContentType property of the WebRequest.
-		request.ContentType = "application/json; Charset=UTF-8"; //but this is not enough, see this line:
-
 		// Creates the json object
 		JsonObject json = new JsonObject();
-		json.Add("stationId", stationId);
+		json.Add("station_id", stationId);
 
 		// Converts it to a String
 		String js = json.ToString();
@@ -398,12 +388,12 @@ public class JsonCompujump : Json
 		else if(responseFromServer == "[]")
 			LogB.Information(" Empty2 "); //when rfid is not on server
 		else {
-			ex_list = stationExercisesDeserialize(responseFromServer);
+			ex_list = stationExercisesDeserialize(responseFromServer, stationType);
 		}
 
 		return ex_list;
 	}
-	private List<EncoderExercise> stationExercisesDeserialize(string str)
+	private List<EncoderExercise> stationExercisesDeserialize(string str, Constants.EncoderGI stationType)
 	{
 		List<EncoderExercise> ex_list = new List<EncoderExercise>();
 
@@ -413,11 +403,11 @@ public class JsonCompujump : Json
 		{
 			Int32 id = jsonSE ["id"];
 			string name = jsonSE ["name"];
-			Int32 stationId = jsonSE ["stationId"];
-			int percentBodyMassDisplaced = jsonSE ["percentBodyMassDisplaced"];
+			//Int32 stationId = jsonSE ["station_id"];
+			int percentBodyMassDisplaced = jsonSE ["percent_body_mass_displaced"];
 
 			ex_list.Add(new EncoderExercise(id, name, percentBodyMassDisplaced,
-					"", "", 0)); //ressitance, description, speed1RM
+					"", "", 0, stationType)); //resistance, description, speed1RM, stationType
 		}
 		return ex_list;
 	}
@@ -441,7 +431,7 @@ public class JsonCompujump : Json
 
 		// Creates the json object
 		JsonObject json = new JsonObject();
-		json.Add("exerciseId", exerciseId);
+		json.Add("exercise_id", exerciseId);
 
 		// Converts it to a String
 		String js = json.ToString();
@@ -495,8 +485,8 @@ public class JsonCompujump : Json
 
 		Int32 id = jsonEx ["id"];
 		string name = jsonEx ["name"];
-		Int32 stationId = jsonEx ["stationId"];
-		int percentBodyMassDisplaced = jsonEx ["percentBodyMassDisplaced"];
+		Int32 stationId = jsonEx ["station_id"];
+		int percentBodyMassDisplaced = jsonEx ["percent_body_mass_displaced"];
 
 		return new EncoderExercise(id, name, percentBodyMassDisplaced,
 				"", "", 0); //ressitance, description, speed1RM
@@ -507,7 +497,7 @@ public class JsonCompujump : Json
 	{
 		LogB.Information("calling upload sprint");
 		// Create a request using a URL that can receive a post.
-		if (! createWebRequest(requestType.GENERIC, "/uploadSprintData"))
+		if (! createWebRequest(requestType.AUTHENTICATED, "/api/v1/client/uploadSprintData"))
 			return false;
 
 		/*
@@ -519,13 +509,9 @@ public class JsonCompujump : Json
 		// Set the Method property of the request to POST.
 		request.Method = "POST";
 
-		// Set the ContentType property of the WebRequest.
-		request.ContentType = "application/json; Charset=UTF-8"; //but this is not enough, see this line:
-		//exerciseName = Util.RemoveAccents(exerciseName);
-
 		// Creates the json object
 		JsonObject json = new JsonObject();
-		json.Add("personId", o.personId);
+		json.Add("person_id", o.personId);
 		json.Add("distances", o.sprintPositions);
 		json.Add("t1", o.splitTimesL[1]);
 
@@ -600,41 +586,37 @@ public class JsonCompujump : Json
 	public bool UploadEncoderData(UploadEncoderDataFullObject o)
 	{
 		// Create a request using a URL that can receive a post.
-		if (! createWebRequest(requestType.GENERIC, "/uploadEncoderData"))
+		if (! createWebRequest(requestType.AUTHENTICATED, "/api/v1/client/uploadEncoderData"))
 			return false;
 
 		// Set the Method property of the request to POST.
 		request.Method = "POST";
 
-		// Set the ContentType property of the WebRequest.
-		request.ContentType = "application/json; Charset=UTF-8"; //but this is not enough, see this line:
-		//exerciseName = Util.RemoveAccents(exerciseName);
-
 		// Creates the json object
 		JsonObject json = new JsonObject();
-		json.Add("personId", o.personId);
-		json.Add("stationId", o.stationId);
-		//json.Add("exerciseName", exerciseName);
-		json.Add("exerciseId", o.exerciseId);
+		json.Add("person_id", o.personId);
+		json.Add("station_id", o.stationId);
+		//json.Add("exercise_name", Util.RemoveAccents(exerciseName));
+		json.Add("exercise_id", o.exerciseId);
 		json.Add("laterality", o.laterality);
 		json.Add("resistance", o.resistance);
 		json.Add("repetitions", o.uo.repetitions);
 
-		json.Add("numBySpeed", o.uo.numBySpeed);
-		json.Add("lossBySpeed", o.uo.lossBySpeed);
-		json.Add("rangeBySpeed", o.uo.rangeBySpeed);
-		json.Add("vmeanBySpeed", o.uo.vmeanBySpeed);
-		json.Add("vmaxBySpeed", o.uo.vmaxBySpeed);
-		json.Add("pmeanBySpeed", o.uo.pmeanBySpeed);
-		json.Add("pmaxBySpeed", o.uo.pmaxBySpeed);
+		json.Add("num_by_speed", o.uo.numBySpeed);
+		json.Add("loss_by_speed", o.uo.lossBySpeed);
+		json.Add("range_by_speed", o.uo.rangeBySpeed);
+		json.Add("vmean_by_speed", o.uo.vmeanBySpeed);
+		json.Add("vmax_by_speed", o.uo.vmaxBySpeed);
+		json.Add("pmean_by_speed", o.uo.pmeanBySpeed);
+		json.Add("pmax_by_speed", o.uo.pmaxBySpeed);
 
-		json.Add("numByPower", o.uo.numByPower);
-		json.Add("lossByPower", o.uo.lossByPower);
-		json.Add("rangeByPower", o.uo.rangeByPower);
-		json.Add("vmeanByPower", o.uo.vmeanByPower);
-		json.Add("vmaxByPower", o.uo.vmaxByPower);
-		json.Add("pmeanByPower", o.uo.pmeanByPower);
-		json.Add("pmaxByPower", o.uo.pmaxByPower);
+		json.Add("num_by_power", o.uo.numByPower);
+		json.Add("loss_by_power", o.uo.lossByPower);
+		json.Add("range_by_power", o.uo.rangeByPower);
+		json.Add("vmean_by_power", o.uo.vmeanByPower);
+		json.Add("vmax_by_power", o.uo.vmaxByPower);
+		json.Add("pmean_by_power", o.uo.pmeanByPower);
+		json.Add("pmax_by_power", o.uo.pmaxByPower);
 
 		// Converts it to a String
 		String js = json.ToString();
@@ -668,22 +650,18 @@ public class JsonCompujump : Json
 	public bool UploadForceSensorData(UploadForceSensorDataFullObject o)
 	{
 		// Create a request using a URL that can receive a post.
-		if (! createWebRequest(requestType.GENERIC, "/uploadForceSensorData"))
+		if (! createWebRequest(requestType.AUTHENTICATED, "/api/v1/client/uploadForceSensorData"))
 			return false;
 
 		// Set the Method property of the request to POST.
 		request.Method = "POST";
 
-		// Set the ContentType property of the WebRequest.
-		request.ContentType = "application/json; Charset=UTF-8"; //but this is not enough, see this line:
-		//exerciseName = Util.RemoveAccents(exerciseName);
-
 		// Creates the json object
 		JsonObject json = new JsonObject();
-		json.Add("personId", o.personId);
-		json.Add("stationId", o.stationId);
-		//json.Add("exerciseName", exerciseName);
-		json.Add("exerciseId", o.exerciseId);
+		json.Add("person_id", o.personId);
+		json.Add("station_id", o.stationId);
+		//json.Add("exercise_name", Util.RemoveAccents(exerciseName));
+		json.Add("exercise_id", o.exerciseId);
 		json.Add("laterality", o.laterality);
 		json.Add("resistance", o.resistance);
 
