@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2021   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -25,7 +25,7 @@ using System.Collections.Generic; //List<T>
 public class Preferences 
 {
 	/*
-	 * these are sent to preferences window
+	 * these are managed on preferences window
 	 */
 
 	//main tab
@@ -42,6 +42,8 @@ public class Preferences
 	public bool logoAnimatedShow;
 	public enum FontTypes { Courier, Helvetica};
 	public FontTypes fontType;
+	public int restTimeMinutes; //-1 deactivated minutes and seconds
+	public int restTimeSeconds;
 
 	public string GetFontTypeWithSize(int size) {
 		return string.Format("{0} {1}", fontType, size);
@@ -51,7 +53,7 @@ public class Preferences
 	public int lastSessionID;
 	public bool loadLastModeAtStart;
 	public Constants.Menuitem_modes lastMode;
-
+	public SessionLoadDisplay sessionLoadDisplay;
 
 	public enum UnitsEnum { METRIC, IMPERIAL };
 	public UnitsEnum units;
@@ -96,6 +98,8 @@ public class Preferences
 	//encoder other
 	public bool encoderPropulsive;
 	public bool encoderWorkKcal;
+	public enum EncoderInertialGraphsXTypes { EQUIVALENT_MASS, INERTIA_MOMENT, DIAMETER };
+	public EncoderInertialGraphsXTypes encoderInertialGraphsX;
 	public double encoderSmoothCon;
 	public Constants.Encoder1RMMethod encoder1RMMethod;
 
@@ -118,10 +122,15 @@ public class Preferences
 	public double forceSensorElasticConMinDispl;
 	public int forceSensorNotElasticEccMinForce;
 	public int forceSensorNotElasticConMinForce;
+	public enum VariabilityMethodEnum { CHRONOJUMP_OLD, RMSSD, CVRMSSD };
+	public VariabilityMethodEnum forceSensorVariabilityMethod;
+	public double forceSensorAnalyzeABSliderIncrement;
+	public double forceSensorAnalyzeMaxAVGInWindow; //seconds
 	public int forceSensorGraphsLineWidth;
 
 	//runEncoder
 	public double runEncoderMinAccel;
+	public double runEncoderPPS;
 
 	public static string runEncoderAnalyzeAFPSqlNO = "NO";
 	public static string runEncoderAnalyzeAFPSqlFITTED = "FITTED";
@@ -155,10 +164,12 @@ public class Preferences
 	public bool muteLogs;
 	public bool networksAllowChangeDevices; //managed on preferences;
 
-	public enum pythonVersionEnum { Python, Python2, Python3 };
+	public enum pythonVersionEnum { Python2, Python3 };
 	public pythonVersionEnum importerPythonVersion;
 
 	/*
+	 * at DB: 2.06, vales pythonVersionEnum were Python2, Python3, we do not use "Python" anymore
+	 *
 	 * at DB: 1.95, vales pythonVersionEnum were Python, Python2, Python3
 	 * so we need the executable: python, python2, python3
 	 * chronojump_importer.py works on python2 and python3
@@ -174,9 +185,10 @@ public class Preferences
 	}
 
 	/*
-	 * these are NOT sent to preferences window
+	 * these are NOT managed on preferences window
 	 */
-	
+
+	public bool personSelectWinImages;
 	public bool allowFinishRjAfterTime;
 	public bool volumeOn;
 	public bool videoOn;
@@ -186,11 +198,24 @@ public class Preferences
 	public Constants.MultimediaStorage multimediaStorage;
 	public string databaseVersion;
 
+	//news
+	public bool newsLanguageEs; 		// on SQL
+	public string serverNewsDatetime;  	// NOT on SQL
+	public string clientNewsDatetime; 	// on SQL
+
+	//socialNetwork poll
+	public string socialNetwork;
+	public string socialNetworkDatetime; // "": not answered, -1: it should be sent when there's network (after a ping)
+
 	//jumps
 	public bool jumpsFVProfileOnlyBestInWeight;
 	public bool jumpsFVProfileShowFullGraph;
 	public bool jumpsEvolutionOnlyBestInSession;
 
+	//runs
+	public bool runsEvolutionOnlyBestInSession;
+	public bool runsEvolutionShowTime;
+
 	//encoder
 	public Constants.EncoderAutoSaveCurve encoderAutoSaveCurve;
 	public int encoderAutoSaveCurveBestNValue;
@@ -217,6 +242,7 @@ public class Preferences
 	public int encoderCaptureMainVariableLowerValue;
 	public enum EncoderPhasesEnum { BOTH, ECC, CON}
 	public EncoderPhasesEnum encoderCaptureFeedbackEccon;
+	public bool encoderCaptureShowLoss;
 
 	//forceSensor
 	public string forceSensorTareDateTime;
@@ -224,14 +250,26 @@ public class Preferences
 	public string forceSensorCalibrationDateTime;
 	public double forceSensorCalibrationWeight;
 	public double forceSensorCalibrationFactor;
-	public bool forceSensorCaptureFeedbackActive;
-	public int forceSensorCaptureFeedbackAt;
-	public int forceSensorCaptureFeedbackRange;
+	public bool forceSensorStartEndOptimized;
 	public enum ForceSensorMIFDurationModes { SECONDS, PERCENT };
 	public ForceSensorMIFDurationModes forceSensorMIFDurationMode;
 	public double forceSensorMIFDurationSeconds;
 	public int forceSensorMIFDurationPercent;
-				
+
+	//forceSensor feedback
+	public enum ForceSensorCaptureFeedbackActiveEnum { NO, RECTANGLE, PATH };
+	//rectangle
+	public ForceSensorCaptureFeedbackActiveEnum forceSensorCaptureFeedbackActive;
+	public int forceSensorCaptureFeedbackAt;
+	public int forceSensorCaptureFeedbackRange;
+	//path
+	public int forceSensorFeedbackPathMax;
+	public int forceSensorFeedbackPathMin;
+	public int forceSensorFeedbackPathMasters;
+	public int forceSensorFeedbackPathMasterSeconds;
+	public int forceSensorFeedbackPathLineWidth;
+
+
 	public int encoderCaptureTimeIM = 180; //hardcoded 3 minutes.
 
 	public enum GstreamerTypes { GST_0_1, GST_1_0, FFPLAY, SYSTEMSOUNDS };
@@ -242,6 +280,10 @@ public class Preferences
 
 	public bool debugMode;
 
+	//export
+	public int exportGraphWidth;
+	public int exportGraphHeight;
+
 	/*
 	 * these are unused on SqlitePreferences.SelectAll
 	 */
@@ -427,6 +469,18 @@ public class Preferences
 		}
 	}
 
+	//get the decimalChar for R . or ,
+	public char CSVExportDecimalSeparatorChar
+	{
+		get {
+			char c = '.';
+			if(CSVExportDecimalSeparator == "COMMA")
+				c = ',';
+
+			return c;
+		}
+	}
+
 	public bool IsVideoConfigured()
 	{
 		return (videoDevice != "" &&
@@ -471,6 +525,31 @@ public class Preferences
 		get { return UtilGtk.ColorParse(colorBackgroundString); }
 	}
 
+	public enum RunEncoderPlotVariables { RAWACCEL, FITTEDACCEL, RAWFORCE, FITTEDFORCE, RAWPOWER, FITTEDPOWER};
+	public static bool RunEncoderShouldPlotVariable(RunEncoderPlotVariables v)
+	{
+		if(v == RunEncoderPlotVariables.RAWACCEL)
+			return ( runEncoderAnalyzeAccel.SqlCurrentName == runEncoderAnalyzeAFPSqlRAW ||
+					runEncoderAnalyzeAccel.SqlCurrentName == runEncoderAnalyzeAFPSqlBOTH );
+		else if(v == RunEncoderPlotVariables.FITTEDACCEL)
+			return ( runEncoderAnalyzeAccel.SqlCurrentName == runEncoderAnalyzeAFPSqlFITTED ||
+					runEncoderAnalyzeAccel.SqlCurrentName == runEncoderAnalyzeAFPSqlBOTH );
+		else if(v == RunEncoderPlotVariables.RAWFORCE)
+			return ( runEncoderAnalyzeForce.SqlCurrentName ==  runEncoderAnalyzeAFPSqlRAW ||
+					runEncoderAnalyzeForce.SqlCurrentName == runEncoderAnalyzeAFPSqlBOTH );
+		else if(v == RunEncoderPlotVariables.FITTEDFORCE)
+			return ( runEncoderAnalyzeForce.SqlCurrentName == runEncoderAnalyzeAFPSqlFITTED ||
+					runEncoderAnalyzeForce.SqlCurrentName == runEncoderAnalyzeAFPSqlBOTH );
+		else if(v == RunEncoderPlotVariables.RAWPOWER)
+			return ( runEncoderAnalyzePower.SqlCurrentName ==  runEncoderAnalyzeAFPSqlRAW ||
+					runEncoderAnalyzePower.SqlCurrentName == runEncoderAnalyzeAFPSqlBOTH );
+		else if(v == RunEncoderPlotVariables.FITTEDPOWER)
+			return ( runEncoderAnalyzePower.SqlCurrentName == runEncoderAnalyzeAFPSqlFITTED ||
+					runEncoderAnalyzePower.SqlCurrentName == runEncoderAnalyzeAFPSqlBOTH );
+
+		return true;
+	}
+
 	~Preferences() {}
 	   
 }
