@@ -15,11 +15,12 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2021   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
 using System.Data;
+using System.IO; 		//for detect OS //TextWriter
 using System.Collections.Generic; //List
 using System.Threading;
 using Mono.Unix;
@@ -36,6 +37,7 @@ public class Run : Event
 	
 	//protected Chronopic cp;
 	protected bool metersSecondsPreferred;
+	protected string datetime;
 
 /*
 	//used by the updateTimeProgressBar for display its time information
@@ -51,7 +53,7 @@ public class Run : Event
 	}
 
 	//after inserting database (SQL)
-	public Run(int uniqueID, int personID, int sessionID, string type, double distance, double time, string description, int simulated, bool initialSpeed)
+	public Run(int uniqueID, int personID, int sessionID, string type, double distance, double time, string description, int simulated, bool initialSpeed, string datetime)
 	{
 		this.uniqueID = uniqueID;
 		this.personID = personID;
@@ -62,6 +64,7 @@ public class Run : Event
 		this.description = description;
 		this.simulated = simulated;
 		this.initialSpeed = initialSpeed;
+		this.datetime = datetime;
 	}
 
 	//used to select a run at SqliteRun.SelectNormalRunData and at Sqlite.convertTables
@@ -76,6 +79,7 @@ public class Run : Event
 		this.description = eventString[6].ToString();
 		this.simulated = Convert.ToInt32(eventString[7]);
 		this.initialSpeed = Util.IntToBool(Convert.ToInt32(eventString[8]));
+		this.datetime = eventString[9];
 	}
 	
 	public static List<Event> RunListToEventList(List<Run> runs)
@@ -93,9 +97,12 @@ public class Run : Event
 				uniqueID.ToString(), 
 				personID, sessionID, 
 				type, distance, time, 
-				description, simulated, initialSpeed);
+				description, simulated, initialSpeed, datetime);
 	}
 
+	public override string ToString() {
+		return uniqueID + ":" + personID + ":" + sessionID + ":" + type + ":" + distance + ":" + time + ":" + datetime + ":" + description + ":" + simulated + ":" + initialSpeed;
+	}
 	
 	public virtual double Speed
 	{
@@ -129,7 +136,11 @@ public class Run : Event
 		get { return initialSpeed; }
 		set { initialSpeed = value; }
 	}
-	
+
+	public string Datetime {
+		get { return datetime; }
+		set { datetime = value; }
+	}
 
 	
 	~Run() {}
@@ -151,7 +162,7 @@ public class RunInterval : Run
 	}
 	
 	//after inserting database (SQL)
-	public RunInterval(int uniqueID, int personID, int sessionID, string type, double distanceTotal, double timeTotal, double distanceInterval, string intervalTimesString, double tracks, string description, string limited, int simulated, bool initialSpeed)
+	public RunInterval(int uniqueID, int personID, int sessionID, string type, double distanceTotal, double timeTotal, double distanceInterval, string intervalTimesString, double tracks, string description, string limited, int simulated, bool initialSpeed, string datetime)
 	{
 		this.uniqueID = uniqueID;
 		this.personID = personID;
@@ -166,6 +177,7 @@ public class RunInterval : Run
 		this.limited = limited;
 		this.simulated = simulated;
 		this.initialSpeed = initialSpeed;
+		this.datetime = datetime;
 	}
 
 	//used to select a run at SqliteRun.SelectIntervalRunData and at Sqlite.convertTables
@@ -184,6 +196,7 @@ public class RunInterval : Run
 		this.limited = eventString[10].ToString();
 		this.simulated = Convert.ToInt32(eventString[11]);
 		this.initialSpeed = Util.IntToBool(Convert.ToInt32(eventString[12]));
+		this.datetime = eventString[13];
 	}
 	
 
@@ -194,7 +207,57 @@ public class RunInterval : Run
 				type, distanceTotal, timeTotal, 
 				distanceInterval, intervalTimesString,
 				tracks, description, 
-				limited, simulated, initialSpeed);
+				limited, simulated, initialSpeed, datetime);
+	}
+
+	//this discards RSA
+	public static string GetSprintPositions(double distanceInterval, string intervalTimesString, string distancesString)
+	{
+		string positions = "";
+		string [] intervalTimesSplit = intervalTimesString.Split(new char[] {'='});
+		if(! distancesString.Contains("R") ) 	//discard RSA
+		{
+			string sep = "";
+			for(int i=0; i < intervalTimesSplit.Length; i ++)
+			{
+				positions += sep + Util.GetRunITotalDistance(distanceInterval, distancesString, i+1);
+				sep = ";";
+			}
+
+			//format positions
+			positions = Util.ChangeChars(positions, "-", ";");
+		}
+		return positions;
+	}
+
+	public static string GetSplitTimes(string intervalTimesString, int prefsDigitsNumber)
+	{
+		string [] intervalTimesSplit = intervalTimesString.Split(new char[] {'='});
+
+		//manage accumulated time
+		double timeAccumulated = 0;
+		string splitTimes = "";
+		string sep = "";
+		foreach(string time in intervalTimesSplit)
+		{
+			double timeD = Convert.ToDouble(time);
+			timeAccumulated += timeD;
+			splitTimes += sep + Util.TrimDecimals(timeAccumulated, prefsDigitsNumber);
+			sep = ";";
+		}
+
+		return splitTimes;
+	}
+
+	public static string GetCSVInputMulti() {
+		return Path.Combine(Path.GetTempPath(), "sprintInputMulti.csv");
+	}
+
+	public static string GetCSVResultsFileName() {
+		return "sprintResults.csv";
+	}
+	public static string GetCSVResultsURL() {
+		return Path.Combine(Path.GetTempPath(), GetCSVResultsFileName());
 	}
 
 	public string IntervalTimesString
