@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -23,7 +23,7 @@ using System.Data;
 using System.Text; //StringBuilder
 using Mono.Unix;
 
-public partial class Session {
+public class Session {
 
 	protected int uniqueID;
 	
@@ -204,7 +204,7 @@ public partial class Session {
 	   
 }
 
-public partial class ServerSession : Session
+public class ServerSession : Session
 {
 	//server stuff
 	int evaluatorID;
