@@ -291,7 +291,8 @@ class SqlitePersonSession : Sqlite
 					reader[6].ToString(),			//description
 					reader[7].ToString(),			//future1: rfid
 					reader[8].ToString(),			//future2: clubID
-					Convert.ToInt32(reader[9].ToString())	//serverUniqueID
+					Convert.ToInt32(reader[9].ToString()),	//serverUniqueID
+					reader[10].ToString()			//linkServerImage
 					);
 			person_l.Add(person);
 		}
@@ -336,25 +337,25 @@ class SqlitePersonSession : Sqlite
 					reader[6].ToString(),			//description
 					reader[7].ToString(),			//future1: rfid
 					reader[8].ToString(),			//future2: clubID
-					Convert.ToInt32(reader[9].ToString())	//serverUniqueID
+					Convert.ToInt32(reader[9].ToString()),	//serverUniqueID
+					reader[10].ToString()			//linkServerImage
 					);
 
 			if(returnPersonAndPSlist) {
 				PersonSession ps = new PersonSession(
-						Convert.ToInt32(reader[10].ToString()), 	//uniqueID
-						Convert.ToInt32(reader[11].ToString()), 	//personID
-						Convert.ToInt32(reader[12].ToString()), 	//sessionID
-						Convert.ToDouble(Util.ChangeDecimalSeparator(reader[13].ToString())), //height
-						Convert.ToDouble(Util.ChangeDecimalSeparator(reader[14].ToString())), //weight
-						Convert.ToInt32(reader[15].ToString()), 	//sportID
-						Convert.ToInt32(reader[16].ToString()), 	//speciallityID
-						Convert.ToInt32(reader[17].ToString()),	//practice
-						reader[18].ToString(), 			//comments
-						Convert.ToDouble(Util.ChangeDecimalSeparator(reader[19].ToString())), //trochanterToe
-						Convert.ToDouble(Util.ChangeDecimalSeparator(reader[20].ToString())) //trochanterFloorOnFlexion
+						Convert.ToInt32(reader[11].ToString()), 	//uniqueID
+						Convert.ToInt32(reader[12].ToString()), 	//personID
+						Convert.ToInt32(reader[13].ToString()), 	//sessionID
+						Convert.ToDouble(Util.ChangeDecimalSeparator(reader[14].ToString())), //height
+						Convert.ToDouble(Util.ChangeDecimalSeparator(reader[15].ToString())), //weight
+						Convert.ToInt32(reader[16].ToString()), 	//sportID
+						Convert.ToInt32(reader[17].ToString()), 	//speciallityID
+						Convert.ToInt32(reader[18].ToString()),	//practice
+						reader[19].ToString(), 			//comments
+						Convert.ToDouble(Util.ChangeDecimalSeparator(reader[20].ToString())), //trochanterToe
+						Convert.ToDouble(Util.ChangeDecimalSeparator(reader[21].ToString())) //trochanterFloorOnFlexion
 						);
 				myArray.Add(new PersonAndPS(person, ps));
-				
 			} else
 				myArray.Add (person);
 		}
@@ -505,7 +506,7 @@ class SqlitePersonSession : Sqlite
 		}
 
 		// 5) delete forceSensor and related triggers
-		List<ForceSensor> fs_l = SqliteForceSensor.Select (true, -1, -1, Convert.ToInt32(sessionID));
+		List<ForceSensor> fs_l = SqliteForceSensor.Select (true, -1, Convert.ToInt32(personID), Convert.ToInt32(sessionID));
 		foreach(ForceSensor fs in fs_l)
 		{
 			SqliteForceSensor.DeleteSQLAndFiles (true, fs); //deletes also the .csv
@@ -515,8 +516,8 @@ class SqlitePersonSession : Sqlite
 		}
 
 		// 6) delete runEncoder and related triggers
-		ArrayList re_a = SqliteRunEncoder.Select (true, -1, -1, Convert.ToInt32(sessionID));
-		foreach(RunEncoder re in re_a)
+		List<RunEncoder> re_l = SqliteRunEncoder.Select (true, -1, Convert.ToInt32(personID), Convert.ToInt32(sessionID));
+		foreach(RunEncoder re in re_l)
 		{
 			SqliteRunEncoder.DeleteSQLAndFiles (true, re); //deletes also the .csv
 
@@ -600,7 +601,7 @@ class SqlitePersonSessionTransaction : Sqlite
 					foreach(Person p in persons) {
 						dbcmdTr.CommandText = 
 							"INSERT INTO " + Constants.PersonTable +
-							" (uniqueID, name, sex, dateBorn, race, countryID, description, future1, future2, serverUniqueID) " + 
+							" (uniqueID, name, sex, dateBorn, race, countryID, description, future1, future2, serverUniqueID, linkServerImage) " +
 							" VALUES (" + p.ToSQLInsertString() + ")";
 						LogB.SQL(dbcmdTr.CommandText.ToString());
 						dbcmdTr.ExecuteNonQuery();
