@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2021   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -33,12 +33,28 @@ class SqlitePreferences : Sqlite
 	public const string ColorBackgroundOsColor = "colorBackgroundOsColor";
 	public const string LogoAnimatedShow = "logoAnimatedShow";
 	public const string FontsOnGraphs = "fontsOnGraphs";
+	public const string RestTimeMinutes = "restTimeMinutes";
+	public const string RestTimeSeconds = "restTimeSeconds";
+
+	//person (appearance)
+	public const string PersonSelectWinImages = "personSelectWinImages";
+
+	//news stuff
+	public const string NewsLanguageEs = "newsLanguageEs";
+	public const string ServerNewsDatetime = "serverNewsDatetime"; // NOT stored on SQL. string of last news in server, obtained on pingAtNewsAtStart
+	public const string ClientNewsDatetime = "clientNewsDatetime"; // stored on SQL. string of last news local, when user clicks on getNews(), if this is diff than server... news are downloaded and this is updated
+
+	public const string SocialNetwork = "socialNetwork";
+	public const string SocialNetworkDatetime = "socialNetworkDatetime"; //"": not answered, -1: should be sent when there's network (after a ping)
 
 	//contacts
 	public const string JumpsFVProfileOnlyBestInWeight = "jumpsFVProfileOnlyBestInWeight";
 	public const string JumpsFVProfileShowFullGraph = "jumpsFVProfileShowFullGraph";
 	public const string JumpsEvolutionOnlyBestInSession = "jumpsEvolutionOnlyBestInSession";
 
+	public const string RunsEvolutionOnlyBestInSession = "runsEvolutionOnlyBestInSession";
+	public const string RunsEvolutionShowTime = "runsEvolutionShowTime";
+
 	//encoder
 	public const string EncoderCaptureInfinite = "encoderCaptureInfinite";
 	public const string EncoderExerciseIDGravitatory = "encoderExerciseIDGravitatory";
@@ -52,6 +68,7 @@ class SqlitePreferences : Sqlite
 
 	public const string EncoderAutoSaveCurveBestNValue = "encoderAutoSaveCurveBestNValue";
 	public const string EncoderWorkKcal = "encoderWorkKcal";
+	public const string EncoderInertialGraphsX = "encoderInertialGraphsX";
 
 	public const string EncoderRhythmActiveStr = "encoderRhythmActive";
 	public const string EncoderRhythmRepsOrPhasesStr = "encoderRhythmRepsOrPhases";
@@ -69,6 +86,7 @@ class SqlitePreferences : Sqlite
 	public const string EncoderCaptureMainVariableLowerValue = "encoderCaptureMainVariableLowerValue";
 	public const string EncoderCaptureFeedbackEccon = "encoderCaptureFeedbackEccon";
 	public const string EncoderCaptureInertialEccOverloadMode = "encoderCaptureInertialEccOverloadMode";
+	public const string EncoderCaptureShowLoss = "encoderCaptureShowLoss";
 
 	//forceSensor
 	public const string ForceSensorCaptureWidthSeconds = "forceSensorCaptureWidthSeconds";
@@ -78,21 +96,35 @@ class SqlitePreferences : Sqlite
 	public const string ForceSensorNotElasticEccMinForce = "forceSensorNotElasticEccMinForce";
 	public const string ForceSensorNotElasticConMinForce = "forceSensorNotElasticConMinForce";
 	public const string ForceSensorGraphsLineWidth = "forceSensorGraphsLineWidth";
+	public const string ForceSensorVariabilityMethod = "forceSensorVariabilityMethod";
 
 	public const string ForceSensorTareDateTimeStr = "forceSensorTareDateTime";
 	public const string ForceSensorTareStr = "forceSensorTare";
 	public const string ForceSensorCalibrationDateTimeStr = "forceSensorCalibrationDateTime";
 	public const string ForceSensorCalibrationWeightStr = "forceSensorCalibrationWeight";
 	public const string ForceSensorCalibrationFactorStr = "forceSensorCalibrationFactor";
-	public const string ForceSensorCaptureFeedbackActive = "forceSensorCaptureFeedbackActive";
-	public const string ForceSensorCaptureFeedbackAt = "forceSensorCaptureFeedbackAt";
-	public const string ForceSensorCaptureFeedbackRange = "forceSensorCaptureFeedbackRange";
+	public const string ForceSensorStartEndOptimized = "forceSensorStartEndOptimized";
 	public const string ForceSensorMIFDurationMode = "forceSensorMIFDurationMode";
 	public const string ForceSensorMIFDurationSeconds = "forceSensorMIFDurationSeconds";
 	public const string ForceSensorMIFDurationPercent = "forceSensorMIFDurationPercent";
+	public const string ForceSensorAnalyzeABSliderIncrement = "forceSensorAnalyzeABSliderIncrement";
+	public const string ForceSensorAnalyzeMaxAVGInWindow = "forceSensorAnalyzeMaxAVGInWindow";
+
+	//forceSensor feedback
+	public const string ForceSensorCaptureFeedbackActive = "forceSensorCaptureFeedbackActive";
+	//rectangle
+	public const string ForceSensorCaptureFeedbackAt = "forceSensorCaptureFeedbackAt";
+	public const string ForceSensorCaptureFeedbackRange = "forceSensorCaptureFeedbackRange";
+	//path
+	public const string ForceSensorFeedbackPathMax = "forceSensorFeedbackPathMax";
+	public const string ForceSensorFeedbackPathMin = "forceSensorFeedbackPathMin";
+	public const string ForceSensorFeedbackPathMasters = "forceSensorFeedbackPathMasters";
+	public const string ForceSensorFeedbackPathMasterSeconds = "forceSensorFeedbackPathMasterSeconds";
+	public const string ForceSensorFeedbackPathLineWidth = "forceSensorFeedbackPathLineWidth";
 
 	//runEncoder
 	public const string RunEncoderMinAccel = "runEncoderMinAccel";
+	public const string RunEncoderPPS = "runEncoderPPS";
 
 	//advanced
 	public const string ImporterPythonVersion = "importerPythonVersion";
@@ -102,6 +134,11 @@ class SqlitePreferences : Sqlite
 	public const string LastSessionID = "lastSessionID";
 	public const string LoadLastModeAtStart = "loadLastModeAtStart";
 	public const string LastMode = "lastMode";
+	public const string SessionLoadDisplay = "sessionLoadDisplay";
+
+	//export
+	public const string ExportGraphWidth = "exportGraphWidth";
+	public const string ExportGraphHeight = "exportGraphHeight";
 
 	protected internal static new void createTable()
 	{
@@ -131,11 +168,21 @@ class SqlitePreferences : Sqlite
 				Insert ("maximized", Preferences.MaximizedTypes.NO.ToString(), dbcmdTr);
 				Insert ("personWinHide", "False", dbcmdTr);
 				Insert ("personPhoto", "True", dbcmdTr);
+				Insert (PersonSelectWinImages, "True", dbcmdTr);
 				Insert (MenuType, Preferences.MenuTypes.ALL.ToString(), dbcmdTr);
-				Insert (LogoAnimatedShow, "True", dbcmdTr);
+
+				UtilAll.OperatingSystems os = UtilAll.GetOSEnum();
+
+				if(os == UtilAll.OperatingSystems.MACOSX)
+					Insert (LogoAnimatedShow, "False", dbcmdTr); //false until fixed Big Sur problems
+				else
+					Insert (LogoAnimatedShow, "True", dbcmdTr);
+
 				Insert (ColorBackground, "#0e1e46", dbcmdTr);
 				Insert (ColorBackgroundOsColor, "False", dbcmdTr);
 				Insert (FontsOnGraphs, Preferences.FontTypes.Helvetica.ToString(), dbcmdTr);
+				Insert (RestTimeMinutes, "2", dbcmdTr);
+				Insert (RestTimeSeconds, "0", dbcmdTr);
 				Insert (UnitsStr, Preferences.UnitsEnum.METRIC.ToString(), dbcmdTr);
 				Insert (EncoderCaptureInfinite, "False", dbcmdTr);
 				Insert ("encoderCaptureShowOnlyBars", "True", dbcmdTr);
@@ -157,7 +204,6 @@ class SqlitePreferences : Sqlite
 				Insert ("allowFinishRjAfterTime", "True", dbcmdTr); 
 				Insert ("volumeOn", "True", dbcmdTr);
 
-				UtilAll.OperatingSystems os = UtilAll.GetOSEnum();
 				if(os == UtilAll.OperatingSystems.WINDOWS)
 					Insert (Preferences.GstreamerStr, Preferences.GstreamerTypes.SYSTEMSOUNDS.ToString());
 				else if(os == UtilAll.OperatingSystems.MACOSX)
@@ -192,6 +238,10 @@ class SqlitePreferences : Sqlite
 				SqlitePreferences.Insert (JumpsFVProfileShowFullGraph, "True", dbcmdTr);
 				SqlitePreferences.Insert (JumpsEvolutionOnlyBestInSession, "False", dbcmdTr);
 
+				//runs
+				SqlitePreferences.Insert (RunsEvolutionOnlyBestInSession, "False", dbcmdTr);
+				SqlitePreferences.Insert (RunsEvolutionShowTime, "False", dbcmdTr);
+
 				//encoder
 				Insert ("encoderCaptureTime", "60", dbcmdTr);
 				Insert ("encoderCaptureInactivityEndTime", "3", dbcmdTr);
@@ -205,6 +255,7 @@ class SqlitePreferences : Sqlite
 				Insert (EncoderCaptureMainVariableGreaterValue, "90", dbcmdTr);
 				Insert (EncoderCaptureMainVariableLowerActive, "False", dbcmdTr);
 				Insert (EncoderCaptureMainVariableLowerValue, "70", dbcmdTr);
+				Insert (EncoderCaptureShowLoss, "True", dbcmdTr);
 				Insert ("encoderCaptureMinHeightGravitatory", "20", dbcmdTr);
 				Insert ("encoderCaptureMinHeightInertial", "5", dbcmdTr);
 				Insert ("encoderCaptureInertialDiscardFirstN", "3", dbcmdTr);
@@ -215,13 +266,13 @@ class SqlitePreferences : Sqlite
 				Insert ("encoderCaptureCutByTriggers", Preferences.TriggerTypes.NO_TRIGGERS.ToString(), dbcmdTr);
 				Insert ("encoderPropulsive", "True", dbcmdTr);
 				Insert (EncoderWorkKcal, "True", dbcmdTr);
-				Insert ("encoderWorkKcal", "True", dbcmdTr);
+				Insert (EncoderInertialGraphsX, Preferences.EncoderInertialGraphsXTypes.EQUIVALENT_MASS.ToString(), dbcmdTr);
 				Insert ("encoderSmoothEccCon", "0.6", dbcmdTr);
 				Insert ("encoderSmoothCon", "0.7", dbcmdTr);
 				Insert ("encoder1RMMethod", Constants.Encoder1RMMethod.WEIGHTED2.ToString(), dbcmdTr);
 
 				ArrayList encoderExercises =
-					SqliteEncoder.SelectEncoderExercises(true, -1, true);
+					SqliteEncoder.SelectEncoderExercises(true, -1, true, Constants.EncoderGI.ALL);
 
 				if(encoderExercises.Count > 0) {
 					EncoderExercise ex = (EncoderExercise) encoderExercises[0];
@@ -260,20 +311,31 @@ class SqlitePreferences : Sqlite
 				Insert (ForceSensorNotElasticEccMinForce, "100", dbcmdTr);
 				Insert (ForceSensorNotElasticConMinForce, "100", dbcmdTr);
 				Insert (ForceSensorGraphsLineWidth, "2", dbcmdTr);
-				Insert (ForceSensorCaptureFeedbackActive, "False", dbcmdTr);
+				Insert (ForceSensorVariabilityMethod, Preferences.VariabilityMethodEnum.CVRMSSD.ToString(), dbcmdTr);
+				Insert (ForceSensorCaptureFeedbackActive, Preferences.ForceSensorCaptureFeedbackActiveEnum.NO.ToString(), dbcmdTr);
 				Insert (ForceSensorCaptureFeedbackAt, "100", dbcmdTr);
 				Insert (ForceSensorCaptureFeedbackRange, "40", dbcmdTr);
+				Insert (ForceSensorFeedbackPathMax, "100", dbcmdTr);
+				Insert (ForceSensorFeedbackPathMin, "0", dbcmdTr);
+				Insert (ForceSensorFeedbackPathMasters, "8", dbcmdTr);
+				Insert (ForceSensorFeedbackPathMasterSeconds, "2", dbcmdTr);
+				Insert (ForceSensorFeedbackPathLineWidth, "33", dbcmdTr);
+
 				Insert (ForceSensorTareDateTimeStr, "", dbcmdTr);
 				Insert (ForceSensorTareStr, "-1", dbcmdTr); //result value from sensor. Decimal is point!!
 				Insert (ForceSensorCalibrationDateTimeStr, "", dbcmdTr);
 				Insert (ForceSensorCalibrationWeightStr, "-1", dbcmdTr);
 				Insert (ForceSensorCalibrationFactorStr, "-1", dbcmdTr); //result value from sensor. Decimal is point!!
+				Insert (ForceSensorStartEndOptimized, "True", dbcmdTr);
 				Insert (ForceSensorMIFDurationMode, Preferences.ForceSensorMIFDurationModes.SECONDS.ToString(), dbcmdTr);
 				Insert (ForceSensorMIFDurationSeconds, "2", dbcmdTr);
 				Insert (ForceSensorMIFDurationPercent, "5", dbcmdTr);
+				Insert (ForceSensorAnalyzeABSliderIncrement, "1", dbcmdTr);
+				Insert (ForceSensorAnalyzeMaxAVGInWindow, "1", dbcmdTr);
 
 				//runEncoder
 				Insert (RunEncoderMinAccel, "10.0", dbcmdTr);
+				Insert (RunEncoderPPS, "10", dbcmdTr);
 
 				Insert (Preferences.runEncoderAnalyzeAccel.Name,
 					Preferences.runEncoderAnalyzeAccel.SqlDefaultName, dbcmdTr);
@@ -298,13 +360,26 @@ class SqlitePreferences : Sqlite
 				Insert (EncoderAutoSaveCurveBestNValue, "3", dbcmdTr);
 				Insert ("email", "", dbcmdTr);
 				Insert ("muteLogs", "False", dbcmdTr);
-				Insert (ImporterPythonVersion, Preferences.pythonVersionEnum.Python.ToString(), dbcmdTr);
+				Insert (ImporterPythonVersion, Preferences.pythonVersionEnum.Python3.ToString(), dbcmdTr);
+
+				//news
+				Insert (NewsLanguageEs, "False", dbcmdTr);
+				Insert (ClientNewsDatetime, "", dbcmdTr);
+
+				//socialNetwork
+				Insert (SocialNetwork, "", dbcmdTr);
+				Insert (SocialNetworkDatetime, "", dbcmdTr);
 
 				//session
 				Insert (LoadLastSessionAtStart, "True", dbcmdTr);
 				Insert (LastSessionID, "-1", dbcmdTr);
 				Insert (LoadLastModeAtStart, "True", dbcmdTr);
 				Insert (LastMode, Constants.Menuitem_modes.UNDEFINED.ToString(), dbcmdTr);
+				Insert (SessionLoadDisplay, "0", dbcmdTr);
+
+				//export
+				Insert (ExportGraphWidth, "900", dbcmdTr);
+				Insert (ExportGraphHeight, "600", dbcmdTr);
 
 				//removed on 1.37
 				//Insert ("encoderConfiguration", new EncoderConfiguration().ToStringOutput(EncoderConfiguration.Outputs.SQL), dbcmdTr);
@@ -409,6 +484,8 @@ class SqlitePreferences : Sqlite
 				preferences.personWinHide = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "personPhoto")
 				preferences.personPhoto = reader[1].ToString() == "True";
+			else if(reader[0].ToString() == PersonSelectWinImages)
+				preferences.personSelectWinImages = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == MenuType)
 				preferences.menuType = (Preferences.MenuTypes)
 					Enum.Parse(typeof(Preferences.MenuTypes), reader[1].ToString());
@@ -424,6 +501,28 @@ class SqlitePreferences : Sqlite
 			else if(reader[0].ToString() == FontsOnGraphs)
 				preferences.fontType = (Preferences.FontTypes)
 					Enum.Parse(typeof(Preferences.FontTypes), reader[1].ToString());
+			else if(reader[0].ToString() == RestTimeMinutes)
+			{
+				if(Util.IsNumber(reader[1].ToString(), false))
+					preferences.restTimeMinutes = Convert.ToInt32(reader[1].ToString());
+				else
+					preferences.restTimeMinutes = 0;
+			}
+			else if(reader[0].ToString() == RestTimeSeconds)
+			{
+				if(Util.IsNumber(reader[1].ToString(), false))
+					preferences.restTimeSeconds = Convert.ToInt32(reader[1].ToString());
+				else
+					preferences.restTimeSeconds = 0;
+			}
+			else if(reader[0].ToString() == NewsLanguageEs )
+				preferences.newsLanguageEs = reader[1].ToString() == "True"; //bool
+			else if(reader[0].ToString() == ClientNewsDatetime )
+				preferences.clientNewsDatetime = reader[1].ToString();
+			else if(reader[0].ToString() == SocialNetwork )
+				preferences.socialNetwork = reader[1].ToString();
+			else if(reader[0].ToString() == SocialNetworkDatetime )
+				preferences.socialNetworkDatetime = reader[1].ToString();
 			else if(reader[0].ToString() == UnitsStr)
 				preferences.units = (Preferences.UnitsEnum)
 					Enum.Parse(typeof(Preferences.UnitsEnum), reader[1].ToString());
@@ -458,6 +557,10 @@ class SqlitePreferences : Sqlite
 				preferences.jumpsFVProfileShowFullGraph = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == JumpsEvolutionOnlyBestInSession)
 				preferences.jumpsEvolutionOnlyBestInSession = reader[1].ToString() == "True";
+			else if(reader[0].ToString() == RunsEvolutionOnlyBestInSession)
+				preferences.runsEvolutionOnlyBestInSession = reader[1].ToString() == "True";
+			else if(reader[0].ToString() == RunsEvolutionShowTime)
+				preferences.runsEvolutionShowTime = reader[1].ToString() == "True";
 			//encoder capture
 			else if(reader[0].ToString() == "encoderCaptureTime")
 				preferences.encoderCaptureTime = Convert.ToInt32(reader[1].ToString());
@@ -487,6 +590,8 @@ class SqlitePreferences : Sqlite
 				preferences.encoderCaptureMainVariableLowerActive = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == EncoderCaptureMainVariableLowerValue)
 				preferences.encoderCaptureMainVariableLowerValue = Convert.ToInt32(reader[1].ToString());
+			else if(reader[0].ToString() == EncoderCaptureShowLoss)
+				preferences.encoderCaptureShowLoss = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "encoderCaptureMinHeightGravitatory")
 				preferences.encoderCaptureMinHeightGravitatory = Convert.ToInt32(reader[1].ToString());
 			else if(reader[0].ToString() == "encoderCaptureMinHeightInertial")
@@ -514,6 +619,9 @@ class SqlitePreferences : Sqlite
 				preferences.encoderPropulsive = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == EncoderWorkKcal)
 				preferences.encoderWorkKcal = reader[1].ToString() == "True";
+			else if(reader[0].ToString() == EncoderInertialGraphsX)
+				preferences.encoderInertialGraphsX = (Preferences.EncoderInertialGraphsXTypes)
+					Enum.Parse(typeof(Preferences.EncoderInertialGraphsXTypes), reader[1].ToString());
 			else if(reader[0].ToString() == "encoderSmoothCon")
 				preferences.encoderSmoothCon = Convert.ToDouble(
 						Util.ChangeDecimalSeparator(reader[1].ToString()));
@@ -624,12 +732,35 @@ class SqlitePreferences : Sqlite
 				preferences.forceSensorNotElasticConMinForce = Convert.ToInt32(reader[1].ToString());
 			else if(reader[0].ToString() == ForceSensorGraphsLineWidth)
 				preferences.forceSensorGraphsLineWidth = Convert.ToInt32(reader[1].ToString());
+			else if(reader[0].ToString() == ForceSensorVariabilityMethod)
+				preferences.forceSensorVariabilityMethod = (Preferences.VariabilityMethodEnum)
+					Enum.Parse(typeof(Preferences.VariabilityMethodEnum), reader[1].ToString());
 			else if(reader[0].ToString() == ForceSensorCaptureFeedbackActive)
-				preferences.forceSensorCaptureFeedbackActive = reader[1].ToString() == "True";
+			{
+				//preferences.forceSensorCaptureFeedbackActive = reader[1].ToString() == "True";
+				//note first it was a boolean "False" or "True"
+				if(reader[1].ToString() == "False")
+					preferences.forceSensorCaptureFeedbackActive = Preferences.ForceSensorCaptureFeedbackActiveEnum.NO;
+				else if(reader[1].ToString() == "True")
+					preferences.forceSensorCaptureFeedbackActive = Preferences.ForceSensorCaptureFeedbackActiveEnum.RECTANGLE;
+				else
+					preferences.forceSensorCaptureFeedbackActive = (Preferences.ForceSensorCaptureFeedbackActiveEnum)
+						Enum.Parse(typeof(Preferences.ForceSensorCaptureFeedbackActiveEnum), reader[1].ToString());
+			}
 			else if(reader[0].ToString() == ForceSensorCaptureFeedbackAt)
 				preferences.forceSensorCaptureFeedbackAt = Convert.ToInt32(reader[1].ToString());
 			else if(reader[0].ToString() == ForceSensorCaptureFeedbackRange)
 				preferences.forceSensorCaptureFeedbackRange = Convert.ToInt32(reader[1].ToString());
+			else if(reader[0].ToString() == ForceSensorFeedbackPathMax)
+				preferences.forceSensorFeedbackPathMax = Convert.ToInt32(reader[1].ToString());
+			else if(reader[0].ToString() == ForceSensorFeedbackPathMin)
+				preferences.forceSensorFeedbackPathMin = Convert.ToInt32(reader[1].ToString());
+			else if(reader[0].ToString() == ForceSensorFeedbackPathMasters)
+				preferences.forceSensorFeedbackPathMasters = Convert.ToInt32(reader[1].ToString());
+			else if(reader[0].ToString() == ForceSensorFeedbackPathMasterSeconds)
+				preferences.forceSensorFeedbackPathMasterSeconds = Convert.ToInt32(reader[1].ToString());
+			else if(reader[0].ToString() == ForceSensorFeedbackPathLineWidth)
+				preferences.forceSensorFeedbackPathLineWidth = Convert.ToInt32(reader[1].ToString());
 
 			//force sensor tare
 			else if(reader[0].ToString() == ForceSensorTareDateTimeStr)
@@ -647,8 +778,9 @@ class SqlitePreferences : Sqlite
 			else if(reader[0].ToString() == ForceSensorCalibrationFactorStr)
 				preferences.forceSensorCalibrationFactor = Convert.ToDouble(
 						Util.ChangeDecimalSeparator(reader[1].ToString()));
-
 			//force sensor MIF
+			else if(reader[0].ToString() == ForceSensorStartEndOptimized)
+				preferences.forceSensorStartEndOptimized = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == ForceSensorMIFDurationMode)
 				preferences.forceSensorMIFDurationMode = (Preferences.ForceSensorMIFDurationModes)
 					Enum.Parse(typeof(Preferences.ForceSensorMIFDurationModes), reader[1].ToString());
@@ -659,10 +791,20 @@ class SqlitePreferences : Sqlite
 				preferences.forceSensorMIFDurationPercent = Convert.ToInt32(
 						reader[1].ToString());
 
+			else if(reader[0].ToString() == ForceSensorAnalyzeABSliderIncrement)
+				preferences.forceSensorAnalyzeABSliderIncrement = Convert.ToDouble(
+						Util.ChangeDecimalSeparator(reader[1].ToString()));
+
+			else if(reader[0].ToString() == ForceSensorAnalyzeMaxAVGInWindow)
+				preferences.forceSensorAnalyzeMaxAVGInWindow = Convert.ToDouble(
+						Util.ChangeDecimalSeparator(reader[1].ToString()));
+
 			//runEncoder
 			else if(reader[0].ToString() == RunEncoderMinAccel)
 				preferences.runEncoderMinAccel = Convert.ToDouble(
 						Util.ChangeDecimalSeparator(reader[1].ToString()));
+			else if(reader[0].ToString() == RunEncoderPPS)
+				preferences.runEncoderPPS = Convert.ToInt32(reader[1].ToString());
 
 			else if(reader[0].ToString() == Preferences.runEncoderAnalyzeAccel.Name)
 				Preferences.runEncoderAnalyzeAccel.SetCurrentFromSQL(reader[1].ToString());
@@ -704,6 +846,14 @@ class SqlitePreferences : Sqlite
 			else if(reader[0].ToString() == LastMode)
 				preferences.lastMode = (Constants.Menuitem_modes)
 					Enum.Parse(typeof(Constants.Menuitem_modes), reader[1].ToString());
+			else if(reader[0].ToString() == SessionLoadDisplay)
+				preferences.sessionLoadDisplay = new SessionLoadDisplay(Convert.ToInt32(reader[1].ToString()));
+
+			//export
+			else if(reader[0].ToString() == ExportGraphWidth)
+				preferences.exportGraphWidth = Convert.ToInt32(reader[1].ToString());
+			else if(reader[0].ToString() == ExportGraphHeight)
+				preferences.exportGraphHeight = Convert.ToInt32(reader[1].ToString());
 		}
 
 		reader.Close();
