@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2021   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -49,7 +49,8 @@ class SqliteRun : Sqlite
 			"time FLOAT, " +
 			"description TEXT, " +
 			"simulated INT, " +
-			"initialSpeed INT )";
+			"initialSpeed INT, " +
+			"datetime TEXT )";
 		dbcmd.ExecuteNonQuery();
 	}
 	
@@ -58,7 +59,7 @@ class SqliteRun : Sqlite
 	 * Run class methods
 	 */
 	
-	public static int Insert(bool dbconOpened, string tableName, string uniqueID, int personID, int sessionID, string type, double distance, double time, string description, int simulated, bool initialSpeed)
+	public static int Insert(bool dbconOpened, string tableName, string uniqueID, int personID, int sessionID, string type, double distance, double time, string description, int simulated, bool initialSpeed, string datetime)
 	{
 		if(! dbconOpened)
 			Sqlite.Open();
@@ -67,11 +68,11 @@ class SqliteRun : Sqlite
 			uniqueID = "NULL";
 
 		dbcmd.CommandText = "INSERT INTO " + tableName + 
-				" (uniqueID, personID, sessionID, type, distance, time, description, simulated, initialSpeed)" +
+				" (uniqueID, personID, sessionID, type, distance, time, description, simulated, initialSpeed, datetime)" +
 				" VALUES (" + uniqueID + ", " +
 				+ personID + ", " + sessionID + ", \"" + type + "\", "
 				+ Util.ConvertToPoint(distance) + ", " + Util.ConvertToPoint(time) + ", \"" + 
-				description + "\", " + simulated + ", " + Util.BoolToInt(initialSpeed) + ")" ;
+				description + "\", " + simulated + ", " + Util.BoolToInt(initialSpeed) + ", \"" + datetime + "\")";
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 
@@ -89,7 +90,7 @@ class SqliteRun : Sqlite
 
 	//note this is selecting also the person.name
 	private static string selectRunsCreateSelection (int sessionID, int personID, string filterType,
-			Orders_by order, int limit) 
+			Orders_by order, int limit, bool onlyBestInSession)
 	{
 		string tp = Constants.PersonTable;
 
@@ -108,6 +109,8 @@ class SqliteRun : Sqlite
 		string orderByString = " ORDER BY upper(" + tp + ".name), run.uniqueID ";
 		if(order == Orders_by.ID_DESC)
 			orderByString = " ORDER BY run.uniqueID DESC ";
+		if(onlyBestInSession)
+			orderByString = " ORDER BY run.sessionID, run.distance/run.time DESC ";
 
 		string limitString = "";
 		if(limit != -1)
@@ -135,7 +138,7 @@ class SqliteRun : Sqlite
 		if(!dbconOpened)
 			Sqlite.Open();
 
-		dbcmd.CommandText = selectRunsCreateSelection (sessionID, personID, filterType, order, limit);
+		dbcmd.CommandText = selectRunsCreateSelection (sessionID, personID, filterType, order, limit, false);
 		
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
@@ -148,7 +151,8 @@ class SqliteRun : Sqlite
 		int count = new int();
 		count = 0;
 
-		while(reader.Read()) {
+		while(reader.Read())
+		{
 			myArray.Add (reader[0].ToString() + ":" +	//person.name
 					reader[1].ToString() + ":" +	//run.uniqueID
 					reader[2].ToString() + ":" + 	//run.personID
@@ -158,7 +162,8 @@ class SqliteRun : Sqlite
 					Util.ChangeDecimalSeparator(reader[6].ToString()) + ":" + //run.time
 					reader[7].ToString() + ":" + 	//description
 					reader[8].ToString() + ":" +	//simulated
-					Util.IntToBool(Convert.ToInt32(reader[9])) //initialSpeed
+					Util.IntToBool(Convert.ToInt32(reader[9])) + ":" + //initialSpeed
+					reader[10].ToString() 		//datetime
 					);
 			count ++;
 		}
@@ -188,12 +193,24 @@ class SqliteRun : Sqlite
          */
 
 	public static List<Run> SelectRuns (bool dbconOpened, int sessionID, int personID, string runType,
-			Orders_by order, int limit, bool personNameInComment)
+			Orders_by order, int limit, bool personNameInComment, bool onlyBestInSession)
 	{
-		dbcmd.CommandText = selectRunsCreateSelection (sessionID, personID, runType, order, limit);
+		//need to close DB for SqliteSession.SelectAll
+		if(dbconOpened)
+		{
+			Sqlite.Close();
+//			dbconOpened = false;
+		}
+
+		//runs previous to DB 2.13 have no datetime on run
+		//find session datetime for that runs
+		List<Session> session_l = SqliteSession.SelectAll(Sqlite.Orders_by.DEFAULT);
+
+
+		dbcmd.CommandText = selectRunsCreateSelection (sessionID, personID, runType, order, limit, onlyBestInSession);
 		LogB.SQL(dbcmd.CommandText.ToString());
 
-		if(! dbconOpened)
+//		if(! dbconOpened)
 			Sqlite.Open();
 
 		dbcmd.ExecuteNonQuery();
@@ -213,9 +230,31 @@ class SqliteRun : Sqlite
 					Convert.ToDouble(Util.ChangeDecimalSeparator(reader[6].ToString())), //run.time
 					reader[7].ToString(), 	//description
 					Convert.ToInt32(reader[8].ToString()),	//simulated
-					Util.IntToBool(Convert.ToInt32(reader[9])) //initialSpeed
+					Util.IntToBool(Convert.ToInt32(reader[9])), //initialSpeed
+					reader[10].ToString() 	//datetime
 					);
 
+			//runs previous to DB 2.13 have no datetime on run
+			//find session datetime for that runs
+			if(run.Datetime == "")
+			{
+				bool found = false;
+				foreach(Session session in session_l)
+				{
+					if(session.UniqueID == run.SessionID)
+					{
+						run.Datetime = UtilDate.ToFile(session.Date);
+						found = true;
+						break;
+					}
+
+				}
+				//on really old versions of Chronojump, deleting a session maybe does not delete the runs
+				//so could be able to found a run without a session, so assign here the MinValue possible of DateTime
+				if(! found)
+					run.Datetime = UtilDate.ToFile(DateTime.MinValue);
+			}
+
 			if(personNameInComment)
 				run.Description = reader[0].ToString();
 
@@ -245,7 +284,7 @@ class SqliteRun : Sqlite
 		reader = dbcmd.ExecuteReader();
 		reader.Read();
 	
-		Run myRun = new Run(DataReaderToStringArray(reader, 9));
+		Run myRun = new Run(DataReaderToStringArray(reader, 10));
 	
 		reader.Close();
 		if(!dbconOpened)
