@@ -22,6 +22,7 @@ using System;
 using System.Data;
 using System.IO;
 using System.Collections; //ArrayList
+using System.Collections.Generic; //List
 using Mono.Data.Sqlite;
 
 
@@ -50,11 +51,12 @@ class SqliteRunInterval : SqliteRun
 			"description TEXT, " +
 			"limited TEXT, " +
 			"simulated INT, " +
-			"initialSpeed INT)";
+			"initialSpeed INT, " +
+			"datetime TEXT )";
 		dbcmd.ExecuteNonQuery();
 	}
 
-	public static int Insert(bool dbconOpened, string tableName, string uniqueID, int personID, int sessionID, string type, double distanceTotal, double timeTotal, double distanceInterval, string intervalTimesString, double tracks, string description, string limited, int simulated, bool initialSpeed )
+	public static int Insert(bool dbconOpened, string tableName, string uniqueID, int personID, int sessionID, string type, double distanceTotal, double timeTotal, double distanceInterval, string intervalTimesString, double tracks, string description, string limited, int simulated, bool initialSpeed, string datetime)
 	{
 		if(! dbconOpened)
 			Sqlite.Open();
@@ -63,7 +65,7 @@ class SqliteRunInterval : SqliteRun
 			uniqueID = "NULL";
 
 		dbcmd.CommandText = "INSERT INTO "+ tableName + 
-				" (uniqueID, personID, sessionID, type, distanceTotal, timeTotal, distanceInterval, intervalTimesString, tracks, description, limited, simulated, initialSpeed)" +
+				" (uniqueID, personID, sessionID, type, distanceTotal, timeTotal, distanceInterval, intervalTimesString, tracks, description, limited, simulated, initialSpeed, datetime)" +
 				"VALUES (" + uniqueID + ", " +
 				personID + ", " + sessionID + ", \"" + type + "\", " +
 				Util.ConvertToPoint(distanceTotal) + ", " + 
@@ -72,7 +74,8 @@ class SqliteRunInterval : SqliteRun
 				Util.ConvertToPoint(intervalTimesString) + "\", " +
 				Util.ConvertToPoint(tracks) + ", \"" + 
 				description + "\", \"" + limited + "\", " + simulated + ", " +
-				Util.BoolToInt(initialSpeed) + ")" ;
+				Util.BoolToInt(initialSpeed) + ", \"" +
+				datetime + "\")";
 				
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
@@ -89,11 +92,8 @@ class SqliteRunInterval : SqliteRun
 		return myLast;
 	}
 
-	public static string[] SelectRuns(bool dbconOpened, int sessionID, int personID, string filterType) 
+	private static string selectRunsIntervalCreateSelection (int sessionID, int personID, string filterType)
 	{
-		if(!dbconOpened)
-			Sqlite.Open();
-
 		string tp = Constants.PersonTable;
 
 		string filterSessionString = "";
@@ -108,13 +108,64 @@ class SqliteRunInterval : SqliteRun
 		if(filterType != "")
 			filterTypeString = " AND runInterval.type == \"" + filterType + "\" " ;
 
-		dbcmd.CommandText = "SELECT " + tp + ".name, runInterval.* " +
+		return "SELECT " + tp + ".name, runInterval.* " +
 			" FROM " + tp + ", runInterval " +
-			" WHERE " + tp + ".uniqueID == runInterval.personID" + 
+			" WHERE " + tp + ".uniqueID == runInterval.personID" +
 			filterSessionString +
 			filterPersonString +
 			filterTypeString +
 			" ORDER BY upper(" + tp + ".name), runInterval.uniqueID";
+	}
+
+        //like SelectRunsSA below method but much better: return list of RunInterval
+	public static List<RunInterval> SelectRuns (bool dbconOpened, int sessionID, int personID, string filterType)
+	{
+		if(!dbconOpened)
+			Sqlite.Open();
+
+		dbcmd.CommandText = selectRunsIntervalCreateSelection (sessionID, personID, filterType);
+
+		LogB.SQL(dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery();
+
+		SqliteDataReader reader;
+		reader = dbcmd.ExecuteReader();
+
+		List<RunInterval> ri_l = new List<RunInterval>();
+
+		while(reader.Read())
+			ri_l.Add(new RunInterval(
+					Convert.ToInt32(reader[1].ToString()),	//runInterval.uniqueID
+					Convert.ToInt32(reader[2].ToString()), 	//runInterval.personID
+					Convert.ToInt32(reader[3].ToString()), 	//runInterval.sessionID
+					reader[4].ToString(), 	//runInterval.type
+					Convert.ToDouble(Util.ChangeDecimalSeparator(reader[5].ToString())), //distanceTotal
+					Convert.ToDouble(Util.ChangeDecimalSeparator(reader[6].ToString())), //timeTotal
+					Convert.ToDouble(Util.ChangeDecimalSeparator(reader[7].ToString())), //distanceInterval
+					Util.ChangeDecimalSeparator(reader[8].ToString()), //intervalTimesString
+					Convert.ToDouble(Util.ChangeDecimalSeparator(reader[9].ToString())), //tracks
+					reader[10].ToString(), 	//description
+					reader[11].ToString(), 	//limited
+					Convert.ToInt32(reader[12].ToString()),	//simulated
+					Util.IntToBool(Convert.ToInt32(reader[13])), //initialSpeed
+					reader[14].ToString() 		//datetime
+					));
+
+		reader.Close();
+
+		if(!dbconOpened)
+			Sqlite.Close();
+
+		return ri_l;
+	}
+
+	//method that retruns an string array
+	public static string[] SelectRunsSA (bool dbconOpened, int sessionID, int personID, string filterType)
+	{
+		if(!dbconOpened)
+			Sqlite.Open();
+
+		dbcmd.CommandText = selectRunsIntervalCreateSelection (sessionID, personID, filterType);
 		
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
@@ -127,7 +178,8 @@ class SqliteRunInterval : SqliteRun
 		int count = new int();
 		count = 0;
 
-		while(reader.Read()) {
+		while(reader.Read())
+		{
 			myArray.Add (reader[0].ToString() + ":" +	//person.name
 					reader[1].ToString() + ":" +	//runInterval.uniqueID
 					reader[2].ToString() + ":" + 	//runInterval.personID
@@ -141,7 +193,8 @@ class SqliteRunInterval : SqliteRun
 					reader[10].ToString() + ":" + 	//description
 					reader[11].ToString() + ":" +  	//limited
 					reader[12].ToString() + ":" +	//simulated
-					Util.IntToBool(Convert.ToInt32(reader[13])) //initialSpeed
+					Util.IntToBool(Convert.ToInt32(reader[13])) + ":" + //initialSpeed
+					reader[14].ToString() 		//datetime
 					);
 			count ++;
 		}
@@ -176,7 +229,7 @@ class SqliteRunInterval : SqliteRun
 		reader = dbcmd.ExecuteReader();
 		reader.Read();
 
-		RunInterval myRun = new RunInterval(DataReaderToStringArray(reader, 13));
+		RunInterval myRun = new RunInterval(DataReaderToStringArray(reader, 14));
 
 		reader.Close();
 		if(!dbconOpened)
