@@ -250,7 +250,7 @@ class SqliteSession : Sqlite
 	//be careful because name is not unique
 	public static Session SelectByName(string name)
 	{
-		dbcmd.CommandText = "SELECT * FROM " + Constants.SessionTable + " WHERE name == \"" + name + "\"";
+		dbcmd.CommandText = "SELECT * FROM " + Constants.SessionTable + " WHERE LOWER(name) = LOWER(\"" + name + "\")";
 
 		List<Session> session_l = selectDo(dbcmd);
 		if(session_l.Count == 0)
@@ -271,9 +271,13 @@ class SqliteSession : Sqlite
 		//return (Session) selectDo(dbcmd)[0];
 		return session_l[0];
 	}
-	public static List<Session> SelectAll()
+	public static List<Session> SelectAll(Orders_by orderBy)
 	{
-		dbcmd.CommandText = "SELECT * FROM " + Constants.SessionTable;
+		string orderByStr = " ORDER BY uniqueID";
+		if(orderBy == Orders_by.ID_DESC)
+			orderByStr += " DESC";
+
+		dbcmd.CommandText = "SELECT * FROM " + Constants.SessionTable + orderByStr;
 		return selectDo(dbcmd);
 	}
 	private static List<Session> selectDo(SqliteCommand mydbcmd)
@@ -317,6 +321,7 @@ class SqliteSession : Sqlite
 	
 	//used by the stats selector of sessions
 	//also by PersonsRecuperateFromOtherSessionWindowBox (src/gui/person.cs)
+	//sessionIdDisable allows to not return current session on selection, for returning all just put -1
 	public static string[] SelectAllSessionsSimple(bool commentsDisable, int sessionIdDisable) 
 	{
 		string selectString = " uniqueID, name, place, date, comments ";
