@@ -44,6 +44,41 @@ public class Util
 		return false;
 	}
 
+	/*
+	 * before 2.0.3 decimal point of forceSensor forces was culture specific. From 2.0.3 is .
+	 * this method helps to see how is stored to be opened in R
+	 */
+	public static bool CSVDecimalColumnIsPoint(string filename, int column) //column starts at 0
+	{
+		List<string> contents = Util.ReadFileAsStringList(filename);
+		bool headersRow = true;
+
+		foreach(string str in contents)
+		{
+			//avoid header row (if any)
+			if(headersRow)
+				headersRow = false;
+			else {
+				string [] strFull = str.Split(new char[] {';'});
+				if(strFull.Length < column)
+					continue;
+
+				//check that is a number when converted to current locale
+				if(! Util.IsNumber(Util.ChangeDecimalSeparator(strFull[column]), true))
+					continue;
+
+				//it could be a int, or a double, if is a double check the decimal sep
+				if(strFull[column].Contains("."))
+					return true;
+				else if(strFull[column].Contains(","))
+					return false;
+				//if it is an int, check on next number
+			}
+		}
+		//if nothing is found, just say is point '.' Is not relevant
+		return(true);
+	}
+
 	//all numbers are saved in database with '.' as decimal separator (method for numbers)
 	public static string ConvertToPoint (double myDouble)
 	{
@@ -561,7 +596,7 @@ public class Util
 
 		if(tcFull.Length > tvFull.Length) {
 			int lastEqualPos = tcString.LastIndexOf('=');
-			return tcString.Substring(0, lastEqualPos -1);
+			return tcString.Substring(0, lastEqualPos);
 		} else {
 			return tcString;
 		}
@@ -846,10 +881,13 @@ public class Util
 		LogB.Information("tryParse 'joan' as double: " + Util.IsNumber("joan",true).ToString()); //catalan (True)
 	}
 
-	public static bool IsNumber(char c, bool canBeDecimal)
+	/*
+	 * unused
+	public static bool IsNumber(char c)
 	{
-		return IsNumber(c.ToString(), canBeDecimal);
+		return IsNumber(c.ToString(), false);
 	}
+	*/
 
 	//gets a string and returns if all the chars are numbers or the decimal point in current localization
 	public static bool IsNumber(string str, bool canBeDecimal) 
@@ -1072,6 +1110,13 @@ public class Util
 		}
 	}
 
+	public static string GetRunEncoderTempProgressDir() {
+		return Path.Combine(Path.GetTempPath(), "chronojump_race_analyzer_progress");
+	}
+	public static string GetRunEncoderTempGraphsDir() {
+		return Path.Combine(Path.GetTempPath(), "chronojump_race_analyzer_graphs");
+	}
+
 	/*
 	 * <--------------- end of force sensor suff
 	 */
@@ -1139,6 +1184,16 @@ public class Util
 	 * --------------------- End of GetPhoto stuff
 	 */
 
+	public static bool IsJpeg(string filename)
+	{
+		return (filename.ToLower().EndsWith("jpeg") || filename.ToLower().EndsWith("jpg"));
+	}
+
+	public static bool IsPng(string filename)
+	{
+		return (filename.ToLower().EndsWith("png"));
+	}
+
 	/*
 	 * --------------------- Start of video stuff
 	 */
@@ -1486,9 +1541,15 @@ public class Util
 		}
 	}
 
-	public static bool OpenFolder(string url)
+	//file or folder
+	public static bool OpenURL (string url)
 	{
-		LogB.Information("OpenFolder: " + url);
+		LogB.Information("OpenFolder without quotes: " + url);
+
+		//add quotes to solve spacing problems
+		url = "\"" + url + "\"";
+		LogB.Information("OpenFolder with quotes: " + url);
+
 		try {
 			//more system specific methods on: https://stackoverflow.com/a/49664847/12366369
 			//also if do not work, check about relative paths here: https://stackoverflow.com/questions/52599105/c-sharp-under-linux-process-start-exception-of-no-such-file-or-directory
@@ -1639,17 +1700,17 @@ public class Util
 		string fileName = "";
 		switch(mySound) {
 			case Constants.SoundTypes.CAN_START:
-				fileName = "123804__kendallbear__kendallklap1.wav";
+				fileName = "start.wav";
 				//author: kendallbear
 				//https://www.freesound.org/people/kendallbear/sounds/123804/
 				break;
 			case Constants.SoundTypes.GOOD:
-				fileName = "135936__bradwesson__collectcoin.wav";
+				fileName = "ok.wav";
 				//author: bradwesson
 				//https://www.freesound.org/people/bradwesson/sounds/135936/
 				break;
 			case Constants.SoundTypes.BAD:
-				fileName = "142608__autistic-lucario__error.wav";
+				fileName = "bad.wav";
 				//author: Autistic Lucario
 				//https://www.freesound.org/people/Autistic%20Lucario/sounds/142608/
 				break;
@@ -1924,6 +1985,43 @@ public class Util
 		return a;
 	}
 
+	public static void TestSortDoublesListstring()
+	{
+		List<string> numbers_l = new List<string>() { "3", "99", "135", "45", "75", "17", "88", "5" }; //ints
+		//List<string> numbers_l = new List<string>() { "3,5", "99,54", "135,1", "45,5", "75,5", "45,9", "88", "45,3" }; //latin
+
+		List<string> numbersSorted_l = SortDoublesListString(numbers_l);
+
+		LogB.Information("Sorted: ");
+		foreach(string s in numbersSorted_l)
+			LogB.Information(s);
+	}
+
+	//sort a list of doubles descending until 0
+	public static List<string> SortDoublesListString (List<string> unsorted_l)
+	{
+		if(unsorted_l.Count < 2)
+			return unsorted_l;
+
+		List<string> sorted_l = new List<string>();
+		for(int i = 0; i < unsorted_l.Count; i ++)
+		{
+			double highest = 0;
+			int highestPos = 0;
+			for(int j = 0; j < unsorted_l.Count; j ++)
+			{
+				double comparingToNum = Convert.ToDouble(unsorted_l[j]);
+				if(comparingToNum > highest)
+				{
+					highest = comparingToNum;
+					highestPos = j;
+				}
+			}
+			sorted_l.Add(unsorted_l[highestPos]); //store highest value on sorted_l
+			unsorted_l[highestPos] = "0"; //mark as 0 on unsortd_l to not choose it again
+		}
+		return sorted_l;
+	}
 
 	/*
 	//delete a row of and arraylist of string[] if the string[0] is the value coming from startsWith
@@ -2428,3 +2526,78 @@ public class UtilCopy
 		}
 	}
 }
+
+/*
+   Manage conversions between 3 booleans (or maybe more) and one int.
+   Booleans have weights 1, 2, 4
+   eg 6 will be false, false, true
+   tested with:
+   for(int i = 0; i <= 7; i++)
+     LogB.Information(new SessionLoadDisplay(i).ToString());
+*/
+public class BooleansInt
+{
+	protected int i;
+
+	//to inherit
+	public BooleansInt()
+	{
+	}
+
+	public BooleansInt(int i)
+	{
+		this.i = i;
+	}
+
+	public BooleansInt(bool b1, bool b2, bool b3)
+	{
+		this.i = 0;
+		if(b1)
+			i ++;
+		if(b2)
+			i += 2;
+		if(b3)
+			i += 4;
+	}
+
+	public bool Bit3
+	{
+		get { return (i >= 4); }
+	}
+
+	public bool Bit2
+	{
+		get {
+			int temp = i;
+			if(temp >= 4)
+				temp -= 4;
+
+			return (temp >= 2);
+		}
+	}
+
+	public bool Bit1
+	{
+		get {
+			int temp = i;
+			if(temp >= 4)
+				temp -= 4;
+			if(temp >= 2)
+				temp -= 2;
+
+			return (temp == 1);
+		}
+	}
+
+	public int GetInt
+	{
+		get { return i; }
+	}
+
+	//just to debug
+	public override string ToString()
+	{
+		return string.Format("i: {0} (bit1: {1}, bit2: {2}, bit3: {3})",
+				i, Bit1, Bit2, Bit3);
+	}
+}
