@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -128,7 +128,7 @@ public class UtilAll
 		string detected = "";
 		string [] usbSerial = Directory.GetFiles("/dev/", "ttyUSB*");
 		if(usbSerial.Length > 0) {
-			detected += Constants.FoundUSBSerialPortsString + " " + usbSerial.Length + "\n" + startStr;
+			detected += Constants.FoundUSBSerialPortsString() + " " + usbSerial.Length + "\n" + startStr;
 			foreach(string myPort in usbSerial)
 				detected += midStr + myPort;
 			detected += endStr;
@@ -191,5 +191,41 @@ public class UtilAll
 		return path;
 	}
 
+	//avoids divide by zero
+	//thought for being between 0, 1
+	//ideal for progressBars
+	public static double DivideSafeFraction (double num, double denom)
+	{
+		if(num == 0 || denom == 0)
+			return 0;
+
+		double result = num / denom;
+
+		if(result > 1)
+			result = 1;
+		else if(result < 0)
+			result = 0;
+
+		return result;
+	}
+
+	public static double DivideSafeFraction (int val1, int val2) {
+		return DivideSafeFraction(Convert.ToDouble(val1), Convert.ToDouble(val2));
+	}
+
+	//Not restricted to values 0-1
+	public static double DivideSafe (double val1, double val2)
+	{
+		if(val1 == 0 || val2 == 0)
+			return 0;
+
+		return val1 / val2;
+	}
+
+	public static int DivideSafeAndGetInt (double val1, double val2)
+	{
+		return Convert.ToInt32(DivideSafe(val1, val2));
+	}
+
 
 }
