@@ -242,6 +242,9 @@ public class UtilEncoder
 	public static string GetSprintPhotocellsScript() {
 		return System.IO.Path.Combine(GetSprintPath(), "sprintPhotocells.R");
 	}
+	public static string GetSprintCSVInputMulti() {
+		return Path.Combine(Path.GetTempPath(), "sprintInputMulti.csv");
+	}
 
 	public static string GetSprintImage() {
 		return System.IO.Path.Combine(Path.GetTempPath(), "sprintGraph.png");
@@ -257,6 +260,9 @@ public class UtilEncoder
 	public static string GetmifScript() {
 		return System.IO.Path.Combine(GetSprintPath(), "maximumIsometricForce.R");
 	}
+	public static string GetmifCSVInputMulti() {
+		return Path.Combine(Path.GetTempPath(), "maximumIsometricForceInputMulti.csv");
+	}
 	public static string GetmifCSVFileName() {
 		return Path.Combine(Path.GetTempPath(), "cj_mif_Data.csv");
 	}
@@ -340,7 +346,8 @@ public class UtilEncoder
 
 	public static EncoderGraphROptions PrepareEncoderGraphOptions(
 			string title, EncoderStruct es, bool neuromuscularProfileDo, bool translate, bool debug, bool crossValidate,
-			bool cutByTriggers, string triggerStr, bool separateSessionInDays, EncoderGraphROptions.AnalysisModes analysisMode)
+			bool cutByTriggers, string triggerStr, bool separateSessionInDays,
+			EncoderGraphROptions.AnalysisModes analysisMode, Preferences.EncoderInertialGraphsXTypes inertialGraphX)
 	{
 		string operatingSystem = OperatingSystemForRGraphs();
 			
@@ -395,7 +402,8 @@ public class UtilEncoder
 				title, operatingSystem,
 				Util.StringArrayToString(Constants.EncoderEnglishWords,";"),
 				Util.StringArrayToString(encoderTranslatedWordsOK,";"),
-				debug, crossValidate, cutByTriggers, triggerStr, separateSessionInDays, analysisMode
+				debug, crossValidate, cutByTriggers, triggerStr, separateSessionInDays,
+				analysisMode, inertialGraphX
 				);
 	}
 
