@@ -73,6 +73,21 @@ public class UtilGtk
 		return myCombo;
 	}
 
+	public static bool ComboSelectedIsLast(ComboBox myCombo)
+	{
+		TreeIter iter;
+		myCombo.Model.GetIterFirst(out iter);
+		int current = myCombo.Active;
+		int count = 0;
+		do {
+			if(count > current)
+				return false;
+			count ++;
+		} while (myCombo.Model.IterNext (ref iter));
+
+		return true;
+	}
+
 
 	public static string ComboGetActive(ComboBox myCombo) {
 		TreeIter iter;
@@ -89,6 +104,18 @@ public class UtilGtk
 		return ComboMakeActive(myCombo, ComboGetActive(myCombo));
 	}
 
+	public static int ComboCount(ComboBox myCombo) {
+		int count = 0;
+		TreeIter iter;
+		myCombo.Model.GetIterFirst(out iter);
+		do {
+			count ++;
+		} while (myCombo.Model.IterNext (ref iter));
+
+		return count;
+	}
+
+
 
 	//this is better than the below method, because this search in current combo values
 	//if we use a predefined set of values (like below method), we can have problems 
@@ -414,15 +441,15 @@ public class UtilGtk
 		return tv;
 	}
 
-	//startOrEnd is true at start, false at end
-	public static void TreeviewAddRow(Gtk.TreeView tv, TreeStore store, string [] row, bool startOrEnd) {
+	//position 0 is start, -1 is end
+	public static void TreeviewAddRow(Gtk.TreeView tv, TreeStore store, string [] row, int position) {
 		TreeIter iter = new TreeIter();
 		store.GetIterFirst(out iter);
 		
-		if(startOrEnd)
-			iter = store.InsertWithValues(0,row);
-		else
+		if(position == -1)
 			iter = store.AppendValues(row);
+		else
+			iter = store.InsertWithValues(position, row);
 
 		//scroll treeview if needed
 		TreePath path = store.GetPath (iter);
@@ -670,6 +697,10 @@ public class UtilGtk
 	{
 		contrastLabelsContainer (bgDark, (Gtk.Container) notebook);
 	}
+	public static void ContrastLabelsFrame (bool bgDark, Gtk.Frame frame)
+	{
+		contrastLabelsContainer (bgDark, (Gtk.Container) frame);
+	}
 
 	private static void contrastLabelsContainer (bool bgDark, Gtk.Container container)
 	{
@@ -712,7 +743,111 @@ public class UtilGtk
 			//l.ModifyFg(StateType.Active, BLACK);
 		}
 	}
-	
+
+	public static string IdentifyPixelColor(uint col)
+	{
+		if(col == 16777215)
+			return "WHITE";
+		else if(col == 11722734)
+			return "LIGHT_BLUE_PLOTS"; //force sensor feedback rectangle and path
+		else if(col == 6710886)
+			return "GRAY"; //lines on force sensor capture
+		else
+			return "other";
+	}
+	public static bool IdentifyPixelColorIsInPath(uint col)
+	{
+		/*
+		rgb to decimal and viceversa:
+		https://convertingcolors.com/rgb-color-238_0_0.html?search=rgb(238,0,0)
+		https://convertingcolors.com/decimal-color-15597568.html
+		*/
+		return (col == 11722734); //LIGHT_BLUE_PLOTS
+		//return (col == 15597568); //RED_LIGHT
+	}
+
+	public static void GetPixelsInOutOfPath (Gdk.Point [] points, int start, Gdk.Pixmap pixmap, ref int inPath, ref int outPath, bool methodSafeMemory)
+	{
+		//on resize screen, start is < 0
+		if(start < 0)
+			start = 0;
+
+		if(methodSafeMemory)
+			getPixelsInOutOfPathSafeMemory (points, start, pixmap, ref inPath, ref outPath);
+		else
+			getPixelsInOutOfPathFaster (points, start, pixmap, ref inPath, ref outPath);
+	}
+
+	private static void getPixelsInOutOfPathSafeMemory (Gdk.Point [] points, int start, Gdk.Pixmap pixmap, ref int inPath, ref int outPath)
+	{
+		// 1) create the image surrounding the points
+		int minX = 100000;
+		int minY = 100000;
+		int maxX = -100000;
+		int maxY = -100000;
+		for(int i = start; i < points.Length; i ++)
+		{
+			if(points[i].X < minX)
+				minX = points[i].X;
+			if(points[i].Y < minY)
+				minY = points[i].Y;
+			if(points[i].X > maxX)
+				maxX = points[i].X;
+			if(points[i].Y > maxY)
+				maxY = points[i].Y;
+		}
+
+		//fixes for a path with negative values
+		if(minY < 0)
+			minY = 0;
+		if(maxY < 0)
+			maxY = 0;
+		if(minY > maxY)
+			maxY = minY;
+
+		//if points are on an horiz line, eg minY == maxY == 346, height is 1 point
+		int width = (maxX - minX) + 1;
+		int height = (maxY - minY) + 1;
+		//LogB.Information(string.Format("ttt points.Length: {0}, start: {1}, width: {2}, height: {3}",
+		//			points.Length, start, width, height));
+
+		if(width <= 0 || height <= 0) //just a caution
+			return;
+
+		Gdk.Image image = pixmap.GetImage(minX, minY, width, height);
+
+		// 2) calculate inPath, outPath
+		for(int i = start; i < points.Length; i ++)
+		{
+			uint px = image.GetPixel(points[i].X - minX, points[i].Y - minY);
+			if(IdentifyPixelColorIsInPath(px))
+				inPath ++;
+			else
+				outPath ++;
+		}
+		image.Dispose(); //force to erase it because GC does not do it (but is not really erasing it)
+	}
+
+	//for continuous use (long) do not use, use above method, because this method causes memory grow
+	private static void getPixelsInOutOfPathFaster (Gdk.Point [] points, int start, Gdk.Pixmap pixmap, ref int inPath, ref int outPath)
+	{
+		int width = 0;
+		int height = 0;
+		pixmap.GetSize(out width, out height);
+		Gdk.Image image = pixmap.GetImage(0, 0, width, height); //this accumulates memory, is not correctly disposed
+
+		for(int i = start; i < points.Length; i ++)
+		{
+			uint px = image.GetPixel(points[i].X, points[i].Y);
+			if(UtilGtk.IdentifyPixelColorIsInPath(px))
+				inPath ++;
+			else
+				outPath ++;
+		}
+		image.Dispose(); //force to erase it because GC does not do it (but is not really erasing it)
+	}
+
+
 
 	/*
 	 *
@@ -766,7 +901,11 @@ public class UtilGtk
 		return s;
 	}
 
-	
+	public static void TextViewClear (Gtk.TextView tv)
+	{
+		tv.Buffer.Text = "";
+	}
+
 	public static TextBuffer TextViewPrint(string message) {
 		TextBuffer tb = new TextBuffer (new TextTagTable());
 		tb.Text = message;
